import{j as e,T as a,A as s}from"./index-s57B3ha7.js";import{B as l}from"./index-CTyZRJhn.js";const t=()=>e.jsxs(e.Fragment,{children:[e.jsx(a,{items:[{key:"function_analysis",label:"功能分析",children:e.jsx(e.Fragment,{children:e.jsx(s,{inputAnalysisMethod:[{name:"reads",label:"去宿主后的reads",inputKey:["samtools_remove_hosts"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]},{name:"abundance",label:"metaphlan丰度文件",inputKey:["metaphlan_sam_abundance"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],analysisPipline:"pipeline_humann",analysisMethod:[{name:"humann_profile",label:"humann_profile",inputKey:["humann_profile"],mode:"multiple"}],analysisType:"sample",children:e.jsx(l,{analysisKey:"bowtie2_align_host"})})})}]}),e.jsx("p",{})]});export{t as default};
