import{j as e,T as c,A as g,r as l,B as i,F as r,S as p}from"./index-s57B3ha7.js";import{B as d}from"./index-CTyZRJhn.js";const f=()=>e.jsxs(e.Fragment,{children:[e.jsx(c,{items:[{key:"gene_count",label:"gene_count",children:e.jsx(e.Fragment,{children:e.jsx(g,{analysisPipline:"gene_count",inputAnalysisMethod:[{name:"rna_seq",label:"RNA测序文件",inputKey:["V1_single_genome_NGS_RNA"],mode:"multiple"},{name:"genome_assembly",label:"基因组参考文件",inputKey:["ngs-individual-assembly","tgs_individual_assembly"],mode:"single"},{name:"prokka",label:"基因组注释文件",inputKey:["prokka"],mode:"single"}],analysisMethod:[{name:"bowtie2_RNA_mapping",label:"bowtie2_RNA_mapping",inputKey:["bowtie2_RNA_mapping"],mode:"multiple"},{name:"feature_counts_RNA_mapping",label:"feature_counts_RNA_mapping",inputKey:["feature_counts_RNA_mapping"],mode:"multiple"}],analysisType:"sample",children:e.jsx(x,{})})})}]}),e.jsx("p",{})]}),x=({resultTableList:a,plot:s,activeTabKey:m})=>{const[o,_]=l.useState([]);l.useEffect(()=>{if(console.log(a.feature_counts_RNA_mapping),a.feature_counts_RNA_mapping){const t=a.feature_counts_RNA_mapping.map(n=>({label:`${n.sample_key} `,value:`${n.id}`}));_(t)}},[a]);const u=t=>a[t].map(n=>n.content.log);return e.jsxs(e.Fragment,{children:[m=="bowtie2_RNA_mapping"&&e.jsx(e.Fragment,{children:e.jsx(d,{resultTableList:a,plot:s,analysisKey:"bowtie2_RNA_mapping"})}),m=="feature_counts_RNA_mapping"&&e.jsxs(e.Fragment,{children:[e.jsx(i,{type:"primary",onClick:()=>{s({saveAnalysisMethod:"feature_counts_RNA_mapping_stat",moduleName:"feature_counts_stat",params:{log_path_list:u("feature_counts_RNA_mapping")},tableDesc:`
                                `})},children:"基因计数统计"}),e.jsx(i,{type:"primary",onClick:()=>{s({saveAnalysisMethod:"feature_counts_RNA_deg",moduleName:"feature_counts_RNA_deg",params:{},formDom:e.jsxs(e.Fragment,{children:[e.jsx(r.Item,{label:"选择处理组",name:"treatment",children:e.jsx(p,{mode:"multiple",style:{maxWidth:"20rem"},allowClear:!0,options:o})}),e.jsx(r.Item,{label:"选择对照组",name:"control",children:e.jsx(p,{mode:"multiple",style:{maxWidth:"20rem"},allowClear:!0,options:o})})]}),tableDesc:`

                                `})},children:"差异表达基因分析"})]})]})};export{f as default};
