import{j as e,T as l,A as s}from"./index-s57B3ha7.js";const n=()=>e.jsxs(e.Fragment,{children:[e.jsx(l,{items:[{key:"ngs-individual-assembly",label:"二代测序单独组装",children:e.jsx(e.Fragment,{children:e.jsx(s,{inputAnalysisMethod:[{name:"1",label:"V1_single_genome_NGS_DNA",inputKey:["V1_single_genome_NGS_DNA"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],analysisMethod:[{name:"1",label:"ngs-individual-assembly",inputKey:["ngs-individual-assembly"],mode:"multiple"}],analysisType:"sample"})})},{key:"tgs_individual_assembly",label:"三代测序单独组装",children:e.jsx(e.Fragment,{children:e.jsx(s,{inputAnalysisMethod:[{name:"1",label:"V1_single_genome_PACBIO_HIFI_DNA",inputKey:["V1_single_genome_PACBIO_HIFI_DNA"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],analysisMethod:[{name:"1",label:"tgs_individual_assembly",inputKey:["tgs_individual_assembly"],mode:"multiple"}],analysisType:"sample"})})},{key:"ngs-co-assembly",label:"二代测序混合组装",children:e.jsx(e.Fragment,{})},{key:"ngs-tgs-co-assembly",label:"二三代测序混合组装",children:e.jsx(e.Fragment,{})}]}),e.jsx("p",{})]});export{n as default};
