import{aA as t,z as i,j as e,T as p,A as m,B as n,f as o,a as c}from"./index-s57B3ha7.js";const x=()=>{const[a,s]=t.useMessage(),{project:l}=i(),r=async()=>{await c.post(`/fast-api/add-sample-analysis?project=${l}`),t.success("导入成功!")};return e.jsxs(e.Fragment,{children:[s,e.jsx(p,{items:[{key:"ngs-sample-qc",label:"NGS样本质控",children:e.jsx(e.Fragment,{children:e.jsx(m,{cardExtra:e.jsx(n,{onClick:r,children:"从样本导入"}),analysisMethod:[{name:"fastp_clean_reads",label:"fastp_clean_reads",inputKey:["fastp_clean_reads"],mode:"multiple"}],analysisPipline:"ngs-sample-qc",inputAnalysisMethod:[{name:"reads",label:"reads",inputKey:["V1_meta_genome_NGS_DNA","V1_single_genome_NGS_DNA"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],analysisType:"sample",children:e.jsx(d,{})})})}]}),e.jsx("p",{})]})},d=({plot:a,record:s})=>e.jsx(e.Fragment,{children:s&&e.jsx(e.Fragment,{children:e.jsxs(n,{onClick:()=>{a({url:o(s.content.html),tableDesc:""})},children:["查看报告(",s.sample_name,")"]})})});export{x as default};
