import{r as t,aX as u}from"./index-s57B3ha7.js";function s(){}const c=t.createContext({add:s,remove:s});function l(n){const r=t.useContext(c),o=t.useRef(null);return u(e=>{if(e){const a=n?e.querySelector(n):e;r.add(a),o.current=a}else r.remove(o.current)})}export{l as u};
