import{j as e,T as s,A as a}from"./index-s57B3ha7.js";import{B as t}from"./index-CTyZRJhn.js";const i=()=>e.jsxs(e.Fragment,{children:[e.jsx(s,{items:[{key:"bowtie2_align_host",label:"比对到比对到宿主基因组",children:e.jsx(e.Fragment,{children:e.jsx(a,{inputAnalysisMethod:[{name:"clean_reads",label:"clean reads",inputKey:["fastp_clean_reads"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],upstreamFormJson:[{name:"genome_index",dataKey:"host_genome_index",label:"宿主基因组",rules:[{required:!0,message:"该字段不能为空!"}],type:"BaseSelect"}],analysisPipline:"bowtie2_remove_host",analysisMethod:[{name:"bowtie2_align_host",label:"bowtie2_align_host",inputKey:["bowtie2_align_host"],mode:"multiple"},{name:"samtools_remove_hosts",label:"samtools_remove_hosts",inputKey:["samtools_remove_hosts"],mode:"multiple"}],analysisType:"sample",children:e.jsx(t,{analysisKey:"bowtie2_align_host"})})})}]}),e.jsx("p",{})]});export{i as default};
