import{r as i,j as t,M as s}from"./index-s57B3ha7.js";const o=`
# Bioinformatics Reactive Analysis and Visualization Engine(BRAVE)

![](/brave-api/img/logo.png)
`,e=()=>{const[a,n]=i.useState(o);return t.jsx("div",{style:{maxWidth:"1000px",margin:"1rem auto"},children:t.jsx(s,{data:a})})};export{e as default};
