import{j as e,T as n,A as s,B as r,f as m}from"./index-s57B3ha7.js";const i=()=>e.jsxs(e.Fragment,{children:[e.jsx(n,{items:[{key:"ngs_individual_assembly",label:"二代测序宏基因组单独组装",children:e.jsx(e.Fragment,{children:e.jsx(s,{inputAnalysisMethod:[{name:"remove_hosts_reads",label:"remove_hosts_reads",inputKey:["samtools_remove_hosts"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]},{name:"clean_reads",label:"clean_reads",inputKey:["fastp_clean_reads"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group"}],analysisPipline:"pipeline_ngs_individual_metawrap_assembly",analysisMethod:[{name:"metawrap_assembly",label:"metawrap_assembly",inputKey:["metawrap_assembly"],mode:"multiple"}],analysisType:"sample",children:e.jsx(l,{})})})},{key:"ngs_co_assembly",label:"二代测序宏基因组共组装",children:e.jsx(e.Fragment,{children:e.jsx(s,{inputAnalysisMethod:[{name:"remove_hosts_reads",label:"remove_hosts_reads",inputKey:["samtools_remove_hosts"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]},{name:"clean_reads",label:"clean_reads",inputKey:["fastp_clean_reads"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group"}],analysisPipline:"pipeline_ngs_individual_metawrap_assembly",analysisMethod:[{name:"metawrap_assembly",label:"metawrap_assembly",inputKey:["metawrap_assembly"],mode:"multiple"}],analysisType:"sample",children:e.jsx(l,{})})})}]}),e.jsx("p",{})]}),l=({plot:t,record:a})=>e.jsx(e.Fragment,{children:a&&e.jsx(e.Fragment,{children:e.jsx(r,{onClick:()=>{t({url:m(a.content.html),tableDesc:""})},children:"查看报告"})})});export{i as default};
