import{j as e,B as t,T as i,A as n}from"./index-s57B3ha7.js";import{a as r}from"./index-CTyZRJhn.js";const m=({record:a,resultTableList:l,plot:s})=>e.jsx(e.Fragment,{children:e.jsx(t,{type:"primary",onClick:()=>{s({saveAnalysisMethod:"metaphlan_sam_abundance_matrix",moduleName:"abundance_matrix",sampleSelectComp:!0,tableDesc:" "})},children:"丰度矩阵"})}),o=()=>e.jsxs(e.Fragment,{children:[e.jsx(i,{items:[{key:"bowtie2_align_metaphlan",label:"比对到metaphlan marker库",children:e.jsx(e.Fragment,{children:e.jsx(n,{inputAnalysisMethod:[{name:"remove_hosts_reads",label:"remove_hosts_reads",inputKey:["samtools_remove_hosts"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]},{name:"clean_reads",label:"clean_reads",inputKey:["fastp_clean_reads"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group"}],analysisPipline:"pipeline_align_metaphlan_marker",analysisMethod:[{name:"bowtie2_align_metaphlan",label:"marker比对bam文件",inputKey:["bowtie2_align_metaphlan"],mode:"multiple"}],downstreamAnalysis:[{name:"查看比对日志",analysisType:"one",sampleGroupJSON:!1,paramsFun:a=>({text:a.content.log}),sampleGroupApI:!1,saveAnalysisMethod:"text",moduleName:"text",sampleSelectComp:!1,tableDesc:" "}],analysisType:"sample",children:e.jsx(r,{})})})},{key:"abundance_estimation ",label:"丰度估计",children:e.jsx(e.Fragment,{children:e.jsx(n,{upstreamFormJson:[{name:"stat_q",data:[{label:"0.2",value:.2},{label:"0",value:0}],initialValue:.2,label:" Quantile value for the robust average(--stat_q)",rules:[{required:!0,message:"该字段不能为空!"}],type:"BaseSelect"}],analysisMethod:[{name:"metaphlan_sam_abundance",label:"metaphlan abundance",inputKey:["metaphlan_sam_abundance"],mode:"multiple"}],analysisPipline:"pipeline_metaphlan_abundance",inputAnalysisMethod:[{name:"bowtie2_align_metaphlan",label:"marker比对bam文件",inputKey:["bowtie2_align_metaphlan"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],analysisType:"sample",children:e.jsx(m,{})})})},{key:"consensus_marker",label:"consensus_marker",children:e.jsx(e.Fragment,{children:e.jsx(n,{inputAnalysisMethod:[{name:"bowtie2_align_metaphlan",label:"marker比对bam文件",inputKey:["bowtie2_align_metaphlan"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]}],analysisPipline:"pipeline_consensus_marker",analysisMethod:[{name:"consensus_marker",label:"consensus_marker",inputKey:["consensus_marker"],mode:"multiple"}],analysisType:"sample"})})},{key:"strain_level_profiling",label:"strain_level_profiling",children:e.jsx(e.Fragment,{children:e.jsx(n,{appendSampleColumns:[{title:"参考基因组",dataIndex:"reference",key:"reference",ellipsis:!0,render:(a,l)=>{var s;return e.jsx(e.Fragment,{children:(s=l==null?void 0:l.content)==null?void 0:s.reference})}}],upstreamFormJson:[{name:"clade",labelInValue:!0,label:"clade",mode:"multiple",type:"MetaphlanCladeSelect"}],inputAnalysisMethod:[{name:"consensus_marker",label:"consensus_marker",inputKey:["consensus_marker"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group",rules:[{required:!0,message:"该字段不能为空!"}]},{name:"assembly_genome",label:"assembly_genome",inputKey:["tgs_individual_assembly"],mode:"single",labelInValue:!0,type:"BaseSelect"},{name:"samples_abundance",label:"选择鉴定出SGB的样本",inputKey:["metaphlan_sam_abundance"],mode:"multiple",type:"GroupSelectSampleButton",groupField:"sample_group"}],analysisPipline:"pipeline_strain_level_profiling",analysisMethod:[{name:"strain_level_profiling",label:"strain_level_profiling",inputKey:["strain_level_profiling"]}],analysisType:"sample",downstreamAnalysis:[{name:"菌株水平系统发育树",analysisType:"one",sampleGroupJSON:!1,paramsFun:a=>({best_tree:a.content.best_tree,tree_pairwisedists:a.content.tree_pairwisedists}),sampleGroupApI:!1,saveAnalysisMethod:"strain_level_profiling_tree",moduleName:"strain_level_profiling_tree",sampleSelectComp:!1,tableDesc:" "}]})})}]}),e.jsx("p",{})]});export{o as default};
