const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["./index-DvoFO-WG.js","./index-D4sVsYOu.js","./context-BWPM1aaO.js","./index-DZv1haOu.js","./index-DXu7euAS.js","./index-DVhD5lce.js","./index-D7Hz1C2T.css","./index-B-anftD_.js","./index-CTyZRJhn.js","./index-DkK2gsQm.js","./index-DdGi63SI.js","./index-C_YGCAyS.js","./index-CD9deHrI.js","./index-XJsuonX4.js"])))=>i.map(i=>d[i]);
function _mergeNamespaces(a,c){for(var u=0;u<c.length;u++){const d=c[u];if(typeof d!="string"&&!Array.isArray(d)){for(const f in d)if(f!=="default"&&!(f in a)){const m=Object.getOwnPropertyDescriptor(d,f);m&&Object.defineProperty(a,f,m.get?m:{enumerable:!0,get:()=>d[f]})}}}return Object.freeze(Object.defineProperty(a,Symbol.toStringTag,{value:"Module"}))}(function(){const c=document.createElement("link").relList;if(c&&c.supports&&c.supports("modulepreload"))return;for(const f of document.querySelectorAll('link[rel="modulepreload"]'))d(f);new MutationObserver(f=>{for(const m of f)if(m.type==="childList")for(const g of m.addedNodes)g.tagName==="LINK"&&g.rel==="modulepreload"&&d(g)}).observe(document,{childList:!0,subtree:!0});function u(f){const m={};return f.integrity&&(m.integrity=f.integrity),f.referrerPolicy&&(m.referrerPolicy=f.referrerPolicy),f.crossOrigin==="use-credentials"?m.credentials="include":f.crossOrigin==="anonymous"?m.credentials="omit":m.credentials="same-origin",m}function d(f){if(f.ep)return;f.ep=!0;const m=u(f);fetch(f.href,m)}})();var commonjsGlobal=typeof globalThis<"u"?globalThis:typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{};function getDefaultExportFromCjs(a){return a&&a.__esModule&&Object.prototype.hasOwnProperty.call(a,"default")?a.default:a}var jsxRuntime={exports:{}},reactJsxRuntime_production={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredReactJsxRuntime_production;function requireReactJsxRuntime_production(){if(hasRequiredReactJsxRuntime_production)return reactJsxRuntime_production;hasRequiredReactJsxRuntime_production=1;var a=Symbol.for("react.transitional.element"),c=Symbol.for("react.fragment");function u(d,f,m){var g=null;if(m!==void 0&&(g=""+m),f.key!==void 0&&(g=""+f.key),"key"in f){m={};for(var y in f)y!=="key"&&(m[y]=f[y])}else m=f;return f=m.ref,{$$typeof:a,type:d,key:g,ref:f!==void 0?f:null,props:m}}return reactJsxRuntime_production.Fragment=c,reactJsxRuntime_production.jsx=u,reactJsxRuntime_production.jsxs=u,reactJsxRuntime_production}var hasRequiredJsxRuntime;function requireJsxRuntime(){return hasRequiredJsxRuntime||(hasRequiredJsxRuntime=1,jsxRuntime.exports=requireReactJsxRuntime_production()),jsxRuntime.exports}var jsxRuntimeExports=requireJsxRuntime(),client={exports:{}},reactDomClient_production={},scheduler={exports:{}},scheduler_production={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredScheduler_production;function requireScheduler_production(){return hasRequiredScheduler_production||(hasRequiredScheduler_production=1,function(a){function c(W,G){var te=W.length;W.push(G);e:for(;0<te;){var ae=te-1>>>1,V=W[ae];if(0<f(V,G))W[ae]=G,W[te]=V,te=ae;else break e}}function u(W){return W.length===0?null:W[0]}function d(W){if(W.length===0)return null;var G=W[0],te=W.pop();if(te!==G){W[0]=te;e:for(var ae=0,V=W.length,ne=V>>>1;ae<ne;){var le=2*(ae+1)-1,ee=W[le],ie=le+1,ce=W[ie];if(0>f(ee,te))ie<V&&0>f(ce,ee)?(W[ae]=ce,W[ie]=te,ae=ie):(W[ae]=ee,W[le]=te,ae=le);else if(ie<V&&0>f(ce,te))W[ae]=ce,W[ie]=te,ae=ie;else break e}}return G}function f(W,G){var te=W.sortIndex-G.sortIndex;return te!==0?te:W.id-G.id}if(a.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var m=performance;a.unstable_now=function(){return m.now()}}else{var g=Date,y=g.now();a.unstable_now=function(){return g.now()-y}}var b=[],E=[],C=1,w=null,R=3,_=!1,M=!1,I=!1,N=!1,A=typeof setTimeout=="function"?setTimeout:null,P=typeof clearTimeout=="function"?clearTimeout:null,z=typeof setImmediate<"u"?setImmediate:null;function B(W){for(var G=u(E);G!==null;){if(G.callback===null)d(E);else if(G.startTime<=W)d(E),G.sortIndex=G.expirationTime,c(b,G);else break;G=u(E)}}function j(W){if(I=!1,B(W),!M)if(u(b)!==null)M=!0,L||(L=!0,Q());else{var G=u(E);G!==null&&J(j,G.startTime-W)}}var L=!1,U=-1,q=5,F=-1;function K(){return N?!0:!(a.unstable_now()-F<q)}function X(){if(N=!1,L){var W=a.unstable_now();F=W;var G=!0;try{e:{M=!1,I&&(I=!1,P(U),U=-1),_=!0;var te=R;try{t:{for(B(W),w=u(b);w!==null&&!(w.expirationTime>W&&K());){var ae=w.callback;if(typeof ae=="function"){w.callback=null,R=w.priorityLevel;var V=ae(w.expirationTime<=W);if(W=a.unstable_now(),typeof V=="function"){w.callback=V,B(W),G=!0;break t}w===u(b)&&d(b),B(W)}else d(b);w=u(b)}if(w!==null)G=!0;else{var ne=u(E);ne!==null&&J(j,ne.startTime-W),G=!1}}break e}finally{w=null,R=te,_=!1}G=void 0}}finally{G?Q():L=!1}}}var Q;if(typeof z=="function")Q=function(){z(X)};else if(typeof MessageChannel<"u"){var Y=new MessageChannel,Z=Y.port2;Y.port1.onmessage=X,Q=function(){Z.postMessage(null)}}else Q=function(){A(X,0)};function J(W,G){U=A(function(){W(a.unstable_now())},G)}a.unstable_IdlePriority=5,a.unstable_ImmediatePriority=1,a.unstable_LowPriority=4,a.unstable_NormalPriority=3,a.unstable_Profiling=null,a.unstable_UserBlockingPriority=2,a.unstable_cancelCallback=function(W){W.callback=null},a.unstable_forceFrameRate=function(W){0>W||125<W?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):q=0<W?Math.floor(1e3/W):5},a.unstable_getCurrentPriorityLevel=function(){return R},a.unstable_next=function(W){switch(R){case 1:case 2:case 3:var G=3;break;default:G=R}var te=R;R=G;try{return W()}finally{R=te}},a.unstable_requestPaint=function(){N=!0},a.unstable_runWithPriority=function(W,G){switch(W){case 1:case 2:case 3:case 4:case 5:break;default:W=3}var te=R;R=W;try{return G()}finally{R=te}},a.unstable_scheduleCallback=function(W,G,te){var ae=a.unstable_now();switch(typeof te=="object"&&te!==null?(te=te.delay,te=typeof te=="number"&&0<te?ae+te:ae):te=ae,W){case 1:var V=-1;break;case 2:V=250;break;case 5:V=1073741823;break;case 4:V=1e4;break;default:V=5e3}return V=te+V,W={id:C++,callback:G,priorityLevel:W,startTime:te,expirationTime:V,sortIndex:-1},te>ae?(W.sortIndex=te,c(E,W),u(b)===null&&W===u(E)&&(I?(P(U),U=-1):I=!0,J(j,te-ae))):(W.sortIndex=V,c(b,W),M||_||(M=!0,L||(L=!0,Q()))),W},a.unstable_shouldYield=K,a.unstable_wrapCallback=function(W){var G=R;return function(){var te=R;R=G;try{return W.apply(this,arguments)}finally{R=te}}}}(scheduler_production)),scheduler_production}var hasRequiredScheduler;function requireScheduler(){return hasRequiredScheduler||(hasRequiredScheduler=1,scheduler.exports=requireScheduler_production()),scheduler.exports}var react={exports:{}},react_production={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredReact_production;function requireReact_production(){if(hasRequiredReact_production)return react_production;hasRequiredReact_production=1;var a=Symbol.for("react.transitional.element"),c=Symbol.for("react.portal"),u=Symbol.for("react.fragment"),d=Symbol.for("react.strict_mode"),f=Symbol.for("react.profiler"),m=Symbol.for("react.consumer"),g=Symbol.for("react.context"),y=Symbol.for("react.forward_ref"),b=Symbol.for("react.suspense"),E=Symbol.for("react.memo"),C=Symbol.for("react.lazy"),w=Symbol.iterator;function R(V){return V===null||typeof V!="object"?null:(V=w&&V[w]||V["@@iterator"],typeof V=="function"?V:null)}var _={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},M=Object.assign,I={};function N(V,ne,le){this.props=V,this.context=ne,this.refs=I,this.updater=le||_}N.prototype.isReactComponent={},N.prototype.setState=function(V,ne){if(typeof V!="object"&&typeof V!="function"&&V!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,V,ne,"setState")},N.prototype.forceUpdate=function(V){this.updater.enqueueForceUpdate(this,V,"forceUpdate")};function A(){}A.prototype=N.prototype;function P(V,ne,le){this.props=V,this.context=ne,this.refs=I,this.updater=le||_}var z=P.prototype=new A;z.constructor=P,M(z,N.prototype),z.isPureReactComponent=!0;var B=Array.isArray,j={H:null,A:null,T:null,S:null,V:null},L=Object.prototype.hasOwnProperty;function U(V,ne,le,ee,ie,ce){return le=ce.ref,{$$typeof:a,type:V,key:ne,ref:le!==void 0?le:null,props:ce}}function q(V,ne){return U(V.type,ne,void 0,void 0,void 0,V.props)}function F(V){return typeof V=="object"&&V!==null&&V.$$typeof===a}function K(V){var ne={"=":"=0",":":"=2"};return"$"+V.replace(/[=:]/g,function(le){return ne[le]})}var X=/\/+/g;function Q(V,ne){return typeof V=="object"&&V!==null&&V.key!=null?K(""+V.key):ne.toString(36)}function Y(){}function Z(V){switch(V.status){case"fulfilled":return V.value;case"rejected":throw V.reason;default:switch(typeof V.status=="string"?V.then(Y,Y):(V.status="pending",V.then(function(ne){V.status==="pending"&&(V.status="fulfilled",V.value=ne)},function(ne){V.status==="pending"&&(V.status="rejected",V.reason=ne)})),V.status){case"fulfilled":return V.value;case"rejected":throw V.reason}}throw V}function J(V,ne,le,ee,ie){var ce=typeof V;(ce==="undefined"||ce==="boolean")&&(V=null);var ue=!1;if(V===null)ue=!0;else switch(ce){case"bigint":case"string":case"number":ue=!0;break;case"object":switch(V.$$typeof){case a:case c:ue=!0;break;case C:return ue=V._init,J(ue(V._payload),ne,le,ee,ie)}}if(ue)return ie=ie(V),ue=ee===""?"."+Q(V,0):ee,B(ie)?(le="",ue!=null&&(le=ue.replace(X,"$&/")+"/"),J(ie,ne,le,"",function(ge){return ge})):ie!=null&&(F(ie)&&(ie=q(ie,le+(ie.key==null||V&&V.key===ie.key?"":(""+ie.key).replace(X,"$&/")+"/")+ue)),ne.push(ie)),1;ue=0;var me=ee===""?".":ee+":";if(B(V))for(var de=0;de<V.length;de++)ee=V[de],ce=me+Q(ee,de),ue+=J(ee,ne,le,ce,ie);else if(de=R(V),typeof de=="function")for(V=de.call(V),de=0;!(ee=V.next()).done;)ee=ee.value,ce=me+Q(ee,de++),ue+=J(ee,ne,le,ce,ie);else if(ce==="object"){if(typeof V.then=="function")return J(Z(V),ne,le,ee,ie);throw ne=String(V),Error("Objects are not valid as a React child (found: "+(ne==="[object Object]"?"object with keys {"+Object.keys(V).join(", ")+"}":ne)+"). If you meant to render a collection of children, use an array instead.")}return ue}function W(V,ne,le){if(V==null)return V;var ee=[],ie=0;return J(V,ee,"","",function(ce){return ne.call(le,ce,ie++)}),ee}function G(V){if(V._status===-1){var ne=V._result;ne=ne(),ne.then(function(le){(V._status===0||V._status===-1)&&(V._status=1,V._result=le)},function(le){(V._status===0||V._status===-1)&&(V._status=2,V._result=le)}),V._status===-1&&(V._status=0,V._result=ne)}if(V._status===1)return V._result.default;throw V._result}var te=typeof reportError=="function"?reportError:function(V){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var ne=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof V=="object"&&V!==null&&typeof V.message=="string"?String(V.message):String(V),error:V});if(!window.dispatchEvent(ne))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",V);return}console.error(V)};function ae(){}return react_production.Children={map:W,forEach:function(V,ne,le){W(V,function(){ne.apply(this,arguments)},le)},count:function(V){var ne=0;return W(V,function(){ne++}),ne},toArray:function(V){return W(V,function(ne){return ne})||[]},only:function(V){if(!F(V))throw Error("React.Children.only expected to receive a single React element child.");return V}},react_production.Component=N,react_production.Fragment=u,react_production.Profiler=f,react_production.PureComponent=P,react_production.StrictMode=d,react_production.Suspense=b,react_production.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=j,react_production.__COMPILER_RUNTIME={__proto__:null,c:function(V){return j.H.useMemoCache(V)}},react_production.cache=function(V){return function(){return V.apply(null,arguments)}},react_production.cloneElement=function(V,ne,le){if(V==null)throw Error("The argument must be a React element, but you passed "+V+".");var ee=M({},V.props),ie=V.key,ce=void 0;if(ne!=null)for(ue in ne.ref!==void 0&&(ce=void 0),ne.key!==void 0&&(ie=""+ne.key),ne)!L.call(ne,ue)||ue==="key"||ue==="__self"||ue==="__source"||ue==="ref"&&ne.ref===void 0||(ee[ue]=ne[ue]);var ue=arguments.length-2;if(ue===1)ee.children=le;else if(1<ue){for(var me=Array(ue),de=0;de<ue;de++)me[de]=arguments[de+2];ee.children=me}return U(V.type,ie,void 0,void 0,ce,ee)},react_production.createContext=function(V){return V={$$typeof:g,_currentValue:V,_currentValue2:V,_threadCount:0,Provider:null,Consumer:null},V.Provider=V,V.Consumer={$$typeof:m,_context:V},V},react_production.createElement=function(V,ne,le){var ee,ie={},ce=null;if(ne!=null)for(ee in ne.key!==void 0&&(ce=""+ne.key),ne)L.call(ne,ee)&&ee!=="key"&&ee!=="__self"&&ee!=="__source"&&(ie[ee]=ne[ee]);var ue=arguments.length-2;if(ue===1)ie.children=le;else if(1<ue){for(var me=Array(ue),de=0;de<ue;de++)me[de]=arguments[de+2];ie.children=me}if(V&&V.defaultProps)for(ee in ue=V.defaultProps,ue)ie[ee]===void 0&&(ie[ee]=ue[ee]);return U(V,ce,void 0,void 0,null,ie)},react_production.createRef=function(){return{current:null}},react_production.forwardRef=function(V){return{$$typeof:y,render:V}},react_production.isValidElement=F,react_production.lazy=function(V){return{$$typeof:C,_payload:{_status:-1,_result:V},_init:G}},react_production.memo=function(V,ne){return{$$typeof:E,type:V,compare:ne===void 0?null:ne}},react_production.startTransition=function(V){var ne=j.T,le={};j.T=le;try{var ee=V(),ie=j.S;ie!==null&&ie(le,ee),typeof ee=="object"&&ee!==null&&typeof ee.then=="function"&&ee.then(ae,te)}catch(ce){te(ce)}finally{j.T=ne}},react_production.unstable_useCacheRefresh=function(){return j.H.useCacheRefresh()},react_production.use=function(V){return j.H.use(V)},react_production.useActionState=function(V,ne,le){return j.H.useActionState(V,ne,le)},react_production.useCallback=function(V,ne){return j.H.useCallback(V,ne)},react_production.useContext=function(V){return j.H.useContext(V)},react_production.useDebugValue=function(){},react_production.useDeferredValue=function(V,ne){return j.H.useDeferredValue(V,ne)},react_production.useEffect=function(V,ne,le){var ee=j.H;if(typeof le=="function")throw Error("useEffect CRUD overload is not enabled in this build of React.");return ee.useEffect(V,ne)},react_production.useId=function(){return j.H.useId()},react_production.useImperativeHandle=function(V,ne,le){return j.H.useImperativeHandle(V,ne,le)},react_production.useInsertionEffect=function(V,ne){return j.H.useInsertionEffect(V,ne)},react_production.useLayoutEffect=function(V,ne){return j.H.useLayoutEffect(V,ne)},react_production.useMemo=function(V,ne){return j.H.useMemo(V,ne)},react_production.useOptimistic=function(V,ne){return j.H.useOptimistic(V,ne)},react_production.useReducer=function(V,ne,le){return j.H.useReducer(V,ne,le)},react_production.useRef=function(V){return j.H.useRef(V)},react_production.useState=function(V){return j.H.useState(V)},react_production.useSyncExternalStore=function(V,ne,le){return j.H.useSyncExternalStore(V,ne,le)},react_production.useTransition=function(){return j.H.useTransition()},react_production.version="19.1.0",react_production}var hasRequiredReact;function requireReact(){return hasRequiredReact||(hasRequiredReact=1,react.exports=requireReact_production()),react.exports}var reactDom={exports:{}},reactDom_production={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredReactDom_production;function requireReactDom_production(){if(hasRequiredReactDom_production)return reactDom_production;hasRequiredReactDom_production=1;var a=requireReact();function c(b){var E="https://react.dev/errors/"+b;if(1<arguments.length){E+="?args[]="+encodeURIComponent(arguments[1]);for(var C=2;C<arguments.length;C++)E+="&args[]="+encodeURIComponent(arguments[C])}return"Minified React error #"+b+"; visit "+E+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function u(){}var d={d:{f:u,r:function(){throw Error(c(522))},D:u,C:u,L:u,m:u,X:u,S:u,M:u},p:0,findDOMNode:null},f=Symbol.for("react.portal");function m(b,E,C){var w=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:f,key:w==null?null:""+w,children:b,containerInfo:E,implementation:C}}var g=a.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function y(b,E){if(b==="font")return"";if(typeof E=="string")return E==="use-credentials"?E:""}return reactDom_production.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=d,reactDom_production.createPortal=function(b,E){var C=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!E||E.nodeType!==1&&E.nodeType!==9&&E.nodeType!==11)throw Error(c(299));return m(b,E,null,C)},reactDom_production.flushSync=function(b){var E=g.T,C=d.p;try{if(g.T=null,d.p=2,b)return b()}finally{g.T=E,d.p=C,d.d.f()}},reactDom_production.preconnect=function(b,E){typeof b=="string"&&(E?(E=E.crossOrigin,E=typeof E=="string"?E==="use-credentials"?E:"":void 0):E=null,d.d.C(b,E))},reactDom_production.prefetchDNS=function(b){typeof b=="string"&&d.d.D(b)},reactDom_production.preinit=function(b,E){if(typeof b=="string"&&E&&typeof E.as=="string"){var C=E.as,w=y(C,E.crossOrigin),R=typeof E.integrity=="string"?E.integrity:void 0,_=typeof E.fetchPriority=="string"?E.fetchPriority:void 0;C==="style"?d.d.S(b,typeof E.precedence=="string"?E.precedence:void 0,{crossOrigin:w,integrity:R,fetchPriority:_}):C==="script"&&d.d.X(b,{crossOrigin:w,integrity:R,fetchPriority:_,nonce:typeof E.nonce=="string"?E.nonce:void 0})}},reactDom_production.preinitModule=function(b,E){if(typeof b=="string")if(typeof E=="object"&&E!==null){if(E.as==null||E.as==="script"){var C=y(E.as,E.crossOrigin);d.d.M(b,{crossOrigin:C,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0})}}else E==null&&d.d.M(b)},reactDom_production.preload=function(b,E){if(typeof b=="string"&&typeof E=="object"&&E!==null&&typeof E.as=="string"){var C=E.as,w=y(C,E.crossOrigin);d.d.L(b,C,{crossOrigin:w,integrity:typeof E.integrity=="string"?E.integrity:void 0,nonce:typeof E.nonce=="string"?E.nonce:void 0,type:typeof E.type=="string"?E.type:void 0,fetchPriority:typeof E.fetchPriority=="string"?E.fetchPriority:void 0,referrerPolicy:typeof E.referrerPolicy=="string"?E.referrerPolicy:void 0,imageSrcSet:typeof E.imageSrcSet=="string"?E.imageSrcSet:void 0,imageSizes:typeof E.imageSizes=="string"?E.imageSizes:void 0,media:typeof E.media=="string"?E.media:void 0})}},reactDom_production.preloadModule=function(b,E){if(typeof b=="string")if(E){var C=y(E.as,E.crossOrigin);d.d.m(b,{as:typeof E.as=="string"&&E.as!=="script"?E.as:void 0,crossOrigin:C,integrity:typeof E.integrity=="string"?E.integrity:void 0})}else d.d.m(b)},reactDom_production.requestFormReset=function(b){d.d.r(b)},reactDom_production.unstable_batchedUpdates=function(b,E){return b(E)},reactDom_production.useFormState=function(b,E,C){return g.H.useFormState(b,E,C)},reactDom_production.useFormStatus=function(){return g.H.useHostTransitionStatus()},reactDom_production.version="19.1.0",reactDom_production}var hasRequiredReactDom;function requireReactDom(){if(hasRequiredReactDom)return reactDom.exports;hasRequiredReactDom=1;function a(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(a)}catch(c){console.error(c)}}return a(),reactDom.exports=requireReactDom_production(),reactDom.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredReactDomClient_production;function requireReactDomClient_production(){if(hasRequiredReactDomClient_production)return reactDomClient_production;hasRequiredReactDomClient_production=1;var a=requireScheduler(),c=requireReact(),u=requireReactDom();function d(v){var x="https://react.dev/errors/"+v;if(1<arguments.length){x+="?args[]="+encodeURIComponent(arguments[1]);for(var $=2;$<arguments.length;$++)x+="&args[]="+encodeURIComponent(arguments[$])}return"Minified React error #"+v+"; visit "+x+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function f(v){return!(!v||v.nodeType!==1&&v.nodeType!==9&&v.nodeType!==11)}function m(v){var x=v,$=v;if(v.alternate)for(;x.return;)x=x.return;else{v=x;do x=v,(x.flags&4098)!==0&&($=x.return),v=x.return;while(v)}return x.tag===3?$:null}function g(v){if(v.tag===13){var x=v.memoizedState;if(x===null&&(v=v.alternate,v!==null&&(x=v.memoizedState)),x!==null)return x.dehydrated}return null}function y(v){if(m(v)!==v)throw Error(d(188))}function b(v){var x=v.alternate;if(!x){if(x=m(v),x===null)throw Error(d(188));return x!==v?null:v}for(var $=v,O=x;;){var k=$.return;if(k===null)break;var H=k.alternate;if(H===null){if(O=k.return,O!==null){$=O;continue}break}if(k.child===H.child){for(H=k.child;H;){if(H===$)return y(k),v;if(H===O)return y(k),x;H=H.sibling}throw Error(d(188))}if($.return!==O.return)$=k,O=H;else{for(var oe=!1,se=k.child;se;){if(se===$){oe=!0,$=k,O=H;break}if(se===O){oe=!0,O=k,$=H;break}se=se.sibling}if(!oe){for(se=H.child;se;){if(se===$){oe=!0,$=H,O=k;break}if(se===O){oe=!0,O=H,$=k;break}se=se.sibling}if(!oe)throw Error(d(189))}}if($.alternate!==O)throw Error(d(190))}if($.tag!==3)throw Error(d(188));return $.stateNode.current===$?v:x}function E(v){var x=v.tag;if(x===5||x===26||x===27||x===6)return v;for(v=v.child;v!==null;){if(x=E(v),x!==null)return x;v=v.sibling}return null}var C=Object.assign,w=Symbol.for("react.element"),R=Symbol.for("react.transitional.element"),_=Symbol.for("react.portal"),M=Symbol.for("react.fragment"),I=Symbol.for("react.strict_mode"),N=Symbol.for("react.profiler"),A=Symbol.for("react.provider"),P=Symbol.for("react.consumer"),z=Symbol.for("react.context"),B=Symbol.for("react.forward_ref"),j=Symbol.for("react.suspense"),L=Symbol.for("react.suspense_list"),U=Symbol.for("react.memo"),q=Symbol.for("react.lazy"),F=Symbol.for("react.activity"),K=Symbol.for("react.memo_cache_sentinel"),X=Symbol.iterator;function Q(v){return v===null||typeof v!="object"?null:(v=X&&v[X]||v["@@iterator"],typeof v=="function"?v:null)}var Y=Symbol.for("react.client.reference");function Z(v){if(v==null)return null;if(typeof v=="function")return v.$$typeof===Y?null:v.displayName||v.name||null;if(typeof v=="string")return v;switch(v){case M:return"Fragment";case N:return"Profiler";case I:return"StrictMode";case j:return"Suspense";case L:return"SuspenseList";case F:return"Activity"}if(typeof v=="object")switch(v.$$typeof){case _:return"Portal";case z:return(v.displayName||"Context")+".Provider";case P:return(v._context.displayName||"Context")+".Consumer";case B:var x=v.render;return v=v.displayName,v||(v=x.displayName||x.name||"",v=v!==""?"ForwardRef("+v+")":"ForwardRef"),v;case U:return x=v.displayName||null,x!==null?x:Z(v.type)||"Memo";case q:x=v._payload,v=v._init;try{return Z(v(x))}catch{}}return null}var J=Array.isArray,W=c.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,G=u.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,te={pending:!1,data:null,method:null,action:null},ae=[],V=-1;function ne(v){return{current:v}}function le(v){0>V||(v.current=ae[V],ae[V]=null,V--)}function ee(v,x){V++,ae[V]=v.current,v.current=x}var ie=ne(null),ce=ne(null),ue=ne(null),me=ne(null);function de(v,x){switch(ee(ue,x),ee(ce,v),ee(ie,null),x.nodeType){case 9:case 11:v=(v=x.documentElement)&&(v=v.namespaceURI)?Jd(v):0;break;default:if(v=x.tagName,x=x.namespaceURI)x=Jd(x),v=ef(x,v);else switch(v){case"svg":v=1;break;case"math":v=2;break;default:v=0}}le(ie),ee(ie,v)}function ge(){le(ie),le(ce),le(ue)}function Ce(v){v.memoizedState!==null&&ee(me,v);var x=ie.current,$=ef(x,v.type);x!==$&&(ee(ce,v),ee(ie,$))}function ve(v){ce.current===v&&(le(ie),le(ce)),me.current===v&&(le(me),Yo._currentValue=te)}var fe=Object.prototype.hasOwnProperty,pe=a.unstable_scheduleCallback,xe=a.unstable_cancelCallback,ye=a.unstable_shouldYield,he=a.unstable_requestPaint,we=a.unstable_now,Re=a.unstable_getCurrentPriorityLevel,De=a.unstable_ImmediatePriority,Ae=a.unstable_UserBlockingPriority,Ee=a.unstable_NormalPriority,Ne=a.unstable_LowPriority,_e=a.unstable_IdlePriority,ke=a.log,Ke=a.unstable_setDisableYieldValue,be=null,Te=null;function Le(v){if(typeof ke=="function"&&Ke(v),Te&&typeof Te.setStrictMode=="function")try{Te.setStrictMode(be,v)}catch{}}var Oe=Math.clz32?Math.clz32:Pe,Be=Math.log,Ve=Math.LN2;function Pe(v){return v>>>=0,v===0?32:31-(Be(v)/Ve|0)|0}var Ge=256,qe=4194304;function Ue(v){var x=v&42;if(x!==0)return x;switch(v&-v){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return v&4194048;case 4194304:case 8388608:case 16777216:case 33554432:return v&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return v}}function je(v,x,$){var O=v.pendingLanes;if(O===0)return 0;var k=0,H=v.suspendedLanes,oe=v.pingedLanes;v=v.warmLanes;var se=O&134217727;return se!==0?(O=se&~H,O!==0?k=Ue(O):(oe&=se,oe!==0?k=Ue(oe):$||($=se&~v,$!==0&&(k=Ue($))))):(se=O&~H,se!==0?k=Ue(se):oe!==0?k=Ue(oe):$||($=O&~v,$!==0&&(k=Ue($)))),k===0?0:x!==0&&x!==k&&(x&H)===0&&(H=k&-k,$=x&-x,H>=$||H===32&&($&4194048)!==0)?x:k}function We(v,x){return(v.pendingLanes&~(v.suspendedLanes&~v.pingedLanes)&x)===0}function ut(v,x){switch(v){case 1:case 2:case 4:case 8:case 64:return x+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return x+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function gt(){var v=Ge;return Ge<<=1,(Ge&4194048)===0&&(Ge=256),v}function kt(){var v=qe;return qe<<=1,(qe&62914560)===0&&(qe=4194304),v}function Ut(v){for(var x=[],$=0;31>$;$++)x.push(v);return x}function at(v,x){v.pendingLanes|=x,x!==268435456&&(v.suspendedLanes=0,v.pingedLanes=0,v.warmLanes=0)}function ct(v,x,$,O,k,H){var oe=v.pendingLanes;v.pendingLanes=$,v.suspendedLanes=0,v.pingedLanes=0,v.warmLanes=0,v.expiredLanes&=$,v.entangledLanes&=$,v.errorRecoveryDisabledLanes&=$,v.shellSuspendCounter=0;var se=v.entanglements,Se=v.expirationTimes,ze=v.hiddenUpdates;for($=oe&~$;0<$;){var Xe=31-Oe($),Qe=1<<Xe;se[Xe]=0,Se[Xe]=-1;var Fe=ze[Xe];if(Fe!==null)for(ze[Xe]=null,Xe=0;Xe<Fe.length;Xe++){var He=Fe[Xe];He!==null&&(He.lane&=-536870913)}$&=~Qe}O!==0&&bt(v,O,0),H!==0&&k===0&&v.tag!==0&&(v.suspendedLanes|=H&~(oe&~x))}function bt(v,x,$){v.pendingLanes|=x,v.suspendedLanes&=~x;var O=31-Oe(x);v.entangledLanes|=x,v.entanglements[O]=v.entanglements[O]|1073741824|$&4194090}function it(v,x){var $=v.entangledLanes|=x;for(v=v.entanglements;$;){var O=31-Oe($),k=1<<O;k&x|v[O]&x&&(v[O]|=x),$&=~k}}function vt(v){switch(v){case 2:v=1;break;case 8:v=4;break;case 32:v=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:v=128;break;case 268435456:v=134217728;break;default:v=0}return v}function ot(v){return v&=-v,2<v?8<v?(v&134217727)!==0?32:268435456:8:2}function rt(){var v=G.p;return v!==0?v:(v=window.event,v===void 0?32:xf(v.type))}function et(v,x){var $=G.p;try{return G.p=v,x()}finally{G.p=$}}var $t=Math.random().toString(36).slice(2),mt="__reactFiber$"+$t,Ze="__reactProps$"+$t,Je="__reactContainer$"+$t,yt="__reactEvents$"+$t,Ct="__reactListeners$"+$t,pt="__reactHandles$"+$t,Rt="__reactResources$"+$t,ft="__reactMarker$"+$t;function dt(v){delete v[mt],delete v[Ze],delete v[yt],delete v[Ct],delete v[pt]}function xt(v){var x=v[mt];if(x)return x;for(var $=v.parentNode;$;){if(x=$[Je]||$[mt]){if($=x.alternate,x.child!==null||$!==null&&$.child!==null)for(v=af(v);v!==null;){if($=v[mt])return $;v=af(v)}return x}v=$,$=v.parentNode}return null}function Tt(v){if(v=v[mt]||v[Je]){var x=v.tag;if(x===5||x===6||x===13||x===26||x===27||x===3)return v}return null}function Dt(v){var x=v.tag;if(x===5||x===26||x===27||x===6)return v.stateNode;throw Error(d(33))}function Vt(v){var x=v[Rt];return x||(x=v[Rt]={hoistableStyles:new Map,hoistableScripts:new Map}),x}function Nt(v){v[ft]=!0}var Kt=new Set,Zt={};function Gt(v,x){tt(v,x),tt(v+"Capture",x)}function tt(v,x){for(Zt[v]=x,v=0;v<x.length;v++)Kt.add(x[v])}var ht=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),lt={},nt={};function Ot(v){return fe.call(nt,v)?!0:fe.call(lt,v)?!1:ht.test(v)?nt[v]=!0:(lt[v]=!0,!1)}function Bt(v,x,$){if(Ot(x))if($===null)v.removeAttribute(x);else{switch(typeof $){case"undefined":case"function":case"symbol":v.removeAttribute(x);return;case"boolean":var O=x.toLowerCase().slice(0,5);if(O!=="data-"&&O!=="aria-"){v.removeAttribute(x);return}}v.setAttribute(x,""+$)}}function qt(v,x,$){if($===null)v.removeAttribute(x);else{switch(typeof $){case"undefined":case"function":case"symbol":case"boolean":v.removeAttribute(x);return}v.setAttribute(x,""+$)}}function er(v,x,$,O){if(O===null)v.removeAttribute($);else{switch(typeof O){case"undefined":case"function":case"symbol":case"boolean":v.removeAttribute($);return}v.setAttributeNS(x,$,""+O)}}var St,_t;function zt(v){if(St===void 0)try{throw Error()}catch($){var x=$.stack.trim().match(/\n( *(at )?)/);St=x&&x[1]||"",_t=-1<$.stack.indexOf(`
    at`)?" (<anonymous>)":-1<$.stack.indexOf("@")?"@unknown:0:0":""}return`
`+St+v+_t}var nr=!1;function Rr(v,x){if(!v||nr)return"";nr=!0;var $=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var O={DetermineComponentFrameRoot:function(){try{if(x){var Qe=function(){throw Error()};if(Object.defineProperty(Qe.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(Qe,[])}catch(He){var Fe=He}Reflect.construct(v,[],Qe)}else{try{Qe.call()}catch(He){Fe=He}v.call(Qe.prototype)}}else{try{throw Error()}catch(He){Fe=He}(Qe=v())&&typeof Qe.catch=="function"&&Qe.catch(function(){})}}catch(He){if(He&&Fe&&typeof He.stack=="string")return[He.stack,Fe.stack]}return[null,null]}};O.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var k=Object.getOwnPropertyDescriptor(O.DetermineComponentFrameRoot,"name");k&&k.configurable&&Object.defineProperty(O.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var H=O.DetermineComponentFrameRoot(),oe=H[0],se=H[1];if(oe&&se){var Se=oe.split(`
`),ze=se.split(`
`);for(k=O=0;O<Se.length&&!Se[O].includes("DetermineComponentFrameRoot");)O++;for(;k<ze.length&&!ze[k].includes("DetermineComponentFrameRoot");)k++;if(O===Se.length||k===ze.length)for(O=Se.length-1,k=ze.length-1;1<=O&&0<=k&&Se[O]!==ze[k];)k--;for(;1<=O&&0<=k;O--,k--)if(Se[O]!==ze[k]){if(O!==1||k!==1)do if(O--,k--,0>k||Se[O]!==ze[k]){var Xe=`
`+Se[O].replace(" at new "," at ");return v.displayName&&Xe.includes("<anonymous>")&&(Xe=Xe.replace("<anonymous>",v.displayName)),Xe}while(1<=O&&0<=k);break}}}finally{nr=!1,Error.prepareStackTrace=$}return($=v?v.displayName||v.name:"")?zt($):""}function Jr(v){switch(v.tag){case 26:case 27:case 5:return zt(v.type);case 16:return zt("Lazy");case 13:return zt("Suspense");case 19:return zt("SuspenseList");case 0:case 15:return Rr(v.type,!1);case 11:return Rr(v.type.render,!1);case 1:return Rr(v.type,!0);case 31:return zt("Activity");default:return""}}function Tr(v){try{var x="";do x+=Jr(v),v=v.return;while(v);return x}catch($){return`
Error generating stack: `+$.message+`
`+$.stack}}function lr(v){switch(typeof v){case"bigint":case"boolean":case"number":case"string":case"undefined":return v;case"object":return v;default:return""}}function en(v){var x=v.type;return(v=v.nodeName)&&v.toLowerCase()==="input"&&(x==="checkbox"||x==="radio")}function tn(v){var x=en(v)?"checked":"value",$=Object.getOwnPropertyDescriptor(v.constructor.prototype,x),O=""+v[x];if(!v.hasOwnProperty(x)&&typeof $<"u"&&typeof $.get=="function"&&typeof $.set=="function"){var k=$.get,H=$.set;return Object.defineProperty(v,x,{configurable:!0,get:function(){return k.call(this)},set:function(oe){O=""+oe,H.call(this,oe)}}),Object.defineProperty(v,x,{enumerable:$.enumerable}),{getValue:function(){return O},setValue:function(oe){O=""+oe},stopTracking:function(){v._valueTracker=null,delete v[x]}}}}function wr(v){v._valueTracker||(v._valueTracker=tn(v))}function rn(v){if(!v)return!1;var x=v._valueTracker;if(!x)return!0;var $=x.getValue(),O="";return v&&(O=en(v)?v.checked?"true":"false":v.value),v=O,v!==$?(x.setValue(v),!0):!1}function Wt(v){if(v=v||(typeof document<"u"?document:void 0),typeof v>"u")return null;try{return v.activeElement||v.body}catch{return v.body}}var wt=/[\n"\\]/g;function st(v){return v.replace(wt,function(x){return"\\"+x.charCodeAt(0).toString(16)+" "})}function Xt(v,x,$,O,k,H,oe,se){v.name="",oe!=null&&typeof oe!="function"&&typeof oe!="symbol"&&typeof oe!="boolean"?v.type=oe:v.removeAttribute("type"),x!=null?oe==="number"?(x===0&&v.value===""||v.value!=x)&&(v.value=""+lr(x)):v.value!==""+lr(x)&&(v.value=""+lr(x)):oe!=="submit"&&oe!=="reset"||v.removeAttribute("value"),x!=null?or(v,oe,lr(x)):$!=null?or(v,oe,lr($)):O!=null&&v.removeAttribute("value"),k==null&&H!=null&&(v.defaultChecked=!!H),k!=null&&(v.checked=k&&typeof k!="function"&&typeof k!="symbol"),se!=null&&typeof se!="function"&&typeof se!="symbol"&&typeof se!="boolean"?v.name=""+lr(se):v.removeAttribute("name")}function Qt(v,x,$,O,k,H,oe,se){if(H!=null&&typeof H!="function"&&typeof H!="symbol"&&typeof H!="boolean"&&(v.type=H),x!=null||$!=null){if(!(H!=="submit"&&H!=="reset"||x!=null))return;$=$!=null?""+lr($):"",x=x!=null?""+lr(x):$,se||x===v.value||(v.value=x),v.defaultValue=x}O=O??k,O=typeof O!="function"&&typeof O!="symbol"&&!!O,v.checked=se?v.checked:!!O,v.defaultChecked=!!O,oe!=null&&typeof oe!="function"&&typeof oe!="symbol"&&typeof oe!="boolean"&&(v.name=oe)}function or(v,x,$){x==="number"&&Wt(v.ownerDocument)===v||v.defaultValue===""+$||(v.defaultValue=""+$)}function ar(v,x,$,O){if(v=v.options,x){x={};for(var k=0;k<$.length;k++)x["$"+$[k]]=!0;for($=0;$<v.length;$++)k=x.hasOwnProperty("$"+v[$].value),v[$].selected!==k&&(v[$].selected=k),k&&O&&(v[$].defaultSelected=!0)}else{for($=""+lr($),x=null,k=0;k<v.length;k++){if(v[k].value===$){v[k].selected=!0,O&&(v[k].defaultSelected=!0);return}x!==null||v[k].disabled||(x=v[k])}x!==null&&(x.selected=!0)}}function Ir(v,x,$){if(x!=null&&(x=""+lr(x),x!==v.value&&(v.value=x),$==null)){v.defaultValue!==x&&(v.defaultValue=x);return}v.defaultValue=$!=null?""+lr($):""}function _r(v,x,$,O){if(x==null){if(O!=null){if($!=null)throw Error(d(92));if(J(O)){if(1<O.length)throw Error(d(93));O=O[0]}$=O}$==null&&($=""),x=$}$=lr(x),v.defaultValue=$,O=v.textContent,O===$&&O!==""&&O!==null&&(v.value=O)}function Sr(v,x){if(x){var $=v.firstChild;if($&&$===v.lastChild&&$.nodeType===3){$.nodeValue=x;return}}v.textContent=x}var kr=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function jr(v,x,$){var O=x.indexOf("--")===0;$==null||typeof $=="boolean"||$===""?O?v.setProperty(x,""):x==="float"?v.cssFloat="":v[x]="":O?v.setProperty(x,$):typeof $!="number"||$===0||kr.has(x)?x==="float"?v.cssFloat=$:v[x]=(""+$).trim():v[x]=$+"px"}function Pt(v,x,$){if(x!=null&&typeof x!="object")throw Error(d(62));if(v=v.style,$!=null){for(var O in $)!$.hasOwnProperty(O)||x!=null&&x.hasOwnProperty(O)||(O.indexOf("--")===0?v.setProperty(O,""):O==="float"?v.cssFloat="":v[O]="");for(var k in x)O=x[k],x.hasOwnProperty(k)&&$[k]!==O&&jr(v,k,O)}else for(var H in x)x.hasOwnProperty(H)&&jr(v,H,x[H])}function It(v){if(v.indexOf("-")===-1)return!1;switch(v){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var Or=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),vr=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function yr(v){return vr.test(""+v)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":v}var Gr=null;function Lr(v){return v=v.target||v.srcElement||window,v.correspondingUseElement&&(v=v.correspondingUseElement),v.nodeType===3?v.parentNode:v}var Mr=null,Ur=null;function Cn(v){var x=Tt(v);if(x&&(v=x.stateNode)){var $=v[Ze]||null;e:switch(v=x.stateNode,x.type){case"input":if(Xt(v,$.value,$.defaultValue,$.defaultValue,$.checked,$.defaultChecked,$.type,$.name),x=$.name,$.type==="radio"&&x!=null){for($=v;$.parentNode;)$=$.parentNode;for($=$.querySelectorAll('input[name="'+st(""+x)+'"][type="radio"]'),x=0;x<$.length;x++){var O=$[x];if(O!==v&&O.form===v.form){var k=O[Ze]||null;if(!k)throw Error(d(90));Xt(O,k.value,k.defaultValue,k.defaultValue,k.checked,k.defaultChecked,k.type,k.name)}}for(x=0;x<$.length;x++)O=$[x],O.form===v.form&&rn(O)}break e;case"textarea":Ir(v,$.value,$.defaultValue);break e;case"select":x=$.value,x!=null&&ar(v,!!$.multiple,x,!1)}}}var ha=!1;function Aa(v,x,$){if(ha)return v(x,$);ha=!0;try{var O=v(x);return O}finally{if(ha=!1,(Mr!==null||Ur!==null)&&(ji(),Mr&&(x=Mr,v=Ur,Ur=Mr=null,Cn(x),v)))for(x=0;x<v.length;x++)Cn(v[x])}}function In(v,x){var $=v.stateNode;if($===null)return null;var O=$[Ze]||null;if(O===null)return null;$=O[x];e:switch(x){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(O=!O.disabled)||(v=v.type,O=!(v==="button"||v==="input"||v==="select"||v==="textarea")),v=!O;break e;default:v=!1}if(v)return null;if($&&typeof $!="function")throw Error(d(231,x,typeof $));return $}var Et=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),jt=!1;if(Et)try{var ur={};Object.defineProperty(ur,"passive",{get:function(){jt=!0}}),window.addEventListener("test",ur,ur),window.removeEventListener("test",ur,ur)}catch{jt=!1}var mr=null,Er=null,An=null;function Pa(){if(An)return An;var v,x=Er,$=x.length,O,k="value"in mr?mr.value:mr.textContent,H=k.length;for(v=0;v<$&&x[v]===k[v];v++);var oe=$-v;for(O=1;O<=oe&&x[$-O]===k[H-O];O++);return An=k.slice(v,1<O?1-O:void 0)}function ga(v){var x=v.keyCode;return"charCode"in v?(v=v.charCode,v===0&&x===13&&(v=13)):v=x,v===10&&(v=13),32<=v||v===13?v:0}function Pn(){return!0}function tc(){return!1}function an(v){function x($,O,k,H,oe){this._reactName=$,this._targetInst=k,this.type=O,this.nativeEvent=H,this.target=oe,this.currentTarget=null;for(var se in v)v.hasOwnProperty(se)&&($=v[se],this[se]=$?$(H):H[se]);return this.isDefaultPrevented=(H.defaultPrevented!=null?H.defaultPrevented:H.returnValue===!1)?Pn:tc,this.isPropagationStopped=tc,this}return C(x.prototype,{preventDefault:function(){this.defaultPrevented=!0;var $=this.nativeEvent;$&&($.preventDefault?$.preventDefault():typeof $.returnValue!="unknown"&&($.returnValue=!1),this.isDefaultPrevented=Pn)},stopPropagation:function(){var $=this.nativeEvent;$&&($.stopPropagation?$.stopPropagation():typeof $.cancelBubble!="unknown"&&($.cancelBubble=!0),this.isPropagationStopped=Pn)},persist:function(){},isPersistent:Pn}),x}var va={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(v){return v.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},ri=an(va),uo=C({},va,{view:0,detail:0}),Tf=an(uo),ol,il,fo,ni=C({},uo,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:sl,button:0,buttons:0,relatedTarget:function(v){return v.relatedTarget===void 0?v.fromElement===v.srcElement?v.toElement:v.fromElement:v.relatedTarget},movementX:function(v){return"movementX"in v?v.movementX:(v!==fo&&(fo&&v.type==="mousemove"?(ol=v.screenX-fo.screenX,il=v.screenY-fo.screenY):il=ol=0,fo=v),ol)},movementY:function(v){return"movementY"in v?v.movementY:il}}),rc=an(ni),_f=C({},ni,{dataTransfer:0}),Of=an(_f),Mf=C({},uo,{relatedTarget:0}),ll=an(Mf),Nf=C({},va,{animationName:0,elapsedTime:0,pseudoElement:0}),If=an(Nf),Af=C({},va,{clipboardData:function(v){return"clipboardData"in v?v.clipboardData:window.clipboardData}}),Pf=an(Af),kf=C({},va,{data:0}),nc=an(kf),zf={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},Df={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},jf={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Lf(v){var x=this.nativeEvent;return x.getModifierState?x.getModifierState(v):(v=jf[v])?!!x[v]:!1}function sl(){return Lf}var Bf=C({},uo,{key:function(v){if(v.key){var x=zf[v.key]||v.key;if(x!=="Unidentified")return x}return v.type==="keypress"?(v=ga(v),v===13?"Enter":String.fromCharCode(v)):v.type==="keydown"||v.type==="keyup"?Df[v.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:sl,charCode:function(v){return v.type==="keypress"?ga(v):0},keyCode:function(v){return v.type==="keydown"||v.type==="keyup"?v.keyCode:0},which:function(v){return v.type==="keypress"?ga(v):v.type==="keydown"||v.type==="keyup"?v.keyCode:0}}),Ff=an(Bf),Hf=C({},ni,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),ac=an(Hf),Vf=C({},uo,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:sl}),Uf=an(Vf),Kf=C({},va,{propertyName:0,elapsedTime:0,pseudoElement:0}),qf=an(Kf),Wf=C({},ni,{deltaX:function(v){return"deltaX"in v?v.deltaX:"wheelDeltaX"in v?-v.wheelDeltaX:0},deltaY:function(v){return"deltaY"in v?v.deltaY:"wheelDeltaY"in v?-v.wheelDeltaY:"wheelDelta"in v?-v.wheelDelta:0},deltaZ:0,deltaMode:0}),Gf=an(Wf),Xf=C({},va,{newState:0,oldState:0}),Yf=an(Xf),Zf=[9,13,27,32],cl=Et&&"CompositionEvent"in window,mo=null;Et&&"documentMode"in document&&(mo=document.documentMode);var Qf=Et&&"TextEvent"in window&&!mo,oc=Et&&(!cl||mo&&8<mo&&11>=mo),ic=" ",lc=!1;function sc(v,x){switch(v){case"keyup":return Zf.indexOf(x.keyCode)!==-1;case"keydown":return x.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function cc(v){return v=v.detail,typeof v=="object"&&"data"in v?v.data:null}var ka=!1;function Jf(v,x){switch(v){case"compositionend":return cc(x);case"keypress":return x.which!==32?null:(lc=!0,ic);case"textInput":return v=x.data,v===ic&&lc?null:v;default:return null}}function em(v,x){if(ka)return v==="compositionend"||!cl&&sc(v,x)?(v=Pa(),An=Er=mr=null,ka=!1,v):null;switch(v){case"paste":return null;case"keypress":if(!(x.ctrlKey||x.altKey||x.metaKey)||x.ctrlKey&&x.altKey){if(x.char&&1<x.char.length)return x.char;if(x.which)return String.fromCharCode(x.which)}return null;case"compositionend":return oc&&x.locale!=="ko"?null:x.data;default:return null}}var tm={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function uc(v){var x=v&&v.nodeName&&v.nodeName.toLowerCase();return x==="input"?!!tm[v.type]:x==="textarea"}function dc(v,x,$,O){Mr?Ur?Ur.push(O):Ur=[O]:Mr=O,x=Ui(x,"onChange"),0<x.length&&($=new ri("onChange","change",null,$,O),v.push({event:$,listeners:x}))}var po=null,ho=null;function rm(v){Gd(v,0)}function ai(v){var x=Dt(v);if(rn(x))return v}function fc(v,x){if(v==="change")return x}var mc=!1;if(Et){var ul;if(Et){var dl="oninput"in document;if(!dl){var pc=document.createElement("div");pc.setAttribute("oninput","return;"),dl=typeof pc.oninput=="function"}ul=dl}else ul=!1;mc=ul&&(!document.documentMode||9<document.documentMode)}function hc(){po&&(po.detachEvent("onpropertychange",gc),ho=po=null)}function gc(v){if(v.propertyName==="value"&&ai(ho)){var x=[];dc(x,ho,v,Lr(v)),Aa(rm,x)}}function nm(v,x,$){v==="focusin"?(hc(),po=x,ho=$,po.attachEvent("onpropertychange",gc)):v==="focusout"&&hc()}function am(v){if(v==="selectionchange"||v==="keyup"||v==="keydown")return ai(ho)}function om(v,x){if(v==="click")return ai(x)}function im(v,x){if(v==="input"||v==="change")return ai(x)}function lm(v,x){return v===x&&(v!==0||1/v===1/x)||v!==v&&x!==x}var cn=typeof Object.is=="function"?Object.is:lm;function go(v,x){if(cn(v,x))return!0;if(typeof v!="object"||v===null||typeof x!="object"||x===null)return!1;var $=Object.keys(v),O=Object.keys(x);if($.length!==O.length)return!1;for(O=0;O<$.length;O++){var k=$[O];if(!fe.call(x,k)||!cn(v[k],x[k]))return!1}return!0}function vc(v){for(;v&&v.firstChild;)v=v.firstChild;return v}function yc(v,x){var $=vc(v);v=0;for(var O;$;){if($.nodeType===3){if(O=v+$.textContent.length,v<=x&&O>=x)return{node:$,offset:x-v};v=O}e:{for(;$;){if($.nextSibling){$=$.nextSibling;break e}$=$.parentNode}$=void 0}$=vc($)}}function bc(v,x){return v&&x?v===x?!0:v&&v.nodeType===3?!1:x&&x.nodeType===3?bc(v,x.parentNode):"contains"in v?v.contains(x):v.compareDocumentPosition?!!(v.compareDocumentPosition(x)&16):!1:!1}function xc(v){v=v!=null&&v.ownerDocument!=null&&v.ownerDocument.defaultView!=null?v.ownerDocument.defaultView:window;for(var x=Wt(v.document);x instanceof v.HTMLIFrameElement;){try{var $=typeof x.contentWindow.location.href=="string"}catch{$=!1}if($)v=x.contentWindow;else break;x=Wt(v.document)}return x}function fl(v){var x=v&&v.nodeName&&v.nodeName.toLowerCase();return x&&(x==="input"&&(v.type==="text"||v.type==="search"||v.type==="tel"||v.type==="url"||v.type==="password")||x==="textarea"||v.contentEditable==="true")}var sm=Et&&"documentMode"in document&&11>=document.documentMode,za=null,ml=null,vo=null,pl=!1;function Ec(v,x,$){var O=$.window===$?$.document:$.nodeType===9?$:$.ownerDocument;pl||za==null||za!==Wt(O)||(O=za,"selectionStart"in O&&fl(O)?O={start:O.selectionStart,end:O.selectionEnd}:(O=(O.ownerDocument&&O.ownerDocument.defaultView||window).getSelection(),O={anchorNode:O.anchorNode,anchorOffset:O.anchorOffset,focusNode:O.focusNode,focusOffset:O.focusOffset}),vo&&go(vo,O)||(vo=O,O=Ui(ml,"onSelect"),0<O.length&&(x=new ri("onSelect","select",null,x,$),v.push({event:x,listeners:O}),x.target=za)))}function ya(v,x){var $={};return $[v.toLowerCase()]=x.toLowerCase(),$["Webkit"+v]="webkit"+x,$["Moz"+v]="moz"+x,$}var Da={animationend:ya("Animation","AnimationEnd"),animationiteration:ya("Animation","AnimationIteration"),animationstart:ya("Animation","AnimationStart"),transitionrun:ya("Transition","TransitionRun"),transitionstart:ya("Transition","TransitionStart"),transitioncancel:ya("Transition","TransitionCancel"),transitionend:ya("Transition","TransitionEnd")},hl={},Cc={};Et&&(Cc=document.createElement("div").style,"AnimationEvent"in window||(delete Da.animationend.animation,delete Da.animationiteration.animation,delete Da.animationstart.animation),"TransitionEvent"in window||delete Da.transitionend.transition);function ba(v){if(hl[v])return hl[v];if(!Da[v])return v;var x=Da[v],$;for($ in x)if(x.hasOwnProperty($)&&$ in Cc)return hl[v]=x[$];return v}var wc=ba("animationend"),$c=ba("animationiteration"),Rc=ba("animationstart"),cm=ba("transitionrun"),um=ba("transitionstart"),dm=ba("transitioncancel"),_c=ba("transitionend"),Oc=new Map,gl="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");gl.push("scrollEnd");function wn(v,x){Oc.set(v,x),Gt(x,[v])}var Mc=new WeakMap;function gn(v,x){if(typeof v=="object"&&v!==null){var $=Mc.get(v);return $!==void 0?$:(x={value:v,source:x,stack:Tr(x)},Mc.set(v,x),x)}return{value:v,source:x,stack:Tr(x)}}var vn=[],ja=0,vl=0;function oi(){for(var v=ja,x=vl=ja=0;x<v;){var $=vn[x];vn[x++]=null;var O=vn[x];vn[x++]=null;var k=vn[x];vn[x++]=null;var H=vn[x];if(vn[x++]=null,O!==null&&k!==null){var oe=O.pending;oe===null?k.next=k:(k.next=oe.next,oe.next=k),O.pending=k}H!==0&&Nc($,k,H)}}function ii(v,x,$,O){vn[ja++]=v,vn[ja++]=x,vn[ja++]=$,vn[ja++]=O,vl|=O,v.lanes|=O,v=v.alternate,v!==null&&(v.lanes|=O)}function yl(v,x,$,O){return ii(v,x,$,O),li(v)}function La(v,x){return ii(v,null,null,x),li(v)}function Nc(v,x,$){v.lanes|=$;var O=v.alternate;O!==null&&(O.lanes|=$);for(var k=!1,H=v.return;H!==null;)H.childLanes|=$,O=H.alternate,O!==null&&(O.childLanes|=$),H.tag===22&&(v=H.stateNode,v===null||v._visibility&1||(k=!0)),v=H,H=H.return;return v.tag===3?(H=v.stateNode,k&&x!==null&&(k=31-Oe($),v=H.hiddenUpdates,O=v[k],O===null?v[k]=[x]:O.push(x),x.lane=$|536870912),H):null}function li(v){if(50<Ho)throw Ho=0,$s=null,Error(d(185));for(var x=v.return;x!==null;)v=x,x=v.return;return v.tag===3?v.stateNode:null}var Ba={};function fm(v,x,$,O){this.tag=v,this.key=$,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=x,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=O,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function un(v,x,$,O){return new fm(v,x,$,O)}function bl(v){return v=v.prototype,!(!v||!v.isReactComponent)}function kn(v,x){var $=v.alternate;return $===null?($=un(v.tag,x,v.key,v.mode),$.elementType=v.elementType,$.type=v.type,$.stateNode=v.stateNode,$.alternate=v,v.alternate=$):($.pendingProps=x,$.type=v.type,$.flags=0,$.subtreeFlags=0,$.deletions=null),$.flags=v.flags&65011712,$.childLanes=v.childLanes,$.lanes=v.lanes,$.child=v.child,$.memoizedProps=v.memoizedProps,$.memoizedState=v.memoizedState,$.updateQueue=v.updateQueue,x=v.dependencies,$.dependencies=x===null?null:{lanes:x.lanes,firstContext:x.firstContext},$.sibling=v.sibling,$.index=v.index,$.ref=v.ref,$.refCleanup=v.refCleanup,$}function Ic(v,x){v.flags&=65011714;var $=v.alternate;return $===null?(v.childLanes=0,v.lanes=x,v.child=null,v.subtreeFlags=0,v.memoizedProps=null,v.memoizedState=null,v.updateQueue=null,v.dependencies=null,v.stateNode=null):(v.childLanes=$.childLanes,v.lanes=$.lanes,v.child=$.child,v.subtreeFlags=0,v.deletions=null,v.memoizedProps=$.memoizedProps,v.memoizedState=$.memoizedState,v.updateQueue=$.updateQueue,v.type=$.type,x=$.dependencies,v.dependencies=x===null?null:{lanes:x.lanes,firstContext:x.firstContext}),v}function si(v,x,$,O,k,H){var oe=0;if(O=v,typeof v=="function")bl(v)&&(oe=1);else if(typeof v=="string")oe=p0(v,$,ie.current)?26:v==="html"||v==="head"||v==="body"?27:5;else e:switch(v){case F:return v=un(31,$,x,k),v.elementType=F,v.lanes=H,v;case M:return xa($.children,k,H,x);case I:oe=8,k|=24;break;case N:return v=un(12,$,x,k|2),v.elementType=N,v.lanes=H,v;case j:return v=un(13,$,x,k),v.elementType=j,v.lanes=H,v;case L:return v=un(19,$,x,k),v.elementType=L,v.lanes=H,v;default:if(typeof v=="object"&&v!==null)switch(v.$$typeof){case A:case z:oe=10;break e;case P:oe=9;break e;case B:oe=11;break e;case U:oe=14;break e;case q:oe=16,O=null;break e}oe=29,$=Error(d(130,v===null?"null":typeof v,"")),O=null}return x=un(oe,$,x,k),x.elementType=v,x.type=O,x.lanes=H,x}function xa(v,x,$,O){return v=un(7,v,O,x),v.lanes=$,v}function xl(v,x,$){return v=un(6,v,null,x),v.lanes=$,v}function Sl(v,x,$){return x=un(4,v.children!==null?v.children:[],v.key,x),x.lanes=$,x.stateNode={containerInfo:v.containerInfo,pendingChildren:null,implementation:v.implementation},x}var Fa=[],Ha=0,ci=null,ui=0,yn=[],bn=0,Sa=null,zn=1,Dn="";function Ea(v,x){Fa[Ha++]=ui,Fa[Ha++]=ci,ci=v,ui=x}function Ac(v,x,$){yn[bn++]=zn,yn[bn++]=Dn,yn[bn++]=Sa,Sa=v;var O=zn;v=Dn;var k=32-Oe(O)-1;O&=~(1<<k),$+=1;var H=32-Oe(x)+k;if(30<H){var oe=k-k%5;H=(O&(1<<oe)-1).toString(32),O>>=oe,k-=oe,zn=1<<32-Oe(x)+k|$<<k|O,Dn=H+v}else zn=1<<H|$<<k|O,Dn=v}function El(v){v.return!==null&&(Ea(v,1),Ac(v,1,0))}function Cl(v){for(;v===ci;)ci=Fa[--Ha],Fa[Ha]=null,ui=Fa[--Ha],Fa[Ha]=null;for(;v===Sa;)Sa=yn[--bn],yn[bn]=null,Dn=yn[--bn],yn[bn]=null,zn=yn[--bn],yn[bn]=null}var nn=null,Ar=null,cr=!1,Ca=null,Tn=!1,wl=Error(d(519));function wa(v){var x=Error(d(418,""));throw xo(gn(x,v)),wl}function Pc(v){var x=v.stateNode,$=v.type,O=v.memoizedProps;switch(x[mt]=v,x[Ze]=O,$){case"dialog":rr("cancel",x),rr("close",x);break;case"iframe":case"object":case"embed":rr("load",x);break;case"video":case"audio":for($=0;$<Uo.length;$++)rr(Uo[$],x);break;case"source":rr("error",x);break;case"img":case"image":case"link":rr("error",x),rr("load",x);break;case"details":rr("toggle",x);break;case"input":rr("invalid",x),Qt(x,O.value,O.defaultValue,O.checked,O.defaultChecked,O.type,O.name,!0),wr(x);break;case"select":rr("invalid",x);break;case"textarea":rr("invalid",x),_r(x,O.value,O.defaultValue,O.children),wr(x)}$=O.children,typeof $!="string"&&typeof $!="number"&&typeof $!="bigint"||x.textContent===""+$||O.suppressHydrationWarning===!0||Qd(x.textContent,$)?(O.popover!=null&&(rr("beforetoggle",x),rr("toggle",x)),O.onScroll!=null&&rr("scroll",x),O.onScrollEnd!=null&&rr("scrollend",x),O.onClick!=null&&(x.onclick=Ki),x=!0):x=!1,x||wa(v)}function kc(v){for(nn=v.return;nn;)switch(nn.tag){case 5:case 13:Tn=!1;return;case 27:case 3:Tn=!0;return;default:nn=nn.return}}function yo(v){if(v!==nn)return!1;if(!cr)return kc(v),cr=!0,!1;var x=v.tag,$;if(($=x!==3&&x!==27)&&(($=x===5)&&($=v.type,$=!($!=="form"&&$!=="button")||Fs(v.type,v.memoizedProps)),$=!$),$&&Ar&&wa(v),kc(v),x===13){if(v=v.memoizedState,v=v!==null?v.dehydrated:null,!v)throw Error(d(317));e:{for(v=v.nextSibling,x=0;v;){if(v.nodeType===8)if($=v.data,$==="/$"){if(x===0){Ar=Rn(v.nextSibling);break e}x--}else $!=="$"&&$!=="$!"&&$!=="$?"||x++;v=v.nextSibling}Ar=null}}else x===27?(x=Ar,ca(v.type)?(v=Ks,Ks=null,Ar=v):Ar=x):Ar=nn?Rn(v.stateNode.nextSibling):null;return!0}function bo(){Ar=nn=null,cr=!1}function zc(){var v=Ca;return v!==null&&(sn===null?sn=v:sn.push.apply(sn,v),Ca=null),v}function xo(v){Ca===null?Ca=[v]:Ca.push(v)}var $l=ne(null),$a=null,jn=null;function Gn(v,x,$){ee($l,x._currentValue),x._currentValue=$}function Ln(v){v._currentValue=$l.current,le($l)}function Rl(v,x,$){for(;v!==null;){var O=v.alternate;if((v.childLanes&x)!==x?(v.childLanes|=x,O!==null&&(O.childLanes|=x)):O!==null&&(O.childLanes&x)!==x&&(O.childLanes|=x),v===$)break;v=v.return}}function Tl(v,x,$,O){var k=v.child;for(k!==null&&(k.return=v);k!==null;){var H=k.dependencies;if(H!==null){var oe=k.child;H=H.firstContext;e:for(;H!==null;){var se=H;H=k;for(var Se=0;Se<x.length;Se++)if(se.context===x[Se]){H.lanes|=$,se=H.alternate,se!==null&&(se.lanes|=$),Rl(H.return,$,v),O||(oe=null);break e}H=se.next}}else if(k.tag===18){if(oe=k.return,oe===null)throw Error(d(341));oe.lanes|=$,H=oe.alternate,H!==null&&(H.lanes|=$),Rl(oe,$,v),oe=null}else oe=k.child;if(oe!==null)oe.return=k;else for(oe=k;oe!==null;){if(oe===v){oe=null;break}if(k=oe.sibling,k!==null){k.return=oe.return,oe=k;break}oe=oe.return}k=oe}}function So(v,x,$,O){v=null;for(var k=x,H=!1;k!==null;){if(!H){if((k.flags&524288)!==0)H=!0;else if((k.flags&262144)!==0)break}if(k.tag===10){var oe=k.alternate;if(oe===null)throw Error(d(387));if(oe=oe.memoizedProps,oe!==null){var se=k.type;cn(k.pendingProps.value,oe.value)||(v!==null?v.push(se):v=[se])}}else if(k===me.current){if(oe=k.alternate,oe===null)throw Error(d(387));oe.memoizedState.memoizedState!==k.memoizedState.memoizedState&&(v!==null?v.push(Yo):v=[Yo])}k=k.return}v!==null&&Tl(x,v,$,O),x.flags|=262144}function di(v){for(v=v.firstContext;v!==null;){if(!cn(v.context._currentValue,v.memoizedValue))return!0;v=v.next}return!1}function Ra(v){$a=v,jn=null,v=v.dependencies,v!==null&&(v.firstContext=null)}function Qr(v){return jc($a,v)}function fi(v,x){return $a===null&&Ra(v),jc(v,x)}function jc(v,x){var $=x._currentValue;if(x={context:x,memoizedValue:$,next:null},jn===null){if(v===null)throw Error(d(308));jn=x,v.dependencies={lanes:0,firstContext:x},v.flags|=524288}else jn=jn.next=x;return $}var mm=typeof AbortController<"u"?AbortController:function(){var v=[],x=this.signal={aborted:!1,addEventListener:function($,O){v.push(O)}};this.abort=function(){x.aborted=!0,v.forEach(function($){return $()})}},pm=a.unstable_scheduleCallback,hm=a.unstable_NormalPriority,Hr={$$typeof:z,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function _l(){return{controller:new mm,data:new Map,refCount:0}}function Eo(v){v.refCount--,v.refCount===0&&pm(hm,function(){v.controller.abort()})}var Co=null,Ol=0,Va=0,Ua=null;function gm(v,x){if(Co===null){var $=Co=[];Ol=0,Va=Is(),Ua={status:"pending",value:void 0,then:function(O){$.push(O)}}}return Ol++,x.then(Lc,Lc),x}function Lc(){if(--Ol===0&&Co!==null){Ua!==null&&(Ua.status="fulfilled");var v=Co;Co=null,Va=0,Ua=null;for(var x=0;x<v.length;x++)(0,v[x])()}}function vm(v,x){var $=[],O={status:"pending",value:null,reason:null,then:function(k){$.push(k)}};return v.then(function(){O.status="fulfilled",O.value=x;for(var k=0;k<$.length;k++)(0,$[k])(x)},function(k){for(O.status="rejected",O.reason=k,k=0;k<$.length;k++)(0,$[k])(void 0)}),O}var Bc=W.S;W.S=function(v,x){typeof x=="object"&&x!==null&&typeof x.then=="function"&&gm(v,x),Bc!==null&&Bc(v,x)};var Ta=ne(null);function Ml(){var v=Ta.current;return v!==null?v:Cr.pooledCache}function mi(v,x){x===null?ee(Ta,Ta.current):ee(Ta,x.pool)}function Fc(){var v=Ml();return v===null?null:{parent:Hr._currentValue,pool:v}}var wo=Error(d(460)),Hc=Error(d(474)),pi=Error(d(542)),Nl={then:function(){}};function Vc(v){return v=v.status,v==="fulfilled"||v==="rejected"}function hi(){}function Uc(v,x,$){switch($=v[$],$===void 0?v.push(x):$!==x&&(x.then(hi,hi),x=$),x.status){case"fulfilled":return x.value;case"rejected":throw v=x.reason,qc(v),v;default:if(typeof x.status=="string")x.then(hi,hi);else{if(v=Cr,v!==null&&100<v.shellSuspendCounter)throw Error(d(482));v=x,v.status="pending",v.then(function(O){if(x.status==="pending"){var k=x;k.status="fulfilled",k.value=O}},function(O){if(x.status==="pending"){var k=x;k.status="rejected",k.reason=O}})}switch(x.status){case"fulfilled":return x.value;case"rejected":throw v=x.reason,qc(v),v}throw $o=x,wo}}var $o=null;function Kc(){if($o===null)throw Error(d(459));var v=$o;return $o=null,v}function qc(v){if(v===wo||v===pi)throw Error(d(483))}var Xn=!1;function Il(v){v.updateQueue={baseState:v.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function Al(v,x){v=v.updateQueue,x.updateQueue===v&&(x.updateQueue={baseState:v.baseState,firstBaseUpdate:v.firstBaseUpdate,lastBaseUpdate:v.lastBaseUpdate,shared:v.shared,callbacks:null})}function Yn(v){return{lane:v,tag:0,payload:null,callback:null,next:null}}function Zn(v,x,$){var O=v.updateQueue;if(O===null)return null;if(O=O.shared,(dr&2)!==0){var k=O.pending;return k===null?x.next=x:(x.next=k.next,k.next=x),O.pending=x,x=li(v),Nc(v,null,$),x}return ii(v,O,x,$),li(v)}function Ro(v,x,$){if(x=x.updateQueue,x!==null&&(x=x.shared,($&4194048)!==0)){var O=x.lanes;O&=v.pendingLanes,$|=O,x.lanes=$,it(v,$)}}function Pl(v,x){var $=v.updateQueue,O=v.alternate;if(O!==null&&(O=O.updateQueue,$===O)){var k=null,H=null;if($=$.firstBaseUpdate,$!==null){do{var oe={lane:$.lane,tag:$.tag,payload:$.payload,callback:null,next:null};H===null?k=H=oe:H=H.next=oe,$=$.next}while($!==null);H===null?k=H=x:H=H.next=x}else k=H=x;$={baseState:O.baseState,firstBaseUpdate:k,lastBaseUpdate:H,shared:O.shared,callbacks:O.callbacks},v.updateQueue=$;return}v=$.lastBaseUpdate,v===null?$.firstBaseUpdate=x:v.next=x,$.lastBaseUpdate=x}var kl=!1;function To(){if(kl){var v=Ua;if(v!==null)throw v}}function _o(v,x,$,O){kl=!1;var k=v.updateQueue;Xn=!1;var H=k.firstBaseUpdate,oe=k.lastBaseUpdate,se=k.shared.pending;if(se!==null){k.shared.pending=null;var Se=se,ze=Se.next;Se.next=null,oe===null?H=ze:oe.next=ze,oe=Se;var Xe=v.alternate;Xe!==null&&(Xe=Xe.updateQueue,se=Xe.lastBaseUpdate,se!==oe&&(se===null?Xe.firstBaseUpdate=ze:se.next=ze,Xe.lastBaseUpdate=Se))}if(H!==null){var Qe=k.baseState;oe=0,Xe=ze=Se=null,se=H;do{var Fe=se.lane&-536870913,He=Fe!==se.lane;if(He?(ir&Fe)===Fe:(O&Fe)===Fe){Fe!==0&&Fe===Va&&(kl=!0),Xe!==null&&(Xe=Xe.next={lane:0,tag:se.tag,payload:se.payload,callback:null,next:null});e:{var Ht=v,Lt=se;Fe=x;var gr=$;switch(Lt.tag){case 1:if(Ht=Lt.payload,typeof Ht=="function"){Qe=Ht.call(gr,Qe,Fe);break e}Qe=Ht;break e;case 3:Ht.flags=Ht.flags&-65537|128;case 0:if(Ht=Lt.payload,Fe=typeof Ht=="function"?Ht.call(gr,Qe,Fe):Ht,Fe==null)break e;Qe=C({},Qe,Fe);break e;case 2:Xn=!0}}Fe=se.callback,Fe!==null&&(v.flags|=64,He&&(v.flags|=8192),He=k.callbacks,He===null?k.callbacks=[Fe]:He.push(Fe))}else He={lane:Fe,tag:se.tag,payload:se.payload,callback:se.callback,next:null},Xe===null?(ze=Xe=He,Se=Qe):Xe=Xe.next=He,oe|=Fe;if(se=se.next,se===null){if(se=k.shared.pending,se===null)break;He=se,se=He.next,He.next=null,k.lastBaseUpdate=He,k.shared.pending=null}}while(!0);Xe===null&&(Se=Qe),k.baseState=Se,k.firstBaseUpdate=ze,k.lastBaseUpdate=Xe,H===null&&(k.shared.lanes=0),oa|=oe,v.lanes=oe,v.memoizedState=Qe}}function Wc(v,x){if(typeof v!="function")throw Error(d(191,v));v.call(x)}function Gc(v,x){var $=v.callbacks;if($!==null)for(v.callbacks=null,v=0;v<$.length;v++)Wc($[v],x)}var Ka=ne(null),gi=ne(0);function Xc(v,x){v=qn,ee(gi,v),ee(Ka,x),qn=v|x.baseLanes}function zl(){ee(gi,qn),ee(Ka,Ka.current)}function Dl(){qn=gi.current,le(Ka),le(gi)}var Qn=0,Yt=null,pr=null,Br=null,vi=!1,qa=!1,_a=!1,yi=0,Oo=0,Wa=null,ym=0;function zr(){throw Error(d(321))}function jl(v,x){if(x===null)return!1;for(var $=0;$<x.length&&$<v.length;$++)if(!cn(v[$],x[$]))return!1;return!0}function Ll(v,x,$,O,k,H){return Qn=H,Yt=x,x.memoizedState=null,x.updateQueue=null,x.lanes=0,W.H=v===null||v.memoizedState===null?Iu:Au,_a=!1,H=$(O,k),_a=!1,qa&&(H=Zc(x,$,O,k)),Yc(v),H}function Yc(v){W.H=wi;var x=pr!==null&&pr.next!==null;if(Qn=0,Br=pr=Yt=null,vi=!1,Oo=0,Wa=null,x)throw Error(d(300));v===null||Kr||(v=v.dependencies,v!==null&&di(v)&&(Kr=!0))}function Zc(v,x,$,O){Yt=v;var k=0;do{if(qa&&(Wa=null),Oo=0,qa=!1,25<=k)throw Error(d(301));if(k+=1,Br=pr=null,v.updateQueue!=null){var H=v.updateQueue;H.lastEffect=null,H.events=null,H.stores=null,H.memoCache!=null&&(H.memoCache.index=0)}W.H=$m,H=x($,O)}while(qa);return H}function bm(){var v=W.H,x=v.useState()[0];return x=typeof x.then=="function"?Mo(x):x,v=v.useState()[0],(pr!==null?pr.memoizedState:null)!==v&&(Yt.flags|=1024),x}function Bl(){var v=yi!==0;return yi=0,v}function Fl(v,x,$){x.updateQueue=v.updateQueue,x.flags&=-2053,v.lanes&=~$}function Hl(v){if(vi){for(v=v.memoizedState;v!==null;){var x=v.queue;x!==null&&(x.pending=null),v=v.next}vi=!1}Qn=0,Br=pr=Yt=null,qa=!1,Oo=yi=0,Wa=null}function on(){var v={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Br===null?Yt.memoizedState=Br=v:Br=Br.next=v,Br}function Fr(){if(pr===null){var v=Yt.alternate;v=v!==null?v.memoizedState:null}else v=pr.next;var x=Br===null?Yt.memoizedState:Br.next;if(x!==null)Br=x,pr=v;else{if(v===null)throw Yt.alternate===null?Error(d(467)):Error(d(310));pr=v,v={memoizedState:pr.memoizedState,baseState:pr.baseState,baseQueue:pr.baseQueue,queue:pr.queue,next:null},Br===null?Yt.memoizedState=Br=v:Br=Br.next=v}return Br}function Vl(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Mo(v){var x=Oo;return Oo+=1,Wa===null&&(Wa=[]),v=Uc(Wa,v,x),x=Yt,(Br===null?x.memoizedState:Br.next)===null&&(x=x.alternate,W.H=x===null||x.memoizedState===null?Iu:Au),v}function bi(v){if(v!==null&&typeof v=="object"){if(typeof v.then=="function")return Mo(v);if(v.$$typeof===z)return Qr(v)}throw Error(d(438,String(v)))}function Ul(v){var x=null,$=Yt.updateQueue;if($!==null&&(x=$.memoCache),x==null){var O=Yt.alternate;O!==null&&(O=O.updateQueue,O!==null&&(O=O.memoCache,O!=null&&(x={data:O.data.map(function(k){return k.slice()}),index:0})))}if(x==null&&(x={data:[],index:0}),$===null&&($=Vl(),Yt.updateQueue=$),$.memoCache=x,$=x.data[x.index],$===void 0)for($=x.data[x.index]=Array(v),O=0;O<v;O++)$[O]=K;return x.index++,$}function Bn(v,x){return typeof x=="function"?x(v):x}function xi(v){var x=Fr();return Kl(x,pr,v)}function Kl(v,x,$){var O=v.queue;if(O===null)throw Error(d(311));O.lastRenderedReducer=$;var k=v.baseQueue,H=O.pending;if(H!==null){if(k!==null){var oe=k.next;k.next=H.next,H.next=oe}x.baseQueue=k=H,O.pending=null}if(H=v.baseState,k===null)v.memoizedState=H;else{x=k.next;var se=oe=null,Se=null,ze=x,Xe=!1;do{var Qe=ze.lane&-536870913;if(Qe!==ze.lane?(ir&Qe)===Qe:(Qn&Qe)===Qe){var Fe=ze.revertLane;if(Fe===0)Se!==null&&(Se=Se.next={lane:0,revertLane:0,action:ze.action,hasEagerState:ze.hasEagerState,eagerState:ze.eagerState,next:null}),Qe===Va&&(Xe=!0);else if((Qn&Fe)===Fe){ze=ze.next,Fe===Va&&(Xe=!0);continue}else Qe={lane:0,revertLane:ze.revertLane,action:ze.action,hasEagerState:ze.hasEagerState,eagerState:ze.eagerState,next:null},Se===null?(se=Se=Qe,oe=H):Se=Se.next=Qe,Yt.lanes|=Fe,oa|=Fe;Qe=ze.action,_a&&$(H,Qe),H=ze.hasEagerState?ze.eagerState:$(H,Qe)}else Fe={lane:Qe,revertLane:ze.revertLane,action:ze.action,hasEagerState:ze.hasEagerState,eagerState:ze.eagerState,next:null},Se===null?(se=Se=Fe,oe=H):Se=Se.next=Fe,Yt.lanes|=Qe,oa|=Qe;ze=ze.next}while(ze!==null&&ze!==x);if(Se===null?oe=H:Se.next=se,!cn(H,v.memoizedState)&&(Kr=!0,Xe&&($=Ua,$!==null)))throw $;v.memoizedState=H,v.baseState=oe,v.baseQueue=Se,O.lastRenderedState=H}return k===null&&(O.lanes=0),[v.memoizedState,O.dispatch]}function ql(v){var x=Fr(),$=x.queue;if($===null)throw Error(d(311));$.lastRenderedReducer=v;var O=$.dispatch,k=$.pending,H=x.memoizedState;if(k!==null){$.pending=null;var oe=k=k.next;do H=v(H,oe.action),oe=oe.next;while(oe!==k);cn(H,x.memoizedState)||(Kr=!0),x.memoizedState=H,x.baseQueue===null&&(x.baseState=H),$.lastRenderedState=H}return[H,O]}function Qc(v,x,$){var O=Yt,k=Fr(),H=cr;if(H){if($===void 0)throw Error(d(407));$=$()}else $=x();var oe=!cn((pr||k).memoizedState,$);oe&&(k.memoizedState=$,Kr=!0),k=k.queue;var se=tu.bind(null,O,k,v);if(No(2048,8,se,[v]),k.getSnapshot!==x||oe||Br!==null&&Br.memoizedState.tag&1){if(O.flags|=2048,Ga(9,Si(),eu.bind(null,O,k,$,x),null),Cr===null)throw Error(d(349));H||(Qn&124)!==0||Jc(O,x,$)}return $}function Jc(v,x,$){v.flags|=16384,v={getSnapshot:x,value:$},x=Yt.updateQueue,x===null?(x=Vl(),Yt.updateQueue=x,x.stores=[v]):($=x.stores,$===null?x.stores=[v]:$.push(v))}function eu(v,x,$,O){x.value=$,x.getSnapshot=O,ru(x)&&nu(v)}function tu(v,x,$){return $(function(){ru(x)&&nu(v)})}function ru(v){var x=v.getSnapshot;v=v.value;try{var $=x();return!cn(v,$)}catch{return!0}}function nu(v){var x=La(v,2);x!==null&&hn(x,v,2)}function Wl(v){var x=on();if(typeof v=="function"){var $=v;if(v=$(),_a){Le(!0);try{$()}finally{Le(!1)}}}return x.memoizedState=x.baseState=v,x.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Bn,lastRenderedState:v},x}function au(v,x,$,O){return v.baseState=$,Kl(v,pr,typeof O=="function"?O:Bn)}function xm(v,x,$,O,k){if(Ci(v))throw Error(d(485));if(v=x.action,v!==null){var H={payload:k,action:v,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(oe){H.listeners.push(oe)}};W.T!==null?$(!0):H.isTransition=!1,O(H),$=x.pending,$===null?(H.next=x.pending=H,ou(x,H)):(H.next=$.next,x.pending=$.next=H)}}function ou(v,x){var $=x.action,O=x.payload,k=v.state;if(x.isTransition){var H=W.T,oe={};W.T=oe;try{var se=$(k,O),Se=W.S;Se!==null&&Se(oe,se),iu(v,x,se)}catch(ze){Gl(v,x,ze)}finally{W.T=H}}else try{H=$(k,O),iu(v,x,H)}catch(ze){Gl(v,x,ze)}}function iu(v,x,$){$!==null&&typeof $=="object"&&typeof $.then=="function"?$.then(function(O){lu(v,x,O)},function(O){return Gl(v,x,O)}):lu(v,x,$)}function lu(v,x,$){x.status="fulfilled",x.value=$,su(x),v.state=$,x=v.pending,x!==null&&($=x.next,$===x?v.pending=null:($=$.next,x.next=$,ou(v,$)))}function Gl(v,x,$){var O=v.pending;if(v.pending=null,O!==null){O=O.next;do x.status="rejected",x.reason=$,su(x),x=x.next;while(x!==O)}v.action=null}function su(v){v=v.listeners;for(var x=0;x<v.length;x++)(0,v[x])()}function cu(v,x){return x}function uu(v,x){if(cr){var $=Cr.formState;if($!==null){e:{var O=Yt;if(cr){if(Ar){t:{for(var k=Ar,H=Tn;k.nodeType!==8;){if(!H){k=null;break t}if(k=Rn(k.nextSibling),k===null){k=null;break t}}H=k.data,k=H==="F!"||H==="F"?k:null}if(k){Ar=Rn(k.nextSibling),O=k.data==="F!";break e}}wa(O)}O=!1}O&&(x=$[0])}}return $=on(),$.memoizedState=$.baseState=x,O={pending:null,lanes:0,dispatch:null,lastRenderedReducer:cu,lastRenderedState:x},$.queue=O,$=Ou.bind(null,Yt,O),O.dispatch=$,O=Wl(!1),H=Jl.bind(null,Yt,!1,O.queue),O=on(),k={state:x,dispatch:null,action:v,pending:null},O.queue=k,$=xm.bind(null,Yt,k,H,$),k.dispatch=$,O.memoizedState=v,[x,$,!1]}function du(v){var x=Fr();return fu(x,pr,v)}function fu(v,x,$){if(x=Kl(v,x,cu)[0],v=xi(Bn)[0],typeof x=="object"&&x!==null&&typeof x.then=="function")try{var O=Mo(x)}catch(oe){throw oe===wo?pi:oe}else O=x;x=Fr();var k=x.queue,H=k.dispatch;return $!==x.memoizedState&&(Yt.flags|=2048,Ga(9,Si(),Sm.bind(null,k,$),null)),[O,H,v]}function Sm(v,x){v.action=x}function mu(v){var x=Fr(),$=pr;if($!==null)return fu(x,$,v);Fr(),x=x.memoizedState,$=Fr();var O=$.queue.dispatch;return $.memoizedState=v,[x,O,!1]}function Ga(v,x,$,O){return v={tag:v,create:$,deps:O,inst:x,next:null},x=Yt.updateQueue,x===null&&(x=Vl(),Yt.updateQueue=x),$=x.lastEffect,$===null?x.lastEffect=v.next=v:(O=$.next,$.next=v,v.next=O,x.lastEffect=v),v}function Si(){return{destroy:void 0,resource:void 0}}function pu(){return Fr().memoizedState}function Ei(v,x,$,O){var k=on();O=O===void 0?null:O,Yt.flags|=v,k.memoizedState=Ga(1|x,Si(),$,O)}function No(v,x,$,O){var k=Fr();O=O===void 0?null:O;var H=k.memoizedState.inst;pr!==null&&O!==null&&jl(O,pr.memoizedState.deps)?k.memoizedState=Ga(x,H,$,O):(Yt.flags|=v,k.memoizedState=Ga(1|x,H,$,O))}function hu(v,x){Ei(8390656,8,v,x)}function gu(v,x){No(2048,8,v,x)}function vu(v,x){return No(4,2,v,x)}function yu(v,x){return No(4,4,v,x)}function bu(v,x){if(typeof x=="function"){v=v();var $=x(v);return function(){typeof $=="function"?$():x(null)}}if(x!=null)return v=v(),x.current=v,function(){x.current=null}}function xu(v,x,$){$=$!=null?$.concat([v]):null,No(4,4,bu.bind(null,x,v),$)}function Xl(){}function Su(v,x){var $=Fr();x=x===void 0?null:x;var O=$.memoizedState;return x!==null&&jl(x,O[1])?O[0]:($.memoizedState=[v,x],v)}function Eu(v,x){var $=Fr();x=x===void 0?null:x;var O=$.memoizedState;if(x!==null&&jl(x,O[1]))return O[0];if(O=v(),_a){Le(!0);try{v()}finally{Le(!1)}}return $.memoizedState=[O,x],O}function Yl(v,x,$){return $===void 0||(Qn&1073741824)!==0?v.memoizedState=x:(v.memoizedState=$,v=$d(),Yt.lanes|=v,oa|=v,$)}function Cu(v,x,$,O){return cn($,x)?$:Ka.current!==null?(v=Yl(v,$,O),cn(v,x)||(Kr=!0),v):(Qn&42)===0?(Kr=!0,v.memoizedState=$):(v=$d(),Yt.lanes|=v,oa|=v,x)}function wu(v,x,$,O,k){var H=G.p;G.p=H!==0&&8>H?H:8;var oe=W.T,se={};W.T=se,Jl(v,!1,x,$);try{var Se=k(),ze=W.S;if(ze!==null&&ze(se,Se),Se!==null&&typeof Se=="object"&&typeof Se.then=="function"){var Xe=vm(Se,O);Io(v,x,Xe,pn(v))}else Io(v,x,O,pn(v))}catch(Qe){Io(v,x,{then:function(){},status:"rejected",reason:Qe},pn())}finally{G.p=H,W.T=oe}}function Em(){}function Zl(v,x,$,O){if(v.tag!==5)throw Error(d(476));var k=$u(v).queue;wu(v,k,x,te,$===null?Em:function(){return Ru(v),$(O)})}function $u(v){var x=v.memoizedState;if(x!==null)return x;x={memoizedState:te,baseState:te,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Bn,lastRenderedState:te},next:null};var $={};return x.next={memoizedState:$,baseState:$,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:Bn,lastRenderedState:$},next:null},v.memoizedState=x,v=v.alternate,v!==null&&(v.memoizedState=x),x}function Ru(v){var x=$u(v).next.queue;Io(v,x,{},pn())}function Ql(){return Qr(Yo)}function Tu(){return Fr().memoizedState}function _u(){return Fr().memoizedState}function Cm(v){for(var x=v.return;x!==null;){switch(x.tag){case 24:case 3:var $=pn();v=Yn($);var O=Zn(x,v,$);O!==null&&(hn(O,x,$),Ro(O,x,$)),x={cache:_l()},v.payload=x;return}x=x.return}}function wm(v,x,$){var O=pn();$={lane:O,revertLane:0,action:$,hasEagerState:!1,eagerState:null,next:null},Ci(v)?Mu(x,$):($=yl(v,x,$,O),$!==null&&(hn($,v,O),Nu($,x,O)))}function Ou(v,x,$){var O=pn();Io(v,x,$,O)}function Io(v,x,$,O){var k={lane:O,revertLane:0,action:$,hasEagerState:!1,eagerState:null,next:null};if(Ci(v))Mu(x,k);else{var H=v.alternate;if(v.lanes===0&&(H===null||H.lanes===0)&&(H=x.lastRenderedReducer,H!==null))try{var oe=x.lastRenderedState,se=H(oe,$);if(k.hasEagerState=!0,k.eagerState=se,cn(se,oe))return ii(v,x,k,0),Cr===null&&oi(),!1}catch{}finally{}if($=yl(v,x,k,O),$!==null)return hn($,v,O),Nu($,x,O),!0}return!1}function Jl(v,x,$,O){if(O={lane:2,revertLane:Is(),action:O,hasEagerState:!1,eagerState:null,next:null},Ci(v)){if(x)throw Error(d(479))}else x=yl(v,$,O,2),x!==null&&hn(x,v,2)}function Ci(v){var x=v.alternate;return v===Yt||x!==null&&x===Yt}function Mu(v,x){qa=vi=!0;var $=v.pending;$===null?x.next=x:(x.next=$.next,$.next=x),v.pending=x}function Nu(v,x,$){if(($&4194048)!==0){var O=x.lanes;O&=v.pendingLanes,$|=O,x.lanes=$,it(v,$)}}var wi={readContext:Qr,use:bi,useCallback:zr,useContext:zr,useEffect:zr,useImperativeHandle:zr,useLayoutEffect:zr,useInsertionEffect:zr,useMemo:zr,useReducer:zr,useRef:zr,useState:zr,useDebugValue:zr,useDeferredValue:zr,useTransition:zr,useSyncExternalStore:zr,useId:zr,useHostTransitionStatus:zr,useFormState:zr,useActionState:zr,useOptimistic:zr,useMemoCache:zr,useCacheRefresh:zr},Iu={readContext:Qr,use:bi,useCallback:function(v,x){return on().memoizedState=[v,x===void 0?null:x],v},useContext:Qr,useEffect:hu,useImperativeHandle:function(v,x,$){$=$!=null?$.concat([v]):null,Ei(4194308,4,bu.bind(null,x,v),$)},useLayoutEffect:function(v,x){return Ei(4194308,4,v,x)},useInsertionEffect:function(v,x){Ei(4,2,v,x)},useMemo:function(v,x){var $=on();x=x===void 0?null:x;var O=v();if(_a){Le(!0);try{v()}finally{Le(!1)}}return $.memoizedState=[O,x],O},useReducer:function(v,x,$){var O=on();if($!==void 0){var k=$(x);if(_a){Le(!0);try{$(x)}finally{Le(!1)}}}else k=x;return O.memoizedState=O.baseState=k,v={pending:null,lanes:0,dispatch:null,lastRenderedReducer:v,lastRenderedState:k},O.queue=v,v=v.dispatch=wm.bind(null,Yt,v),[O.memoizedState,v]},useRef:function(v){var x=on();return v={current:v},x.memoizedState=v},useState:function(v){v=Wl(v);var x=v.queue,$=Ou.bind(null,Yt,x);return x.dispatch=$,[v.memoizedState,$]},useDebugValue:Xl,useDeferredValue:function(v,x){var $=on();return Yl($,v,x)},useTransition:function(){var v=Wl(!1);return v=wu.bind(null,Yt,v.queue,!0,!1),on().memoizedState=v,[!1,v]},useSyncExternalStore:function(v,x,$){var O=Yt,k=on();if(cr){if($===void 0)throw Error(d(407));$=$()}else{if($=x(),Cr===null)throw Error(d(349));(ir&124)!==0||Jc(O,x,$)}k.memoizedState=$;var H={value:$,getSnapshot:x};return k.queue=H,hu(tu.bind(null,O,H,v),[v]),O.flags|=2048,Ga(9,Si(),eu.bind(null,O,H,$,x),null),$},useId:function(){var v=on(),x=Cr.identifierPrefix;if(cr){var $=Dn,O=zn;$=(O&~(1<<32-Oe(O)-1)).toString(32)+$,x="«"+x+"R"+$,$=yi++,0<$&&(x+="H"+$.toString(32)),x+="»"}else $=ym++,x="«"+x+"r"+$.toString(32)+"»";return v.memoizedState=x},useHostTransitionStatus:Ql,useFormState:uu,useActionState:uu,useOptimistic:function(v){var x=on();x.memoizedState=x.baseState=v;var $={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return x.queue=$,x=Jl.bind(null,Yt,!0,$),$.dispatch=x,[v,x]},useMemoCache:Ul,useCacheRefresh:function(){return on().memoizedState=Cm.bind(null,Yt)}},Au={readContext:Qr,use:bi,useCallback:Su,useContext:Qr,useEffect:gu,useImperativeHandle:xu,useInsertionEffect:vu,useLayoutEffect:yu,useMemo:Eu,useReducer:xi,useRef:pu,useState:function(){return xi(Bn)},useDebugValue:Xl,useDeferredValue:function(v,x){var $=Fr();return Cu($,pr.memoizedState,v,x)},useTransition:function(){var v=xi(Bn)[0],x=Fr().memoizedState;return[typeof v=="boolean"?v:Mo(v),x]},useSyncExternalStore:Qc,useId:Tu,useHostTransitionStatus:Ql,useFormState:du,useActionState:du,useOptimistic:function(v,x){var $=Fr();return au($,pr,v,x)},useMemoCache:Ul,useCacheRefresh:_u},$m={readContext:Qr,use:bi,useCallback:Su,useContext:Qr,useEffect:gu,useImperativeHandle:xu,useInsertionEffect:vu,useLayoutEffect:yu,useMemo:Eu,useReducer:ql,useRef:pu,useState:function(){return ql(Bn)},useDebugValue:Xl,useDeferredValue:function(v,x){var $=Fr();return pr===null?Yl($,v,x):Cu($,pr.memoizedState,v,x)},useTransition:function(){var v=ql(Bn)[0],x=Fr().memoizedState;return[typeof v=="boolean"?v:Mo(v),x]},useSyncExternalStore:Qc,useId:Tu,useHostTransitionStatus:Ql,useFormState:mu,useActionState:mu,useOptimistic:function(v,x){var $=Fr();return pr!==null?au($,pr,v,x):($.baseState=v,[v,$.queue.dispatch])},useMemoCache:Ul,useCacheRefresh:_u},Xa=null,Ao=0;function $i(v){var x=Ao;return Ao+=1,Xa===null&&(Xa=[]),Uc(Xa,v,x)}function Po(v,x){x=x.props.ref,v.ref=x!==void 0?x:null}function Ri(v,x){throw x.$$typeof===w?Error(d(525)):(v=Object.prototype.toString.call(x),Error(d(31,v==="[object Object]"?"object with keys {"+Object.keys(x).join(", ")+"}":v)))}function Pu(v){var x=v._init;return x(v._payload)}function ku(v){function x(Me,$e){if(v){var Ie=Me.deletions;Ie===null?(Me.deletions=[$e],Me.flags|=16):Ie.push($e)}}function $(Me,$e){if(!v)return null;for(;$e!==null;)x(Me,$e),$e=$e.sibling;return null}function O(Me){for(var $e=new Map;Me!==null;)Me.key!==null?$e.set(Me.key,Me):$e.set(Me.index,Me),Me=Me.sibling;return $e}function k(Me,$e){return Me=kn(Me,$e),Me.index=0,Me.sibling=null,Me}function H(Me,$e,Ie){return Me.index=Ie,v?(Ie=Me.alternate,Ie!==null?(Ie=Ie.index,Ie<$e?(Me.flags|=67108866,$e):Ie):(Me.flags|=67108866,$e)):(Me.flags|=1048576,$e)}function oe(Me){return v&&Me.alternate===null&&(Me.flags|=67108866),Me}function se(Me,$e,Ie,Ye){return $e===null||$e.tag!==6?($e=xl(Ie,Me.mode,Ye),$e.return=Me,$e):($e=k($e,Ie),$e.return=Me,$e)}function Se(Me,$e,Ie,Ye){var Mt=Ie.type;return Mt===M?Xe(Me,$e,Ie.props.children,Ye,Ie.key):$e!==null&&($e.elementType===Mt||typeof Mt=="object"&&Mt!==null&&Mt.$$typeof===q&&Pu(Mt)===$e.type)?($e=k($e,Ie.props),Po($e,Ie),$e.return=Me,$e):($e=si(Ie.type,Ie.key,Ie.props,null,Me.mode,Ye),Po($e,Ie),$e.return=Me,$e)}function ze(Me,$e,Ie,Ye){return $e===null||$e.tag!==4||$e.stateNode.containerInfo!==Ie.containerInfo||$e.stateNode.implementation!==Ie.implementation?($e=Sl(Ie,Me.mode,Ye),$e.return=Me,$e):($e=k($e,Ie.children||[]),$e.return=Me,$e)}function Xe(Me,$e,Ie,Ye,Mt){return $e===null||$e.tag!==7?($e=xa(Ie,Me.mode,Ye,Mt),$e.return=Me,$e):($e=k($e,Ie),$e.return=Me,$e)}function Qe(Me,$e,Ie){if(typeof $e=="string"&&$e!==""||typeof $e=="number"||typeof $e=="bigint")return $e=xl(""+$e,Me.mode,Ie),$e.return=Me,$e;if(typeof $e=="object"&&$e!==null){switch($e.$$typeof){case R:return Ie=si($e.type,$e.key,$e.props,null,Me.mode,Ie),Po(Ie,$e),Ie.return=Me,Ie;case _:return $e=Sl($e,Me.mode,Ie),$e.return=Me,$e;case q:var Ye=$e._init;return $e=Ye($e._payload),Qe(Me,$e,Ie)}if(J($e)||Q($e))return $e=xa($e,Me.mode,Ie,null),$e.return=Me,$e;if(typeof $e.then=="function")return Qe(Me,$i($e),Ie);if($e.$$typeof===z)return Qe(Me,fi(Me,$e),Ie);Ri(Me,$e)}return null}function Fe(Me,$e,Ie,Ye){var Mt=$e!==null?$e.key:null;if(typeof Ie=="string"&&Ie!==""||typeof Ie=="number"||typeof Ie=="bigint")return Mt!==null?null:se(Me,$e,""+Ie,Ye);if(typeof Ie=="object"&&Ie!==null){switch(Ie.$$typeof){case R:return Ie.key===Mt?Se(Me,$e,Ie,Ye):null;case _:return Ie.key===Mt?ze(Me,$e,Ie,Ye):null;case q:return Mt=Ie._init,Ie=Mt(Ie._payload),Fe(Me,$e,Ie,Ye)}if(J(Ie)||Q(Ie))return Mt!==null?null:Xe(Me,$e,Ie,Ye,null);if(typeof Ie.then=="function")return Fe(Me,$e,$i(Ie),Ye);if(Ie.$$typeof===z)return Fe(Me,$e,fi(Me,Ie),Ye);Ri(Me,Ie)}return null}function He(Me,$e,Ie,Ye,Mt){if(typeof Ye=="string"&&Ye!==""||typeof Ye=="number"||typeof Ye=="bigint")return Me=Me.get(Ie)||null,se($e,Me,""+Ye,Mt);if(typeof Ye=="object"&&Ye!==null){switch(Ye.$$typeof){case R:return Me=Me.get(Ye.key===null?Ie:Ye.key)||null,Se($e,Me,Ye,Mt);case _:return Me=Me.get(Ye.key===null?Ie:Ye.key)||null,ze($e,Me,Ye,Mt);case q:var Jt=Ye._init;return Ye=Jt(Ye._payload),He(Me,$e,Ie,Ye,Mt)}if(J(Ye)||Q(Ye))return Me=Me.get(Ie)||null,Xe($e,Me,Ye,Mt,null);if(typeof Ye.then=="function")return He(Me,$e,Ie,$i(Ye),Mt);if(Ye.$$typeof===z)return He(Me,$e,Ie,fi($e,Ye),Mt);Ri($e,Ye)}return null}function Ht(Me,$e,Ie,Ye){for(var Mt=null,Jt=null,At=$e,Ft=$e=0,Wr=null;At!==null&&Ft<Ie.length;Ft++){At.index>Ft?(Wr=At,At=null):Wr=At.sibling;var sr=Fe(Me,At,Ie[Ft],Ye);if(sr===null){At===null&&(At=Wr);break}v&&At&&sr.alternate===null&&x(Me,At),$e=H(sr,$e,Ft),Jt===null?Mt=sr:Jt.sibling=sr,Jt=sr,At=Wr}if(Ft===Ie.length)return $(Me,At),cr&&Ea(Me,Ft),Mt;if(At===null){for(;Ft<Ie.length;Ft++)At=Qe(Me,Ie[Ft],Ye),At!==null&&($e=H(At,$e,Ft),Jt===null?Mt=At:Jt.sibling=At,Jt=At);return cr&&Ea(Me,Ft),Mt}for(At=O(At);Ft<Ie.length;Ft++)Wr=He(At,Me,Ft,Ie[Ft],Ye),Wr!==null&&(v&&Wr.alternate!==null&&At.delete(Wr.key===null?Ft:Wr.key),$e=H(Wr,$e,Ft),Jt===null?Mt=Wr:Jt.sibling=Wr,Jt=Wr);return v&&At.forEach(function(pa){return x(Me,pa)}),cr&&Ea(Me,Ft),Mt}function Lt(Me,$e,Ie,Ye){if(Ie==null)throw Error(d(151));for(var Mt=null,Jt=null,At=$e,Ft=$e=0,Wr=null,sr=Ie.next();At!==null&&!sr.done;Ft++,sr=Ie.next()){At.index>Ft?(Wr=At,At=null):Wr=At.sibling;var pa=Fe(Me,At,sr.value,Ye);if(pa===null){At===null&&(At=Wr);break}v&&At&&pa.alternate===null&&x(Me,At),$e=H(pa,$e,Ft),Jt===null?Mt=pa:Jt.sibling=pa,Jt=pa,At=Wr}if(sr.done)return $(Me,At),cr&&Ea(Me,Ft),Mt;if(At===null){for(;!sr.done;Ft++,sr=Ie.next())sr=Qe(Me,sr.value,Ye),sr!==null&&($e=H(sr,$e,Ft),Jt===null?Mt=sr:Jt.sibling=sr,Jt=sr);return cr&&Ea(Me,Ft),Mt}for(At=O(At);!sr.done;Ft++,sr=Ie.next())sr=He(At,Me,Ft,sr.value,Ye),sr!==null&&(v&&sr.alternate!==null&&At.delete(sr.key===null?Ft:sr.key),$e=H(sr,$e,Ft),Jt===null?Mt=sr:Jt.sibling=sr,Jt=sr);return v&&At.forEach(function(R0){return x(Me,R0)}),cr&&Ea(Me,Ft),Mt}function gr(Me,$e,Ie,Ye){if(typeof Ie=="object"&&Ie!==null&&Ie.type===M&&Ie.key===null&&(Ie=Ie.props.children),typeof Ie=="object"&&Ie!==null){switch(Ie.$$typeof){case R:e:{for(var Mt=Ie.key;$e!==null;){if($e.key===Mt){if(Mt=Ie.type,Mt===M){if($e.tag===7){$(Me,$e.sibling),Ye=k($e,Ie.props.children),Ye.return=Me,Me=Ye;break e}}else if($e.elementType===Mt||typeof Mt=="object"&&Mt!==null&&Mt.$$typeof===q&&Pu(Mt)===$e.type){$(Me,$e.sibling),Ye=k($e,Ie.props),Po(Ye,Ie),Ye.return=Me,Me=Ye;break e}$(Me,$e);break}else x(Me,$e);$e=$e.sibling}Ie.type===M?(Ye=xa(Ie.props.children,Me.mode,Ye,Ie.key),Ye.return=Me,Me=Ye):(Ye=si(Ie.type,Ie.key,Ie.props,null,Me.mode,Ye),Po(Ye,Ie),Ye.return=Me,Me=Ye)}return oe(Me);case _:e:{for(Mt=Ie.key;$e!==null;){if($e.key===Mt)if($e.tag===4&&$e.stateNode.containerInfo===Ie.containerInfo&&$e.stateNode.implementation===Ie.implementation){$(Me,$e.sibling),Ye=k($e,Ie.children||[]),Ye.return=Me,Me=Ye;break e}else{$(Me,$e);break}else x(Me,$e);$e=$e.sibling}Ye=Sl(Ie,Me.mode,Ye),Ye.return=Me,Me=Ye}return oe(Me);case q:return Mt=Ie._init,Ie=Mt(Ie._payload),gr(Me,$e,Ie,Ye)}if(J(Ie))return Ht(Me,$e,Ie,Ye);if(Q(Ie)){if(Mt=Q(Ie),typeof Mt!="function")throw Error(d(150));return Ie=Mt.call(Ie),Lt(Me,$e,Ie,Ye)}if(typeof Ie.then=="function")return gr(Me,$e,$i(Ie),Ye);if(Ie.$$typeof===z)return gr(Me,$e,fi(Me,Ie),Ye);Ri(Me,Ie)}return typeof Ie=="string"&&Ie!==""||typeof Ie=="number"||typeof Ie=="bigint"?(Ie=""+Ie,$e!==null&&$e.tag===6?($(Me,$e.sibling),Ye=k($e,Ie),Ye.return=Me,Me=Ye):($(Me,$e),Ye=xl(Ie,Me.mode,Ye),Ye.return=Me,Me=Ye),oe(Me)):$(Me,$e)}return function(Me,$e,Ie,Ye){try{Ao=0;var Mt=gr(Me,$e,Ie,Ye);return Xa=null,Mt}catch(At){if(At===wo||At===pi)throw At;var Jt=un(29,At,null,Me.mode);return Jt.lanes=Ye,Jt.return=Me,Jt}finally{}}}var Ya=ku(!0),zu=ku(!1),xn=ne(null),_n=null;function Jn(v){var x=v.alternate;ee(Vr,Vr.current&1),ee(xn,v),_n===null&&(x===null||Ka.current!==null||x.memoizedState!==null)&&(_n=v)}function Du(v){if(v.tag===22){if(ee(Vr,Vr.current),ee(xn,v),_n===null){var x=v.alternate;x!==null&&x.memoizedState!==null&&(_n=v)}}else ea()}function ea(){ee(Vr,Vr.current),ee(xn,xn.current)}function Fn(v){le(xn),_n===v&&(_n=null),le(Vr)}var Vr=ne(0);function Ti(v){for(var x=v;x!==null;){if(x.tag===13){var $=x.memoizedState;if($!==null&&($=$.dehydrated,$===null||$.data==="$?"||Us($)))return x}else if(x.tag===19&&x.memoizedProps.revealOrder!==void 0){if((x.flags&128)!==0)return x}else if(x.child!==null){x.child.return=x,x=x.child;continue}if(x===v)break;for(;x.sibling===null;){if(x.return===null||x.return===v)return null;x=x.return}x.sibling.return=x.return,x=x.sibling}return null}function es(v,x,$,O){x=v.memoizedState,$=$(O,x),$=$==null?x:C({},x,$),v.memoizedState=$,v.lanes===0&&(v.updateQueue.baseState=$)}var ts={enqueueSetState:function(v,x,$){v=v._reactInternals;var O=pn(),k=Yn(O);k.payload=x,$!=null&&(k.callback=$),x=Zn(v,k,O),x!==null&&(hn(x,v,O),Ro(x,v,O))},enqueueReplaceState:function(v,x,$){v=v._reactInternals;var O=pn(),k=Yn(O);k.tag=1,k.payload=x,$!=null&&(k.callback=$),x=Zn(v,k,O),x!==null&&(hn(x,v,O),Ro(x,v,O))},enqueueForceUpdate:function(v,x){v=v._reactInternals;var $=pn(),O=Yn($);O.tag=2,x!=null&&(O.callback=x),x=Zn(v,O,$),x!==null&&(hn(x,v,$),Ro(x,v,$))}};function ju(v,x,$,O,k,H,oe){return v=v.stateNode,typeof v.shouldComponentUpdate=="function"?v.shouldComponentUpdate(O,H,oe):x.prototype&&x.prototype.isPureReactComponent?!go($,O)||!go(k,H):!0}function Lu(v,x,$,O){v=x.state,typeof x.componentWillReceiveProps=="function"&&x.componentWillReceiveProps($,O),typeof x.UNSAFE_componentWillReceiveProps=="function"&&x.UNSAFE_componentWillReceiveProps($,O),x.state!==v&&ts.enqueueReplaceState(x,x.state,null)}function Oa(v,x){var $=x;if("ref"in x){$={};for(var O in x)O!=="ref"&&($[O]=x[O])}if(v=v.defaultProps){$===x&&($=C({},$));for(var k in v)$[k]===void 0&&($[k]=v[k])}return $}var Oi=typeof reportError=="function"?reportError:function(v){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var x=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof v=="object"&&v!==null&&typeof v.message=="string"?String(v.message):String(v),error:v});if(!window.dispatchEvent(x))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",v);return}console.error(v)};function Bu(v){Oi(v)}function Fu(v){console.error(v)}function Hu(v){Oi(v)}function Mi(v,x){try{var $=v.onUncaughtError;$(x.value,{componentStack:x.stack})}catch(O){setTimeout(function(){throw O})}}function Vu(v,x,$){try{var O=v.onCaughtError;O($.value,{componentStack:$.stack,errorBoundary:x.tag===1?x.stateNode:null})}catch(k){setTimeout(function(){throw k})}}function rs(v,x,$){return $=Yn($),$.tag=3,$.payload={element:null},$.callback=function(){Mi(v,x)},$}function Uu(v){return v=Yn(v),v.tag=3,v}function Ku(v,x,$,O){var k=$.type.getDerivedStateFromError;if(typeof k=="function"){var H=O.value;v.payload=function(){return k(H)},v.callback=function(){Vu(x,$,O)}}var oe=$.stateNode;oe!==null&&typeof oe.componentDidCatch=="function"&&(v.callback=function(){Vu(x,$,O),typeof k!="function"&&(ia===null?ia=new Set([this]):ia.add(this));var se=O.stack;this.componentDidCatch(O.value,{componentStack:se!==null?se:""})})}function Rm(v,x,$,O,k){if($.flags|=32768,O!==null&&typeof O=="object"&&typeof O.then=="function"){if(x=$.alternate,x!==null&&So(x,$,k,!0),$=xn.current,$!==null){switch($.tag){case 13:return _n===null?Ts():$.alternate===null&&Pr===0&&(Pr=3),$.flags&=-257,$.flags|=65536,$.lanes=k,O===Nl?$.flags|=16384:(x=$.updateQueue,x===null?$.updateQueue=new Set([O]):x.add(O),Os(v,O,k)),!1;case 22:return $.flags|=65536,O===Nl?$.flags|=16384:(x=$.updateQueue,x===null?(x={transitions:null,markerInstances:null,retryQueue:new Set([O])},$.updateQueue=x):($=x.retryQueue,$===null?x.retryQueue=new Set([O]):$.add(O)),Os(v,O,k)),!1}throw Error(d(435,$.tag))}return Os(v,O,k),Ts(),!1}if(cr)return x=xn.current,x!==null?((x.flags&65536)===0&&(x.flags|=256),x.flags|=65536,x.lanes=k,O!==wl&&(v=Error(d(422),{cause:O}),xo(gn(v,$)))):(O!==wl&&(x=Error(d(423),{cause:O}),xo(gn(x,$))),v=v.current.alternate,v.flags|=65536,k&=-k,v.lanes|=k,O=gn(O,$),k=rs(v.stateNode,O,k),Pl(v,k),Pr!==4&&(Pr=2)),!1;var H=Error(d(520),{cause:O});if(H=gn(H,$),Fo===null?Fo=[H]:Fo.push(H),Pr!==4&&(Pr=2),x===null)return!0;O=gn(O,$),$=x;do{switch($.tag){case 3:return $.flags|=65536,v=k&-k,$.lanes|=v,v=rs($.stateNode,O,v),Pl($,v),!1;case 1:if(x=$.type,H=$.stateNode,($.flags&128)===0&&(typeof x.getDerivedStateFromError=="function"||H!==null&&typeof H.componentDidCatch=="function"&&(ia===null||!ia.has(H))))return $.flags|=65536,k&=-k,$.lanes|=k,k=Uu(k),Ku(k,v,$,O),Pl($,k),!1}$=$.return}while($!==null);return!1}var qu=Error(d(461)),Kr=!1;function Xr(v,x,$,O){x.child=v===null?zu(x,null,$,O):Ya(x,v.child,$,O)}function Wu(v,x,$,O,k){$=$.render;var H=x.ref;if("ref"in O){var oe={};for(var se in O)se!=="ref"&&(oe[se]=O[se])}else oe=O;return Ra(x),O=Ll(v,x,$,oe,H,k),se=Bl(),v!==null&&!Kr?(Fl(v,x,k),Hn(v,x,k)):(cr&&se&&El(x),x.flags|=1,Xr(v,x,O,k),x.child)}function Gu(v,x,$,O,k){if(v===null){var H=$.type;return typeof H=="function"&&!bl(H)&&H.defaultProps===void 0&&$.compare===null?(x.tag=15,x.type=H,Xu(v,x,H,O,k)):(v=si($.type,null,O,x,x.mode,k),v.ref=x.ref,v.return=x,x.child=v)}if(H=v.child,!ds(v,k)){var oe=H.memoizedProps;if($=$.compare,$=$!==null?$:go,$(oe,O)&&v.ref===x.ref)return Hn(v,x,k)}return x.flags|=1,v=kn(H,O),v.ref=x.ref,v.return=x,x.child=v}function Xu(v,x,$,O,k){if(v!==null){var H=v.memoizedProps;if(go(H,O)&&v.ref===x.ref)if(Kr=!1,x.pendingProps=O=H,ds(v,k))(v.flags&131072)!==0&&(Kr=!0);else return x.lanes=v.lanes,Hn(v,x,k)}return ns(v,x,$,O,k)}function Yu(v,x,$){var O=x.pendingProps,k=O.children,H=v!==null?v.memoizedState:null;if(O.mode==="hidden"){if((x.flags&128)!==0){if(O=H!==null?H.baseLanes|$:$,v!==null){for(k=x.child=v.child,H=0;k!==null;)H=H|k.lanes|k.childLanes,k=k.sibling;x.childLanes=H&~O}else x.childLanes=0,x.child=null;return Zu(v,x,O,$)}if(($&536870912)!==0)x.memoizedState={baseLanes:0,cachePool:null},v!==null&&mi(x,H!==null?H.cachePool:null),H!==null?Xc(x,H):zl(),Du(x);else return x.lanes=x.childLanes=536870912,Zu(v,x,H!==null?H.baseLanes|$:$,$)}else H!==null?(mi(x,H.cachePool),Xc(x,H),ea(),x.memoizedState=null):(v!==null&&mi(x,null),zl(),ea());return Xr(v,x,k,$),x.child}function Zu(v,x,$,O){var k=Ml();return k=k===null?null:{parent:Hr._currentValue,pool:k},x.memoizedState={baseLanes:$,cachePool:k},v!==null&&mi(x,null),zl(),Du(x),v!==null&&So(v,x,O,!0),null}function Ni(v,x){var $=x.ref;if($===null)v!==null&&v.ref!==null&&(x.flags|=4194816);else{if(typeof $!="function"&&typeof $!="object")throw Error(d(284));(v===null||v.ref!==$)&&(x.flags|=4194816)}}function ns(v,x,$,O,k){return Ra(x),$=Ll(v,x,$,O,void 0,k),O=Bl(),v!==null&&!Kr?(Fl(v,x,k),Hn(v,x,k)):(cr&&O&&El(x),x.flags|=1,Xr(v,x,$,k),x.child)}function Qu(v,x,$,O,k,H){return Ra(x),x.updateQueue=null,$=Zc(x,O,$,k),Yc(v),O=Bl(),v!==null&&!Kr?(Fl(v,x,H),Hn(v,x,H)):(cr&&O&&El(x),x.flags|=1,Xr(v,x,$,H),x.child)}function Ju(v,x,$,O,k){if(Ra(x),x.stateNode===null){var H=Ba,oe=$.contextType;typeof oe=="object"&&oe!==null&&(H=Qr(oe)),H=new $(O,H),x.memoizedState=H.state!==null&&H.state!==void 0?H.state:null,H.updater=ts,x.stateNode=H,H._reactInternals=x,H=x.stateNode,H.props=O,H.state=x.memoizedState,H.refs={},Il(x),oe=$.contextType,H.context=typeof oe=="object"&&oe!==null?Qr(oe):Ba,H.state=x.memoizedState,oe=$.getDerivedStateFromProps,typeof oe=="function"&&(es(x,$,oe,O),H.state=x.memoizedState),typeof $.getDerivedStateFromProps=="function"||typeof H.getSnapshotBeforeUpdate=="function"||typeof H.UNSAFE_componentWillMount!="function"&&typeof H.componentWillMount!="function"||(oe=H.state,typeof H.componentWillMount=="function"&&H.componentWillMount(),typeof H.UNSAFE_componentWillMount=="function"&&H.UNSAFE_componentWillMount(),oe!==H.state&&ts.enqueueReplaceState(H,H.state,null),_o(x,O,H,k),To(),H.state=x.memoizedState),typeof H.componentDidMount=="function"&&(x.flags|=4194308),O=!0}else if(v===null){H=x.stateNode;var se=x.memoizedProps,Se=Oa($,se);H.props=Se;var ze=H.context,Xe=$.contextType;oe=Ba,typeof Xe=="object"&&Xe!==null&&(oe=Qr(Xe));var Qe=$.getDerivedStateFromProps;Xe=typeof Qe=="function"||typeof H.getSnapshotBeforeUpdate=="function",se=x.pendingProps!==se,Xe||typeof H.UNSAFE_componentWillReceiveProps!="function"&&typeof H.componentWillReceiveProps!="function"||(se||ze!==oe)&&Lu(x,H,O,oe),Xn=!1;var Fe=x.memoizedState;H.state=Fe,_o(x,O,H,k),To(),ze=x.memoizedState,se||Fe!==ze||Xn?(typeof Qe=="function"&&(es(x,$,Qe,O),ze=x.memoizedState),(Se=Xn||ju(x,$,Se,O,Fe,ze,oe))?(Xe||typeof H.UNSAFE_componentWillMount!="function"&&typeof H.componentWillMount!="function"||(typeof H.componentWillMount=="function"&&H.componentWillMount(),typeof H.UNSAFE_componentWillMount=="function"&&H.UNSAFE_componentWillMount()),typeof H.componentDidMount=="function"&&(x.flags|=4194308)):(typeof H.componentDidMount=="function"&&(x.flags|=4194308),x.memoizedProps=O,x.memoizedState=ze),H.props=O,H.state=ze,H.context=oe,O=Se):(typeof H.componentDidMount=="function"&&(x.flags|=4194308),O=!1)}else{H=x.stateNode,Al(v,x),oe=x.memoizedProps,Xe=Oa($,oe),H.props=Xe,Qe=x.pendingProps,Fe=H.context,ze=$.contextType,Se=Ba,typeof ze=="object"&&ze!==null&&(Se=Qr(ze)),se=$.getDerivedStateFromProps,(ze=typeof se=="function"||typeof H.getSnapshotBeforeUpdate=="function")||typeof H.UNSAFE_componentWillReceiveProps!="function"&&typeof H.componentWillReceiveProps!="function"||(oe!==Qe||Fe!==Se)&&Lu(x,H,O,Se),Xn=!1,Fe=x.memoizedState,H.state=Fe,_o(x,O,H,k),To();var He=x.memoizedState;oe!==Qe||Fe!==He||Xn||v!==null&&v.dependencies!==null&&di(v.dependencies)?(typeof se=="function"&&(es(x,$,se,O),He=x.memoizedState),(Xe=Xn||ju(x,$,Xe,O,Fe,He,Se)||v!==null&&v.dependencies!==null&&di(v.dependencies))?(ze||typeof H.UNSAFE_componentWillUpdate!="function"&&typeof H.componentWillUpdate!="function"||(typeof H.componentWillUpdate=="function"&&H.componentWillUpdate(O,He,Se),typeof H.UNSAFE_componentWillUpdate=="function"&&H.UNSAFE_componentWillUpdate(O,He,Se)),typeof H.componentDidUpdate=="function"&&(x.flags|=4),typeof H.getSnapshotBeforeUpdate=="function"&&(x.flags|=1024)):(typeof H.componentDidUpdate!="function"||oe===v.memoizedProps&&Fe===v.memoizedState||(x.flags|=4),typeof H.getSnapshotBeforeUpdate!="function"||oe===v.memoizedProps&&Fe===v.memoizedState||(x.flags|=1024),x.memoizedProps=O,x.memoizedState=He),H.props=O,H.state=He,H.context=Se,O=Xe):(typeof H.componentDidUpdate!="function"||oe===v.memoizedProps&&Fe===v.memoizedState||(x.flags|=4),typeof H.getSnapshotBeforeUpdate!="function"||oe===v.memoizedProps&&Fe===v.memoizedState||(x.flags|=1024),O=!1)}return H=O,Ni(v,x),O=(x.flags&128)!==0,H||O?(H=x.stateNode,$=O&&typeof $.getDerivedStateFromError!="function"?null:H.render(),x.flags|=1,v!==null&&O?(x.child=Ya(x,v.child,null,k),x.child=Ya(x,null,$,k)):Xr(v,x,$,k),x.memoizedState=H.state,v=x.child):v=Hn(v,x,k),v}function ed(v,x,$,O){return bo(),x.flags|=256,Xr(v,x,$,O),x.child}var as={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function os(v){return{baseLanes:v,cachePool:Fc()}}function ls(v,x,$){return v=v!==null?v.childLanes&~$:0,x&&(v|=Sn),v}function td(v,x,$){var O=x.pendingProps,k=!1,H=(x.flags&128)!==0,oe;if((oe=H)||(oe=v!==null&&v.memoizedState===null?!1:(Vr.current&2)!==0),oe&&(k=!0,x.flags&=-129),oe=(x.flags&32)!==0,x.flags&=-33,v===null){if(cr){if(k?Jn(x):ea(),cr){var se=Ar,Se;if(Se=se){e:{for(Se=se,se=Tn;Se.nodeType!==8;){if(!se){se=null;break e}if(Se=Rn(Se.nextSibling),Se===null){se=null;break e}}se=Se}se!==null?(x.memoizedState={dehydrated:se,treeContext:Sa!==null?{id:zn,overflow:Dn}:null,retryLane:536870912,hydrationErrors:null},Se=un(18,null,null,0),Se.stateNode=se,Se.return=x,x.child=Se,nn=x,Ar=null,Se=!0):Se=!1}Se||wa(x)}if(se=x.memoizedState,se!==null&&(se=se.dehydrated,se!==null))return Us(se)?x.lanes=32:x.lanes=536870912,null;Fn(x)}return se=O.children,O=O.fallback,k?(ea(),k=x.mode,se=Ii({mode:"hidden",children:se},k),O=xa(O,k,$,null),se.return=x,O.return=x,se.sibling=O,x.child=se,k=x.child,k.memoizedState=os($),k.childLanes=ls(v,oe,$),x.memoizedState=as,O):(Jn(x),ss(x,se))}if(Se=v.memoizedState,Se!==null&&(se=Se.dehydrated,se!==null)){if(H)x.flags&256?(Jn(x),x.flags&=-257,x=cs(v,x,$)):x.memoizedState!==null?(ea(),x.child=v.child,x.flags|=128,x=null):(ea(),k=O.fallback,se=x.mode,O=Ii({mode:"visible",children:O.children},se),k=xa(k,se,$,null),k.flags|=2,O.return=x,k.return=x,O.sibling=k,x.child=O,Ya(x,v.child,null,$),O=x.child,O.memoizedState=os($),O.childLanes=ls(v,oe,$),x.memoizedState=as,x=k);else if(Jn(x),Us(se)){if(oe=se.nextSibling&&se.nextSibling.dataset,oe)var ze=oe.dgst;oe=ze,O=Error(d(419)),O.stack="",O.digest=oe,xo({value:O,source:null,stack:null}),x=cs(v,x,$)}else if(Kr||So(v,x,$,!1),oe=($&v.childLanes)!==0,Kr||oe){if(oe=Cr,oe!==null&&(O=$&-$,O=(O&42)!==0?1:vt(O),O=(O&(oe.suspendedLanes|$))!==0?0:O,O!==0&&O!==Se.retryLane))throw Se.retryLane=O,La(v,O),hn(oe,v,O),qu;se.data==="$?"||Ts(),x=cs(v,x,$)}else se.data==="$?"?(x.flags|=192,x.child=v.child,x=null):(v=Se.treeContext,Ar=Rn(se.nextSibling),nn=x,cr=!0,Ca=null,Tn=!1,v!==null&&(yn[bn++]=zn,yn[bn++]=Dn,yn[bn++]=Sa,zn=v.id,Dn=v.overflow,Sa=x),x=ss(x,O.children),x.flags|=4096);return x}return k?(ea(),k=O.fallback,se=x.mode,Se=v.child,ze=Se.sibling,O=kn(Se,{mode:"hidden",children:O.children}),O.subtreeFlags=Se.subtreeFlags&65011712,ze!==null?k=kn(ze,k):(k=xa(k,se,$,null),k.flags|=2),k.return=x,O.return=x,O.sibling=k,x.child=O,O=k,k=x.child,se=v.child.memoizedState,se===null?se=os($):(Se=se.cachePool,Se!==null?(ze=Hr._currentValue,Se=Se.parent!==ze?{parent:ze,pool:ze}:Se):Se=Fc(),se={baseLanes:se.baseLanes|$,cachePool:Se}),k.memoizedState=se,k.childLanes=ls(v,oe,$),x.memoizedState=as,O):(Jn(x),$=v.child,v=$.sibling,$=kn($,{mode:"visible",children:O.children}),$.return=x,$.sibling=null,v!==null&&(oe=x.deletions,oe===null?(x.deletions=[v],x.flags|=16):oe.push(v)),x.child=$,x.memoizedState=null,$)}function ss(v,x){return x=Ii({mode:"visible",children:x},v.mode),x.return=v,v.child=x}function Ii(v,x){return v=un(22,v,null,x),v.lanes=0,v.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null},v}function cs(v,x,$){return Ya(x,v.child,null,$),v=ss(x,x.pendingProps.children),v.flags|=2,x.memoizedState=null,v}function rd(v,x,$){v.lanes|=x;var O=v.alternate;O!==null&&(O.lanes|=x),Rl(v.return,x,$)}function us(v,x,$,O,k){var H=v.memoizedState;H===null?v.memoizedState={isBackwards:x,rendering:null,renderingStartTime:0,last:O,tail:$,tailMode:k}:(H.isBackwards=x,H.rendering=null,H.renderingStartTime=0,H.last=O,H.tail=$,H.tailMode=k)}function nd(v,x,$){var O=x.pendingProps,k=O.revealOrder,H=O.tail;if(Xr(v,x,O.children,$),O=Vr.current,(O&2)!==0)O=O&1|2,x.flags|=128;else{if(v!==null&&(v.flags&128)!==0)e:for(v=x.child;v!==null;){if(v.tag===13)v.memoizedState!==null&&rd(v,$,x);else if(v.tag===19)rd(v,$,x);else if(v.child!==null){v.child.return=v,v=v.child;continue}if(v===x)break e;for(;v.sibling===null;){if(v.return===null||v.return===x)break e;v=v.return}v.sibling.return=v.return,v=v.sibling}O&=1}switch(ee(Vr,O),k){case"forwards":for($=x.child,k=null;$!==null;)v=$.alternate,v!==null&&Ti(v)===null&&(k=$),$=$.sibling;$=k,$===null?(k=x.child,x.child=null):(k=$.sibling,$.sibling=null),us(x,!1,k,$,H);break;case"backwards":for($=null,k=x.child,x.child=null;k!==null;){if(v=k.alternate,v!==null&&Ti(v)===null){x.child=k;break}v=k.sibling,k.sibling=$,$=k,k=v}us(x,!0,$,null,H);break;case"together":us(x,!1,null,null,void 0);break;default:x.memoizedState=null}return x.child}function Hn(v,x,$){if(v!==null&&(x.dependencies=v.dependencies),oa|=x.lanes,($&x.childLanes)===0)if(v!==null){if(So(v,x,$,!1),($&x.childLanes)===0)return null}else return null;if(v!==null&&x.child!==v.child)throw Error(d(153));if(x.child!==null){for(v=x.child,$=kn(v,v.pendingProps),x.child=$,$.return=x;v.sibling!==null;)v=v.sibling,$=$.sibling=kn(v,v.pendingProps),$.return=x;$.sibling=null}return x.child}function ds(v,x){return(v.lanes&x)!==0?!0:(v=v.dependencies,!!(v!==null&&di(v)))}function Tm(v,x,$){switch(x.tag){case 3:de(x,x.stateNode.containerInfo),Gn(x,Hr,v.memoizedState.cache),bo();break;case 27:case 5:Ce(x);break;case 4:de(x,x.stateNode.containerInfo);break;case 10:Gn(x,x.type,x.memoizedProps.value);break;case 13:var O=x.memoizedState;if(O!==null)return O.dehydrated!==null?(Jn(x),x.flags|=128,null):($&x.child.childLanes)!==0?td(v,x,$):(Jn(x),v=Hn(v,x,$),v!==null?v.sibling:null);Jn(x);break;case 19:var k=(v.flags&128)!==0;if(O=($&x.childLanes)!==0,O||(So(v,x,$,!1),O=($&x.childLanes)!==0),k){if(O)return nd(v,x,$);x.flags|=128}if(k=x.memoizedState,k!==null&&(k.rendering=null,k.tail=null,k.lastEffect=null),ee(Vr,Vr.current),O)break;return null;case 22:case 23:return x.lanes=0,Yu(v,x,$);case 24:Gn(x,Hr,v.memoizedState.cache)}return Hn(v,x,$)}function ad(v,x,$){if(v!==null)if(v.memoizedProps!==x.pendingProps)Kr=!0;else{if(!ds(v,$)&&(x.flags&128)===0)return Kr=!1,Tm(v,x,$);Kr=(v.flags&131072)!==0}else Kr=!1,cr&&(x.flags&1048576)!==0&&Ac(x,ui,x.index);switch(x.lanes=0,x.tag){case 16:e:{v=x.pendingProps;var O=x.elementType,k=O._init;if(O=k(O._payload),x.type=O,typeof O=="function")bl(O)?(v=Oa(O,v),x.tag=1,x=Ju(null,x,O,v,$)):(x.tag=0,x=ns(null,x,O,v,$));else{if(O!=null){if(k=O.$$typeof,k===B){x.tag=11,x=Wu(null,x,O,v,$);break e}else if(k===U){x.tag=14,x=Gu(null,x,O,v,$);break e}}throw x=Z(O)||O,Error(d(306,x,""))}}return x;case 0:return ns(v,x,x.type,x.pendingProps,$);case 1:return O=x.type,k=Oa(O,x.pendingProps),Ju(v,x,O,k,$);case 3:e:{if(de(x,x.stateNode.containerInfo),v===null)throw Error(d(387));O=x.pendingProps;var H=x.memoizedState;k=H.element,Al(v,x),_o(x,O,null,$);var oe=x.memoizedState;if(O=oe.cache,Gn(x,Hr,O),O!==H.cache&&Tl(x,[Hr],$,!0),To(),O=oe.element,H.isDehydrated)if(H={element:O,isDehydrated:!1,cache:oe.cache},x.updateQueue.baseState=H,x.memoizedState=H,x.flags&256){x=ed(v,x,O,$);break e}else if(O!==k){k=gn(Error(d(424)),x),xo(k),x=ed(v,x,O,$);break e}else{switch(v=x.stateNode.containerInfo,v.nodeType){case 9:v=v.body;break;default:v=v.nodeName==="HTML"?v.ownerDocument.body:v}for(Ar=Rn(v.firstChild),nn=x,cr=!0,Ca=null,Tn=!0,$=zu(x,null,O,$),x.child=$;$;)$.flags=$.flags&-3|4096,$=$.sibling}else{if(bo(),O===k){x=Hn(v,x,$);break e}Xr(v,x,O,$)}x=x.child}return x;case 26:return Ni(v,x),v===null?($=cf(x.type,null,x.pendingProps,null))?x.memoizedState=$:cr||($=x.type,v=x.pendingProps,O=qi(ue.current).createElement($),O[mt]=x,O[Ze]=v,Zr(O,$,v),Nt(O),x.stateNode=O):x.memoizedState=cf(x.type,v.memoizedProps,x.pendingProps,v.memoizedState),null;case 27:return Ce(x),v===null&&cr&&(O=x.stateNode=of(x.type,x.pendingProps,ue.current),nn=x,Tn=!0,k=Ar,ca(x.type)?(Ks=k,Ar=Rn(O.firstChild)):Ar=k),Xr(v,x,x.pendingProps.children,$),Ni(v,x),v===null&&(x.flags|=4194304),x.child;case 5:return v===null&&cr&&((k=O=Ar)&&(O=t0(O,x.type,x.pendingProps,Tn),O!==null?(x.stateNode=O,nn=x,Ar=Rn(O.firstChild),Tn=!1,k=!0):k=!1),k||wa(x)),Ce(x),k=x.type,H=x.pendingProps,oe=v!==null?v.memoizedProps:null,O=H.children,Fs(k,H)?O=null:oe!==null&&Fs(k,oe)&&(x.flags|=32),x.memoizedState!==null&&(k=Ll(v,x,bm,null,null,$),Yo._currentValue=k),Ni(v,x),Xr(v,x,O,$),x.child;case 6:return v===null&&cr&&((v=$=Ar)&&($=r0($,x.pendingProps,Tn),$!==null?(x.stateNode=$,nn=x,Ar=null,v=!0):v=!1),v||wa(x)),null;case 13:return td(v,x,$);case 4:return de(x,x.stateNode.containerInfo),O=x.pendingProps,v===null?x.child=Ya(x,null,O,$):Xr(v,x,O,$),x.child;case 11:return Wu(v,x,x.type,x.pendingProps,$);case 7:return Xr(v,x,x.pendingProps,$),x.child;case 8:return Xr(v,x,x.pendingProps.children,$),x.child;case 12:return Xr(v,x,x.pendingProps.children,$),x.child;case 10:return O=x.pendingProps,Gn(x,x.type,O.value),Xr(v,x,O.children,$),x.child;case 9:return k=x.type._context,O=x.pendingProps.children,Ra(x),k=Qr(k),O=O(k),x.flags|=1,Xr(v,x,O,$),x.child;case 14:return Gu(v,x,x.type,x.pendingProps,$);case 15:return Xu(v,x,x.type,x.pendingProps,$);case 19:return nd(v,x,$);case 31:return O=x.pendingProps,$=x.mode,O={mode:O.mode,children:O.children},v===null?($=Ii(O,$),$.ref=x.ref,x.child=$,$.return=x,x=$):($=kn(v.child,O),$.ref=x.ref,x.child=$,$.return=x,x=$),x;case 22:return Yu(v,x,$);case 24:return Ra(x),O=Qr(Hr),v===null?(k=Ml(),k===null&&(k=Cr,H=_l(),k.pooledCache=H,H.refCount++,H!==null&&(k.pooledCacheLanes|=$),k=H),x.memoizedState={parent:O,cache:k},Il(x),Gn(x,Hr,k)):((v.lanes&$)!==0&&(Al(v,x),_o(x,null,null,$),To()),k=v.memoizedState,H=x.memoizedState,k.parent!==O?(k={parent:O,cache:O},x.memoizedState=k,x.lanes===0&&(x.memoizedState=x.updateQueue.baseState=k),Gn(x,Hr,O)):(O=H.cache,Gn(x,Hr,O),O!==k.cache&&Tl(x,[Hr],$,!0))),Xr(v,x,x.pendingProps.children,$),x.child;case 29:throw x.pendingProps}throw Error(d(156,x.tag))}function Vn(v){v.flags|=4}function od(v,x){if(x.type!=="stylesheet"||(x.state.loading&4)!==0)v.flags&=-16777217;else if(v.flags|=16777216,!pf(x)){if(x=xn.current,x!==null&&((ir&4194048)===ir?_n!==null:(ir&62914560)!==ir&&(ir&536870912)===0||x!==_n))throw $o=Nl,Hc;v.flags|=8192}}function Ai(v,x){x!==null&&(v.flags|=4),v.flags&16384&&(x=v.tag!==22?kt():536870912,v.lanes|=x,eo|=x)}function ko(v,x){if(!cr)switch(v.tailMode){case"hidden":x=v.tail;for(var $=null;x!==null;)x.alternate!==null&&($=x),x=x.sibling;$===null?v.tail=null:$.sibling=null;break;case"collapsed":$=v.tail;for(var O=null;$!==null;)$.alternate!==null&&(O=$),$=$.sibling;O===null?x||v.tail===null?v.tail=null:v.tail.sibling=null:O.sibling=null}}function Nr(v){var x=v.alternate!==null&&v.alternate.child===v.child,$=0,O=0;if(x)for(var k=v.child;k!==null;)$|=k.lanes|k.childLanes,O|=k.subtreeFlags&65011712,O|=k.flags&65011712,k.return=v,k=k.sibling;else for(k=v.child;k!==null;)$|=k.lanes|k.childLanes,O|=k.subtreeFlags,O|=k.flags,k.return=v,k=k.sibling;return v.subtreeFlags|=O,v.childLanes=$,x}function _m(v,x,$){var O=x.pendingProps;switch(Cl(x),x.tag){case 31:case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Nr(x),null;case 1:return Nr(x),null;case 3:return $=x.stateNode,O=null,v!==null&&(O=v.memoizedState.cache),x.memoizedState.cache!==O&&(x.flags|=2048),Ln(Hr),ge(),$.pendingContext&&($.context=$.pendingContext,$.pendingContext=null),(v===null||v.child===null)&&(yo(x)?Vn(x):v===null||v.memoizedState.isDehydrated&&(x.flags&256)===0||(x.flags|=1024,zc())),Nr(x),null;case 26:return $=x.memoizedState,v===null?(Vn(x),$!==null?(Nr(x),od(x,$)):(Nr(x),x.flags&=-16777217)):$?$!==v.memoizedState?(Vn(x),Nr(x),od(x,$)):(Nr(x),x.flags&=-16777217):(v.memoizedProps!==O&&Vn(x),Nr(x),x.flags&=-16777217),null;case 27:ve(x),$=ue.current;var k=x.type;if(v!==null&&x.stateNode!=null)v.memoizedProps!==O&&Vn(x);else{if(!O){if(x.stateNode===null)throw Error(d(166));return Nr(x),null}v=ie.current,yo(x)?Pc(x):(v=of(k,O,$),x.stateNode=v,Vn(x))}return Nr(x),null;case 5:if(ve(x),$=x.type,v!==null&&x.stateNode!=null)v.memoizedProps!==O&&Vn(x);else{if(!O){if(x.stateNode===null)throw Error(d(166));return Nr(x),null}if(v=ie.current,yo(x))Pc(x);else{switch(k=qi(ue.current),v){case 1:v=k.createElementNS("http://www.w3.org/2000/svg",$);break;case 2:v=k.createElementNS("http://www.w3.org/1998/Math/MathML",$);break;default:switch($){case"svg":v=k.createElementNS("http://www.w3.org/2000/svg",$);break;case"math":v=k.createElementNS("http://www.w3.org/1998/Math/MathML",$);break;case"script":v=k.createElement("div"),v.innerHTML="<script><\/script>",v=v.removeChild(v.firstChild);break;case"select":v=typeof O.is=="string"?k.createElement("select",{is:O.is}):k.createElement("select"),O.multiple?v.multiple=!0:O.size&&(v.size=O.size);break;default:v=typeof O.is=="string"?k.createElement($,{is:O.is}):k.createElement($)}}v[mt]=x,v[Ze]=O;e:for(k=x.child;k!==null;){if(k.tag===5||k.tag===6)v.appendChild(k.stateNode);else if(k.tag!==4&&k.tag!==27&&k.child!==null){k.child.return=k,k=k.child;continue}if(k===x)break e;for(;k.sibling===null;){if(k.return===null||k.return===x)break e;k=k.return}k.sibling.return=k.return,k=k.sibling}x.stateNode=v;e:switch(Zr(v,$,O),$){case"button":case"input":case"select":case"textarea":v=!!O.autoFocus;break e;case"img":v=!0;break e;default:v=!1}v&&Vn(x)}}return Nr(x),x.flags&=-16777217,null;case 6:if(v&&x.stateNode!=null)v.memoizedProps!==O&&Vn(x);else{if(typeof O!="string"&&x.stateNode===null)throw Error(d(166));if(v=ue.current,yo(x)){if(v=x.stateNode,$=x.memoizedProps,O=null,k=nn,k!==null)switch(k.tag){case 27:case 5:O=k.memoizedProps}v[mt]=x,v=!!(v.nodeValue===$||O!==null&&O.suppressHydrationWarning===!0||Qd(v.nodeValue,$)),v||wa(x)}else v=qi(v).createTextNode(O),v[mt]=x,x.stateNode=v}return Nr(x),null;case 13:if(O=x.memoizedState,v===null||v.memoizedState!==null&&v.memoizedState.dehydrated!==null){if(k=yo(x),O!==null&&O.dehydrated!==null){if(v===null){if(!k)throw Error(d(318));if(k=x.memoizedState,k=k!==null?k.dehydrated:null,!k)throw Error(d(317));k[mt]=x}else bo(),(x.flags&128)===0&&(x.memoizedState=null),x.flags|=4;Nr(x),k=!1}else k=zc(),v!==null&&v.memoizedState!==null&&(v.memoizedState.hydrationErrors=k),k=!0;if(!k)return x.flags&256?(Fn(x),x):(Fn(x),null)}if(Fn(x),(x.flags&128)!==0)return x.lanes=$,x;if($=O!==null,v=v!==null&&v.memoizedState!==null,$){O=x.child,k=null,O.alternate!==null&&O.alternate.memoizedState!==null&&O.alternate.memoizedState.cachePool!==null&&(k=O.alternate.memoizedState.cachePool.pool);var H=null;O.memoizedState!==null&&O.memoizedState.cachePool!==null&&(H=O.memoizedState.cachePool.pool),H!==k&&(O.flags|=2048)}return $!==v&&$&&(x.child.flags|=8192),Ai(x,x.updateQueue),Nr(x),null;case 4:return ge(),v===null&&zs(x.stateNode.containerInfo),Nr(x),null;case 10:return Ln(x.type),Nr(x),null;case 19:if(le(Vr),k=x.memoizedState,k===null)return Nr(x),null;if(O=(x.flags&128)!==0,H=k.rendering,H===null)if(O)ko(k,!1);else{if(Pr!==0||v!==null&&(v.flags&128)!==0)for(v=x.child;v!==null;){if(H=Ti(v),H!==null){for(x.flags|=128,ko(k,!1),v=H.updateQueue,x.updateQueue=v,Ai(x,v),x.subtreeFlags=0,v=$,$=x.child;$!==null;)Ic($,v),$=$.sibling;return ee(Vr,Vr.current&1|2),x.child}v=v.sibling}k.tail!==null&&we()>zi&&(x.flags|=128,O=!0,ko(k,!1),x.lanes=4194304)}else{if(!O)if(v=Ti(H),v!==null){if(x.flags|=128,O=!0,v=v.updateQueue,x.updateQueue=v,Ai(x,v),ko(k,!0),k.tail===null&&k.tailMode==="hidden"&&!H.alternate&&!cr)return Nr(x),null}else 2*we()-k.renderingStartTime>zi&&$!==536870912&&(x.flags|=128,O=!0,ko(k,!1),x.lanes=4194304);k.isBackwards?(H.sibling=x.child,x.child=H):(v=k.last,v!==null?v.sibling=H:x.child=H,k.last=H)}return k.tail!==null?(x=k.tail,k.rendering=x,k.tail=x.sibling,k.renderingStartTime=we(),x.sibling=null,v=Vr.current,ee(Vr,O?v&1|2:v&1),x):(Nr(x),null);case 22:case 23:return Fn(x),Dl(),O=x.memoizedState!==null,v!==null?v.memoizedState!==null!==O&&(x.flags|=8192):O&&(x.flags|=8192),O?($&536870912)!==0&&(x.flags&128)===0&&(Nr(x),x.subtreeFlags&6&&(x.flags|=8192)):Nr(x),$=x.updateQueue,$!==null&&Ai(x,$.retryQueue),$=null,v!==null&&v.memoizedState!==null&&v.memoizedState.cachePool!==null&&($=v.memoizedState.cachePool.pool),O=null,x.memoizedState!==null&&x.memoizedState.cachePool!==null&&(O=x.memoizedState.cachePool.pool),O!==$&&(x.flags|=2048),v!==null&&le(Ta),null;case 24:return $=null,v!==null&&($=v.memoizedState.cache),x.memoizedState.cache!==$&&(x.flags|=2048),Ln(Hr),Nr(x),null;case 25:return null;case 30:return null}throw Error(d(156,x.tag))}function Om(v,x){switch(Cl(x),x.tag){case 1:return v=x.flags,v&65536?(x.flags=v&-65537|128,x):null;case 3:return Ln(Hr),ge(),v=x.flags,(v&65536)!==0&&(v&128)===0?(x.flags=v&-65537|128,x):null;case 26:case 27:case 5:return ve(x),null;case 13:if(Fn(x),v=x.memoizedState,v!==null&&v.dehydrated!==null){if(x.alternate===null)throw Error(d(340));bo()}return v=x.flags,v&65536?(x.flags=v&-65537|128,x):null;case 19:return le(Vr),null;case 4:return ge(),null;case 10:return Ln(x.type),null;case 22:case 23:return Fn(x),Dl(),v!==null&&le(Ta),v=x.flags,v&65536?(x.flags=v&-65537|128,x):null;case 24:return Ln(Hr),null;case 25:return null;default:return null}}function id(v,x){switch(Cl(x),x.tag){case 3:Ln(Hr),ge();break;case 26:case 27:case 5:ve(x);break;case 4:ge();break;case 13:Fn(x);break;case 19:le(Vr);break;case 10:Ln(x.type);break;case 22:case 23:Fn(x),Dl(),v!==null&&le(Ta);break;case 24:Ln(Hr)}}function zo(v,x){try{var $=x.updateQueue,O=$!==null?$.lastEffect:null;if(O!==null){var k=O.next;$=k;do{if(($.tag&v)===v){O=void 0;var H=$.create,oe=$.inst;O=H(),oe.destroy=O}$=$.next}while($!==k)}}catch(se){xr(x,x.return,se)}}function ta(v,x,$){try{var O=x.updateQueue,k=O!==null?O.lastEffect:null;if(k!==null){var H=k.next;O=H;do{if((O.tag&v)===v){var oe=O.inst,se=oe.destroy;if(se!==void 0){oe.destroy=void 0,k=x;var Se=$,ze=se;try{ze()}catch(Xe){xr(k,Se,Xe)}}}O=O.next}while(O!==H)}}catch(Xe){xr(x,x.return,Xe)}}function ld(v){var x=v.updateQueue;if(x!==null){var $=v.stateNode;try{Gc(x,$)}catch(O){xr(v,v.return,O)}}}function sd(v,x,$){$.props=Oa(v.type,v.memoizedProps),$.state=v.memoizedState;try{$.componentWillUnmount()}catch(O){xr(v,x,O)}}function Do(v,x){try{var $=v.ref;if($!==null){switch(v.tag){case 26:case 27:case 5:var O=v.stateNode;break;case 30:O=v.stateNode;break;default:O=v.stateNode}typeof $=="function"?v.refCleanup=$(O):$.current=O}}catch(k){xr(v,x,k)}}function On(v,x){var $=v.ref,O=v.refCleanup;if($!==null)if(typeof O=="function")try{O()}catch(k){xr(v,x,k)}finally{v.refCleanup=null,v=v.alternate,v!=null&&(v.refCleanup=null)}else if(typeof $=="function")try{$(null)}catch(k){xr(v,x,k)}else $.current=null}function cd(v){var x=v.type,$=v.memoizedProps,O=v.stateNode;try{e:switch(x){case"button":case"input":case"select":case"textarea":$.autoFocus&&O.focus();break e;case"img":$.src?O.src=$.src:$.srcSet&&(O.srcset=$.srcSet)}}catch(k){xr(v,v.return,k)}}function fs(v,x,$){try{var O=v.stateNode;Ym(O,v.type,$,x),O[Ze]=x}catch(k){xr(v,v.return,k)}}function ud(v){return v.tag===5||v.tag===3||v.tag===26||v.tag===27&&ca(v.type)||v.tag===4}function ms(v){e:for(;;){for(;v.sibling===null;){if(v.return===null||ud(v.return))return null;v=v.return}for(v.sibling.return=v.return,v=v.sibling;v.tag!==5&&v.tag!==6&&v.tag!==18;){if(v.tag===27&&ca(v.type)||v.flags&2||v.child===null||v.tag===4)continue e;v.child.return=v,v=v.child}if(!(v.flags&2))return v.stateNode}}function ps(v,x,$){var O=v.tag;if(O===5||O===6)v=v.stateNode,x?($.nodeType===9?$.body:$.nodeName==="HTML"?$.ownerDocument.body:$).insertBefore(v,x):(x=$.nodeType===9?$.body:$.nodeName==="HTML"?$.ownerDocument.body:$,x.appendChild(v),$=$._reactRootContainer,$!=null||x.onclick!==null||(x.onclick=Ki));else if(O!==4&&(O===27&&ca(v.type)&&($=v.stateNode,x=null),v=v.child,v!==null))for(ps(v,x,$),v=v.sibling;v!==null;)ps(v,x,$),v=v.sibling}function Pi(v,x,$){var O=v.tag;if(O===5||O===6)v=v.stateNode,x?$.insertBefore(v,x):$.appendChild(v);else if(O!==4&&(O===27&&ca(v.type)&&($=v.stateNode),v=v.child,v!==null))for(Pi(v,x,$),v=v.sibling;v!==null;)Pi(v,x,$),v=v.sibling}function dd(v){var x=v.stateNode,$=v.memoizedProps;try{for(var O=v.type,k=x.attributes;k.length;)x.removeAttributeNode(k[0]);Zr(x,O,$),x[mt]=v,x[Ze]=$}catch(H){xr(v,v.return,H)}}var Un=!1,Dr=!1,hs=!1,fd=typeof WeakSet=="function"?WeakSet:Set,qr=null;function Mm(v,x){if(v=v.containerInfo,Ls=Qi,v=xc(v),fl(v)){if("selectionStart"in v)var $={start:v.selectionStart,end:v.selectionEnd};else e:{$=($=v.ownerDocument)&&$.defaultView||window;var O=$.getSelection&&$.getSelection();if(O&&O.rangeCount!==0){$=O.anchorNode;var k=O.anchorOffset,H=O.focusNode;O=O.focusOffset;try{$.nodeType,H.nodeType}catch{$=null;break e}var oe=0,se=-1,Se=-1,ze=0,Xe=0,Qe=v,Fe=null;t:for(;;){for(var He;Qe!==$||k!==0&&Qe.nodeType!==3||(se=oe+k),Qe!==H||O!==0&&Qe.nodeType!==3||(Se=oe+O),Qe.nodeType===3&&(oe+=Qe.nodeValue.length),(He=Qe.firstChild)!==null;)Fe=Qe,Qe=He;for(;;){if(Qe===v)break t;if(Fe===$&&++ze===k&&(se=oe),Fe===H&&++Xe===O&&(Se=oe),(He=Qe.nextSibling)!==null)break;Qe=Fe,Fe=Qe.parentNode}Qe=He}$=se===-1||Se===-1?null:{start:se,end:Se}}else $=null}$=$||{start:0,end:0}}else $=null;for(Bs={focusedElem:v,selectionRange:$},Qi=!1,qr=x;qr!==null;)if(x=qr,v=x.child,(x.subtreeFlags&1024)!==0&&v!==null)v.return=x,qr=v;else for(;qr!==null;){switch(x=qr,H=x.alternate,v=x.flags,x.tag){case 0:break;case 11:case 15:break;case 1:if((v&1024)!==0&&H!==null){v=void 0,$=x,k=H.memoizedProps,H=H.memoizedState,O=$.stateNode;try{var Ht=Oa($.type,k,$.elementType===$.type);v=O.getSnapshotBeforeUpdate(Ht,H),O.__reactInternalSnapshotBeforeUpdate=v}catch(Lt){xr($,$.return,Lt)}}break;case 3:if((v&1024)!==0){if(v=x.stateNode.containerInfo,$=v.nodeType,$===9)Vs(v);else if($===1)switch(v.nodeName){case"HEAD":case"HTML":case"BODY":Vs(v);break;default:v.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((v&1024)!==0)throw Error(d(163))}if(v=x.sibling,v!==null){v.return=x.return,qr=v;break}qr=x.return}}function md(v,x,$){var O=$.flags;switch($.tag){case 0:case 11:case 15:ra(v,$),O&4&&zo(5,$);break;case 1:if(ra(v,$),O&4)if(v=$.stateNode,x===null)try{v.componentDidMount()}catch(oe){xr($,$.return,oe)}else{var k=Oa($.type,x.memoizedProps);x=x.memoizedState;try{v.componentDidUpdate(k,x,v.__reactInternalSnapshotBeforeUpdate)}catch(oe){xr($,$.return,oe)}}O&64&&ld($),O&512&&Do($,$.return);break;case 3:if(ra(v,$),O&64&&(v=$.updateQueue,v!==null)){if(x=null,$.child!==null)switch($.child.tag){case 27:case 5:x=$.child.stateNode;break;case 1:x=$.child.stateNode}try{Gc(v,x)}catch(oe){xr($,$.return,oe)}}break;case 27:x===null&&O&4&&dd($);case 26:case 5:ra(v,$),x===null&&O&4&&cd($),O&512&&Do($,$.return);break;case 12:ra(v,$);break;case 13:ra(v,$),O&4&&gd(v,$),O&64&&(v=$.memoizedState,v!==null&&(v=v.dehydrated,v!==null&&($=Lm.bind(null,$),n0(v,$))));break;case 22:if(O=$.memoizedState!==null||Un,!O){x=x!==null&&x.memoizedState!==null||Dr,k=Un;var H=Dr;Un=O,(Dr=x)&&!H?na(v,$,($.subtreeFlags&8772)!==0):ra(v,$),Un=k,Dr=H}break;case 30:break;default:ra(v,$)}}function pd(v){var x=v.alternate;x!==null&&(v.alternate=null,pd(x)),v.child=null,v.deletions=null,v.sibling=null,v.tag===5&&(x=v.stateNode,x!==null&&dt(x)),v.stateNode=null,v.return=null,v.dependencies=null,v.memoizedProps=null,v.memoizedState=null,v.pendingProps=null,v.stateNode=null,v.updateQueue=null}var $r=null,ln=!1;function Kn(v,x,$){for($=$.child;$!==null;)hd(v,x,$),$=$.sibling}function hd(v,x,$){if(Te&&typeof Te.onCommitFiberUnmount=="function")try{Te.onCommitFiberUnmount(be,$)}catch{}switch($.tag){case 26:Dr||On($,x),Kn(v,x,$),$.memoizedState?$.memoizedState.count--:$.stateNode&&($=$.stateNode,$.parentNode.removeChild($));break;case 27:Dr||On($,x);var O=$r,k=ln;ca($.type)&&($r=$.stateNode,ln=!1),Kn(v,x,$),qo($.stateNode),$r=O,ln=k;break;case 5:Dr||On($,x);case 6:if(O=$r,k=ln,$r=null,Kn(v,x,$),$r=O,ln=k,$r!==null)if(ln)try{($r.nodeType===9?$r.body:$r.nodeName==="HTML"?$r.ownerDocument.body:$r).removeChild($.stateNode)}catch(H){xr($,x,H)}else try{$r.removeChild($.stateNode)}catch(H){xr($,x,H)}break;case 18:$r!==null&&(ln?(v=$r,nf(v.nodeType===9?v.body:v.nodeName==="HTML"?v.ownerDocument.body:v,$.stateNode),ei(v)):nf($r,$.stateNode));break;case 4:O=$r,k=ln,$r=$.stateNode.containerInfo,ln=!0,Kn(v,x,$),$r=O,ln=k;break;case 0:case 11:case 14:case 15:Dr||ta(2,$,x),Dr||ta(4,$,x),Kn(v,x,$);break;case 1:Dr||(On($,x),O=$.stateNode,typeof O.componentWillUnmount=="function"&&sd($,x,O)),Kn(v,x,$);break;case 21:Kn(v,x,$);break;case 22:Dr=(O=Dr)||$.memoizedState!==null,Kn(v,x,$),Dr=O;break;default:Kn(v,x,$)}}function gd(v,x){if(x.memoizedState===null&&(v=x.alternate,v!==null&&(v=v.memoizedState,v!==null&&(v=v.dehydrated,v!==null))))try{ei(v)}catch($){xr(x,x.return,$)}}function Nm(v){switch(v.tag){case 13:case 19:var x=v.stateNode;return x===null&&(x=v.stateNode=new fd),x;case 22:return v=v.stateNode,x=v._retryCache,x===null&&(x=v._retryCache=new fd),x;default:throw Error(d(435,v.tag))}}function gs(v,x){var $=Nm(v);x.forEach(function(O){var k=Bm.bind(null,v,O);$.has(O)||($.add(O),O.then(k,k))})}function dn(v,x){var $=x.deletions;if($!==null)for(var O=0;O<$.length;O++){var k=$[O],H=v,oe=x,se=oe;e:for(;se!==null;){switch(se.tag){case 27:if(ca(se.type)){$r=se.stateNode,ln=!1;break e}break;case 5:$r=se.stateNode,ln=!1;break e;case 3:case 4:$r=se.stateNode.containerInfo,ln=!0;break e}se=se.return}if($r===null)throw Error(d(160));hd(H,oe,k),$r=null,ln=!1,H=k.alternate,H!==null&&(H.return=null),k.return=null}if(x.subtreeFlags&13878)for(x=x.child;x!==null;)vd(x,v),x=x.sibling}var $n=null;function vd(v,x){var $=v.alternate,O=v.flags;switch(v.tag){case 0:case 11:case 14:case 15:dn(x,v),fn(v),O&4&&(ta(3,v,v.return),zo(3,v),ta(5,v,v.return));break;case 1:dn(x,v),fn(v),O&512&&(Dr||$===null||On($,$.return)),O&64&&Un&&(v=v.updateQueue,v!==null&&(O=v.callbacks,O!==null&&($=v.shared.hiddenCallbacks,v.shared.hiddenCallbacks=$===null?O:$.concat(O))));break;case 26:var k=$n;if(dn(x,v),fn(v),O&512&&(Dr||$===null||On($,$.return)),O&4){var H=$!==null?$.memoizedState:null;if(O=v.memoizedState,$===null)if(O===null)if(v.stateNode===null){e:{O=v.type,$=v.memoizedProps,k=k.ownerDocument||k;t:switch(O){case"title":H=k.getElementsByTagName("title")[0],(!H||H[ft]||H[mt]||H.namespaceURI==="http://www.w3.org/2000/svg"||H.hasAttribute("itemprop"))&&(H=k.createElement(O),k.head.insertBefore(H,k.querySelector("head > title"))),Zr(H,O,$),H[mt]=v,Nt(H),O=H;break e;case"link":var oe=ff("link","href",k).get(O+($.href||""));if(oe){for(var se=0;se<oe.length;se++)if(H=oe[se],H.getAttribute("href")===($.href==null||$.href===""?null:$.href)&&H.getAttribute("rel")===($.rel==null?null:$.rel)&&H.getAttribute("title")===($.title==null?null:$.title)&&H.getAttribute("crossorigin")===($.crossOrigin==null?null:$.crossOrigin)){oe.splice(se,1);break t}}H=k.createElement(O),Zr(H,O,$),k.head.appendChild(H);break;case"meta":if(oe=ff("meta","content",k).get(O+($.content||""))){for(se=0;se<oe.length;se++)if(H=oe[se],H.getAttribute("content")===($.content==null?null:""+$.content)&&H.getAttribute("name")===($.name==null?null:$.name)&&H.getAttribute("property")===($.property==null?null:$.property)&&H.getAttribute("http-equiv")===($.httpEquiv==null?null:$.httpEquiv)&&H.getAttribute("charset")===($.charSet==null?null:$.charSet)){oe.splice(se,1);break t}}H=k.createElement(O),Zr(H,O,$),k.head.appendChild(H);break;default:throw Error(d(468,O))}H[mt]=v,Nt(H),O=H}v.stateNode=O}else mf(k,v.type,v.stateNode);else v.stateNode=df(k,O,v.memoizedProps);else H!==O?(H===null?$.stateNode!==null&&($=$.stateNode,$.parentNode.removeChild($)):H.count--,O===null?mf(k,v.type,v.stateNode):df(k,O,v.memoizedProps)):O===null&&v.stateNode!==null&&fs(v,v.memoizedProps,$.memoizedProps)}break;case 27:dn(x,v),fn(v),O&512&&(Dr||$===null||On($,$.return)),$!==null&&O&4&&fs(v,v.memoizedProps,$.memoizedProps);break;case 5:if(dn(x,v),fn(v),O&512&&(Dr||$===null||On($,$.return)),v.flags&32){k=v.stateNode;try{Sr(k,"")}catch(He){xr(v,v.return,He)}}O&4&&v.stateNode!=null&&(k=v.memoizedProps,fs(v,k,$!==null?$.memoizedProps:k)),O&1024&&(hs=!0);break;case 6:if(dn(x,v),fn(v),O&4){if(v.stateNode===null)throw Error(d(162));O=v.memoizedProps,$=v.stateNode;try{$.nodeValue=O}catch(He){xr(v,v.return,He)}}break;case 3:if(Xi=null,k=$n,$n=Wi(x.containerInfo),dn(x,v),$n=k,fn(v),O&4&&$!==null&&$.memoizedState.isDehydrated)try{ei(x.containerInfo)}catch(He){xr(v,v.return,He)}hs&&(hs=!1,yd(v));break;case 4:O=$n,$n=Wi(v.stateNode.containerInfo),dn(x,v),fn(v),$n=O;break;case 12:dn(x,v),fn(v);break;case 13:dn(x,v),fn(v),v.child.flags&8192&&v.memoizedState!==null!=($!==null&&$.memoizedState!==null)&&(Es=we()),O&4&&(O=v.updateQueue,O!==null&&(v.updateQueue=null,gs(v,O)));break;case 22:k=v.memoizedState!==null;var Se=$!==null&&$.memoizedState!==null,ze=Un,Xe=Dr;if(Un=ze||k,Dr=Xe||Se,dn(x,v),Dr=Xe,Un=ze,fn(v),O&8192)e:for(x=v.stateNode,x._visibility=k?x._visibility&-2:x._visibility|1,k&&($===null||Se||Un||Dr||Ma(v)),$=null,x=v;;){if(x.tag===5||x.tag===26){if($===null){Se=$=x;try{if(H=Se.stateNode,k)oe=H.style,typeof oe.setProperty=="function"?oe.setProperty("display","none","important"):oe.display="none";else{se=Se.stateNode;var Qe=Se.memoizedProps.style,Fe=Qe!=null&&Qe.hasOwnProperty("display")?Qe.display:null;se.style.display=Fe==null||typeof Fe=="boolean"?"":(""+Fe).trim()}}catch(He){xr(Se,Se.return,He)}}}else if(x.tag===6){if($===null){Se=x;try{Se.stateNode.nodeValue=k?"":Se.memoizedProps}catch(He){xr(Se,Se.return,He)}}}else if((x.tag!==22&&x.tag!==23||x.memoizedState===null||x===v)&&x.child!==null){x.child.return=x,x=x.child;continue}if(x===v)break e;for(;x.sibling===null;){if(x.return===null||x.return===v)break e;$===x&&($=null),x=x.return}$===x&&($=null),x.sibling.return=x.return,x=x.sibling}O&4&&(O=v.updateQueue,O!==null&&($=O.retryQueue,$!==null&&(O.retryQueue=null,gs(v,$))));break;case 19:dn(x,v),fn(v),O&4&&(O=v.updateQueue,O!==null&&(v.updateQueue=null,gs(v,O)));break;case 30:break;case 21:break;default:dn(x,v),fn(v)}}function fn(v){var x=v.flags;if(x&2){try{for(var $,O=v.return;O!==null;){if(ud(O)){$=O;break}O=O.return}if($==null)throw Error(d(160));switch($.tag){case 27:var k=$.stateNode,H=ms(v);Pi(v,H,k);break;case 5:var oe=$.stateNode;$.flags&32&&(Sr(oe,""),$.flags&=-33);var se=ms(v);Pi(v,se,oe);break;case 3:case 4:var Se=$.stateNode.containerInfo,ze=ms(v);ps(v,ze,Se);break;default:throw Error(d(161))}}catch(Xe){xr(v,v.return,Xe)}v.flags&=-3}x&4096&&(v.flags&=-4097)}function yd(v){if(v.subtreeFlags&1024)for(v=v.child;v!==null;){var x=v;yd(x),x.tag===5&&x.flags&1024&&x.stateNode.reset(),v=v.sibling}}function ra(v,x){if(x.subtreeFlags&8772)for(x=x.child;x!==null;)md(v,x.alternate,x),x=x.sibling}function Ma(v){for(v=v.child;v!==null;){var x=v;switch(x.tag){case 0:case 11:case 14:case 15:ta(4,x,x.return),Ma(x);break;case 1:On(x,x.return);var $=x.stateNode;typeof $.componentWillUnmount=="function"&&sd(x,x.return,$),Ma(x);break;case 27:qo(x.stateNode);case 26:case 5:On(x,x.return),Ma(x);break;case 22:x.memoizedState===null&&Ma(x);break;case 30:Ma(x);break;default:Ma(x)}v=v.sibling}}function na(v,x,$){for($=$&&(x.subtreeFlags&8772)!==0,x=x.child;x!==null;){var O=x.alternate,k=v,H=x,oe=H.flags;switch(H.tag){case 0:case 11:case 15:na(k,H,$),zo(4,H);break;case 1:if(na(k,H,$),O=H,k=O.stateNode,typeof k.componentDidMount=="function")try{k.componentDidMount()}catch(ze){xr(O,O.return,ze)}if(O=H,k=O.updateQueue,k!==null){var se=O.stateNode;try{var Se=k.shared.hiddenCallbacks;if(Se!==null)for(k.shared.hiddenCallbacks=null,k=0;k<Se.length;k++)Wc(Se[k],se)}catch(ze){xr(O,O.return,ze)}}$&&oe&64&&ld(H),Do(H,H.return);break;case 27:dd(H);case 26:case 5:na(k,H,$),$&&O===null&&oe&4&&cd(H),Do(H,H.return);break;case 12:na(k,H,$);break;case 13:na(k,H,$),$&&oe&4&&gd(k,H);break;case 22:H.memoizedState===null&&na(k,H,$),Do(H,H.return);break;case 30:break;default:na(k,H,$)}x=x.sibling}}function vs(v,x){var $=null;v!==null&&v.memoizedState!==null&&v.memoizedState.cachePool!==null&&($=v.memoizedState.cachePool.pool),v=null,x.memoizedState!==null&&x.memoizedState.cachePool!==null&&(v=x.memoizedState.cachePool.pool),v!==$&&(v!=null&&v.refCount++,$!=null&&Eo($))}function ys(v,x){v=null,x.alternate!==null&&(v=x.alternate.memoizedState.cache),x=x.memoizedState.cache,x!==v&&(x.refCount++,v!=null&&Eo(v))}function Mn(v,x,$,O){if(x.subtreeFlags&10256)for(x=x.child;x!==null;)bd(v,x,$,O),x=x.sibling}function bd(v,x,$,O){var k=x.flags;switch(x.tag){case 0:case 11:case 15:Mn(v,x,$,O),k&2048&&zo(9,x);break;case 1:Mn(v,x,$,O);break;case 3:Mn(v,x,$,O),k&2048&&(v=null,x.alternate!==null&&(v=x.alternate.memoizedState.cache),x=x.memoizedState.cache,x!==v&&(x.refCount++,v!=null&&Eo(v)));break;case 12:if(k&2048){Mn(v,x,$,O),v=x.stateNode;try{var H=x.memoizedProps,oe=H.id,se=H.onPostCommit;typeof se=="function"&&se(oe,x.alternate===null?"mount":"update",v.passiveEffectDuration,-0)}catch(Se){xr(x,x.return,Se)}}else Mn(v,x,$,O);break;case 13:Mn(v,x,$,O);break;case 23:break;case 22:H=x.stateNode,oe=x.alternate,x.memoizedState!==null?H._visibility&2?Mn(v,x,$,O):jo(v,x):H._visibility&2?Mn(v,x,$,O):(H._visibility|=2,Za(v,x,$,O,(x.subtreeFlags&10256)!==0)),k&2048&&vs(oe,x);break;case 24:Mn(v,x,$,O),k&2048&&ys(x.alternate,x);break;default:Mn(v,x,$,O)}}function Za(v,x,$,O,k){for(k=k&&(x.subtreeFlags&10256)!==0,x=x.child;x!==null;){var H=v,oe=x,se=$,Se=O,ze=oe.flags;switch(oe.tag){case 0:case 11:case 15:Za(H,oe,se,Se,k),zo(8,oe);break;case 23:break;case 22:var Xe=oe.stateNode;oe.memoizedState!==null?Xe._visibility&2?Za(H,oe,se,Se,k):jo(H,oe):(Xe._visibility|=2,Za(H,oe,se,Se,k)),k&&ze&2048&&vs(oe.alternate,oe);break;case 24:Za(H,oe,se,Se,k),k&&ze&2048&&ys(oe.alternate,oe);break;default:Za(H,oe,se,Se,k)}x=x.sibling}}function jo(v,x){if(x.subtreeFlags&10256)for(x=x.child;x!==null;){var $=v,O=x,k=O.flags;switch(O.tag){case 22:jo($,O),k&2048&&vs(O.alternate,O);break;case 24:jo($,O),k&2048&&ys(O.alternate,O);break;default:jo($,O)}x=x.sibling}}var Lo=8192;function Qa(v){if(v.subtreeFlags&Lo)for(v=v.child;v!==null;)xd(v),v=v.sibling}function xd(v){switch(v.tag){case 26:Qa(v),v.flags&Lo&&v.memoizedState!==null&&g0($n,v.memoizedState,v.memoizedProps);break;case 5:Qa(v);break;case 3:case 4:var x=$n;$n=Wi(v.stateNode.containerInfo),Qa(v),$n=x;break;case 22:v.memoizedState===null&&(x=v.alternate,x!==null&&x.memoizedState!==null?(x=Lo,Lo=16777216,Qa(v),Lo=x):Qa(v));break;default:Qa(v)}}function Sd(v){var x=v.alternate;if(x!==null&&(v=x.child,v!==null)){x.child=null;do x=v.sibling,v.sibling=null,v=x;while(v!==null)}}function Bo(v){var x=v.deletions;if((v.flags&16)!==0){if(x!==null)for(var $=0;$<x.length;$++){var O=x[$];qr=O,Cd(O,v)}Sd(v)}if(v.subtreeFlags&10256)for(v=v.child;v!==null;)Ed(v),v=v.sibling}function Ed(v){switch(v.tag){case 0:case 11:case 15:Bo(v),v.flags&2048&&ta(9,v,v.return);break;case 3:Bo(v);break;case 12:Bo(v);break;case 22:var x=v.stateNode;v.memoizedState!==null&&x._visibility&2&&(v.return===null||v.return.tag!==13)?(x._visibility&=-3,ki(v)):Bo(v);break;default:Bo(v)}}function ki(v){var x=v.deletions;if((v.flags&16)!==0){if(x!==null)for(var $=0;$<x.length;$++){var O=x[$];qr=O,Cd(O,v)}Sd(v)}for(v=v.child;v!==null;){switch(x=v,x.tag){case 0:case 11:case 15:ta(8,x,x.return),ki(x);break;case 22:$=x.stateNode,$._visibility&2&&($._visibility&=-3,ki(x));break;default:ki(x)}v=v.sibling}}function Cd(v,x){for(;qr!==null;){var $=qr;switch($.tag){case 0:case 11:case 15:ta(8,$,x);break;case 23:case 22:if($.memoizedState!==null&&$.memoizedState.cachePool!==null){var O=$.memoizedState.cachePool.pool;O!=null&&O.refCount++}break;case 24:Eo($.memoizedState.cache)}if(O=$.child,O!==null)O.return=$,qr=O;else e:for($=v;qr!==null;){O=qr;var k=O.sibling,H=O.return;if(pd(O),O===$){qr=null;break e}if(k!==null){k.return=H,qr=k;break e}qr=H}}}var Im={getCacheForType:function(v){var x=Qr(Hr),$=x.data.get(v);return $===void 0&&($=v(),x.data.set(v,$)),$}},Am=typeof WeakMap=="function"?WeakMap:Map,dr=0,Cr=null,tr=null,ir=0,fr=0,mn=null,aa=!1,Ja=!1,bs=!1,qn=0,Pr=0,oa=0,Na=0,xs=0,Sn=0,eo=0,Fo=null,sn=null,Ss=!1,Es=0,zi=1/0,Di=null,ia=null,Yr=0,la=null,to=null,ro=0,Cs=0,ws=null,wd=null,Ho=0,$s=null;function pn(){if((dr&2)!==0&&ir!==0)return ir&-ir;if(W.T!==null){var v=Va;return v!==0?v:Is()}return rt()}function $d(){Sn===0&&(Sn=(ir&536870912)===0||cr?gt():536870912);var v=xn.current;return v!==null&&(v.flags|=32),Sn}function hn(v,x,$){(v===Cr&&(fr===2||fr===9)||v.cancelPendingCommit!==null)&&(no(v,0),sa(v,ir,Sn,!1)),at(v,$),((dr&2)===0||v!==Cr)&&(v===Cr&&((dr&2)===0&&(Na|=$),Pr===4&&sa(v,ir,Sn,!1)),Nn(v))}function Rd(v,x,$){if((dr&6)!==0)throw Error(d(327));var O=!$&&(x&124)===0&&(x&v.expiredLanes)===0||We(v,x),k=O?zm(v,x):_s(v,x,!0),H=O;do{if(k===0){Ja&&!O&&sa(v,x,0,!1);break}else{if($=v.current.alternate,H&&!Pm($)){k=_s(v,x,!1),H=!1;continue}if(k===2){if(H=x,v.errorRecoveryDisabledLanes&H)var oe=0;else oe=v.pendingLanes&-536870913,oe=oe!==0?oe:oe&536870912?536870912:0;if(oe!==0){x=oe;e:{var se=v;k=Fo;var Se=se.current.memoizedState.isDehydrated;if(Se&&(no(se,oe).flags|=256),oe=_s(se,oe,!1),oe!==2){if(bs&&!Se){se.errorRecoveryDisabledLanes|=H,Na|=H,k=4;break e}H=sn,sn=k,H!==null&&(sn===null?sn=H:sn.push.apply(sn,H))}k=oe}if(H=!1,k!==2)continue}}if(k===1){no(v,0),sa(v,x,0,!0);break}e:{switch(O=v,H=k,H){case 0:case 1:throw Error(d(345));case 4:if((x&4194048)!==x)break;case 6:sa(O,x,Sn,!aa);break e;case 2:sn=null;break;case 3:case 5:break;default:throw Error(d(329))}if((x&62914560)===x&&(k=Es+300-we(),10<k)){if(sa(O,x,Sn,!aa),je(O,0,!0)!==0)break e;O.timeoutHandle=tf(Td.bind(null,O,$,sn,Di,Ss,x,Sn,Na,eo,aa,H,2,-0,0),k);break e}Td(O,$,sn,Di,Ss,x,Sn,Na,eo,aa,H,0,-0,0)}}break}while(!0);Nn(v)}function Td(v,x,$,O,k,H,oe,se,Se,ze,Xe,Qe,Fe,He){if(v.timeoutHandle=-1,Qe=x.subtreeFlags,(Qe&8192||(Qe&16785408)===16785408)&&(Xo={stylesheets:null,count:0,unsuspend:h0},xd(x),Qe=v0(),Qe!==null)){v.cancelPendingCommit=Qe(Pd.bind(null,v,x,H,$,O,k,oe,se,Se,Xe,1,Fe,He)),sa(v,H,oe,!ze);return}Pd(v,x,H,$,O,k,oe,se,Se)}function Pm(v){for(var x=v;;){var $=x.tag;if(($===0||$===11||$===15)&&x.flags&16384&&($=x.updateQueue,$!==null&&($=$.stores,$!==null)))for(var O=0;O<$.length;O++){var k=$[O],H=k.getSnapshot;k=k.value;try{if(!cn(H(),k))return!1}catch{return!1}}if($=x.child,x.subtreeFlags&16384&&$!==null)$.return=x,x=$;else{if(x===v)break;for(;x.sibling===null;){if(x.return===null||x.return===v)return!0;x=x.return}x.sibling.return=x.return,x=x.sibling}}return!0}function sa(v,x,$,O){x&=~xs,x&=~Na,v.suspendedLanes|=x,v.pingedLanes&=~x,O&&(v.warmLanes|=x),O=v.expirationTimes;for(var k=x;0<k;){var H=31-Oe(k),oe=1<<H;O[H]=-1,k&=~oe}$!==0&&bt(v,$,x)}function ji(){return(dr&6)===0?(Vo(0),!1):!0}function Rs(){if(tr!==null){if(fr===0)var v=tr.return;else v=tr,jn=$a=null,Hl(v),Xa=null,Ao=0,v=tr;for(;v!==null;)id(v.alternate,v),v=v.return;tr=null}}function no(v,x){var $=v.timeoutHandle;$!==-1&&(v.timeoutHandle=-1,Qm($)),$=v.cancelPendingCommit,$!==null&&(v.cancelPendingCommit=null,$()),Rs(),Cr=v,tr=$=kn(v.current,null),ir=x,fr=0,mn=null,aa=!1,Ja=We(v,x),bs=!1,eo=Sn=xs=Na=oa=Pr=0,sn=Fo=null,Ss=!1,(x&8)!==0&&(x|=x&32);var O=v.entangledLanes;if(O!==0)for(v=v.entanglements,O&=x;0<O;){var k=31-Oe(O),H=1<<k;x|=v[k],O&=~H}return qn=x,oi(),$}function _d(v,x){Yt=null,W.H=wi,x===wo||x===pi?(x=Kc(),fr=3):x===Hc?(x=Kc(),fr=4):fr=x===qu?8:x!==null&&typeof x=="object"&&typeof x.then=="function"?6:1,mn=x,tr===null&&(Pr=1,Mi(v,gn(x,v.current)))}function Od(){var v=W.H;return W.H=wi,v===null?wi:v}function Md(){var v=W.A;return W.A=Im,v}function Ts(){Pr=4,aa||(ir&4194048)!==ir&&xn.current!==null||(Ja=!0),(oa&134217727)===0&&(Na&134217727)===0||Cr===null||sa(Cr,ir,Sn,!1)}function _s(v,x,$){var O=dr;dr|=2;var k=Od(),H=Md();(Cr!==v||ir!==x)&&(Di=null,no(v,x)),x=!1;var oe=Pr;e:do try{if(fr!==0&&tr!==null){var se=tr,Se=mn;switch(fr){case 8:Rs(),oe=6;break e;case 3:case 2:case 9:case 6:xn.current===null&&(x=!0);var ze=fr;if(fr=0,mn=null,ao(v,se,Se,ze),$&&Ja){oe=0;break e}break;default:ze=fr,fr=0,mn=null,ao(v,se,Se,ze)}}km(),oe=Pr;break}catch(Xe){_d(v,Xe)}while(!0);return x&&v.shellSuspendCounter++,jn=$a=null,dr=O,W.H=k,W.A=H,tr===null&&(Cr=null,ir=0,oi()),oe}function km(){for(;tr!==null;)Nd(tr)}function zm(v,x){var $=dr;dr|=2;var O=Od(),k=Md();Cr!==v||ir!==x?(Di=null,zi=we()+500,no(v,x)):Ja=We(v,x);e:do try{if(fr!==0&&tr!==null){x=tr;var H=mn;t:switch(fr){case 1:fr=0,mn=null,ao(v,x,H,1);break;case 2:case 9:if(Vc(H)){fr=0,mn=null,Id(x);break}x=function(){fr!==2&&fr!==9||Cr!==v||(fr=7),Nn(v)},H.then(x,x);break e;case 3:fr=7;break e;case 4:fr=5;break e;case 7:Vc(H)?(fr=0,mn=null,Id(x)):(fr=0,mn=null,ao(v,x,H,7));break;case 5:var oe=null;switch(tr.tag){case 26:oe=tr.memoizedState;case 5:case 27:var se=tr;if(!oe||pf(oe)){fr=0,mn=null;var Se=se.sibling;if(Se!==null)tr=Se;else{var ze=se.return;ze!==null?(tr=ze,Li(ze)):tr=null}break t}}fr=0,mn=null,ao(v,x,H,5);break;case 6:fr=0,mn=null,ao(v,x,H,6);break;case 8:Rs(),Pr=6;break e;default:throw Error(d(462))}}Dm();break}catch(Xe){_d(v,Xe)}while(!0);return jn=$a=null,W.H=O,W.A=k,dr=$,tr!==null?0:(Cr=null,ir=0,oi(),Pr)}function Dm(){for(;tr!==null&&!ye();)Nd(tr)}function Nd(v){var x=ad(v.alternate,v,qn);v.memoizedProps=v.pendingProps,x===null?Li(v):tr=x}function Id(v){var x=v,$=x.alternate;switch(x.tag){case 15:case 0:x=Qu($,x,x.pendingProps,x.type,void 0,ir);break;case 11:x=Qu($,x,x.pendingProps,x.type.render,x.ref,ir);break;case 5:Hl(x);default:id($,x),x=tr=Ic(x,qn),x=ad($,x,qn)}v.memoizedProps=v.pendingProps,x===null?Li(v):tr=x}function ao(v,x,$,O){jn=$a=null,Hl(x),Xa=null,Ao=0;var k=x.return;try{if(Rm(v,k,x,$,ir)){Pr=1,Mi(v,gn($,v.current)),tr=null;return}}catch(H){if(k!==null)throw tr=k,H;Pr=1,Mi(v,gn($,v.current)),tr=null;return}x.flags&32768?(cr||O===1?v=!0:Ja||(ir&536870912)!==0?v=!1:(aa=v=!0,(O===2||O===9||O===3||O===6)&&(O=xn.current,O!==null&&O.tag===13&&(O.flags|=16384))),Ad(x,v)):Li(x)}function Li(v){var x=v;do{if((x.flags&32768)!==0){Ad(x,aa);return}v=x.return;var $=_m(x.alternate,x,qn);if($!==null){tr=$;return}if(x=x.sibling,x!==null){tr=x;return}tr=x=v}while(x!==null);Pr===0&&(Pr=5)}function Ad(v,x){do{var $=Om(v.alternate,v);if($!==null){$.flags&=32767,tr=$;return}if($=v.return,$!==null&&($.flags|=32768,$.subtreeFlags=0,$.deletions=null),!x&&(v=v.sibling,v!==null)){tr=v;return}tr=v=$}while(v!==null);Pr=6,tr=null}function Pd(v,x,$,O,k,H,oe,se,Se){v.cancelPendingCommit=null;do Bi();while(Yr!==0);if((dr&6)!==0)throw Error(d(327));if(x!==null){if(x===v.current)throw Error(d(177));if(H=x.lanes|x.childLanes,H|=vl,ct(v,$,H,oe,se,Se),v===Cr&&(tr=Cr=null,ir=0),to=x,la=v,ro=$,Cs=H,ws=k,wd=O,(x.subtreeFlags&10256)!==0||(x.flags&10256)!==0?(v.callbackNode=null,v.callbackPriority=0,Fm(Ee,function(){return Ld(),null})):(v.callbackNode=null,v.callbackPriority=0),O=(x.flags&13878)!==0,(x.subtreeFlags&13878)!==0||O){O=W.T,W.T=null,k=G.p,G.p=2,oe=dr,dr|=4;try{Mm(v,x,$)}finally{dr=oe,G.p=k,W.T=O}}Yr=1,kd(),zd(),Dd()}}function kd(){if(Yr===1){Yr=0;var v=la,x=to,$=(x.flags&13878)!==0;if((x.subtreeFlags&13878)!==0||$){$=W.T,W.T=null;var O=G.p;G.p=2;var k=dr;dr|=4;try{vd(x,v);var H=Bs,oe=xc(v.containerInfo),se=H.focusedElem,Se=H.selectionRange;if(oe!==se&&se&&se.ownerDocument&&bc(se.ownerDocument.documentElement,se)){if(Se!==null&&fl(se)){var ze=Se.start,Xe=Se.end;if(Xe===void 0&&(Xe=ze),"selectionStart"in se)se.selectionStart=ze,se.selectionEnd=Math.min(Xe,se.value.length);else{var Qe=se.ownerDocument||document,Fe=Qe&&Qe.defaultView||window;if(Fe.getSelection){var He=Fe.getSelection(),Ht=se.textContent.length,Lt=Math.min(Se.start,Ht),gr=Se.end===void 0?Lt:Math.min(Se.end,Ht);!He.extend&&Lt>gr&&(oe=gr,gr=Lt,Lt=oe);var Me=yc(se,Lt),$e=yc(se,gr);if(Me&&$e&&(He.rangeCount!==1||He.anchorNode!==Me.node||He.anchorOffset!==Me.offset||He.focusNode!==$e.node||He.focusOffset!==$e.offset)){var Ie=Qe.createRange();Ie.setStart(Me.node,Me.offset),He.removeAllRanges(),Lt>gr?(He.addRange(Ie),He.extend($e.node,$e.offset)):(Ie.setEnd($e.node,$e.offset),He.addRange(Ie))}}}}for(Qe=[],He=se;He=He.parentNode;)He.nodeType===1&&Qe.push({element:He,left:He.scrollLeft,top:He.scrollTop});for(typeof se.focus=="function"&&se.focus(),se=0;se<Qe.length;se++){var Ye=Qe[se];Ye.element.scrollLeft=Ye.left,Ye.element.scrollTop=Ye.top}}Qi=!!Ls,Bs=Ls=null}finally{dr=k,G.p=O,W.T=$}}v.current=x,Yr=2}}function zd(){if(Yr===2){Yr=0;var v=la,x=to,$=(x.flags&8772)!==0;if((x.subtreeFlags&8772)!==0||$){$=W.T,W.T=null;var O=G.p;G.p=2;var k=dr;dr|=4;try{md(v,x.alternate,x)}finally{dr=k,G.p=O,W.T=$}}Yr=3}}function Dd(){if(Yr===4||Yr===3){Yr=0,he();var v=la,x=to,$=ro,O=wd;(x.subtreeFlags&10256)!==0||(x.flags&10256)!==0?Yr=5:(Yr=0,to=la=null,jd(v,v.pendingLanes));var k=v.pendingLanes;if(k===0&&(ia=null),ot($),x=x.stateNode,Te&&typeof Te.onCommitFiberRoot=="function")try{Te.onCommitFiberRoot(be,x,void 0,(x.current.flags&128)===128)}catch{}if(O!==null){x=W.T,k=G.p,G.p=2,W.T=null;try{for(var H=v.onRecoverableError,oe=0;oe<O.length;oe++){var se=O[oe];H(se.value,{componentStack:se.stack})}}finally{W.T=x,G.p=k}}(ro&3)!==0&&Bi(),Nn(v),k=v.pendingLanes,($&4194090)!==0&&(k&42)!==0?v===$s?Ho++:(Ho=0,$s=v):Ho=0,Vo(0)}}function jd(v,x){(v.pooledCacheLanes&=x)===0&&(x=v.pooledCache,x!=null&&(v.pooledCache=null,Eo(x)))}function Bi(v){return kd(),zd(),Dd(),Ld()}function Ld(){if(Yr!==5)return!1;var v=la,x=Cs;Cs=0;var $=ot(ro),O=W.T,k=G.p;try{G.p=32>$?32:$,W.T=null,$=ws,ws=null;var H=la,oe=ro;if(Yr=0,to=la=null,ro=0,(dr&6)!==0)throw Error(d(331));var se=dr;if(dr|=4,Ed(H.current),bd(H,H.current,oe,$),dr=se,Vo(0,!1),Te&&typeof Te.onPostCommitFiberRoot=="function")try{Te.onPostCommitFiberRoot(be,H)}catch{}return!0}finally{G.p=k,W.T=O,jd(v,x)}}function Bd(v,x,$){x=gn($,x),x=rs(v.stateNode,x,2),v=Zn(v,x,2),v!==null&&(at(v,2),Nn(v))}function xr(v,x,$){if(v.tag===3)Bd(v,v,$);else for(;x!==null;){if(x.tag===3){Bd(x,v,$);break}else if(x.tag===1){var O=x.stateNode;if(typeof x.type.getDerivedStateFromError=="function"||typeof O.componentDidCatch=="function"&&(ia===null||!ia.has(O))){v=gn($,v),$=Uu(2),O=Zn(x,$,2),O!==null&&(Ku($,O,x,v),at(O,2),Nn(O));break}}x=x.return}}function Os(v,x,$){var O=v.pingCache;if(O===null){O=v.pingCache=new Am;var k=new Set;O.set(x,k)}else k=O.get(x),k===void 0&&(k=new Set,O.set(x,k));k.has($)||(bs=!0,k.add($),v=jm.bind(null,v,x,$),x.then(v,v))}function jm(v,x,$){var O=v.pingCache;O!==null&&O.delete(x),v.pingedLanes|=v.suspendedLanes&$,v.warmLanes&=~$,Cr===v&&(ir&$)===$&&(Pr===4||Pr===3&&(ir&62914560)===ir&&300>we()-Es?(dr&2)===0&&no(v,0):xs|=$,eo===ir&&(eo=0)),Nn(v)}function Fd(v,x){x===0&&(x=kt()),v=La(v,x),v!==null&&(at(v,x),Nn(v))}function Lm(v){var x=v.memoizedState,$=0;x!==null&&($=x.retryLane),Fd(v,$)}function Bm(v,x){var $=0;switch(v.tag){case 13:var O=v.stateNode,k=v.memoizedState;k!==null&&($=k.retryLane);break;case 19:O=v.stateNode;break;case 22:O=v.stateNode._retryCache;break;default:throw Error(d(314))}O!==null&&O.delete(x),Fd(v,$)}function Fm(v,x){return pe(v,x)}var Fi=null,oo=null,Ms=!1,Hi=!1,Ns=!1,Ia=0;function Nn(v){v!==oo&&v.next===null&&(oo===null?Fi=oo=v:oo=oo.next=v),Hi=!0,Ms||(Ms=!0,Vm())}function Vo(v,x){if(!Ns&&Hi){Ns=!0;do for(var $=!1,O=Fi;O!==null;){if(v!==0){var k=O.pendingLanes;if(k===0)var H=0;else{var oe=O.suspendedLanes,se=O.pingedLanes;H=(1<<31-Oe(42|v)+1)-1,H&=k&~(oe&~se),H=H&201326741?H&201326741|1:H?H|2:0}H!==0&&($=!0,Kd(O,H))}else H=ir,H=je(O,O===Cr?H:0,O.cancelPendingCommit!==null||O.timeoutHandle!==-1),(H&3)===0||We(O,H)||($=!0,Kd(O,H));O=O.next}while($);Ns=!1}}function Hm(){Hd()}function Hd(){Hi=Ms=!1;var v=0;Ia!==0&&(Zm()&&(v=Ia),Ia=0);for(var x=we(),$=null,O=Fi;O!==null;){var k=O.next,H=Vd(O,x);H===0?(O.next=null,$===null?Fi=k:$.next=k,k===null&&(oo=$)):($=O,(v!==0||(H&3)!==0)&&(Hi=!0)),O=k}Vo(v)}function Vd(v,x){for(var $=v.suspendedLanes,O=v.pingedLanes,k=v.expirationTimes,H=v.pendingLanes&-62914561;0<H;){var oe=31-Oe(H),se=1<<oe,Se=k[oe];Se===-1?((se&$)===0||(se&O)!==0)&&(k[oe]=ut(se,x)):Se<=x&&(v.expiredLanes|=se),H&=~se}if(x=Cr,$=ir,$=je(v,v===x?$:0,v.cancelPendingCommit!==null||v.timeoutHandle!==-1),O=v.callbackNode,$===0||v===x&&(fr===2||fr===9)||v.cancelPendingCommit!==null)return O!==null&&O!==null&&xe(O),v.callbackNode=null,v.callbackPriority=0;if(($&3)===0||We(v,$)){if(x=$&-$,x===v.callbackPriority)return x;switch(O!==null&&xe(O),ot($)){case 2:case 8:$=Ae;break;case 32:$=Ee;break;case 268435456:$=_e;break;default:$=Ee}return O=Ud.bind(null,v),$=pe($,O),v.callbackPriority=x,v.callbackNode=$,x}return O!==null&&O!==null&&xe(O),v.callbackPriority=2,v.callbackNode=null,2}function Ud(v,x){if(Yr!==0&&Yr!==5)return v.callbackNode=null,v.callbackPriority=0,null;var $=v.callbackNode;if(Bi()&&v.callbackNode!==$)return null;var O=ir;return O=je(v,v===Cr?O:0,v.cancelPendingCommit!==null||v.timeoutHandle!==-1),O===0?null:(Rd(v,O,x),Vd(v,we()),v.callbackNode!=null&&v.callbackNode===$?Ud.bind(null,v):null)}function Kd(v,x){if(Bi())return null;Rd(v,x,!0)}function Vm(){Jm(function(){(dr&6)!==0?pe(De,Hm):Hd()})}function Is(){return Ia===0&&(Ia=gt()),Ia}function qd(v){return v==null||typeof v=="symbol"||typeof v=="boolean"?null:typeof v=="function"?v:yr(""+v)}function Wd(v,x){var $=x.ownerDocument.createElement("input");return $.name=x.name,$.value=x.value,v.id&&$.setAttribute("form",v.id),x.parentNode.insertBefore($,x),v=new FormData(v),$.parentNode.removeChild($),v}function Um(v,x,$,O,k){if(x==="submit"&&$&&$.stateNode===k){var H=qd((k[Ze]||null).action),oe=O.submitter;oe&&(x=(x=oe[Ze]||null)?qd(x.formAction):oe.getAttribute("formAction"),x!==null&&(H=x,oe=null));var se=new ri("action","action",null,O,k);v.push({event:se,listeners:[{instance:null,listener:function(){if(O.defaultPrevented){if(Ia!==0){var Se=oe?Wd(k,oe):new FormData(k);Zl($,{pending:!0,data:Se,method:k.method,action:H},null,Se)}}else typeof H=="function"&&(se.preventDefault(),Se=oe?Wd(k,oe):new FormData(k),Zl($,{pending:!0,data:Se,method:k.method,action:H},H,Se))},currentTarget:k}]})}}for(var As=0;As<gl.length;As++){var Ps=gl[As],Km=Ps.toLowerCase(),qm=Ps[0].toUpperCase()+Ps.slice(1);wn(Km,"on"+qm)}wn(wc,"onAnimationEnd"),wn($c,"onAnimationIteration"),wn(Rc,"onAnimationStart"),wn("dblclick","onDoubleClick"),wn("focusin","onFocus"),wn("focusout","onBlur"),wn(cm,"onTransitionRun"),wn(um,"onTransitionStart"),wn(dm,"onTransitionCancel"),wn(_c,"onTransitionEnd"),tt("onMouseEnter",["mouseout","mouseover"]),tt("onMouseLeave",["mouseout","mouseover"]),tt("onPointerEnter",["pointerout","pointerover"]),tt("onPointerLeave",["pointerout","pointerover"]),Gt("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Gt("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Gt("onBeforeInput",["compositionend","keypress","textInput","paste"]),Gt("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Gt("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Gt("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Uo="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),Wm=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Uo));function Gd(v,x){x=(x&4)!==0;for(var $=0;$<v.length;$++){var O=v[$],k=O.event;O=O.listeners;e:{var H=void 0;if(x)for(var oe=O.length-1;0<=oe;oe--){var se=O[oe],Se=se.instance,ze=se.currentTarget;if(se=se.listener,Se!==H&&k.isPropagationStopped())break e;H=se,k.currentTarget=ze;try{H(k)}catch(Xe){Oi(Xe)}k.currentTarget=null,H=Se}else for(oe=0;oe<O.length;oe++){if(se=O[oe],Se=se.instance,ze=se.currentTarget,se=se.listener,Se!==H&&k.isPropagationStopped())break e;H=se,k.currentTarget=ze;try{H(k)}catch(Xe){Oi(Xe)}k.currentTarget=null,H=Se}}}}function rr(v,x){var $=x[yt];$===void 0&&($=x[yt]=new Set);var O=v+"__bubble";$.has(O)||(Xd(x,v,2,!1),$.add(O))}function ks(v,x,$){var O=0;x&&(O|=4),Xd($,v,O,x)}var Vi="_reactListening"+Math.random().toString(36).slice(2);function zs(v){if(!v[Vi]){v[Vi]=!0,Kt.forEach(function($){$!=="selectionchange"&&(Wm.has($)||ks($,!1,v),ks($,!0,v))});var x=v.nodeType===9?v:v.ownerDocument;x===null||x[Vi]||(x[Vi]=!0,ks("selectionchange",!1,x))}}function Xd(v,x,$,O){switch(xf(x)){case 2:var k=x0;break;case 8:k=S0;break;default:k=Ys}$=k.bind(null,x,$,v),k=void 0,!jt||x!=="touchstart"&&x!=="touchmove"&&x!=="wheel"||(k=!0),O?k!==void 0?v.addEventListener(x,$,{capture:!0,passive:k}):v.addEventListener(x,$,!0):k!==void 0?v.addEventListener(x,$,{passive:k}):v.addEventListener(x,$,!1)}function Ds(v,x,$,O,k){var H=O;if((x&1)===0&&(x&2)===0&&O!==null)e:for(;;){if(O===null)return;var oe=O.tag;if(oe===3||oe===4){var se=O.stateNode.containerInfo;if(se===k)break;if(oe===4)for(oe=O.return;oe!==null;){var Se=oe.tag;if((Se===3||Se===4)&&oe.stateNode.containerInfo===k)return;oe=oe.return}for(;se!==null;){if(oe=xt(se),oe===null)return;if(Se=oe.tag,Se===5||Se===6||Se===26||Se===27){O=H=oe;continue e}se=se.parentNode}}O=O.return}Aa(function(){var ze=H,Xe=Lr($),Qe=[];e:{var Fe=Oc.get(v);if(Fe!==void 0){var He=ri,Ht=v;switch(v){case"keypress":if(ga($)===0)break e;case"keydown":case"keyup":He=Ff;break;case"focusin":Ht="focus",He=ll;break;case"focusout":Ht="blur",He=ll;break;case"beforeblur":case"afterblur":He=ll;break;case"click":if($.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":He=rc;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":He=Of;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":He=Uf;break;case wc:case $c:case Rc:He=If;break;case _c:He=qf;break;case"scroll":case"scrollend":He=Tf;break;case"wheel":He=Gf;break;case"copy":case"cut":case"paste":He=Pf;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":He=ac;break;case"toggle":case"beforetoggle":He=Yf}var Lt=(x&4)!==0,gr=!Lt&&(v==="scroll"||v==="scrollend"),Me=Lt?Fe!==null?Fe+"Capture":null:Fe;Lt=[];for(var $e=ze,Ie;$e!==null;){var Ye=$e;if(Ie=Ye.stateNode,Ye=Ye.tag,Ye!==5&&Ye!==26&&Ye!==27||Ie===null||Me===null||(Ye=In($e,Me),Ye!=null&&Lt.push(Ko($e,Ye,Ie))),gr)break;$e=$e.return}0<Lt.length&&(Fe=new He(Fe,Ht,null,$,Xe),Qe.push({event:Fe,listeners:Lt}))}}if((x&7)===0){e:{if(Fe=v==="mouseover"||v==="pointerover",He=v==="mouseout"||v==="pointerout",Fe&&$!==Gr&&(Ht=$.relatedTarget||$.fromElement)&&(xt(Ht)||Ht[Je]))break e;if((He||Fe)&&(Fe=Xe.window===Xe?Xe:(Fe=Xe.ownerDocument)?Fe.defaultView||Fe.parentWindow:window,He?(Ht=$.relatedTarget||$.toElement,He=ze,Ht=Ht?xt(Ht):null,Ht!==null&&(gr=m(Ht),Lt=Ht.tag,Ht!==gr||Lt!==5&&Lt!==27&&Lt!==6)&&(Ht=null)):(He=null,Ht=ze),He!==Ht)){if(Lt=rc,Ye="onMouseLeave",Me="onMouseEnter",$e="mouse",(v==="pointerout"||v==="pointerover")&&(Lt=ac,Ye="onPointerLeave",Me="onPointerEnter",$e="pointer"),gr=He==null?Fe:Dt(He),Ie=Ht==null?Fe:Dt(Ht),Fe=new Lt(Ye,$e+"leave",He,$,Xe),Fe.target=gr,Fe.relatedTarget=Ie,Ye=null,xt(Xe)===ze&&(Lt=new Lt(Me,$e+"enter",Ht,$,Xe),Lt.target=Ie,Lt.relatedTarget=gr,Ye=Lt),gr=Ye,He&&Ht)t:{for(Lt=He,Me=Ht,$e=0,Ie=Lt;Ie;Ie=io(Ie))$e++;for(Ie=0,Ye=Me;Ye;Ye=io(Ye))Ie++;for(;0<$e-Ie;)Lt=io(Lt),$e--;for(;0<Ie-$e;)Me=io(Me),Ie--;for(;$e--;){if(Lt===Me||Me!==null&&Lt===Me.alternate)break t;Lt=io(Lt),Me=io(Me)}Lt=null}else Lt=null;He!==null&&Yd(Qe,Fe,He,Lt,!1),Ht!==null&&gr!==null&&Yd(Qe,gr,Ht,Lt,!0)}}e:{if(Fe=ze?Dt(ze):window,He=Fe.nodeName&&Fe.nodeName.toLowerCase(),He==="select"||He==="input"&&Fe.type==="file")var Mt=fc;else if(uc(Fe))if(mc)Mt=im;else{Mt=am;var Jt=nm}else He=Fe.nodeName,!He||He.toLowerCase()!=="input"||Fe.type!=="checkbox"&&Fe.type!=="radio"?ze&&It(ze.elementType)&&(Mt=fc):Mt=om;if(Mt&&(Mt=Mt(v,ze))){dc(Qe,Mt,$,Xe);break e}Jt&&Jt(v,Fe,ze),v==="focusout"&&ze&&Fe.type==="number"&&ze.memoizedProps.value!=null&&or(Fe,"number",Fe.value)}switch(Jt=ze?Dt(ze):window,v){case"focusin":(uc(Jt)||Jt.contentEditable==="true")&&(za=Jt,ml=ze,vo=null);break;case"focusout":vo=ml=za=null;break;case"mousedown":pl=!0;break;case"contextmenu":case"mouseup":case"dragend":pl=!1,Ec(Qe,$,Xe);break;case"selectionchange":if(sm)break;case"keydown":case"keyup":Ec(Qe,$,Xe)}var At;if(cl)e:{switch(v){case"compositionstart":var Ft="onCompositionStart";break e;case"compositionend":Ft="onCompositionEnd";break e;case"compositionupdate":Ft="onCompositionUpdate";break e}Ft=void 0}else ka?sc(v,$)&&(Ft="onCompositionEnd"):v==="keydown"&&$.keyCode===229&&(Ft="onCompositionStart");Ft&&(oc&&$.locale!=="ko"&&(ka||Ft!=="onCompositionStart"?Ft==="onCompositionEnd"&&ka&&(At=Pa()):(mr=Xe,Er="value"in mr?mr.value:mr.textContent,ka=!0)),Jt=Ui(ze,Ft),0<Jt.length&&(Ft=new nc(Ft,v,null,$,Xe),Qe.push({event:Ft,listeners:Jt}),At?Ft.data=At:(At=cc($),At!==null&&(Ft.data=At)))),(At=Qf?Jf(v,$):em(v,$))&&(Ft=Ui(ze,"onBeforeInput"),0<Ft.length&&(Jt=new nc("onBeforeInput","beforeinput",null,$,Xe),Qe.push({event:Jt,listeners:Ft}),Jt.data=At)),Um(Qe,v,ze,$,Xe)}Gd(Qe,x)})}function Ko(v,x,$){return{instance:v,listener:x,currentTarget:$}}function Ui(v,x){for(var $=x+"Capture",O=[];v!==null;){var k=v,H=k.stateNode;if(k=k.tag,k!==5&&k!==26&&k!==27||H===null||(k=In(v,$),k!=null&&O.unshift(Ko(v,k,H)),k=In(v,x),k!=null&&O.push(Ko(v,k,H))),v.tag===3)return O;v=v.return}return[]}function io(v){if(v===null)return null;do v=v.return;while(v&&v.tag!==5&&v.tag!==27);return v||null}function Yd(v,x,$,O,k){for(var H=x._reactName,oe=[];$!==null&&$!==O;){var se=$,Se=se.alternate,ze=se.stateNode;if(se=se.tag,Se!==null&&Se===O)break;se!==5&&se!==26&&se!==27||ze===null||(Se=ze,k?(ze=In($,H),ze!=null&&oe.unshift(Ko($,ze,Se))):k||(ze=In($,H),ze!=null&&oe.push(Ko($,ze,Se)))),$=$.return}oe.length!==0&&v.push({event:x,listeners:oe})}var Gm=/\r\n?/g,Xm=/\u0000|\uFFFD/g;function Zd(v){return(typeof v=="string"?v:""+v).replace(Gm,`
`).replace(Xm,"")}function Qd(v,x){return x=Zd(x),Zd(v)===x}function Ki(){}function hr(v,x,$,O,k,H){switch($){case"children":typeof O=="string"?x==="body"||x==="textarea"&&O===""||Sr(v,O):(typeof O=="number"||typeof O=="bigint")&&x!=="body"&&Sr(v,""+O);break;case"className":qt(v,"class",O);break;case"tabIndex":qt(v,"tabindex",O);break;case"dir":case"role":case"viewBox":case"width":case"height":qt(v,$,O);break;case"style":Pt(v,O,H);break;case"data":if(x!=="object"){qt(v,"data",O);break}case"src":case"href":if(O===""&&(x!=="a"||$!=="href")){v.removeAttribute($);break}if(O==null||typeof O=="function"||typeof O=="symbol"||typeof O=="boolean"){v.removeAttribute($);break}O=yr(""+O),v.setAttribute($,O);break;case"action":case"formAction":if(typeof O=="function"){v.setAttribute($,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof H=="function"&&($==="formAction"?(x!=="input"&&hr(v,x,"name",k.name,k,null),hr(v,x,"formEncType",k.formEncType,k,null),hr(v,x,"formMethod",k.formMethod,k,null),hr(v,x,"formTarget",k.formTarget,k,null)):(hr(v,x,"encType",k.encType,k,null),hr(v,x,"method",k.method,k,null),hr(v,x,"target",k.target,k,null)));if(O==null||typeof O=="symbol"||typeof O=="boolean"){v.removeAttribute($);break}O=yr(""+O),v.setAttribute($,O);break;case"onClick":O!=null&&(v.onclick=Ki);break;case"onScroll":O!=null&&rr("scroll",v);break;case"onScrollEnd":O!=null&&rr("scrollend",v);break;case"dangerouslySetInnerHTML":if(O!=null){if(typeof O!="object"||!("__html"in O))throw Error(d(61));if($=O.__html,$!=null){if(k.children!=null)throw Error(d(60));v.innerHTML=$}}break;case"multiple":v.multiple=O&&typeof O!="function"&&typeof O!="symbol";break;case"muted":v.muted=O&&typeof O!="function"&&typeof O!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(O==null||typeof O=="function"||typeof O=="boolean"||typeof O=="symbol"){v.removeAttribute("xlink:href");break}$=yr(""+O),v.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",$);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":O!=null&&typeof O!="function"&&typeof O!="symbol"?v.setAttribute($,""+O):v.removeAttribute($);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":O&&typeof O!="function"&&typeof O!="symbol"?v.setAttribute($,""):v.removeAttribute($);break;case"capture":case"download":O===!0?v.setAttribute($,""):O!==!1&&O!=null&&typeof O!="function"&&typeof O!="symbol"?v.setAttribute($,O):v.removeAttribute($);break;case"cols":case"rows":case"size":case"span":O!=null&&typeof O!="function"&&typeof O!="symbol"&&!isNaN(O)&&1<=O?v.setAttribute($,O):v.removeAttribute($);break;case"rowSpan":case"start":O==null||typeof O=="function"||typeof O=="symbol"||isNaN(O)?v.removeAttribute($):v.setAttribute($,O);break;case"popover":rr("beforetoggle",v),rr("toggle",v),Bt(v,"popover",O);break;case"xlinkActuate":er(v,"http://www.w3.org/1999/xlink","xlink:actuate",O);break;case"xlinkArcrole":er(v,"http://www.w3.org/1999/xlink","xlink:arcrole",O);break;case"xlinkRole":er(v,"http://www.w3.org/1999/xlink","xlink:role",O);break;case"xlinkShow":er(v,"http://www.w3.org/1999/xlink","xlink:show",O);break;case"xlinkTitle":er(v,"http://www.w3.org/1999/xlink","xlink:title",O);break;case"xlinkType":er(v,"http://www.w3.org/1999/xlink","xlink:type",O);break;case"xmlBase":er(v,"http://www.w3.org/XML/1998/namespace","xml:base",O);break;case"xmlLang":er(v,"http://www.w3.org/XML/1998/namespace","xml:lang",O);break;case"xmlSpace":er(v,"http://www.w3.org/XML/1998/namespace","xml:space",O);break;case"is":Bt(v,"is",O);break;case"innerText":case"textContent":break;default:(!(2<$.length)||$[0]!=="o"&&$[0]!=="O"||$[1]!=="n"&&$[1]!=="N")&&($=Or.get($)||$,Bt(v,$,O))}}function js(v,x,$,O,k,H){switch($){case"style":Pt(v,O,H);break;case"dangerouslySetInnerHTML":if(O!=null){if(typeof O!="object"||!("__html"in O))throw Error(d(61));if($=O.__html,$!=null){if(k.children!=null)throw Error(d(60));v.innerHTML=$}}break;case"children":typeof O=="string"?Sr(v,O):(typeof O=="number"||typeof O=="bigint")&&Sr(v,""+O);break;case"onScroll":O!=null&&rr("scroll",v);break;case"onScrollEnd":O!=null&&rr("scrollend",v);break;case"onClick":O!=null&&(v.onclick=Ki);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!Zt.hasOwnProperty($))e:{if($[0]==="o"&&$[1]==="n"&&(k=$.endsWith("Capture"),x=$.slice(2,k?$.length-7:void 0),H=v[Ze]||null,H=H!=null?H[$]:null,typeof H=="function"&&v.removeEventListener(x,H,k),typeof O=="function")){typeof H!="function"&&H!==null&&($ in v?v[$]=null:v.hasAttribute($)&&v.removeAttribute($)),v.addEventListener(x,O,k);break e}$ in v?v[$]=O:O===!0?v.setAttribute($,""):Bt(v,$,O)}}}function Zr(v,x,$){switch(x){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":rr("error",v),rr("load",v);var O=!1,k=!1,H;for(H in $)if($.hasOwnProperty(H)){var oe=$[H];if(oe!=null)switch(H){case"src":O=!0;break;case"srcSet":k=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(d(137,x));default:hr(v,x,H,oe,$,null)}}k&&hr(v,x,"srcSet",$.srcSet,$,null),O&&hr(v,x,"src",$.src,$,null);return;case"input":rr("invalid",v);var se=H=oe=k=null,Se=null,ze=null;for(O in $)if($.hasOwnProperty(O)){var Xe=$[O];if(Xe!=null)switch(O){case"name":k=Xe;break;case"type":oe=Xe;break;case"checked":Se=Xe;break;case"defaultChecked":ze=Xe;break;case"value":H=Xe;break;case"defaultValue":se=Xe;break;case"children":case"dangerouslySetInnerHTML":if(Xe!=null)throw Error(d(137,x));break;default:hr(v,x,O,Xe,$,null)}}Qt(v,H,se,Se,ze,oe,k,!1),wr(v);return;case"select":rr("invalid",v),O=oe=H=null;for(k in $)if($.hasOwnProperty(k)&&(se=$[k],se!=null))switch(k){case"value":H=se;break;case"defaultValue":oe=se;break;case"multiple":O=se;default:hr(v,x,k,se,$,null)}x=H,$=oe,v.multiple=!!O,x!=null?ar(v,!!O,x,!1):$!=null&&ar(v,!!O,$,!0);return;case"textarea":rr("invalid",v),H=k=O=null;for(oe in $)if($.hasOwnProperty(oe)&&(se=$[oe],se!=null))switch(oe){case"value":O=se;break;case"defaultValue":k=se;break;case"children":H=se;break;case"dangerouslySetInnerHTML":if(se!=null)throw Error(d(91));break;default:hr(v,x,oe,se,$,null)}_r(v,O,k,H),wr(v);return;case"option":for(Se in $)if($.hasOwnProperty(Se)&&(O=$[Se],O!=null))switch(Se){case"selected":v.selected=O&&typeof O!="function"&&typeof O!="symbol";break;default:hr(v,x,Se,O,$,null)}return;case"dialog":rr("beforetoggle",v),rr("toggle",v),rr("cancel",v),rr("close",v);break;case"iframe":case"object":rr("load",v);break;case"video":case"audio":for(O=0;O<Uo.length;O++)rr(Uo[O],v);break;case"image":rr("error",v),rr("load",v);break;case"details":rr("toggle",v);break;case"embed":case"source":case"link":rr("error",v),rr("load",v);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(ze in $)if($.hasOwnProperty(ze)&&(O=$[ze],O!=null))switch(ze){case"children":case"dangerouslySetInnerHTML":throw Error(d(137,x));default:hr(v,x,ze,O,$,null)}return;default:if(It(x)){for(Xe in $)$.hasOwnProperty(Xe)&&(O=$[Xe],O!==void 0&&js(v,x,Xe,O,$,void 0));return}}for(se in $)$.hasOwnProperty(se)&&(O=$[se],O!=null&&hr(v,x,se,O,$,null))}function Ym(v,x,$,O){switch(x){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var k=null,H=null,oe=null,se=null,Se=null,ze=null,Xe=null;for(He in $){var Qe=$[He];if($.hasOwnProperty(He)&&Qe!=null)switch(He){case"checked":break;case"value":break;case"defaultValue":Se=Qe;default:O.hasOwnProperty(He)||hr(v,x,He,null,O,Qe)}}for(var Fe in O){var He=O[Fe];if(Qe=$[Fe],O.hasOwnProperty(Fe)&&(He!=null||Qe!=null))switch(Fe){case"type":H=He;break;case"name":k=He;break;case"checked":ze=He;break;case"defaultChecked":Xe=He;break;case"value":oe=He;break;case"defaultValue":se=He;break;case"children":case"dangerouslySetInnerHTML":if(He!=null)throw Error(d(137,x));break;default:He!==Qe&&hr(v,x,Fe,He,O,Qe)}}Xt(v,oe,se,Se,ze,Xe,H,k);return;case"select":He=oe=se=Fe=null;for(H in $)if(Se=$[H],$.hasOwnProperty(H)&&Se!=null)switch(H){case"value":break;case"multiple":He=Se;default:O.hasOwnProperty(H)||hr(v,x,H,null,O,Se)}for(k in O)if(H=O[k],Se=$[k],O.hasOwnProperty(k)&&(H!=null||Se!=null))switch(k){case"value":Fe=H;break;case"defaultValue":se=H;break;case"multiple":oe=H;default:H!==Se&&hr(v,x,k,H,O,Se)}x=se,$=oe,O=He,Fe!=null?ar(v,!!$,Fe,!1):!!O!=!!$&&(x!=null?ar(v,!!$,x,!0):ar(v,!!$,$?[]:"",!1));return;case"textarea":He=Fe=null;for(se in $)if(k=$[se],$.hasOwnProperty(se)&&k!=null&&!O.hasOwnProperty(se))switch(se){case"value":break;case"children":break;default:hr(v,x,se,null,O,k)}for(oe in O)if(k=O[oe],H=$[oe],O.hasOwnProperty(oe)&&(k!=null||H!=null))switch(oe){case"value":Fe=k;break;case"defaultValue":He=k;break;case"children":break;case"dangerouslySetInnerHTML":if(k!=null)throw Error(d(91));break;default:k!==H&&hr(v,x,oe,k,O,H)}Ir(v,Fe,He);return;case"option":for(var Ht in $)if(Fe=$[Ht],$.hasOwnProperty(Ht)&&Fe!=null&&!O.hasOwnProperty(Ht))switch(Ht){case"selected":v.selected=!1;break;default:hr(v,x,Ht,null,O,Fe)}for(Se in O)if(Fe=O[Se],He=$[Se],O.hasOwnProperty(Se)&&Fe!==He&&(Fe!=null||He!=null))switch(Se){case"selected":v.selected=Fe&&typeof Fe!="function"&&typeof Fe!="symbol";break;default:hr(v,x,Se,Fe,O,He)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var Lt in $)Fe=$[Lt],$.hasOwnProperty(Lt)&&Fe!=null&&!O.hasOwnProperty(Lt)&&hr(v,x,Lt,null,O,Fe);for(ze in O)if(Fe=O[ze],He=$[ze],O.hasOwnProperty(ze)&&Fe!==He&&(Fe!=null||He!=null))switch(ze){case"children":case"dangerouslySetInnerHTML":if(Fe!=null)throw Error(d(137,x));break;default:hr(v,x,ze,Fe,O,He)}return;default:if(It(x)){for(var gr in $)Fe=$[gr],$.hasOwnProperty(gr)&&Fe!==void 0&&!O.hasOwnProperty(gr)&&js(v,x,gr,void 0,O,Fe);for(Xe in O)Fe=O[Xe],He=$[Xe],!O.hasOwnProperty(Xe)||Fe===He||Fe===void 0&&He===void 0||js(v,x,Xe,Fe,O,He);return}}for(var Me in $)Fe=$[Me],$.hasOwnProperty(Me)&&Fe!=null&&!O.hasOwnProperty(Me)&&hr(v,x,Me,null,O,Fe);for(Qe in O)Fe=O[Qe],He=$[Qe],!O.hasOwnProperty(Qe)||Fe===He||Fe==null&&He==null||hr(v,x,Qe,Fe,O,He)}var Ls=null,Bs=null;function qi(v){return v.nodeType===9?v:v.ownerDocument}function Jd(v){switch(v){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function ef(v,x){if(v===0)switch(x){case"svg":return 1;case"math":return 2;default:return 0}return v===1&&x==="foreignObject"?0:v}function Fs(v,x){return v==="textarea"||v==="noscript"||typeof x.children=="string"||typeof x.children=="number"||typeof x.children=="bigint"||typeof x.dangerouslySetInnerHTML=="object"&&x.dangerouslySetInnerHTML!==null&&x.dangerouslySetInnerHTML.__html!=null}var Hs=null;function Zm(){var v=window.event;return v&&v.type==="popstate"?v===Hs?!1:(Hs=v,!0):(Hs=null,!1)}var tf=typeof setTimeout=="function"?setTimeout:void 0,Qm=typeof clearTimeout=="function"?clearTimeout:void 0,rf=typeof Promise=="function"?Promise:void 0,Jm=typeof queueMicrotask=="function"?queueMicrotask:typeof rf<"u"?function(v){return rf.resolve(null).then(v).catch(e0)}:tf;function e0(v){setTimeout(function(){throw v})}function ca(v){return v==="head"}function nf(v,x){var $=x,O=0,k=0;do{var H=$.nextSibling;if(v.removeChild($),H&&H.nodeType===8)if($=H.data,$==="/$"){if(0<O&&8>O){$=O;var oe=v.ownerDocument;if($&1&&qo(oe.documentElement),$&2&&qo(oe.body),$&4)for($=oe.head,qo($),oe=$.firstChild;oe;){var se=oe.nextSibling,Se=oe.nodeName;oe[ft]||Se==="SCRIPT"||Se==="STYLE"||Se==="LINK"&&oe.rel.toLowerCase()==="stylesheet"||$.removeChild(oe),oe=se}}if(k===0){v.removeChild(H),ei(x);return}k--}else $==="$"||$==="$?"||$==="$!"?k++:O=$.charCodeAt(0)-48;else O=0;$=H}while($);ei(x)}function Vs(v){var x=v.firstChild;for(x&&x.nodeType===10&&(x=x.nextSibling);x;){var $=x;switch(x=x.nextSibling,$.nodeName){case"HTML":case"HEAD":case"BODY":Vs($),dt($);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if($.rel.toLowerCase()==="stylesheet")continue}v.removeChild($)}}function t0(v,x,$,O){for(;v.nodeType===1;){var k=$;if(v.nodeName.toLowerCase()!==x.toLowerCase()){if(!O&&(v.nodeName!=="INPUT"||v.type!=="hidden"))break}else if(O){if(!v[ft])switch(x){case"meta":if(!v.hasAttribute("itemprop"))break;return v;case"link":if(H=v.getAttribute("rel"),H==="stylesheet"&&v.hasAttribute("data-precedence"))break;if(H!==k.rel||v.getAttribute("href")!==(k.href==null||k.href===""?null:k.href)||v.getAttribute("crossorigin")!==(k.crossOrigin==null?null:k.crossOrigin)||v.getAttribute("title")!==(k.title==null?null:k.title))break;return v;case"style":if(v.hasAttribute("data-precedence"))break;return v;case"script":if(H=v.getAttribute("src"),(H!==(k.src==null?null:k.src)||v.getAttribute("type")!==(k.type==null?null:k.type)||v.getAttribute("crossorigin")!==(k.crossOrigin==null?null:k.crossOrigin))&&H&&v.hasAttribute("async")&&!v.hasAttribute("itemprop"))break;return v;default:return v}}else if(x==="input"&&v.type==="hidden"){var H=k.name==null?null:""+k.name;if(k.type==="hidden"&&v.getAttribute("name")===H)return v}else return v;if(v=Rn(v.nextSibling),v===null)break}return null}function r0(v,x,$){if(x==="")return null;for(;v.nodeType!==3;)if((v.nodeType!==1||v.nodeName!=="INPUT"||v.type!=="hidden")&&!$||(v=Rn(v.nextSibling),v===null))return null;return v}function Us(v){return v.data==="$!"||v.data==="$?"&&v.ownerDocument.readyState==="complete"}function n0(v,x){var $=v.ownerDocument;if(v.data!=="$?"||$.readyState==="complete")x();else{var O=function(){x(),$.removeEventListener("DOMContentLoaded",O)};$.addEventListener("DOMContentLoaded",O),v._reactRetry=O}}function Rn(v){for(;v!=null;v=v.nextSibling){var x=v.nodeType;if(x===1||x===3)break;if(x===8){if(x=v.data,x==="$"||x==="$!"||x==="$?"||x==="F!"||x==="F")break;if(x==="/$")return null}}return v}var Ks=null;function af(v){v=v.previousSibling;for(var x=0;v;){if(v.nodeType===8){var $=v.data;if($==="$"||$==="$!"||$==="$?"){if(x===0)return v;x--}else $==="/$"&&x++}v=v.previousSibling}return null}function of(v,x,$){switch(x=qi($),v){case"html":if(v=x.documentElement,!v)throw Error(d(452));return v;case"head":if(v=x.head,!v)throw Error(d(453));return v;case"body":if(v=x.body,!v)throw Error(d(454));return v;default:throw Error(d(451))}}function qo(v){for(var x=v.attributes;x.length;)v.removeAttributeNode(x[0]);dt(v)}var En=new Map,lf=new Set;function Wi(v){return typeof v.getRootNode=="function"?v.getRootNode():v.nodeType===9?v:v.ownerDocument}var Wn=G.d;G.d={f:a0,r:o0,D:i0,C:l0,L:s0,m:c0,X:d0,S:u0,M:f0};function a0(){var v=Wn.f(),x=ji();return v||x}function o0(v){var x=Tt(v);x!==null&&x.tag===5&&x.type==="form"?Ru(x):Wn.r(v)}var lo=typeof document>"u"?null:document;function sf(v,x,$){var O=lo;if(O&&typeof x=="string"&&x){var k=st(x);k='link[rel="'+v+'"][href="'+k+'"]',typeof $=="string"&&(k+='[crossorigin="'+$+'"]'),lf.has(k)||(lf.add(k),v={rel:v,crossOrigin:$,href:x},O.querySelector(k)===null&&(x=O.createElement("link"),Zr(x,"link",v),Nt(x),O.head.appendChild(x)))}}function i0(v){Wn.D(v),sf("dns-prefetch",v,null)}function l0(v,x){Wn.C(v,x),sf("preconnect",v,x)}function s0(v,x,$){Wn.L(v,x,$);var O=lo;if(O&&v&&x){var k='link[rel="preload"][as="'+st(x)+'"]';x==="image"&&$&&$.imageSrcSet?(k+='[imagesrcset="'+st($.imageSrcSet)+'"]',typeof $.imageSizes=="string"&&(k+='[imagesizes="'+st($.imageSizes)+'"]')):k+='[href="'+st(v)+'"]';var H=k;switch(x){case"style":H=so(v);break;case"script":H=co(v)}En.has(H)||(v=C({rel:"preload",href:x==="image"&&$&&$.imageSrcSet?void 0:v,as:x},$),En.set(H,v),O.querySelector(k)!==null||x==="style"&&O.querySelector(Wo(H))||x==="script"&&O.querySelector(Go(H))||(x=O.createElement("link"),Zr(x,"link",v),Nt(x),O.head.appendChild(x)))}}function c0(v,x){Wn.m(v,x);var $=lo;if($&&v){var O=x&&typeof x.as=="string"?x.as:"script",k='link[rel="modulepreload"][as="'+st(O)+'"][href="'+st(v)+'"]',H=k;switch(O){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":H=co(v)}if(!En.has(H)&&(v=C({rel:"modulepreload",href:v},x),En.set(H,v),$.querySelector(k)===null)){switch(O){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if($.querySelector(Go(H)))return}O=$.createElement("link"),Zr(O,"link",v),Nt(O),$.head.appendChild(O)}}}function u0(v,x,$){Wn.S(v,x,$);var O=lo;if(O&&v){var k=Vt(O).hoistableStyles,H=so(v);x=x||"default";var oe=k.get(H);if(!oe){var se={loading:0,preload:null};if(oe=O.querySelector(Wo(H)))se.loading=5;else{v=C({rel:"stylesheet",href:v,"data-precedence":x},$),($=En.get(H))&&qs(v,$);var Se=oe=O.createElement("link");Nt(Se),Zr(Se,"link",v),Se._p=new Promise(function(ze,Xe){Se.onload=ze,Se.onerror=Xe}),Se.addEventListener("load",function(){se.loading|=1}),Se.addEventListener("error",function(){se.loading|=2}),se.loading|=4,Gi(oe,x,O)}oe={type:"stylesheet",instance:oe,count:1,state:se},k.set(H,oe)}}}function d0(v,x){Wn.X(v,x);var $=lo;if($&&v){var O=Vt($).hoistableScripts,k=co(v),H=O.get(k);H||(H=$.querySelector(Go(k)),H||(v=C({src:v,async:!0},x),(x=En.get(k))&&Ws(v,x),H=$.createElement("script"),Nt(H),Zr(H,"link",v),$.head.appendChild(H)),H={type:"script",instance:H,count:1,state:null},O.set(k,H))}}function f0(v,x){Wn.M(v,x);var $=lo;if($&&v){var O=Vt($).hoistableScripts,k=co(v),H=O.get(k);H||(H=$.querySelector(Go(k)),H||(v=C({src:v,async:!0,type:"module"},x),(x=En.get(k))&&Ws(v,x),H=$.createElement("script"),Nt(H),Zr(H,"link",v),$.head.appendChild(H)),H={type:"script",instance:H,count:1,state:null},O.set(k,H))}}function cf(v,x,$,O){var k=(k=ue.current)?Wi(k):null;if(!k)throw Error(d(446));switch(v){case"meta":case"title":return null;case"style":return typeof $.precedence=="string"&&typeof $.href=="string"?(x=so($.href),$=Vt(k).hoistableStyles,O=$.get(x),O||(O={type:"style",instance:null,count:0,state:null},$.set(x,O)),O):{type:"void",instance:null,count:0,state:null};case"link":if($.rel==="stylesheet"&&typeof $.href=="string"&&typeof $.precedence=="string"){v=so($.href);var H=Vt(k).hoistableStyles,oe=H.get(v);if(oe||(k=k.ownerDocument||k,oe={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},H.set(v,oe),(H=k.querySelector(Wo(v)))&&!H._p&&(oe.instance=H,oe.state.loading=5),En.has(v)||($={rel:"preload",as:"style",href:$.href,crossOrigin:$.crossOrigin,integrity:$.integrity,media:$.media,hrefLang:$.hrefLang,referrerPolicy:$.referrerPolicy},En.set(v,$),H||m0(k,v,$,oe.state))),x&&O===null)throw Error(d(528,""));return oe}if(x&&O!==null)throw Error(d(529,""));return null;case"script":return x=$.async,$=$.src,typeof $=="string"&&x&&typeof x!="function"&&typeof x!="symbol"?(x=co($),$=Vt(k).hoistableScripts,O=$.get(x),O||(O={type:"script",instance:null,count:0,state:null},$.set(x,O)),O):{type:"void",instance:null,count:0,state:null};default:throw Error(d(444,v))}}function so(v){return'href="'+st(v)+'"'}function Wo(v){return'link[rel="stylesheet"]['+v+"]"}function uf(v){return C({},v,{"data-precedence":v.precedence,precedence:null})}function m0(v,x,$,O){v.querySelector('link[rel="preload"][as="style"]['+x+"]")?O.loading=1:(x=v.createElement("link"),O.preload=x,x.addEventListener("load",function(){return O.loading|=1}),x.addEventListener("error",function(){return O.loading|=2}),Zr(x,"link",$),Nt(x),v.head.appendChild(x))}function co(v){return'[src="'+st(v)+'"]'}function Go(v){return"script[async]"+v}function df(v,x,$){if(x.count++,x.instance===null)switch(x.type){case"style":var O=v.querySelector('style[data-href~="'+st($.href)+'"]');if(O)return x.instance=O,Nt(O),O;var k=C({},$,{"data-href":$.href,"data-precedence":$.precedence,href:null,precedence:null});return O=(v.ownerDocument||v).createElement("style"),Nt(O),Zr(O,"style",k),Gi(O,$.precedence,v),x.instance=O;case"stylesheet":k=so($.href);var H=v.querySelector(Wo(k));if(H)return x.state.loading|=4,x.instance=H,Nt(H),H;O=uf($),(k=En.get(k))&&qs(O,k),H=(v.ownerDocument||v).createElement("link"),Nt(H);var oe=H;return oe._p=new Promise(function(se,Se){oe.onload=se,oe.onerror=Se}),Zr(H,"link",O),x.state.loading|=4,Gi(H,$.precedence,v),x.instance=H;case"script":return H=co($.src),(k=v.querySelector(Go(H)))?(x.instance=k,Nt(k),k):(O=$,(k=En.get(H))&&(O=C({},$),Ws(O,k)),v=v.ownerDocument||v,k=v.createElement("script"),Nt(k),Zr(k,"link",O),v.head.appendChild(k),x.instance=k);case"void":return null;default:throw Error(d(443,x.type))}else x.type==="stylesheet"&&(x.state.loading&4)===0&&(O=x.instance,x.state.loading|=4,Gi(O,$.precedence,v));return x.instance}function Gi(v,x,$){for(var O=$.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),k=O.length?O[O.length-1]:null,H=k,oe=0;oe<O.length;oe++){var se=O[oe];if(se.dataset.precedence===x)H=se;else if(H!==k)break}H?H.parentNode.insertBefore(v,H.nextSibling):(x=$.nodeType===9?$.head:$,x.insertBefore(v,x.firstChild))}function qs(v,x){v.crossOrigin==null&&(v.crossOrigin=x.crossOrigin),v.referrerPolicy==null&&(v.referrerPolicy=x.referrerPolicy),v.title==null&&(v.title=x.title)}function Ws(v,x){v.crossOrigin==null&&(v.crossOrigin=x.crossOrigin),v.referrerPolicy==null&&(v.referrerPolicy=x.referrerPolicy),v.integrity==null&&(v.integrity=x.integrity)}var Xi=null;function ff(v,x,$){if(Xi===null){var O=new Map,k=Xi=new Map;k.set($,O)}else k=Xi,O=k.get($),O||(O=new Map,k.set($,O));if(O.has(v))return O;for(O.set(v,null),$=$.getElementsByTagName(v),k=0;k<$.length;k++){var H=$[k];if(!(H[ft]||H[mt]||v==="link"&&H.getAttribute("rel")==="stylesheet")&&H.namespaceURI!=="http://www.w3.org/2000/svg"){var oe=H.getAttribute(x)||"";oe=v+oe;var se=O.get(oe);se?se.push(H):O.set(oe,[H])}}return O}function mf(v,x,$){v=v.ownerDocument||v,v.head.insertBefore($,x==="title"?v.querySelector("head > title"):null)}function p0(v,x,$){if($===1||x.itemProp!=null)return!1;switch(v){case"meta":case"title":return!0;case"style":if(typeof x.precedence!="string"||typeof x.href!="string"||x.href==="")break;return!0;case"link":if(typeof x.rel!="string"||typeof x.href!="string"||x.href===""||x.onLoad||x.onError)break;switch(x.rel){case"stylesheet":return v=x.disabled,typeof x.precedence=="string"&&v==null;default:return!0}case"script":if(x.async&&typeof x.async!="function"&&typeof x.async!="symbol"&&!x.onLoad&&!x.onError&&x.src&&typeof x.src=="string")return!0}return!1}function pf(v){return!(v.type==="stylesheet"&&(v.state.loading&3)===0)}var Xo=null;function h0(){}function g0(v,x,$){if(Xo===null)throw Error(d(475));var O=Xo;if(x.type==="stylesheet"&&(typeof $.media!="string"||matchMedia($.media).matches!==!1)&&(x.state.loading&4)===0){if(x.instance===null){var k=so($.href),H=v.querySelector(Wo(k));if(H){v=H._p,v!==null&&typeof v=="object"&&typeof v.then=="function"&&(O.count++,O=Yi.bind(O),v.then(O,O)),x.state.loading|=4,x.instance=H,Nt(H);return}H=v.ownerDocument||v,$=uf($),(k=En.get(k))&&qs($,k),H=H.createElement("link"),Nt(H);var oe=H;oe._p=new Promise(function(se,Se){oe.onload=se,oe.onerror=Se}),Zr(H,"link",$),x.instance=H}O.stylesheets===null&&(O.stylesheets=new Map),O.stylesheets.set(x,v),(v=x.state.preload)&&(x.state.loading&3)===0&&(O.count++,x=Yi.bind(O),v.addEventListener("load",x),v.addEventListener("error",x))}}function v0(){if(Xo===null)throw Error(d(475));var v=Xo;return v.stylesheets&&v.count===0&&Gs(v,v.stylesheets),0<v.count?function(x){var $=setTimeout(function(){if(v.stylesheets&&Gs(v,v.stylesheets),v.unsuspend){var O=v.unsuspend;v.unsuspend=null,O()}},6e4);return v.unsuspend=x,function(){v.unsuspend=null,clearTimeout($)}}:null}function Yi(){if(this.count--,this.count===0){if(this.stylesheets)Gs(this,this.stylesheets);else if(this.unsuspend){var v=this.unsuspend;this.unsuspend=null,v()}}}var Zi=null;function Gs(v,x){v.stylesheets=null,v.unsuspend!==null&&(v.count++,Zi=new Map,x.forEach(y0,v),Zi=null,Yi.call(v))}function y0(v,x){if(!(x.state.loading&4)){var $=Zi.get(v);if($)var O=$.get(null);else{$=new Map,Zi.set(v,$);for(var k=v.querySelectorAll("link[data-precedence],style[data-precedence]"),H=0;H<k.length;H++){var oe=k[H];(oe.nodeName==="LINK"||oe.getAttribute("media")!=="not all")&&($.set(oe.dataset.precedence,oe),O=oe)}O&&$.set(null,O)}k=x.instance,oe=k.getAttribute("data-precedence"),H=$.get(oe)||O,H===O&&$.set(null,k),$.set(oe,k),this.count++,O=Yi.bind(this),k.addEventListener("load",O),k.addEventListener("error",O),H?H.parentNode.insertBefore(k,H.nextSibling):(v=v.nodeType===9?v.head:v,v.insertBefore(k,v.firstChild)),x.state.loading|=4}}var Yo={$$typeof:z,Provider:null,Consumer:null,_currentValue:te,_currentValue2:te,_threadCount:0};function b0(v,x,$,O,k,H,oe,se){this.tag=1,this.containerInfo=v,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=Ut(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=Ut(0),this.hiddenUpdates=Ut(null),this.identifierPrefix=O,this.onUncaughtError=k,this.onCaughtError=H,this.onRecoverableError=oe,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=se,this.incompleteTransitions=new Map}function hf(v,x,$,O,k,H,oe,se,Se,ze,Xe,Qe){return v=new b0(v,x,$,oe,se,Se,ze,Qe),x=1,H===!0&&(x|=24),H=un(3,null,null,x),v.current=H,H.stateNode=v,x=_l(),x.refCount++,v.pooledCache=x,x.refCount++,H.memoizedState={element:O,isDehydrated:$,cache:x},Il(H),v}function gf(v){return v?(v=Ba,v):Ba}function vf(v,x,$,O,k,H){k=gf(k),O.context===null?O.context=k:O.pendingContext=k,O=Yn(x),O.payload={element:$},H=H===void 0?null:H,H!==null&&(O.callback=H),$=Zn(v,O,x),$!==null&&(hn($,v,x),Ro($,v,x))}function yf(v,x){if(v=v.memoizedState,v!==null&&v.dehydrated!==null){var $=v.retryLane;v.retryLane=$!==0&&$<x?$:x}}function Xs(v,x){yf(v,x),(v=v.alternate)&&yf(v,x)}function bf(v){if(v.tag===13){var x=La(v,67108864);x!==null&&hn(x,v,67108864),Xs(v,67108864)}}var Qi=!0;function x0(v,x,$,O){var k=W.T;W.T=null;var H=G.p;try{G.p=2,Ys(v,x,$,O)}finally{G.p=H,W.T=k}}function S0(v,x,$,O){var k=W.T;W.T=null;var H=G.p;try{G.p=8,Ys(v,x,$,O)}finally{G.p=H,W.T=k}}function Ys(v,x,$,O){if(Qi){var k=Zs(O);if(k===null)Ds(v,x,O,Ji,$),Sf(v,O);else if(C0(k,v,x,$,O))O.stopPropagation();else if(Sf(v,O),x&4&&-1<E0.indexOf(v)){for(;k!==null;){var H=Tt(k);if(H!==null)switch(H.tag){case 3:if(H=H.stateNode,H.current.memoizedState.isDehydrated){var oe=Ue(H.pendingLanes);if(oe!==0){var se=H;for(se.pendingLanes|=2,se.entangledLanes|=2;oe;){var Se=1<<31-Oe(oe);se.entanglements[1]|=Se,oe&=~Se}Nn(H),(dr&6)===0&&(zi=we()+500,Vo(0))}}break;case 13:se=La(H,2),se!==null&&hn(se,H,2),ji(),Xs(H,2)}if(H=Zs(O),H===null&&Ds(v,x,O,Ji,$),H===k)break;k=H}k!==null&&O.stopPropagation()}else Ds(v,x,O,null,$)}}function Zs(v){return v=Lr(v),Qs(v)}var Ji=null;function Qs(v){if(Ji=null,v=xt(v),v!==null){var x=m(v);if(x===null)v=null;else{var $=x.tag;if($===13){if(v=g(x),v!==null)return v;v=null}else if($===3){if(x.stateNode.current.memoizedState.isDehydrated)return x.tag===3?x.stateNode.containerInfo:null;v=null}else x!==v&&(v=null)}}return Ji=v,null}function xf(v){switch(v){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Re()){case De:return 2;case Ae:return 8;case Ee:case Ne:return 32;case _e:return 268435456;default:return 32}default:return 32}}var Js=!1,ua=null,da=null,fa=null,Zo=new Map,Qo=new Map,ma=[],E0="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function Sf(v,x){switch(v){case"focusin":case"focusout":ua=null;break;case"dragenter":case"dragleave":da=null;break;case"mouseover":case"mouseout":fa=null;break;case"pointerover":case"pointerout":Zo.delete(x.pointerId);break;case"gotpointercapture":case"lostpointercapture":Qo.delete(x.pointerId)}}function Jo(v,x,$,O,k,H){return v===null||v.nativeEvent!==H?(v={blockedOn:x,domEventName:$,eventSystemFlags:O,nativeEvent:H,targetContainers:[k]},x!==null&&(x=Tt(x),x!==null&&bf(x)),v):(v.eventSystemFlags|=O,x=v.targetContainers,k!==null&&x.indexOf(k)===-1&&x.push(k),v)}function C0(v,x,$,O,k){switch(x){case"focusin":return ua=Jo(ua,v,x,$,O,k),!0;case"dragenter":return da=Jo(da,v,x,$,O,k),!0;case"mouseover":return fa=Jo(fa,v,x,$,O,k),!0;case"pointerover":var H=k.pointerId;return Zo.set(H,Jo(Zo.get(H)||null,v,x,$,O,k)),!0;case"gotpointercapture":return H=k.pointerId,Qo.set(H,Jo(Qo.get(H)||null,v,x,$,O,k)),!0}return!1}function Ef(v){var x=xt(v.target);if(x!==null){var $=m(x);if($!==null){if(x=$.tag,x===13){if(x=g($),x!==null){v.blockedOn=x,et(v.priority,function(){if($.tag===13){var O=pn();O=vt(O);var k=La($,O);k!==null&&hn(k,$,O),Xs($,O)}});return}}else if(x===3&&$.stateNode.current.memoizedState.isDehydrated){v.blockedOn=$.tag===3?$.stateNode.containerInfo:null;return}}}v.blockedOn=null}function el(v){if(v.blockedOn!==null)return!1;for(var x=v.targetContainers;0<x.length;){var $=Zs(v.nativeEvent);if($===null){$=v.nativeEvent;var O=new $.constructor($.type,$);Gr=O,$.target.dispatchEvent(O),Gr=null}else return x=Tt($),x!==null&&bf(x),v.blockedOn=$,!1;x.shift()}return!0}function Cf(v,x,$){el(v)&&$.delete(x)}function w0(){Js=!1,ua!==null&&el(ua)&&(ua=null),da!==null&&el(da)&&(da=null),fa!==null&&el(fa)&&(fa=null),Zo.forEach(Cf),Qo.forEach(Cf)}function tl(v,x){v.blockedOn===x&&(v.blockedOn=null,Js||(Js=!0,a.unstable_scheduleCallback(a.unstable_NormalPriority,w0)))}var rl=null;function wf(v){rl!==v&&(rl=v,a.unstable_scheduleCallback(a.unstable_NormalPriority,function(){rl===v&&(rl=null);for(var x=0;x<v.length;x+=3){var $=v[x],O=v[x+1],k=v[x+2];if(typeof O!="function"){if(Qs(O||$)===null)continue;break}var H=Tt($);H!==null&&(v.splice(x,3),x-=3,Zl(H,{pending:!0,data:k,method:$.method,action:O},O,k))}}))}function ei(v){function x(Se){return tl(Se,v)}ua!==null&&tl(ua,v),da!==null&&tl(da,v),fa!==null&&tl(fa,v),Zo.forEach(x),Qo.forEach(x);for(var $=0;$<ma.length;$++){var O=ma[$];O.blockedOn===v&&(O.blockedOn=null)}for(;0<ma.length&&($=ma[0],$.blockedOn===null);)Ef($),$.blockedOn===null&&ma.shift();if($=(v.ownerDocument||v).$$reactFormReplay,$!=null)for(O=0;O<$.length;O+=3){var k=$[O],H=$[O+1],oe=k[Ze]||null;if(typeof H=="function")oe||wf($);else if(oe){var se=null;if(H&&H.hasAttribute("formAction")){if(k=H,oe=H[Ze]||null)se=oe.formAction;else if(Qs(k)!==null)continue}else se=oe.action;typeof se=="function"?$[O+1]=se:($.splice(O,3),O-=3),wf($)}}}function ec(v){this._internalRoot=v}nl.prototype.render=ec.prototype.render=function(v){var x=this._internalRoot;if(x===null)throw Error(d(409));var $=x.current,O=pn();vf($,O,v,x,null,null)},nl.prototype.unmount=ec.prototype.unmount=function(){var v=this._internalRoot;if(v!==null){this._internalRoot=null;var x=v.containerInfo;vf(v.current,2,null,v,null,null),ji(),x[Je]=null}};function nl(v){this._internalRoot=v}nl.prototype.unstable_scheduleHydration=function(v){if(v){var x=rt();v={blockedOn:null,target:v,priority:x};for(var $=0;$<ma.length&&x!==0&&x<ma[$].priority;$++);ma.splice($,0,v),$===0&&Ef(v)}};var $f=c.version;if($f!=="19.1.0")throw Error(d(527,$f,"19.1.0"));G.findDOMNode=function(v){var x=v._reactInternals;if(x===void 0)throw typeof v.render=="function"?Error(d(188)):(v=Object.keys(v).join(","),Error(d(268,v)));return v=b(x),v=v!==null?E(v):null,v=v===null?null:v.stateNode,v};var $0={bundleType:0,version:"19.1.0",rendererPackageName:"react-dom",currentDispatcherRef:W,reconcilerVersion:"19.1.0"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var al=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!al.isDisabled&&al.supportsFiber)try{be=al.inject($0),Te=al}catch{}}return reactDomClient_production.createRoot=function(v,x){if(!f(v))throw Error(d(299));var $=!1,O="",k=Bu,H=Fu,oe=Hu,se=null;return x!=null&&(x.unstable_strictMode===!0&&($=!0),x.identifierPrefix!==void 0&&(O=x.identifierPrefix),x.onUncaughtError!==void 0&&(k=x.onUncaughtError),x.onCaughtError!==void 0&&(H=x.onCaughtError),x.onRecoverableError!==void 0&&(oe=x.onRecoverableError),x.unstable_transitionCallbacks!==void 0&&(se=x.unstable_transitionCallbacks)),x=hf(v,1,!1,null,null,$,O,k,H,oe,se,null),v[Je]=x.current,zs(v),new ec(x)},reactDomClient_production.hydrateRoot=function(v,x,$){if(!f(v))throw Error(d(299));var O=!1,k="",H=Bu,oe=Fu,se=Hu,Se=null,ze=null;return $!=null&&($.unstable_strictMode===!0&&(O=!0),$.identifierPrefix!==void 0&&(k=$.identifierPrefix),$.onUncaughtError!==void 0&&(H=$.onUncaughtError),$.onCaughtError!==void 0&&(oe=$.onCaughtError),$.onRecoverableError!==void 0&&(se=$.onRecoverableError),$.unstable_transitionCallbacks!==void 0&&(Se=$.unstable_transitionCallbacks),$.formState!==void 0&&(ze=$.formState)),x=hf(v,1,!0,x,$??null,O,k,H,oe,se,Se,ze),x.context=gf(null),$=x.current,O=pn(),O=vt(O),k=Yn(O),k.callback=null,Zn($,k,O),$=O,x.current.lanes=$,at(x,$),Nn(x),v[Je]=x.current,zs(v),new nl(x)},reactDomClient_production.version="19.1.0",reactDomClient_production}var hasRequiredClient;function requireClient(){if(hasRequiredClient)return client.exports;hasRequiredClient=1;function a(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(a)}catch(c){console.error(c)}}return a(),client.exports=requireReactDomClient_production(),client.exports}var clientExports=requireClient();const scriptRel="modulepreload",assetsURL=function(a,c){return new URL(a,c).href},seen={},__vitePreload=function(c,u,d){let f=Promise.resolve();if(u&&u.length>0){let g=function(C){return Promise.all(C.map(w=>Promise.resolve(w).then(R=>({status:"fulfilled",value:R}),R=>({status:"rejected",reason:R}))))};const y=document.getElementsByTagName("link"),b=document.querySelector("meta[property=csp-nonce]"),E=(b==null?void 0:b.nonce)||(b==null?void 0:b.getAttribute("nonce"));f=g(u.map(C=>{if(C=assetsURL(C,d),C in seen)return;seen[C]=!0;const w=C.endsWith(".css"),R=w?'[rel="stylesheet"]':"";if(!!d)for(let I=y.length-1;I>=0;I--){const N=y[I];if(N.href===C&&(!w||N.rel==="stylesheet"))return}else if(document.querySelector(`link[href="${C}"]${R}`))return;const M=document.createElement("link");if(M.rel=w?"stylesheet":scriptRel,w||(M.as="script"),M.crossOrigin="",M.href=C,E&&M.setAttribute("nonce",E),document.head.appendChild(M),w)return new Promise((I,N)=>{M.addEventListener("load",I),M.addEventListener("error",()=>N(new Error(`Unable to preload CSS for ${C}`)))})}))}function m(g){const y=new Event("vite:preloadError",{cancelable:!0});if(y.payload=g,window.dispatchEvent(y),!y.defaultPrevented)throw g}return f.then(g=>{for(const y of g||[])y.status==="rejected"&&m(y.reason);return c().catch(m)})};var reactExports=requireReact();const React=getDefaultExportFromCjs(reactExports),React$1=_mergeNamespaces({__proto__:null,default:React},[reactExports]);var IconContext=reactExports.createContext({});function _extends(){return _extends=Object.assign?Object.assign.bind():function(a){for(var c=1;c<arguments.length;c++){var u=arguments[c];for(var d in u)({}).hasOwnProperty.call(u,d)&&(a[d]=u[d])}return a},_extends.apply(null,arguments)}function _arrayWithHoles(a){if(Array.isArray(a))return a}function _iterableToArrayLimit(a,c){var u=a==null?null:typeof Symbol<"u"&&a[Symbol.iterator]||a["@@iterator"];if(u!=null){var d,f,m,g,y=[],b=!0,E=!1;try{if(m=(u=u.call(a)).next,c===0){if(Object(u)!==u)return;b=!1}else for(;!(b=(d=m.call(u)).done)&&(y.push(d.value),y.length!==c);b=!0);}catch(C){E=!0,f=C}finally{try{if(!b&&u.return!=null&&(g=u.return(),Object(g)!==g))return}finally{if(E)throw f}}return y}}function _arrayLikeToArray(a,c){(c==null||c>a.length)&&(c=a.length);for(var u=0,d=Array(c);u<c;u++)d[u]=a[u];return d}function _unsupportedIterableToArray(a,c){if(a){if(typeof a=="string")return _arrayLikeToArray(a,c);var u={}.toString.call(a).slice(8,-1);return u==="Object"&&a.constructor&&(u=a.constructor.name),u==="Map"||u==="Set"?Array.from(a):u==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(u)?_arrayLikeToArray(a,c):void 0}}function _nonIterableRest(){throw new TypeError(`Invalid attempt to destructure non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function _slicedToArray(a,c){return _arrayWithHoles(a)||_iterableToArrayLimit(a,c)||_unsupportedIterableToArray(a,c)||_nonIterableRest()}function _typeof(a){"@babel/helpers - typeof";return _typeof=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(c){return typeof c}:function(c){return c&&typeof Symbol=="function"&&c.constructor===Symbol&&c!==Symbol.prototype?"symbol":typeof c},_typeof(a)}function toPrimitive(a,c){if(_typeof(a)!="object"||!a)return a;var u=a[Symbol.toPrimitive];if(u!==void 0){var d=u.call(a,c);if(_typeof(d)!="object")return d;throw new TypeError("@@toPrimitive must return a primitive value.")}return(c==="string"?String:Number)(a)}function toPropertyKey(a){var c=toPrimitive(a,"string");return _typeof(c)=="symbol"?c:c+""}function _defineProperty(a,c,u){return(c=toPropertyKey(c))in a?Object.defineProperty(a,c,{value:u,enumerable:!0,configurable:!0,writable:!0}):a[c]=u,a}function _objectWithoutPropertiesLoose(a,c){if(a==null)return{};var u={};for(var d in a)if({}.hasOwnProperty.call(a,d)){if(c.indexOf(d)!==-1)continue;u[d]=a[d]}return u}function _objectWithoutProperties(a,c){if(a==null)return{};var u,d,f=_objectWithoutPropertiesLoose(a,c);if(Object.getOwnPropertySymbols){var m=Object.getOwnPropertySymbols(a);for(d=0;d<m.length;d++)u=m[d],c.indexOf(u)===-1&&{}.propertyIsEnumerable.call(a,u)&&(f[u]=a[u])}return f}var classnames={exports:{}};/*!
	Copyright (c) 2018 Jed Watson.
	Licensed under the MIT License (MIT), see
	http://jedwatson.github.io/classnames
*/var hasRequiredClassnames;function requireClassnames(){return hasRequiredClassnames||(hasRequiredClassnames=1,function(a){(function(){var c={}.hasOwnProperty;function u(){for(var m="",g=0;g<arguments.length;g++){var y=arguments[g];y&&(m=f(m,d(y)))}return m}function d(m){if(typeof m=="string"||typeof m=="number")return m;if(typeof m!="object")return"";if(Array.isArray(m))return u.apply(null,m);if(m.toString!==Object.prototype.toString&&!m.toString.toString().includes("[native code]"))return m.toString();var g="";for(var y in m)c.call(m,y)&&m[y]&&(g=f(g,y));return g}function f(m,g){return g?m?m+" "+g:m+g:m}a.exports?(u.default=u,a.exports=u):window.classNames=u})()}(classnames)),classnames.exports}var classnamesExports=requireClassnames();const classNames=getDefaultExportFromCjs(classnamesExports),round=Math.round;function splitColorStr(a,c){const u=a.replace(/^[^(]*\((.*)/,"$1").replace(/\).*/,"").match(/\d*\.?\d+%?/g)||[],d=u.map(f=>parseFloat(f));for(let f=0;f<3;f+=1)d[f]=c(d[f]||0,u[f]||"",f);return u[3]?d[3]=u[3].includes("%")?d[3]/100:d[3]:d[3]=1,d}const parseHSVorHSL=(a,c,u)=>u===0?a:a/100;function limitRange(a,c){const u=c||255;return a>u?u:a<0?0:a}class FastColor{constructor(c){_defineProperty(this,"isValid",!0),_defineProperty(this,"r",0),_defineProperty(this,"g",0),_defineProperty(this,"b",0),_defineProperty(this,"a",1),_defineProperty(this,"_h",void 0),_defineProperty(this,"_s",void 0),_defineProperty(this,"_l",void 0),_defineProperty(this,"_v",void 0),_defineProperty(this,"_max",void 0),_defineProperty(this,"_min",void 0),_defineProperty(this,"_brightness",void 0);function u(d){return d[0]in c&&d[1]in c&&d[2]in c}if(c)if(typeof c=="string"){let f=function(m){return d.startsWith(m)};const d=c.trim();/^#?[A-F\d]{3,8}$/i.test(d)?this.fromHexString(d):f("rgb")?this.fromRgbString(d):f("hsl")?this.fromHslString(d):(f("hsv")||f("hsb"))&&this.fromHsvString(d)}else if(c instanceof FastColor)this.r=c.r,this.g=c.g,this.b=c.b,this.a=c.a,this._h=c._h,this._s=c._s,this._l=c._l,this._v=c._v;else if(u("rgb"))this.r=limitRange(c.r),this.g=limitRange(c.g),this.b=limitRange(c.b),this.a=typeof c.a=="number"?limitRange(c.a,1):1;else if(u("hsl"))this.fromHsl(c);else if(u("hsv"))this.fromHsv(c);else throw new Error("@ant-design/fast-color: unsupported input "+JSON.stringify(c))}setR(c){return this._sc("r",c)}setG(c){return this._sc("g",c)}setB(c){return this._sc("b",c)}setA(c){return this._sc("a",c,1)}setHue(c){const u=this.toHsv();return u.h=c,this._c(u)}getLuminance(){function c(m){const g=m/255;return g<=.03928?g/12.92:Math.pow((g+.055)/1.055,2.4)}const u=c(this.r),d=c(this.g),f=c(this.b);return .2126*u+.7152*d+.0722*f}getHue(){if(typeof this._h>"u"){const c=this.getMax()-this.getMin();c===0?this._h=0:this._h=round(60*(this.r===this.getMax()?(this.g-this.b)/c+(this.g<this.b?6:0):this.g===this.getMax()?(this.b-this.r)/c+2:(this.r-this.g)/c+4))}return this._h}getSaturation(){if(typeof this._s>"u"){const c=this.getMax()-this.getMin();c===0?this._s=0:this._s=c/this.getMax()}return this._s}getLightness(){return typeof this._l>"u"&&(this._l=(this.getMax()+this.getMin())/510),this._l}getValue(){return typeof this._v>"u"&&(this._v=this.getMax()/255),this._v}getBrightness(){return typeof this._brightness>"u"&&(this._brightness=(this.r*299+this.g*587+this.b*114)/1e3),this._brightness}darken(c=10){const u=this.getHue(),d=this.getSaturation();let f=this.getLightness()-c/100;return f<0&&(f=0),this._c({h:u,s:d,l:f,a:this.a})}lighten(c=10){const u=this.getHue(),d=this.getSaturation();let f=this.getLightness()+c/100;return f>1&&(f=1),this._c({h:u,s:d,l:f,a:this.a})}mix(c,u=50){const d=this._c(c),f=u/100,m=y=>(d[y]-this[y])*f+this[y],g={r:round(m("r")),g:round(m("g")),b:round(m("b")),a:round(m("a")*100)/100};return this._c(g)}tint(c=10){return this.mix({r:255,g:255,b:255,a:1},c)}shade(c=10){return this.mix({r:0,g:0,b:0,a:1},c)}onBackground(c){const u=this._c(c),d=this.a+u.a*(1-this.a),f=m=>round((this[m]*this.a+u[m]*u.a*(1-this.a))/d);return this._c({r:f("r"),g:f("g"),b:f("b"),a:d})}isDark(){return this.getBrightness()<128}isLight(){return this.getBrightness()>=128}equals(c){return this.r===c.r&&this.g===c.g&&this.b===c.b&&this.a===c.a}clone(){return this._c(this)}toHexString(){let c="#";const u=(this.r||0).toString(16);c+=u.length===2?u:"0"+u;const d=(this.g||0).toString(16);c+=d.length===2?d:"0"+d;const f=(this.b||0).toString(16);if(c+=f.length===2?f:"0"+f,typeof this.a=="number"&&this.a>=0&&this.a<1){const m=round(this.a*255).toString(16);c+=m.length===2?m:"0"+m}return c}toHsl(){return{h:this.getHue(),s:this.getSaturation(),l:this.getLightness(),a:this.a}}toHslString(){const c=this.getHue(),u=round(this.getSaturation()*100),d=round(this.getLightness()*100);return this.a!==1?`hsla(${c},${u}%,${d}%,${this.a})`:`hsl(${c},${u}%,${d}%)`}toHsv(){return{h:this.getHue(),s:this.getSaturation(),v:this.getValue(),a:this.a}}toRgb(){return{r:this.r,g:this.g,b:this.b,a:this.a}}toRgbString(){return this.a!==1?`rgba(${this.r},${this.g},${this.b},${this.a})`:`rgb(${this.r},${this.g},${this.b})`}toString(){return this.toRgbString()}_sc(c,u,d){const f=this.clone();return f[c]=limitRange(u,d),f}_c(c){return new this.constructor(c)}getMax(){return typeof this._max>"u"&&(this._max=Math.max(this.r,this.g,this.b)),this._max}getMin(){return typeof this._min>"u"&&(this._min=Math.min(this.r,this.g,this.b)),this._min}fromHexString(c){const u=c.replace("#","");function d(f,m){return parseInt(u[f]+u[m||f],16)}u.length<6?(this.r=d(0),this.g=d(1),this.b=d(2),this.a=u[3]?d(3)/255:1):(this.r=d(0,1),this.g=d(2,3),this.b=d(4,5),this.a=u[6]?d(6,7)/255:1)}fromHsl({h:c,s:u,l:d,a:f}){if(this._h=c%360,this._s=u,this._l=d,this.a=typeof f=="number"?f:1,u<=0){const R=round(d*255);this.r=R,this.g=R,this.b=R}let m=0,g=0,y=0;const b=c/60,E=(1-Math.abs(2*d-1))*u,C=E*(1-Math.abs(b%2-1));b>=0&&b<1?(m=E,g=C):b>=1&&b<2?(m=C,g=E):b>=2&&b<3?(g=E,y=C):b>=3&&b<4?(g=C,y=E):b>=4&&b<5?(m=C,y=E):b>=5&&b<6&&(m=E,y=C);const w=d-E/2;this.r=round((m+w)*255),this.g=round((g+w)*255),this.b=round((y+w)*255)}fromHsv({h:c,s:u,v:d,a:f}){this._h=c%360,this._s=u,this._v=d,this.a=typeof f=="number"?f:1;const m=round(d*255);if(this.r=m,this.g=m,this.b=m,u<=0)return;const g=c/60,y=Math.floor(g),b=g-y,E=round(d*(1-u)*255),C=round(d*(1-u*b)*255),w=round(d*(1-u*(1-b))*255);switch(y){case 0:this.g=w,this.b=E;break;case 1:this.r=C,this.b=E;break;case 2:this.r=E,this.b=w;break;case 3:this.r=E,this.g=C;break;case 4:this.r=w,this.g=E;break;case 5:default:this.g=E,this.b=C;break}}fromHsvString(c){const u=splitColorStr(c,parseHSVorHSL);this.fromHsv({h:u[0],s:u[1],v:u[2],a:u[3]})}fromHslString(c){const u=splitColorStr(c,parseHSVorHSL);this.fromHsl({h:u[0],s:u[1],l:u[2],a:u[3]})}fromRgbString(c){const u=splitColorStr(c,(d,f)=>f.includes("%")?round(d/100*255):d);this.r=u[0],this.g=u[1],this.b=u[2],this.a=u[3]}}var hueStep=2,saturationStep=.16,saturationStep2=.05,brightnessStep1=.05,brightnessStep2=.15,lightColorCount=5,darkColorCount=4,darkColorMap=[{index:7,amount:15},{index:6,amount:25},{index:5,amount:30},{index:5,amount:45},{index:5,amount:65},{index:5,amount:85},{index:4,amount:90},{index:3,amount:95},{index:2,amount:97},{index:1,amount:98}];function getHue(a,c,u){var d;return Math.round(a.h)>=60&&Math.round(a.h)<=240?d=u?Math.round(a.h)-hueStep*c:Math.round(a.h)+hueStep*c:d=u?Math.round(a.h)+hueStep*c:Math.round(a.h)-hueStep*c,d<0?d+=360:d>=360&&(d-=360),d}function getSaturation(a,c,u){if(a.h===0&&a.s===0)return a.s;var d;return u?d=a.s-saturationStep*c:c===darkColorCount?d=a.s+saturationStep:d=a.s+saturationStep2*c,d>1&&(d=1),u&&c===lightColorCount&&d>.1&&(d=.1),d<.06&&(d=.06),Math.round(d*100)/100}function getValue$1(a,c,u){var d;return u?d=a.v+brightnessStep1*c:d=a.v-brightnessStep2*c,d=Math.max(0,Math.min(1,d)),Math.round(d*100)/100}function generate$1(a){for(var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},u=[],d=new FastColor(a),f=d.toHsv(),m=lightColorCount;m>0;m-=1){var g=new FastColor({h:getHue(f,m,!0),s:getSaturation(f,m,!0),v:getValue$1(f,m,!0)});u.push(g)}u.push(d);for(var y=1;y<=darkColorCount;y+=1){var b=new FastColor({h:getHue(f,y),s:getSaturation(f,y),v:getValue$1(f,y)});u.push(b)}return c.theme==="dark"?darkColorMap.map(function(E){var C=E.index,w=E.amount;return new FastColor(c.backgroundColor||"#141414").mix(u[C],w).toHexString()}):u.map(function(E){return E.toHexString()})}var presetPrimaryColors={red:"#F5222D",volcano:"#FA541C",orange:"#FA8C16",gold:"#FAAD14",yellow:"#FADB14",lime:"#A0D911",green:"#52C41A",cyan:"#13C2C2",blue:"#1677FF",geekblue:"#2F54EB",purple:"#722ED1",magenta:"#EB2F96",grey:"#666666"},red=["#fff1f0","#ffccc7","#ffa39e","#ff7875","#ff4d4f","#f5222d","#cf1322","#a8071a","#820014","#5c0011"];red.primary=red[5];var volcano=["#fff2e8","#ffd8bf","#ffbb96","#ff9c6e","#ff7a45","#fa541c","#d4380d","#ad2102","#871400","#610b00"];volcano.primary=volcano[5];var orange=["#fff7e6","#ffe7ba","#ffd591","#ffc069","#ffa940","#fa8c16","#d46b08","#ad4e00","#873800","#612500"];orange.primary=orange[5];var gold=["#fffbe6","#fff1b8","#ffe58f","#ffd666","#ffc53d","#faad14","#d48806","#ad6800","#874d00","#613400"];gold.primary=gold[5];var yellow=["#feffe6","#ffffb8","#fffb8f","#fff566","#ffec3d","#fadb14","#d4b106","#ad8b00","#876800","#614700"];yellow.primary=yellow[5];var lime=["#fcffe6","#f4ffb8","#eaff8f","#d3f261","#bae637","#a0d911","#7cb305","#5b8c00","#3f6600","#254000"];lime.primary=lime[5];var green=["#f6ffed","#d9f7be","#b7eb8f","#95de64","#73d13d","#52c41a","#389e0d","#237804","#135200","#092b00"];green.primary=green[5];var cyan=["#e6fffb","#b5f5ec","#87e8de","#5cdbd3","#36cfc9","#13c2c2","#08979c","#006d75","#00474f","#002329"];cyan.primary=cyan[5];var blue=["#e6f4ff","#bae0ff","#91caff","#69b1ff","#4096ff","#1677ff","#0958d9","#003eb3","#002c8c","#001d66"];blue.primary=blue[5];var geekblue=["#f0f5ff","#d6e4ff","#adc6ff","#85a5ff","#597ef7","#2f54eb","#1d39c4","#10239e","#061178","#030852"];geekblue.primary=geekblue[5];var purple=["#f9f0ff","#efdbff","#d3adf7","#b37feb","#9254de","#722ed1","#531dab","#391085","#22075e","#120338"];purple.primary=purple[5];var magenta=["#fff0f6","#ffd6e7","#ffadd2","#ff85c0","#f759ab","#eb2f96","#c41d7f","#9e1068","#780650","#520339"];magenta.primary=magenta[5];var grey=["#a6a6a6","#999999","#8c8c8c","#808080","#737373","#666666","#404040","#1a1a1a","#000000","#000000"];grey.primary=grey[5];var presetPalettes={red,volcano,orange,gold,yellow,lime,green,cyan,blue,geekblue,purple,magenta,grey};function ownKeys(a,c){var u=Object.keys(a);if(Object.getOwnPropertySymbols){var d=Object.getOwnPropertySymbols(a);c&&(d=d.filter(function(f){return Object.getOwnPropertyDescriptor(a,f).enumerable})),u.push.apply(u,d)}return u}function _objectSpread2(a){for(var c=1;c<arguments.length;c++){var u=arguments[c]!=null?arguments[c]:{};c%2?ownKeys(Object(u),!0).forEach(function(d){_defineProperty(a,d,u[d])}):Object.getOwnPropertyDescriptors?Object.defineProperties(a,Object.getOwnPropertyDescriptors(u)):ownKeys(Object(u)).forEach(function(d){Object.defineProperty(a,d,Object.getOwnPropertyDescriptor(u,d))})}return a}function canUseDom(){return!!(typeof window<"u"&&window.document&&window.document.createElement)}function contains$1(a,c){if(!a)return!1;if(a.contains)return a.contains(c);for(var u=c;u;){if(u===a)return!0;u=u.parentNode}return!1}var APPEND_ORDER="data-rc-order",APPEND_PRIORITY="data-rc-priority",MARK_KEY="rc-util-key",containerCache=new Map;function getMark(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},c=a.mark;return c?c.startsWith("data-")?c:"data-".concat(c):MARK_KEY}function getContainer(a){if(a.attachTo)return a.attachTo;var c=document.querySelector("head");return c||document.body}function getOrder(a){return a==="queue"?"prependQueue":a?"prepend":"append"}function findStyles(a){return Array.from((containerCache.get(a)||a).children).filter(function(c){return c.tagName==="STYLE"})}function injectCSS(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};if(!canUseDom())return null;var u=c.csp,d=c.prepend,f=c.priority,m=f===void 0?0:f,g=getOrder(d),y=g==="prependQueue",b=document.createElement("style");b.setAttribute(APPEND_ORDER,g),y&&m&&b.setAttribute(APPEND_PRIORITY,"".concat(m)),u!=null&&u.nonce&&(b.nonce=u==null?void 0:u.nonce),b.innerHTML=a;var E=getContainer(c),C=E.firstChild;if(d){if(y){var w=(c.styles||findStyles(E)).filter(function(R){if(!["prepend","prependQueue"].includes(R.getAttribute(APPEND_ORDER)))return!1;var _=Number(R.getAttribute(APPEND_PRIORITY)||0);return m>=_});if(w.length)return E.insertBefore(b,w[w.length-1].nextSibling),b}E.insertBefore(b,C)}else E.appendChild(b);return b}function findExistNode(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},u=getContainer(c);return(c.styles||findStyles(u)).find(function(d){return d.getAttribute(getMark(c))===a})}function removeCSS(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},u=findExistNode(a,c);if(u){var d=getContainer(c);d.removeChild(u)}}function syncRealContainer(a,c){var u=containerCache.get(a);if(!u||!contains$1(document,u)){var d=injectCSS("",c),f=d.parentNode;containerCache.set(a,f),a.removeChild(d)}}function updateCSS(a,c){var u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},d=getContainer(u),f=findStyles(d),m=_objectSpread2(_objectSpread2({},u),{},{styles:f});syncRealContainer(d,m);var g=findExistNode(c,m);if(g){var y,b;if((y=m.csp)!==null&&y!==void 0&&y.nonce&&g.nonce!==((b=m.csp)===null||b===void 0?void 0:b.nonce)){var E;g.nonce=(E=m.csp)===null||E===void 0?void 0:E.nonce}return g.innerHTML!==a&&(g.innerHTML=a),g}var C=injectCSS(a,m);return C.setAttribute(getMark(m),c),C}function getRoot(a){var c;return a==null||(c=a.getRootNode)===null||c===void 0?void 0:c.call(a)}function inShadow(a){return getRoot(a)instanceof ShadowRoot}function getShadowRoot(a){return inShadow(a)?getRoot(a):null}var warned={},preMessage=function(c){};function warning$3(a,c){}function note(a,c){}function resetWarned(){warned={}}function call(a,c,u){!c&&!warned[u]&&(a(!1,u),warned[u]=!0)}function warningOnce$1(a,c){call(warning$3,a,c)}function noteOnce(a,c){call(note,a,c)}warningOnce$1.preMessage=preMessage;warningOnce$1.resetWarned=resetWarned;warningOnce$1.noteOnce=noteOnce;function camelCase(a){return a.replace(/-(.)/g,function(c,u){return u.toUpperCase()})}function warning$2(a,c){warningOnce$1(a,"[@ant-design/icons] ".concat(c))}function isIconDefinition(a){return _typeof(a)==="object"&&typeof a.name=="string"&&typeof a.theme=="string"&&(_typeof(a.icon)==="object"||typeof a.icon=="function")}function normalizeAttrs(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};return Object.keys(a).reduce(function(c,u){var d=a[u];switch(u){case"class":c.className=d,delete c.class;break;default:delete c[u],c[camelCase(u)]=d}return c},{})}function generate(a,c,u){return u?React.createElement(a.tag,_objectSpread2(_objectSpread2({key:c},normalizeAttrs(a.attrs)),u),(a.children||[]).map(function(d,f){return generate(d,"".concat(c,"-").concat(a.tag,"-").concat(f))})):React.createElement(a.tag,_objectSpread2({key:c},normalizeAttrs(a.attrs)),(a.children||[]).map(function(d,f){return generate(d,"".concat(c,"-").concat(a.tag,"-").concat(f))}))}function getSecondaryColor(a){return generate$1(a)[0]}function normalizeTwoToneColors(a){return a?Array.isArray(a)?a:[a]:[]}var iconStyles=`
.anticon {
  display: inline-flex;
  align-items: center;
  color: inherit;
  font-style: normal;
  line-height: 0;
  text-align: center;
  text-transform: none;
  vertical-align: -0.125em;
  text-rendering: optimizeLegibility;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}

.anticon > * {
  line-height: 1;
}

.anticon svg {
  display: inline-block;
}

.anticon::before {
  display: none;
}

.anticon .anticon-icon {
  display: block;
}

.anticon[tabindex] {
  cursor: pointer;
}

.anticon-spin::before,
.anticon-spin {
  display: inline-block;
  -webkit-animation: loadingCircle 1s infinite linear;
  animation: loadingCircle 1s infinite linear;
}

@-webkit-keyframes loadingCircle {
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}

@keyframes loadingCircle {
  100% {
    -webkit-transform: rotate(360deg);
    transform: rotate(360deg);
  }
}
`,useInsertStyles=function(c){var u=reactExports.useContext(IconContext),d=u.csp,f=u.prefixCls,m=u.layer,g=iconStyles;f&&(g=g.replace(/anticon/g,f)),m&&(g="@layer ".concat(m,` {
`).concat(g,`
}`)),reactExports.useEffect(function(){var y=c.current,b=getShadowRoot(y);updateCSS(g,"@ant-design-icons",{prepend:!m,csp:d,attachTo:b})},[])},_excluded$R=["icon","className","onClick","style","primaryColor","secondaryColor"],twoToneColorPalette={primaryColor:"#333",secondaryColor:"#E6E6E6",calculated:!1};function setTwoToneColors(a){var c=a.primaryColor,u=a.secondaryColor;twoToneColorPalette.primaryColor=c,twoToneColorPalette.secondaryColor=u||getSecondaryColor(c),twoToneColorPalette.calculated=!!u}function getTwoToneColors(){return _objectSpread2({},twoToneColorPalette)}var IconBase=function(c){var u=c.icon,d=c.className,f=c.onClick,m=c.style,g=c.primaryColor,y=c.secondaryColor,b=_objectWithoutProperties(c,_excluded$R),E=reactExports.useRef(),C=twoToneColorPalette;if(g&&(C={primaryColor:g,secondaryColor:y||getSecondaryColor(g)}),useInsertStyles(E),warning$2(isIconDefinition(u),"icon should be icon definiton, but got ".concat(u)),!isIconDefinition(u))return null;var w=u;return w&&typeof w.icon=="function"&&(w=_objectSpread2(_objectSpread2({},w),{},{icon:w.icon(C.primaryColor,C.secondaryColor)})),generate(w.icon,"svg-".concat(w.name),_objectSpread2(_objectSpread2({className:d,onClick:f,style:m,"data-icon":w.name,width:"1em",height:"1em",fill:"currentColor","aria-hidden":"true"},b),{},{ref:E}))};IconBase.displayName="IconReact";IconBase.getTwoToneColors=getTwoToneColors;IconBase.setTwoToneColors=setTwoToneColors;function setTwoToneColor(a){var c=normalizeTwoToneColors(a),u=_slicedToArray(c,2),d=u[0],f=u[1];return IconBase.setTwoToneColors({primaryColor:d,secondaryColor:f})}function getTwoToneColor(){var a=IconBase.getTwoToneColors();return a.calculated?[a.primaryColor,a.secondaryColor]:a.primaryColor}var _excluded$Q=["className","icon","spin","rotate","tabIndex","onClick","twoToneColor"];setTwoToneColor(blue.primary);var Icon$1=reactExports.forwardRef(function(a,c){var u=a.className,d=a.icon,f=a.spin,m=a.rotate,g=a.tabIndex,y=a.onClick,b=a.twoToneColor,E=_objectWithoutProperties(a,_excluded$Q),C=reactExports.useContext(IconContext),w=C.prefixCls,R=w===void 0?"anticon":w,_=C.rootClassName,M=classNames(_,R,_defineProperty(_defineProperty({},"".concat(R,"-").concat(d.name),!!d.name),"".concat(R,"-spin"),!!f||d.name==="loading"),u),I=g;I===void 0&&y&&(I=-1);var N=m?{msTransform:"rotate(".concat(m,"deg)"),transform:"rotate(".concat(m,"deg)")}:void 0,A=normalizeTwoToneColors(b),P=_slicedToArray(A,2),z=P[0],B=P[1];return reactExports.createElement("span",_extends({role:"img","aria-label":d.name},E,{ref:c,tabIndex:I,onClick:y,className:M}),reactExports.createElement(IconBase,{icon:d,primaryColor:z,secondaryColor:B,style:N}))});Icon$1.displayName="AntdIcon";Icon$1.getTwoToneColor=getTwoToneColor;Icon$1.setTwoToneColor=setTwoToneColor;var BarsOutlined$1={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M912 192H328c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h584c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zm0 284H328c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h584c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zm0 284H328c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h584c4.4 0 8-3.6 8-8v-56c0-4.4-3.6-8-8-8zM104 228a56 56 0 10112 0 56 56 0 10-112 0zm0 284a56 56 0 10112 0 56 56 0 10-112 0zm0 284a56 56 0 10112 0 56 56 0 10-112 0z"}}]},name:"bars",theme:"outlined"},BarsOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:BarsOutlined$1}))},RefIcon$E=reactExports.forwardRef(BarsOutlined),CaretDownFilled$1={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M840.4 300H183.6c-19.7 0-30.7 20.8-18.5 35l328.4 380.8c9.4 10.9 27.5 10.9 37 0L858.9 335c12.2-14.2 1.2-35-18.5-35z"}}]},name:"caret-down",theme:"filled"},CaretDownFilled=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CaretDownFilled$1}))},RefIcon$D=reactExports.forwardRef(CaretDownFilled),CaretDownOutlined$1={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M840.4 300H183.6c-19.7 0-30.7 20.8-18.5 35l328.4 380.8c9.4 10.9 27.5 10.9 37 0L858.9 335c12.2-14.2 1.2-35-18.5-35z"}}]},name:"caret-down",theme:"outlined"},CaretDownOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CaretDownOutlined$1}))},RefIcon$C=reactExports.forwardRef(CaretDownOutlined),CaretUpOutlined$1={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M858.9 689L530.5 308.2c-9.4-10.9-27.5-10.9-37 0L165.1 689c-12.2 14.2-1.2 35 18.5 35h656.8c19.7 0 30.7-20.8 18.5-35z"}}]},name:"caret-up",theme:"outlined"},CaretUpOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CaretUpOutlined$1}))},RefIcon$B=reactExports.forwardRef(CaretUpOutlined),CheckCircleFilled$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm193.5 301.7l-210.6 292a31.8 31.8 0 01-51.7 0L318.5 484.9c-3.8-5.3 0-12.7 6.5-12.7h46.9c10.2 0 19.9 4.9 25.9 13.3l71.2 98.8 157.2-218c6-8.3 15.6-13.3 25.9-13.3H699c6.5 0 10.3 7.4 6.5 12.7z"}}]},name:"check-circle",theme:"filled"},CheckCircleFilled=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CheckCircleFilled$1}))},RefIcon$A=reactExports.forwardRef(CheckCircleFilled),CheckOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M912 190h-69.9c-9.8 0-19.1 4.5-25.1 12.2L404.7 724.5 207 474a32 32 0 00-25.1-12.2H112c-6.7 0-10.4 7.7-6.3 12.9l273.9 347c12.8 16.2 37.4 16.2 50.3 0l488.4-618.9c4.1-5.1.4-12.8-6.3-12.8z"}}]},name:"check",theme:"outlined"},CheckOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CheckOutlined$1}))},RefIcon$z=reactExports.forwardRef(CheckOutlined),CloseCircleFilled$1={icon:{tag:"svg",attrs:{"fill-rule":"evenodd",viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64c247.4 0 448 200.6 448 448S759.4 960 512 960 64 759.4 64 512 264.6 64 512 64zm127.98 274.82h-.04l-.08.06L512 466.75 384.14 338.88c-.04-.05-.06-.06-.08-.06a.12.12 0 00-.07 0c-.03 0-.05.01-.09.05l-45.02 45.02a.2.2 0 00-.05.09.12.12 0 000 .07v.02a.27.27 0 00.06.06L466.75 512 338.88 639.86c-.05.04-.06.06-.06.08a.12.12 0 000 .07c0 .03.01.05.05.09l45.02 45.02a.2.2 0 00.09.05.12.12 0 00.07 0c.02 0 .04-.01.08-.05L512 557.25l127.86 127.87c.04.04.06.05.08.05a.12.12 0 00.07 0c.03 0 .05-.01.09-.05l45.02-45.02a.2.2 0 00.05-.09.12.12 0 000-.07v-.02a.27.27 0 00-.05-.06L557.25 512l127.87-127.86c.04-.04.05-.06.05-.08a.12.12 0 000-.07c0-.03-.01-.05-.05-.09l-45.02-45.02a.2.2 0 00-.09-.05.12.12 0 00-.07 0z"}}]},name:"close-circle",theme:"filled"},CloseCircleFilled=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CloseCircleFilled$1}))},RefIcon$y=reactExports.forwardRef(CloseCircleFilled),CloseOutlined$1={icon:{tag:"svg",attrs:{"fill-rule":"evenodd",viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M799.86 166.31c.02 0 .04.02.08.06l57.69 57.7c.04.03.05.05.06.08a.12.12 0 010 .06c0 .03-.02.05-.06.09L569.93 512l287.7 287.7c.04.04.05.06.06.09a.12.12 0 010 .07c0 .02-.02.04-.06.08l-57.7 57.69c-.03.04-.05.05-.07.06a.12.12 0 01-.07 0c-.03 0-.05-.02-.09-.06L512 569.93l-287.7 287.7c-.04.04-.06.05-.09.06a.12.12 0 01-.07 0c-.02 0-.04-.02-.08-.06l-57.69-57.7c-.04-.03-.05-.05-.06-.07a.12.12 0 010-.07c0-.03.02-.05.06-.09L454.07 512l-287.7-287.7c-.04-.04-.05-.06-.06-.09a.12.12 0 010-.07c0-.02.02-.04.06-.08l57.7-57.69c.03-.04.05-.05.07-.06a.12.12 0 01.07 0c.03 0 .05.02.09.06L512 454.07l287.7-287.7c.04-.04.06-.05.09-.06a.12.12 0 01.07 0z"}}]},name:"close",theme:"outlined"},CloseOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CloseOutlined$1}))},RefIcon$x=reactExports.forwardRef(CloseOutlined),CopyOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M832 64H296c-4.4 0-8 3.6-8 8v56c0 4.4 3.6 8 8 8h496v688c0 4.4 3.6 8 8 8h56c4.4 0 8-3.6 8-8V96c0-17.7-14.3-32-32-32zM704 192H192c-17.7 0-32 14.3-32 32v530.7c0 8.5 3.4 16.6 9.4 22.6l173.3 173.3c2.2 2.2 4.7 4 7.4 5.5v1.9h4.2c3.5 1.3 7.2 2 11 2H704c17.7 0 32-14.3 32-32V224c0-17.7-14.3-32-32-32zM350 856.2L263.9 770H350v86.2zM664 888H414V746c0-22.1-17.9-40-40-40H232V264h432v624z"}}]},name:"copy",theme:"outlined"},CopyOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:CopyOutlined$1}))},RefIcon$w=reactExports.forwardRef(CopyOutlined),DoubleLeftOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M272.9 512l265.4-339.1c4.1-5.2.4-12.9-6.3-12.9h-77.3c-4.9 0-9.6 2.3-12.6 6.1L186.8 492.3a31.99 31.99 0 000 39.5l255.3 326.1c3 3.9 7.7 6.1 12.6 6.1H532c6.7 0 10.4-7.7 6.3-12.9L272.9 512zm304 0l265.4-339.1c4.1-5.2.4-12.9-6.3-12.9h-77.3c-4.9 0-9.6 2.3-12.6 6.1L490.8 492.3a31.99 31.99 0 000 39.5l255.3 326.1c3 3.9 7.7 6.1 12.6 6.1H836c6.7 0 10.4-7.7 6.3-12.9L576.9 512z"}}]},name:"double-left",theme:"outlined"},DoubleLeftOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:DoubleLeftOutlined$1}))},RefIcon$v=reactExports.forwardRef(DoubleLeftOutlined),DoubleRightOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M533.2 492.3L277.9 166.1c-3-3.9-7.7-6.1-12.6-6.1H188c-6.7 0-10.4 7.7-6.3 12.9L447.1 512 181.7 851.1A7.98 7.98 0 00188 864h77.3c4.9 0 9.6-2.3 12.6-6.1l255.3-326.1c9.1-11.7 9.1-27.9 0-39.5zm304 0L581.9 166.1c-3-3.9-7.7-6.1-12.6-6.1H492c-6.7 0-10.4 7.7-6.3 12.9L751.1 512 485.7 851.1A7.98 7.98 0 00492 864h77.3c4.9 0 9.6-2.3 12.6-6.1l255.3-326.1c9.1-11.7 9.1-27.9 0-39.5z"}}]},name:"double-right",theme:"outlined"},DoubleRightOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:DoubleRightOutlined$1}))},RefIcon$u=reactExports.forwardRef(DoubleRightOutlined),DownOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M884 256h-75c-5.1 0-9.9 2.5-12.9 6.6L512 654.2 227.9 262.6c-3-4.1-7.8-6.6-12.9-6.6h-75c-6.5 0-10.3 7.4-6.5 12.7l352.6 486.1c12.8 17.6 39 17.6 51.7 0l352.6-486.1c3.9-5.3.1-12.7-6.4-12.7z"}}]},name:"down",theme:"outlined"},DownOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:DownOutlined$1}))},RefIcon$t=reactExports.forwardRef(DownOutlined),EditOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M257.7 752c2 0 4-.2 6-.5L431.9 722c2-.4 3.9-1.3 5.3-2.8l423.9-423.9a9.96 9.96 0 000-14.1L694.9 114.9c-1.9-1.9-4.4-2.9-7.1-2.9s-5.2 1-7.1 2.9L256.8 538.8c-1.5 1.5-2.4 3.3-2.8 5.3l-29.5 168.2a33.5 33.5 0 009.4 29.8c6.6 6.4 14.9 9.9 23.8 9.9zm67.4-174.4L687.8 215l73.3 73.3-362.7 362.6-88.9 15.7 15.6-89zM880 836H144c-17.7 0-32 14.3-32 32v36c0 4.4 3.6 8 8 8h784c4.4 0 8-3.6 8-8v-36c0-17.7-14.3-32-32-32z"}}]},name:"edit",theme:"outlined"},EditOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:EditOutlined$1}))},RefIcon$s=reactExports.forwardRef(EditOutlined),EllipsisOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M176 511a56 56 0 10112 0 56 56 0 10-112 0zm280 0a56 56 0 10112 0 56 56 0 10-112 0zm280 0a56 56 0 10112 0 56 56 0 10-112 0z"}}]},name:"ellipsis",theme:"outlined"},EllipsisOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:EllipsisOutlined$1}))},RefIcon$r=reactExports.forwardRef(EllipsisOutlined),EnterOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M864 170h-60c-4.4 0-8 3.6-8 8v518H310v-73c0-6.7-7.8-10.5-13-6.3l-141.9 112a8 8 0 000 12.6l141.9 112c5.3 4.2 13 .4 13-6.3v-75h498c35.3 0 64-28.7 64-64V178c0-4.4-3.6-8-8-8z"}}]},name:"enter",theme:"outlined"},EnterOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:EnterOutlined$1}))},RefIcon$q=reactExports.forwardRef(EnterOutlined),ExclamationCircleFilled$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm-32 232c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V296zm32 440a48.01 48.01 0 010-96 48.01 48.01 0 010 96z"}}]},name:"exclamation-circle",theme:"filled"},ExclamationCircleFilled=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:ExclamationCircleFilled$1}))},RefIcon$p=reactExports.forwardRef(ExclamationCircleFilled),EyeInvisibleOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M942.2 486.2Q889.47 375.11 816.7 305l-50.88 50.88C807.31 395.53 843.45 447.4 874.7 512 791.5 684.2 673.4 766 512 766q-72.67 0-133.87-22.38L323 798.75Q408 838 512 838q288.3 0 430.2-300.3a60.29 60.29 0 000-51.5zm-63.57-320.64L836 122.88a8 8 0 00-11.32 0L715.31 232.2Q624.86 186 512 186q-288.3 0-430.2 300.3a60.3 60.3 0 000 51.5q56.69 119.4 136.5 191.41L112.48 835a8 8 0 000 11.31L155.17 889a8 8 0 0011.31 0l712.15-712.12a8 8 0 000-11.32zM149.3 512C232.6 339.8 350.7 258 512 258c54.54 0 104.13 9.36 149.12 28.39l-70.3 70.3a176 176 0 00-238.13 238.13l-83.42 83.42C223.1 637.49 183.3 582.28 149.3 512zm246.7 0a112.11 112.11 0 01146.2-106.69L401.31 546.2A112 112 0 01396 512z"}},{tag:"path",attrs:{d:"M508 624c-3.46 0-6.87-.16-10.25-.47l-52.82 52.82a176.09 176.09 0 00227.42-227.42l-52.82 52.82c.31 3.38.47 6.79.47 10.25a111.94 111.94 0 01-112 112z"}}]},name:"eye-invisible",theme:"outlined"},EyeInvisibleOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:EyeInvisibleOutlined$1}))},RefIcon$o=reactExports.forwardRef(EyeInvisibleOutlined),EyeOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M942.2 486.2C847.4 286.5 704.1 186 512 186c-192.2 0-335.4 100.5-430.2 300.3a60.3 60.3 0 000 51.5C176.6 737.5 319.9 838 512 838c192.2 0 335.4-100.5 430.2-300.3 7.7-16.2 7.7-35 0-51.5zM512 766c-161.3 0-279.4-81.8-362.7-254C232.6 339.8 350.7 258 512 258c161.3 0 279.4 81.8 362.7 254C791.5 684.2 673.4 766 512 766zm-4-430c-97.2 0-176 78.8-176 176s78.8 176 176 176 176-78.8 176-176-78.8-176-176-176zm0 288c-61.9 0-112-50.1-112-112s50.1-112 112-112 112 50.1 112 112-50.1 112-112 112z"}}]},name:"eye",theme:"outlined"},EyeOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:EyeOutlined$1}))},RefIcon$n=reactExports.forwardRef(EyeOutlined),FileOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M854.6 288.6L639.4 73.4c-6-6-14.1-9.4-22.6-9.4H192c-17.7 0-32 14.3-32 32v832c0 17.7 14.3 32 32 32h640c17.7 0 32-14.3 32-32V311.3c0-8.5-3.4-16.7-9.4-22.7zM790.2 326H602V137.8L790.2 326zm1.8 562H232V136h302v216a42 42 0 0042 42h216v494z"}}]},name:"file",theme:"outlined"},FileOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:FileOutlined$1}))},RefIcon$m=reactExports.forwardRef(FileOutlined),FilterFilled$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M349 838c0 17.7 14.2 32 31.8 32h262.4c17.6 0 31.8-14.3 31.8-32V642H349v196zm531.1-684H143.9c-24.5 0-39.8 26.7-27.5 48l221.3 376h348.8l221.3-376c12.1-21.3-3.2-48-27.7-48z"}}]},name:"filter",theme:"filled"},FilterFilled=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:FilterFilled$1}))},RefIcon$l=reactExports.forwardRef(FilterFilled),FolderOpenOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M928 444H820V330.4c0-17.7-14.3-32-32-32H473L355.7 186.2a8.15 8.15 0 00-5.5-2.2H96c-17.7 0-32 14.3-32 32v592c0 17.7 14.3 32 32 32h698c13 0 24.8-7.9 29.7-20l134-332c1.5-3.8 2.3-7.9 2.3-12 0-17.7-14.3-32-32-32zM136 256h188.5l119.6 114.4H748V444H238c-13 0-24.8 7.9-29.7 20L136 643.2V256zm635.3 512H159l103.3-256h612.4L771.3 768z"}}]},name:"folder-open",theme:"outlined"},FolderOpenOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:FolderOpenOutlined$1}))},RefIcon$k=reactExports.forwardRef(FolderOpenOutlined),FolderOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M880 298.4H521L403.7 186.2a8.15 8.15 0 00-5.5-2.2H144c-17.7 0-32 14.3-32 32v592c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V330.4c0-17.7-14.3-32-32-32zM840 768H184V256h188.5l119.6 114.4H840V768z"}}]},name:"folder",theme:"outlined"},FolderOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:FolderOutlined$1}))},RefIcon$j=reactExports.forwardRef(FolderOutlined),HolderOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M300 276.5a56 56 0 1056-97 56 56 0 00-56 97zm0 284a56 56 0 1056-97 56 56 0 00-56 97zM640 228a56 56 0 10112 0 56 56 0 00-112 0zm0 284a56 56 0 10112 0 56 56 0 00-112 0zM300 844.5a56 56 0 1056-97 56 56 0 00-56 97zM640 796a56 56 0 10112 0 56 56 0 00-112 0z"}}]},name:"holder",theme:"outlined"},HolderOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:HolderOutlined$1}))},RefIcon$i=reactExports.forwardRef(HolderOutlined),InfoCircleFilled$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm32 664c0 4.4-3.6 8-8 8h-48c-4.4 0-8-3.6-8-8V456c0-4.4 3.6-8 8-8h48c4.4 0 8 3.6 8 8v272zm-32-344a48.01 48.01 0 010-96 48.01 48.01 0 010 96z"}}]},name:"info-circle",theme:"filled"},InfoCircleFilled=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:InfoCircleFilled$1}))},RefIcon$h=reactExports.forwardRef(InfoCircleFilled),LaptopOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M956.9 845.1L896.4 632V168c0-17.7-14.3-32-32-32h-704c-17.7 0-32 14.3-32 32v464L67.9 845.1C60.4 866 75.8 888 98 888h828.8c22.2 0 37.6-22 30.1-42.9zM200.4 208h624v395h-624V208zm228.3 608l8.1-37h150.3l8.1 37H428.7zm224 0l-19.1-86.7c-.8-3.7-4.1-6.3-7.8-6.3H398.2c-3.8 0-7 2.6-7.8 6.3L371.3 816H151l42.3-149h638.2l42.3 149H652.7z"}}]},name:"laptop",theme:"outlined"},LaptopOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:LaptopOutlined$1}))},RefIcon$g=reactExports.forwardRef(LaptopOutlined),LeftOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M724 218.3V141c0-6.7-7.7-10.4-12.9-6.3L260.3 486.8a31.86 31.86 0 000 50.3l450.8 352.1c5.3 4.1 12.9.4 12.9-6.3v-77.3c0-4.9-2.3-9.6-6.1-12.6l-360-281 360-281.1c3.8-3 6.1-7.7 6.1-12.6z"}}]},name:"left",theme:"outlined"},LeftOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:LeftOutlined$1}))},RefIcon$f=reactExports.forwardRef(LeftOutlined),LoadingOutlined$1={icon:{tag:"svg",attrs:{viewBox:"0 0 1024 1024",focusable:"false"},children:[{tag:"path",attrs:{d:"M988 548c-19.9 0-36-16.1-36-36 0-59.4-11.6-117-34.6-171.3a440.45 440.45 0 00-94.3-139.9 437.71 437.71 0 00-139.9-94.3C629 83.6 571.4 72 512 72c-19.9 0-36-16.1-36-36s16.1-36 36-36c69.1 0 136.2 13.5 199.3 40.3C772.3 66 827 103 874 150c47 47 83.9 101.8 109.7 162.7 26.7 63.1 40.2 130.2 40.2 199.3.1 19.9-16 36-35.9 36z"}}]},name:"loading",theme:"outlined"},LoadingOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:LoadingOutlined$1}))},RefIcon$e=reactExports.forwardRef(LoadingOutlined),MinusSquareOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M328 544h368c4.4 0 8-3.6 8-8v-48c0-4.4-3.6-8-8-8H328c-4.4 0-8 3.6-8 8v48c0 4.4 3.6 8 8 8z"}},{tag:"path",attrs:{d:"M880 112H144c-17.7 0-32 14.3-32 32v736c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V144c0-17.7-14.3-32-32-32zm-40 728H184V184h656v656z"}}]},name:"minus-square",theme:"outlined"},MinusSquareOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:MinusSquareOutlined$1}))},RefIcon$d=reactExports.forwardRef(MinusSquareOutlined),NotificationOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M880 112c-3.8 0-7.7.7-11.6 2.3L292 345.9H128c-8.8 0-16 7.4-16 16.6v299c0 9.2 7.2 16.6 16 16.6h101.7c-3.7 11.6-5.7 23.9-5.7 36.4 0 65.9 53.8 119.5 120 119.5 55.4 0 102.1-37.6 115.9-88.4l408.6 164.2c3.9 1.5 7.8 2.3 11.6 2.3 16.9 0 32-14.2 32-33.2V145.2C912 126.2 897 112 880 112zM344 762.3c-26.5 0-48-21.4-48-47.8 0-11.2 3.9-21.9 11-30.4l84.9 34.1c-2 24.6-22.7 44.1-47.9 44.1zm496 58.4L318.8 611.3l-12.9-5.2H184V417.9h121.9l12.9-5.2L840 203.3v617.4z"}}]},name:"notification",theme:"outlined"},NotificationOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:NotificationOutlined$1}))},RefIcon$c=reactExports.forwardRef(NotificationOutlined),PlusOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M482 152h60q8 0 8 8v704q0 8-8 8h-60q-8 0-8-8V160q0-8 8-8z"}},{tag:"path",attrs:{d:"M192 474h672q8 0 8 8v60q0 8-8 8H160q-8 0-8-8v-60q0-8 8-8z"}}]},name:"plus",theme:"outlined"},PlusOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:PlusOutlined$1}))},RefIcon$b=reactExports.forwardRef(PlusOutlined),PlusSquareOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M328 544h152v152c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8V544h152c4.4 0 8-3.6 8-8v-48c0-4.4-3.6-8-8-8H544V328c0-4.4-3.6-8-8-8h-48c-4.4 0-8 3.6-8 8v152H328c-4.4 0-8 3.6-8 8v48c0 4.4 3.6 8 8 8z"}},{tag:"path",attrs:{d:"M880 112H144c-17.7 0-32 14.3-32 32v736c0 17.7 14.3 32 32 32h736c17.7 0 32-14.3 32-32V144c0-17.7-14.3-32-32-32zm-40 728H184V184h656v656z"}}]},name:"plus-square",theme:"outlined"},PlusSquareOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:PlusSquareOutlined$1}))},RefIcon$a=reactExports.forwardRef(PlusSquareOutlined),QuestionCircleOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M512 64C264.6 64 64 264.6 64 512s200.6 448 448 448 448-200.6 448-448S759.4 64 512 64zm0 820c-205.4 0-372-166.6-372-372s166.6-372 372-372 372 166.6 372 372-166.6 372-372 372z"}},{tag:"path",attrs:{d:"M623.6 316.7C593.6 290.4 554 276 512 276s-81.6 14.5-111.6 40.7C369.2 344 352 380.7 352 420v7.6c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8V420c0-44.1 43.1-80 96-80s96 35.9 96 80c0 31.1-22 59.6-56.1 72.7-21.2 8.1-39.2 22.3-52.1 40.9-13.1 19-19.9 41.8-19.9 64.9V620c0 4.4 3.6 8 8 8h48c4.4 0 8-3.6 8-8v-22.7a48.3 48.3 0 0130.9-44.8c59-22.7 97.1-74.7 97.1-132.5.1-39.3-17.1-76-48.3-103.3zM472 732a40 40 0 1080 0 40 40 0 10-80 0z"}}]},name:"question-circle",theme:"outlined"},QuestionCircleOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:QuestionCircleOutlined$1}))},RefIcon$9=reactExports.forwardRef(QuestionCircleOutlined),RightOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M765.7 486.8L314.9 134.7A7.97 7.97 0 00302 141v77.3c0 4.9 2.3 9.6 6.1 12.6l360 281.1-360 281.1c-3.9 3-6.1 7.7-6.1 12.6V883c0 6.7 7.7 10.4 12.9 6.3l450.8-352.1a31.96 31.96 0 000-50.4z"}}]},name:"right",theme:"outlined"},RightOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:RightOutlined$1}))},RefIcon$8=reactExports.forwardRef(RightOutlined),RotateLeftOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"defs",attrs:{},children:[{tag:"style",attrs:{}}]},{tag:"path",attrs:{d:"M672 418H144c-17.7 0-32 14.3-32 32v414c0 17.7 14.3 32 32 32h528c17.7 0 32-14.3 32-32V450c0-17.7-14.3-32-32-32zm-44 402H188V494h440v326z"}},{tag:"path",attrs:{d:"M819.3 328.5c-78.8-100.7-196-153.6-314.6-154.2l-.2-64c0-6.5-7.6-10.1-12.6-6.1l-128 101c-4 3.1-3.9 9.1 0 12.3L492 318.6c5.1 4 12.7.4 12.6-6.1v-63.9c12.9.1 25.9.9 38.8 2.5 42.1 5.2 82.1 18.2 119 38.7 38.1 21.2 71.2 49.7 98.4 84.3 27.1 34.7 46.7 73.7 58.1 115.8a325.95 325.95 0 016.5 140.9h74.9c14.8-103.6-11.3-213-81-302.3z"}}]},name:"rotate-left",theme:"outlined"},RotateLeftOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:RotateLeftOutlined$1}))},RefIcon$7=reactExports.forwardRef(RotateLeftOutlined),RotateRightOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"defs",attrs:{},children:[{tag:"style",attrs:{}}]},{tag:"path",attrs:{d:"M480.5 251.2c13-1.6 25.9-2.4 38.8-2.5v63.9c0 6.5 7.5 10.1 12.6 6.1L660 217.6c4-3.2 4-9.2 0-12.3l-128-101c-5.1-4-12.6-.4-12.6 6.1l-.2 64c-118.6.5-235.8 53.4-314.6 154.2A399.75 399.75 0 00123.5 631h74.9c-.9-5.3-1.7-10.7-2.4-16.1-5.1-42.1-2.1-84.1 8.9-124.8 11.4-42.2 31-81.1 58.1-115.8 27.2-34.7 60.3-63.2 98.4-84.3 37-20.6 76.9-33.6 119.1-38.8z"}},{tag:"path",attrs:{d:"M880 418H352c-17.7 0-32 14.3-32 32v414c0 17.7 14.3 32 32 32h528c17.7 0 32-14.3 32-32V450c0-17.7-14.3-32-32-32zm-44 402H396V494h440v326z"}}]},name:"rotate-right",theme:"outlined"},RotateRightOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:RotateRightOutlined$1}))},RefIcon$6=reactExports.forwardRef(RotateRightOutlined),SearchOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M909.6 854.5L649.9 594.8C690.2 542.7 712 479 712 412c0-80.2-31.3-155.4-87.9-212.1-56.6-56.7-132-87.9-212.1-87.9s-155.5 31.3-212.1 87.9C143.2 256.5 112 331.8 112 412c0 80.1 31.3 155.5 87.9 212.1C256.5 680.8 331.8 712 412 712c67 0 130.6-21.8 182.7-62l259.7 259.6a8.2 8.2 0 0011.6 0l43.6-43.5a8.2 8.2 0 000-11.6zM570.4 570.4C528 612.7 471.8 636 412 636s-116-23.3-158.4-65.6C211.3 528 188 471.8 188 412s23.3-116.1 65.6-158.4C296 211.3 352.2 188 412 188s116.1 23.2 158.4 65.6S636 352.2 636 412s-23.3 116.1-65.6 158.4z"}}]},name:"search",theme:"outlined"},SearchOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:SearchOutlined$1}))},RefIcon$5=reactExports.forwardRef(SearchOutlined),SwapOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M847.9 592H152c-4.4 0-8 3.6-8 8v60c0 4.4 3.6 8 8 8h605.2L612.9 851c-4.1 5.2-.4 13 6.3 13h72.5c4.9 0 9.5-2.2 12.6-6.1l168.8-214.1c16.5-21 1.6-51.8-25.2-51.8zM872 356H266.8l144.3-183c4.1-5.2.4-13-6.3-13h-72.5c-4.9 0-9.5 2.2-12.6 6.1L150.9 380.2c-16.5 21-1.6 51.8 25.1 51.8h696c4.4 0 8-3.6 8-8v-60c0-4.4-3.6-8-8-8z"}}]},name:"swap",theme:"outlined"},SwapOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:SwapOutlined$1}))},RefIcon$4=reactExports.forwardRef(SwapOutlined),UpOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M890.5 755.3L537.9 269.2c-12.8-17.6-39-17.6-51.7 0L133.5 755.3A8 8 0 00140 768h75c5.1 0 9.9-2.5 12.9-6.6L512 369.8l284.1 391.6c3 4.1 7.8 6.6 12.9 6.6h75c6.5 0 10.3-7.4 6.5-12.7z"}}]},name:"up",theme:"outlined"},UpOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:UpOutlined$1}))},RefIcon$3=reactExports.forwardRef(UpOutlined),UserOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M858.5 763.6a374 374 0 00-80.6-119.5 375.63 375.63 0 00-119.5-80.6c-.4-.2-.8-.3-1.2-.5C719.5 518 760 444.7 760 362c0-137-111-248-248-248S264 225 264 362c0 82.7 40.5 156 102.8 201.1-.4.2-.8.3-1.2.5-44.8 18.9-85 46-119.5 80.6a375.63 375.63 0 00-80.6 119.5A371.7 371.7 0 00136 901.8a8 8 0 008 8.2h60c4.4 0 7.9-3.5 8-7.8 2-77.2 33-149.5 87.8-204.3 56.7-56.7 132-87.9 212.2-87.9s155.5 31.2 212.2 87.9C779 752.7 810 825 812 902.2c.1 4.4 3.6 7.8 8 7.8h60a8 8 0 008-8.2c-1-47.8-10.9-94.3-29.5-138.2zM512 534c-45.9 0-89.1-17.9-121.6-50.4S340 407.9 340 362c0-45.9 17.9-89.1 50.4-121.6S466.1 190 512 190s89.1 17.9 121.6 50.4S684 316.1 684 362c0 45.9-17.9 89.1-50.4 121.6S557.9 534 512 534z"}}]},name:"user",theme:"outlined"},UserOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:UserOutlined$1}))},RefIcon$2=reactExports.forwardRef(UserOutlined),ZoomInOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M637 443H519V309c0-4.4-3.6-8-8-8h-60c-4.4 0-8 3.6-8 8v134H325c-4.4 0-8 3.6-8 8v60c0 4.4 3.6 8 8 8h118v134c0 4.4 3.6 8 8 8h60c4.4 0 8-3.6 8-8V519h118c4.4 0 8-3.6 8-8v-60c0-4.4-3.6-8-8-8zm284 424L775 721c122.1-148.9 113.6-369.5-26-509-148-148.1-388.4-148.1-537 0-148.1 148.6-148.1 389 0 537 139.5 139.6 360.1 148.1 509 26l146 146c3.2 2.8 8.3 2.8 11 0l43-43c2.8-2.7 2.8-7.8 0-11zM696 696c-118.8 118.7-311.2 118.7-430 0-118.7-118.8-118.7-311.2 0-430 118.8-118.7 311.2-118.7 430 0 118.7 118.8 118.7 311.2 0 430z"}}]},name:"zoom-in",theme:"outlined"},ZoomInOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:ZoomInOutlined$1}))},RefIcon$1=reactExports.forwardRef(ZoomInOutlined),ZoomOutOutlined$1={icon:{tag:"svg",attrs:{viewBox:"64 64 896 896",focusable:"false"},children:[{tag:"path",attrs:{d:"M637 443H325c-4.4 0-8 3.6-8 8v60c0 4.4 3.6 8 8 8h312c4.4 0 8-3.6 8-8v-60c0-4.4-3.6-8-8-8zm284 424L775 721c122.1-148.9 113.6-369.5-26-509-148-148.1-388.4-148.1-537 0-148.1 148.6-148.1 389 0 537 139.5 139.6 360.1 148.1 509 26l146 146c3.2 2.8 8.3 2.8 11 0l43-43c2.8-2.7 2.8-7.8 0-11zM696 696c-118.8 118.7-311.2 118.7-430 0-118.7-118.8-118.7-311.2 0-430 118.8-118.7 311.2-118.7 430 0 118.7 118.8 118.7 311.2 0 430z"}}]},name:"zoom-out",theme:"outlined"},ZoomOutOutlined=function(c,u){return reactExports.createElement(Icon$1,_extends({},c,{ref:u,icon:ZoomOutOutlined$1}))},RefIcon=reactExports.forwardRef(ZoomOutOutlined),reactIs={exports:{}},reactIs_production_min={};/**
 * @license React
 * react-is.production.min.js
 *
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredReactIs_production_min;function requireReactIs_production_min(){if(hasRequiredReactIs_production_min)return reactIs_production_min;hasRequiredReactIs_production_min=1;var a=Symbol.for("react.element"),c=Symbol.for("react.portal"),u=Symbol.for("react.fragment"),d=Symbol.for("react.strict_mode"),f=Symbol.for("react.profiler"),m=Symbol.for("react.provider"),g=Symbol.for("react.context"),y=Symbol.for("react.server_context"),b=Symbol.for("react.forward_ref"),E=Symbol.for("react.suspense"),C=Symbol.for("react.suspense_list"),w=Symbol.for("react.memo"),R=Symbol.for("react.lazy"),_=Symbol.for("react.offscreen"),M;M=Symbol.for("react.module.reference");function I(N){if(typeof N=="object"&&N!==null){var A=N.$$typeof;switch(A){case a:switch(N=N.type,N){case u:case f:case d:case E:case C:return N;default:switch(N=N&&N.$$typeof,N){case y:case g:case b:case R:case w:case m:return N;default:return A}}case c:return A}}}return reactIs_production_min.ContextConsumer=g,reactIs_production_min.ContextProvider=m,reactIs_production_min.Element=a,reactIs_production_min.ForwardRef=b,reactIs_production_min.Fragment=u,reactIs_production_min.Lazy=R,reactIs_production_min.Memo=w,reactIs_production_min.Portal=c,reactIs_production_min.Profiler=f,reactIs_production_min.StrictMode=d,reactIs_production_min.Suspense=E,reactIs_production_min.SuspenseList=C,reactIs_production_min.isAsyncMode=function(){return!1},reactIs_production_min.isConcurrentMode=function(){return!1},reactIs_production_min.isContextConsumer=function(N){return I(N)===g},reactIs_production_min.isContextProvider=function(N){return I(N)===m},reactIs_production_min.isElement=function(N){return typeof N=="object"&&N!==null&&N.$$typeof===a},reactIs_production_min.isForwardRef=function(N){return I(N)===b},reactIs_production_min.isFragment=function(N){return I(N)===u},reactIs_production_min.isLazy=function(N){return I(N)===R},reactIs_production_min.isMemo=function(N){return I(N)===w},reactIs_production_min.isPortal=function(N){return I(N)===c},reactIs_production_min.isProfiler=function(N){return I(N)===f},reactIs_production_min.isStrictMode=function(N){return I(N)===d},reactIs_production_min.isSuspense=function(N){return I(N)===E},reactIs_production_min.isSuspenseList=function(N){return I(N)===C},reactIs_production_min.isValidElementType=function(N){return typeof N=="string"||typeof N=="function"||N===u||N===f||N===d||N===E||N===C||N===_||typeof N=="object"&&N!==null&&(N.$$typeof===R||N.$$typeof===w||N.$$typeof===m||N.$$typeof===g||N.$$typeof===b||N.$$typeof===M||N.getModuleId!==void 0)},reactIs_production_min.typeOf=I,reactIs_production_min}var hasRequiredReactIs;function requireReactIs(){return hasRequiredReactIs||(hasRequiredReactIs=1,reactIs.exports=requireReactIs_production_min()),reactIs.exports}var reactIsExports=requireReactIs();function useMemo(a,c,u){var d=reactExports.useRef({});return(!("value"in d.current)||u(d.current.condition,c))&&(d.current.value=a(),d.current.condition=c),d.current.value}var REACT_ELEMENT_TYPE_18=Symbol.for("react.element"),REACT_ELEMENT_TYPE_19=Symbol.for("react.transitional.element"),REACT_FRAGMENT_TYPE=Symbol.for("react.fragment");function isFragment$1(a){return a&&_typeof(a)==="object"&&(a.$$typeof===REACT_ELEMENT_TYPE_18||a.$$typeof===REACT_ELEMENT_TYPE_19)&&a.type===REACT_FRAGMENT_TYPE}var ReactMajorVersion=Number(reactExports.version.split(".")[0]),fillRef=function(c,u){typeof c=="function"?c(u):_typeof(c)==="object"&&c&&"current"in c&&(c.current=u)},composeRef=function(){for(var c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];var f=u.filter(Boolean);return f.length<=1?f[0]:function(m){u.forEach(function(g){fillRef(g,m)})}},useComposeRef=function(){for(var c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];return useMemo(function(){return composeRef.apply(void 0,u)},u,function(f,m){return f.length!==m.length||f.every(function(g,y){return g!==m[y]})})},supportRef=function(c){var u,d;if(!c)return!1;if(isReactElement(c)&&ReactMajorVersion>=19)return!0;var f=reactIsExports.isMemo(c)?c.type.type:c.type;return!(typeof f=="function"&&!((u=f.prototype)!==null&&u!==void 0&&u.render)&&f.$$typeof!==reactIsExports.ForwardRef||typeof c=="function"&&!((d=c.prototype)!==null&&d!==void 0&&d.render)&&c.$$typeof!==reactIsExports.ForwardRef)};function isReactElement(a){return reactExports.isValidElement(a)&&!isFragment$1(a)}var supportNodeRef=function(c){return isReactElement(c)&&supportRef(c)},getNodeRef=function(c){if(c&&isReactElement(c)){var u=c;return u.props.propertyIsEnumerable("ref")?u.props.ref:u.ref}return null};function toArray$6(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},u=[];return React.Children.forEach(a,function(d){d==null&&!c.keepEmpty||(Array.isArray(d)?u=u.concat(toArray$6(d)):isFragment$1(d)&&d.props?u=u.concat(toArray$6(d.props.children,c)):u.push(d))}),u}var reactDomExports=requireReactDom();const ReactDOM=getDefaultExportFromCjs(reactDomExports),ReactDOM$1=_mergeNamespaces({__proto__:null,default:ReactDOM},[reactDomExports]);function isDOM$1(a){return a instanceof HTMLElement||a instanceof SVGElement}function getDOM(a){return a&&_typeof(a)==="object"&&isDOM$1(a.nativeElement)?a.nativeElement:isDOM$1(a)?a:null}function findDOMNode(a){var c=getDOM(a);if(c)return c;if(a instanceof React.Component){var u;return(u=ReactDOM.findDOMNode)===null||u===void 0?void 0:u.call(ReactDOM,a)}return null}var CollectionContext=reactExports.createContext(null);function Collection(a){var c=a.children,u=a.onBatchResize,d=reactExports.useRef(0),f=reactExports.useRef([]),m=reactExports.useContext(CollectionContext),g=reactExports.useCallback(function(y,b,E){d.current+=1;var C=d.current;f.current.push({size:y,element:b,data:E}),Promise.resolve().then(function(){C===d.current&&(u==null||u(f.current),f.current=[])}),m==null||m(y,b,E)},[u,m]);return reactExports.createElement(CollectionContext.Provider,{value:g},c)}var MapShim=function(){if(typeof Map<"u")return Map;function a(c,u){var d=-1;return c.some(function(f,m){return f[0]===u?(d=m,!0):!1}),d}return function(){function c(){this.__entries__=[]}return Object.defineProperty(c.prototype,"size",{get:function(){return this.__entries__.length},enumerable:!0,configurable:!0}),c.prototype.get=function(u){var d=a(this.__entries__,u),f=this.__entries__[d];return f&&f[1]},c.prototype.set=function(u,d){var f=a(this.__entries__,u);~f?this.__entries__[f][1]=d:this.__entries__.push([u,d])},c.prototype.delete=function(u){var d=this.__entries__,f=a(d,u);~f&&d.splice(f,1)},c.prototype.has=function(u){return!!~a(this.__entries__,u)},c.prototype.clear=function(){this.__entries__.splice(0)},c.prototype.forEach=function(u,d){d===void 0&&(d=null);for(var f=0,m=this.__entries__;f<m.length;f++){var g=m[f];u.call(d,g[1],g[0])}},c}()}(),isBrowser$1=typeof window<"u"&&typeof document<"u"&&window.document===document,global$1=function(){return typeof global<"u"&&global.Math===Math?global:typeof self<"u"&&self.Math===Math?self:typeof window<"u"&&window.Math===Math?window:Function("return this")()}(),requestAnimationFrame$1=function(){return typeof requestAnimationFrame=="function"?requestAnimationFrame.bind(global$1):function(a){return setTimeout(function(){return a(Date.now())},1e3/60)}}(),trailingTimeout=2;function throttle$2(a,c){var u=!1,d=!1,f=0;function m(){u&&(u=!1,a()),d&&y()}function g(){requestAnimationFrame$1(m)}function y(){var b=Date.now();if(u){if(b-f<trailingTimeout)return;d=!0}else u=!0,d=!1,setTimeout(g,c);f=b}return y}var REFRESH_DELAY=20,transitionKeys=["top","right","bottom","left","width","height","size","weight"],mutationObserverSupported=typeof MutationObserver<"u",ResizeObserverController=function(){function a(){this.connected_=!1,this.mutationEventsAdded_=!1,this.mutationsObserver_=null,this.observers_=[],this.onTransitionEnd_=this.onTransitionEnd_.bind(this),this.refresh=throttle$2(this.refresh.bind(this),REFRESH_DELAY)}return a.prototype.addObserver=function(c){~this.observers_.indexOf(c)||this.observers_.push(c),this.connected_||this.connect_()},a.prototype.removeObserver=function(c){var u=this.observers_,d=u.indexOf(c);~d&&u.splice(d,1),!u.length&&this.connected_&&this.disconnect_()},a.prototype.refresh=function(){var c=this.updateObservers_();c&&this.refresh()},a.prototype.updateObservers_=function(){var c=this.observers_.filter(function(u){return u.gatherActive(),u.hasActive()});return c.forEach(function(u){return u.broadcastActive()}),c.length>0},a.prototype.connect_=function(){!isBrowser$1||this.connected_||(document.addEventListener("transitionend",this.onTransitionEnd_),window.addEventListener("resize",this.refresh),mutationObserverSupported?(this.mutationsObserver_=new MutationObserver(this.refresh),this.mutationsObserver_.observe(document,{attributes:!0,childList:!0,characterData:!0,subtree:!0})):(document.addEventListener("DOMSubtreeModified",this.refresh),this.mutationEventsAdded_=!0),this.connected_=!0)},a.prototype.disconnect_=function(){!isBrowser$1||!this.connected_||(document.removeEventListener("transitionend",this.onTransitionEnd_),window.removeEventListener("resize",this.refresh),this.mutationsObserver_&&this.mutationsObserver_.disconnect(),this.mutationEventsAdded_&&document.removeEventListener("DOMSubtreeModified",this.refresh),this.mutationsObserver_=null,this.mutationEventsAdded_=!1,this.connected_=!1)},a.prototype.onTransitionEnd_=function(c){var u=c.propertyName,d=u===void 0?"":u,f=transitionKeys.some(function(m){return!!~d.indexOf(m)});f&&this.refresh()},a.getInstance=function(){return this.instance_||(this.instance_=new a),this.instance_},a.instance_=null,a}(),defineConfigurable=function(a,c){for(var u=0,d=Object.keys(c);u<d.length;u++){var f=d[u];Object.defineProperty(a,f,{value:c[f],enumerable:!1,writable:!1,configurable:!0})}return a},getWindowOf=function(a){var c=a&&a.ownerDocument&&a.ownerDocument.defaultView;return c||global$1},emptyRect=createRectInit(0,0,0,0);function toFloat(a){return parseFloat(a)||0}function getBordersSize(a){for(var c=[],u=1;u<arguments.length;u++)c[u-1]=arguments[u];return c.reduce(function(d,f){var m=a["border-"+f+"-width"];return d+toFloat(m)},0)}function getPaddings(a){for(var c=["top","right","bottom","left"],u={},d=0,f=c;d<f.length;d++){var m=f[d],g=a["padding-"+m];u[m]=toFloat(g)}return u}function getSVGContentRect(a){var c=a.getBBox();return createRectInit(0,0,c.width,c.height)}function getHTMLElementContentRect(a){var c=a.clientWidth,u=a.clientHeight;if(!c&&!u)return emptyRect;var d=getWindowOf(a).getComputedStyle(a),f=getPaddings(d),m=f.left+f.right,g=f.top+f.bottom,y=toFloat(d.width),b=toFloat(d.height);if(d.boxSizing==="border-box"&&(Math.round(y+m)!==c&&(y-=getBordersSize(d,"left","right")+m),Math.round(b+g)!==u&&(b-=getBordersSize(d,"top","bottom")+g)),!isDocumentElement(a)){var E=Math.round(y+m)-c,C=Math.round(b+g)-u;Math.abs(E)!==1&&(y-=E),Math.abs(C)!==1&&(b-=C)}return createRectInit(f.left,f.top,y,b)}var isSVGGraphicsElement=function(){return typeof SVGGraphicsElement<"u"?function(a){return a instanceof getWindowOf(a).SVGGraphicsElement}:function(a){return a instanceof getWindowOf(a).SVGElement&&typeof a.getBBox=="function"}}();function isDocumentElement(a){return a===getWindowOf(a).document.documentElement}function getContentRect(a){return isBrowser$1?isSVGGraphicsElement(a)?getSVGContentRect(a):getHTMLElementContentRect(a):emptyRect}function createReadOnlyRect(a){var c=a.x,u=a.y,d=a.width,f=a.height,m=typeof DOMRectReadOnly<"u"?DOMRectReadOnly:Object,g=Object.create(m.prototype);return defineConfigurable(g,{x:c,y:u,width:d,height:f,top:u,right:c+d,bottom:f+u,left:c}),g}function createRectInit(a,c,u,d){return{x:a,y:c,width:u,height:d}}var ResizeObservation=function(){function a(c){this.broadcastWidth=0,this.broadcastHeight=0,this.contentRect_=createRectInit(0,0,0,0),this.target=c}return a.prototype.isActive=function(){var c=getContentRect(this.target);return this.contentRect_=c,c.width!==this.broadcastWidth||c.height!==this.broadcastHeight},a.prototype.broadcastRect=function(){var c=this.contentRect_;return this.broadcastWidth=c.width,this.broadcastHeight=c.height,c},a}(),ResizeObserverEntry=function(){function a(c,u){var d=createReadOnlyRect(u);defineConfigurable(this,{target:c,contentRect:d})}return a}(),ResizeObserverSPI=function(){function a(c,u,d){if(this.activeObservations_=[],this.observations_=new MapShim,typeof c!="function")throw new TypeError("The callback provided as parameter 1 is not a function.");this.callback_=c,this.controller_=u,this.callbackCtx_=d}return a.prototype.observe=function(c){if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");if(!(typeof Element>"u"||!(Element instanceof Object))){if(!(c instanceof getWindowOf(c).Element))throw new TypeError('parameter 1 is not of type "Element".');var u=this.observations_;u.has(c)||(u.set(c,new ResizeObservation(c)),this.controller_.addObserver(this),this.controller_.refresh())}},a.prototype.unobserve=function(c){if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");if(!(typeof Element>"u"||!(Element instanceof Object))){if(!(c instanceof getWindowOf(c).Element))throw new TypeError('parameter 1 is not of type "Element".');var u=this.observations_;u.has(c)&&(u.delete(c),u.size||this.controller_.removeObserver(this))}},a.prototype.disconnect=function(){this.clearActive(),this.observations_.clear(),this.controller_.removeObserver(this)},a.prototype.gatherActive=function(){var c=this;this.clearActive(),this.observations_.forEach(function(u){u.isActive()&&c.activeObservations_.push(u)})},a.prototype.broadcastActive=function(){if(this.hasActive()){var c=this.callbackCtx_,u=this.activeObservations_.map(function(d){return new ResizeObserverEntry(d.target,d.broadcastRect())});this.callback_.call(c,u,c),this.clearActive()}},a.prototype.clearActive=function(){this.activeObservations_.splice(0)},a.prototype.hasActive=function(){return this.activeObservations_.length>0},a}(),observers=typeof WeakMap<"u"?new WeakMap:new MapShim,ResizeObserver$2=function(){function a(c){if(!(this instanceof a))throw new TypeError("Cannot call a class as a function.");if(!arguments.length)throw new TypeError("1 argument required, but only 0 present.");var u=ResizeObserverController.getInstance(),d=new ResizeObserverSPI(c,u,this);observers.set(this,d)}return a}();["observe","unobserve","disconnect"].forEach(function(a){ResizeObserver$2.prototype[a]=function(){var c;return(c=observers.get(this))[a].apply(c,arguments)}});var index$1=function(){return typeof global$1.ResizeObserver<"u"?global$1.ResizeObserver:ResizeObserver$2}(),elementListeners=new Map;function onResize(a){a.forEach(function(c){var u,d=c.target;(u=elementListeners.get(d))===null||u===void 0||u.forEach(function(f){return f(d)})})}var resizeObserver=new index$1(onResize);function observe(a,c){elementListeners.has(a)||(elementListeners.set(a,new Set),resizeObserver.observe(a)),elementListeners.get(a).add(c)}function unobserve(a,c){elementListeners.has(a)&&(elementListeners.get(a).delete(c),elementListeners.get(a).size||(resizeObserver.unobserve(a),elementListeners.delete(a)))}function _classCallCheck(a,c){if(!(a instanceof c))throw new TypeError("Cannot call a class as a function")}function _defineProperties(a,c){for(var u=0;u<c.length;u++){var d=c[u];d.enumerable=d.enumerable||!1,d.configurable=!0,"value"in d&&(d.writable=!0),Object.defineProperty(a,toPropertyKey(d.key),d)}}function _createClass(a,c,u){return c&&_defineProperties(a.prototype,c),u&&_defineProperties(a,u),Object.defineProperty(a,"prototype",{writable:!1}),a}function _setPrototypeOf(a,c){return _setPrototypeOf=Object.setPrototypeOf?Object.setPrototypeOf.bind():function(u,d){return u.__proto__=d,u},_setPrototypeOf(a,c)}function _inherits(a,c){if(typeof c!="function"&&c!==null)throw new TypeError("Super expression must either be null or a function");a.prototype=Object.create(c&&c.prototype,{constructor:{value:a,writable:!0,configurable:!0}}),Object.defineProperty(a,"prototype",{writable:!1}),c&&_setPrototypeOf(a,c)}function _getPrototypeOf(a){return _getPrototypeOf=Object.setPrototypeOf?Object.getPrototypeOf.bind():function(c){return c.__proto__||Object.getPrototypeOf(c)},_getPrototypeOf(a)}function _isNativeReflectConstruct(){try{var a=!Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){}))}catch{}return(_isNativeReflectConstruct=function(){return!!a})()}function _assertThisInitialized(a){if(a===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return a}function _possibleConstructorReturn(a,c){if(c&&(_typeof(c)=="object"||typeof c=="function"))return c;if(c!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return _assertThisInitialized(a)}function _createSuper(a){var c=_isNativeReflectConstruct();return function(){var u,d=_getPrototypeOf(a);if(c){var f=_getPrototypeOf(this).constructor;u=Reflect.construct(d,arguments,f)}else u=d.apply(this,arguments);return _possibleConstructorReturn(this,u)}}var DomWrapper$1=function(a){_inherits(u,a);var c=_createSuper(u);function u(){return _classCallCheck(this,u),c.apply(this,arguments)}return _createClass(u,[{key:"render",value:function(){return this.props.children}}]),u}(reactExports.Component);function SingleObserver(a,c){var u=a.children,d=a.disabled,f=reactExports.useRef(null),m=reactExports.useRef(null),g=reactExports.useContext(CollectionContext),y=typeof u=="function",b=y?u(f):u,E=reactExports.useRef({width:-1,height:-1,offsetWidth:-1,offsetHeight:-1}),C=!y&&reactExports.isValidElement(b)&&supportRef(b),w=C?getNodeRef(b):null,R=useComposeRef(w,f),_=function(){var A;return findDOMNode(f.current)||(f.current&&_typeof(f.current)==="object"?findDOMNode((A=f.current)===null||A===void 0?void 0:A.nativeElement):null)||findDOMNode(m.current)};reactExports.useImperativeHandle(c,function(){return _()});var M=reactExports.useRef(a);M.current=a;var I=reactExports.useCallback(function(N){var A=M.current,P=A.onResize,z=A.data,B=N.getBoundingClientRect(),j=B.width,L=B.height,U=N.offsetWidth,q=N.offsetHeight,F=Math.floor(j),K=Math.floor(L);if(E.current.width!==F||E.current.height!==K||E.current.offsetWidth!==U||E.current.offsetHeight!==q){var X={width:F,height:K,offsetWidth:U,offsetHeight:q};E.current=X;var Q=U===Math.round(j)?j:U,Y=q===Math.round(L)?L:q,Z=_objectSpread2(_objectSpread2({},X),{},{offsetWidth:Q,offsetHeight:Y});g==null||g(Z,N,z),P&&Promise.resolve().then(function(){P(Z,N)})}},[]);return reactExports.useEffect(function(){var N=_();return N&&!d&&observe(N,I),function(){return unobserve(N,I)}},[f.current,d]),reactExports.createElement(DomWrapper$1,{ref:m},C?reactExports.cloneElement(b,{ref:R}):b)}var RefSingleObserver=reactExports.forwardRef(SingleObserver),INTERNAL_PREFIX_KEY="rc-observer-key";function ResizeObserver$1(a,c){var u=a.children,d=typeof u=="function"?[u]:toArray$6(u);return d.map(function(f,m){var g=(f==null?void 0:f.key)||"".concat(INTERNAL_PREFIX_KEY,"-").concat(m);return reactExports.createElement(RefSingleObserver,_extends({},a,{key:g,ref:m===0?c:void 0}),f)})}var RefResizeObserver=reactExports.forwardRef(ResizeObserver$1);RefResizeObserver.Collection=Collection;function _arrayWithoutHoles(a){if(Array.isArray(a))return _arrayLikeToArray(a)}function _iterableToArray(a){if(typeof Symbol<"u"&&a[Symbol.iterator]!=null||a["@@iterator"]!=null)return Array.from(a)}function _nonIterableSpread(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}function _toConsumableArray(a){return _arrayWithoutHoles(a)||_iterableToArray(a)||_unsupportedIterableToArray(a)||_nonIterableSpread()}var raf=function(c){return+setTimeout(c,16)},caf=function(c){return clearTimeout(c)};typeof window<"u"&&"requestAnimationFrame"in window&&(raf=function(c){return window.requestAnimationFrame(c)},caf=function(c){return window.cancelAnimationFrame(c)});var rafUUID=0,rafIds=new Map;function cleanup(a){rafIds.delete(a)}var wrapperRaf=function(c){var u=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1;rafUUID+=1;var d=rafUUID;function f(m){if(m===0)cleanup(d),c();else{var g=raf(function(){f(m-1)});rafIds.set(d,g)}}return f(u),d};wrapperRaf.cancel=function(a){var c=rafIds.get(a);return cleanup(a),caf(c)};function murmur2(a){for(var c=0,u,d=0,f=a.length;f>=4;++d,f-=4)u=a.charCodeAt(d)&255|(a.charCodeAt(++d)&255)<<8|(a.charCodeAt(++d)&255)<<16|(a.charCodeAt(++d)&255)<<24,u=(u&65535)*1540483477+((u>>>16)*59797<<16),u^=u>>>24,c=(u&65535)*1540483477+((u>>>16)*59797<<16)^(c&65535)*1540483477+((c>>>16)*59797<<16);switch(f){case 3:c^=(a.charCodeAt(d+2)&255)<<16;case 2:c^=(a.charCodeAt(d+1)&255)<<8;case 1:c^=a.charCodeAt(d)&255,c=(c&65535)*1540483477+((c>>>16)*59797<<16)}return c^=c>>>13,c=(c&65535)*1540483477+((c>>>16)*59797<<16),((c^c>>>15)>>>0).toString(36)}function isEqual(a,c){var u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1,d=new Set;function f(m,g){var y=arguments.length>2&&arguments[2]!==void 0?arguments[2]:1,b=d.has(m);if(warningOnce$1(!b,"Warning: There may be circular references"),b)return!1;if(m===g)return!0;if(u&&y>1)return!1;d.add(m);var E=y+1;if(Array.isArray(m)){if(!Array.isArray(g)||m.length!==g.length)return!1;for(var C=0;C<m.length;C++)if(!f(m[C],g[C],E))return!1;return!0}if(m&&g&&_typeof(m)==="object"&&_typeof(g)==="object"){var w=Object.keys(m);return w.length!==Object.keys(g).length?!1:w.every(function(R){return f(m[R],g[R],E)})}return!1}return f(a,c)}var SPLIT$1="%";function pathKey(a){return a.join(SPLIT$1)}var Entity=function(){function a(c){_classCallCheck(this,a),_defineProperty(this,"instanceId",void 0),_defineProperty(this,"cache",new Map),this.instanceId=c}return _createClass(a,[{key:"get",value:function(u){return this.opGet(pathKey(u))}},{key:"opGet",value:function(u){return this.cache.get(u)||null}},{key:"update",value:function(u,d){return this.opUpdate(pathKey(u),d)}},{key:"opUpdate",value:function(u,d){var f=this.cache.get(u),m=d(f);m===null?this.cache.delete(u):this.cache.set(u,m)}}]),a}(),ATTR_TOKEN="data-token-hash",ATTR_MARK="data-css-hash",CSS_IN_JS_INSTANCE="__cssinjs_instance__";function createCache(){var a=Math.random().toString(12).slice(2);if(typeof document<"u"&&document.head&&document.body){var c=document.body.querySelectorAll("style[".concat(ATTR_MARK,"]"))||[],u=document.head.firstChild;Array.from(c).forEach(function(f){f[CSS_IN_JS_INSTANCE]=f[CSS_IN_JS_INSTANCE]||a,f[CSS_IN_JS_INSTANCE]===a&&document.head.insertBefore(f,u)});var d={};Array.from(document.querySelectorAll("style[".concat(ATTR_MARK,"]"))).forEach(function(f){var m=f.getAttribute(ATTR_MARK);if(d[m]){if(f[CSS_IN_JS_INSTANCE]===a){var g;(g=f.parentNode)===null||g===void 0||g.removeChild(f)}}else d[m]=!0})}return new Entity(a)}var StyleContext=reactExports.createContext({hashPriority:"low",cache:createCache(),defaultCache:!0});function sameDerivativeOption(a,c){if(a.length!==c.length)return!1;for(var u=0;u<a.length;u++)if(a[u]!==c[u])return!1;return!0}var ThemeCache=function(){function a(){_classCallCheck(this,a),_defineProperty(this,"cache",void 0),_defineProperty(this,"keys",void 0),_defineProperty(this,"cacheCallTimes",void 0),this.cache=new Map,this.keys=[],this.cacheCallTimes=0}return _createClass(a,[{key:"size",value:function(){return this.keys.length}},{key:"internalGet",value:function(u){var d,f,m=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,g={map:this.cache};return u.forEach(function(y){if(!g)g=void 0;else{var b;g=(b=g)===null||b===void 0||(b=b.map)===null||b===void 0?void 0:b.get(y)}}),(d=g)!==null&&d!==void 0&&d.value&&m&&(g.value[1]=this.cacheCallTimes++),(f=g)===null||f===void 0?void 0:f.value}},{key:"get",value:function(u){var d;return(d=this.internalGet(u,!0))===null||d===void 0?void 0:d[0]}},{key:"has",value:function(u){return!!this.internalGet(u)}},{key:"set",value:function(u,d){var f=this;if(!this.has(u)){if(this.size()+1>a.MAX_CACHE_SIZE+a.MAX_CACHE_OFFSET){var m=this.keys.reduce(function(E,C){var w=_slicedToArray(E,2),R=w[1];return f.internalGet(C)[1]<R?[C,f.internalGet(C)[1]]:E},[this.keys[0],this.cacheCallTimes]),g=_slicedToArray(m,1),y=g[0];this.delete(y)}this.keys.push(u)}var b=this.cache;u.forEach(function(E,C){if(C===u.length-1)b.set(E,{value:[d,f.cacheCallTimes++]});else{var w=b.get(E);w?w.map||(w.map=new Map):b.set(E,{map:new Map}),b=b.get(E).map}})}},{key:"deleteByPath",value:function(u,d){var f=u.get(d[0]);if(d.length===1){var m;return f.map?u.set(d[0],{map:f.map}):u.delete(d[0]),(m=f.value)===null||m===void 0?void 0:m[0]}var g=this.deleteByPath(f.map,d.slice(1));return(!f.map||f.map.size===0)&&!f.value&&u.delete(d[0]),g}},{key:"delete",value:function(u){if(this.has(u))return this.keys=this.keys.filter(function(d){return!sameDerivativeOption(d,u)}),this.deleteByPath(this.cache,u)}}]),a}();_defineProperty(ThemeCache,"MAX_CACHE_SIZE",20);_defineProperty(ThemeCache,"MAX_CACHE_OFFSET",5);var uuid$4=0,Theme=function(){function a(c){_classCallCheck(this,a),_defineProperty(this,"derivatives",void 0),_defineProperty(this,"id",void 0),this.derivatives=Array.isArray(c)?c:[c],this.id=uuid$4,c.length===0&&(c.length>0,void 0),uuid$4+=1}return _createClass(a,[{key:"getDerivativeToken",value:function(u){return this.derivatives.reduce(function(d,f){return f(u,d)},void 0)}}]),a}(),cacheThemes=new ThemeCache;function createTheme(a){var c=Array.isArray(a)?a:[a];return cacheThemes.has(c)||cacheThemes.set(c,new Theme(c)),cacheThemes.get(c)}var resultCache=new WeakMap,RESULT_VALUE={};function memoResult(a,c){for(var u=resultCache,d=0;d<c.length;d+=1){var f=c[d];u.has(f)||u.set(f,new WeakMap),u=u.get(f)}return u.has(RESULT_VALUE)||u.set(RESULT_VALUE,a()),u.get(RESULT_VALUE)}var flattenTokenCache=new WeakMap;function flattenToken(a){var c=flattenTokenCache.get(a)||"";return c||(Object.keys(a).forEach(function(u){var d=a[u];c+=u,d instanceof Theme?c+=d.id:d&&_typeof(d)==="object"?c+=flattenToken(d):c+=d}),c=murmur2(c),flattenTokenCache.set(a,c)),c}function token2key(a,c){return murmur2("".concat(c,"_").concat(flattenToken(a)))}var isClientSide=canUseDom();function unit$1(a){return typeof a=="number"?"".concat(a,"px"):a}function toStyleStr(a,c,u){var d,f=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{},m=arguments.length>4&&arguments[4]!==void 0?arguments[4]:!1;if(m)return a;var g=_objectSpread2(_objectSpread2({},f),{},(d={},_defineProperty(d,ATTR_TOKEN,c),_defineProperty(d,ATTR_MARK,u),d)),y=Object.keys(g).map(function(b){var E=g[b];return E?"".concat(b,'="').concat(E,'"'):null}).filter(function(b){return b}).join(" ");return"<style ".concat(y,">").concat(a,"</style>")}var token2CSSVar=function(c){var u=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";return"--".concat(u?"".concat(u,"-"):"").concat(c).replace(/([a-z0-9])([A-Z])/g,"$1-$2").replace(/([A-Z]+)([A-Z][a-z0-9]+)/g,"$1-$2").replace(/([a-z])([A-Z0-9])/g,"$1-$2").toLowerCase()},serializeCSSVar=function(c,u,d){return Object.keys(c).length?".".concat(u).concat(d!=null&&d.scope?".".concat(d.scope):"","{").concat(Object.entries(c).map(function(f){var m=_slicedToArray(f,2),g=m[0],y=m[1];return"".concat(g,":").concat(y,";")}).join(""),"}"):""},transformToken=function(c,u,d){var f={},m={};return Object.entries(c).forEach(function(g){var y,b,E=_slicedToArray(g,2),C=E[0],w=E[1];if(d!=null&&(y=d.preserve)!==null&&y!==void 0&&y[C])m[C]=w;else if((typeof w=="string"||typeof w=="number")&&!(d!=null&&(b=d.ignore)!==null&&b!==void 0&&b[C])){var R,_=token2CSSVar(C,d==null?void 0:d.prefix);f[_]=typeof w=="number"&&!(d!=null&&(R=d.unitless)!==null&&R!==void 0&&R[C])?"".concat(w,"px"):String(w),m[C]="var(".concat(_,")")}}),[m,serializeCSSVar(f,u,{scope:d==null?void 0:d.scope})]},useInternalLayoutEffect=canUseDom()?reactExports.useLayoutEffect:reactExports.useEffect,useLayoutEffect$1=function(c,u){var d=reactExports.useRef(!0);useInternalLayoutEffect(function(){return c(d.current)},u),useInternalLayoutEffect(function(){return d.current=!1,function(){d.current=!0}},[])},useLayoutUpdateEffect=function(c,u){useLayoutEffect$1(function(d){if(!d)return c()},u)},fullClone$3=_objectSpread2({},React$1),useInsertionEffect$1=fullClone$3.useInsertionEffect,useInsertionEffectPolyfill=function(c,u,d){reactExports.useMemo(c,d),useLayoutEffect$1(function(){return u(!0)},d)},useCompatibleInsertionEffect=useInsertionEffect$1?function(a,c,u){return useInsertionEffect$1(function(){return a(),c()},u)}:useInsertionEffectPolyfill,fullClone$2=_objectSpread2({},React$1),useInsertionEffect=fullClone$2.useInsertionEffect,useCleanupRegister=function(c){var u=[],d=!1;function f(m){d||u.push(m)}return reactExports.useEffect(function(){return d=!1,function(){d=!0,u.length&&u.forEach(function(m){return m()})}},c),f},useRun=function(){return function(c){c()}},useEffectCleanupRegister=typeof useInsertionEffect<"u"?useCleanupRegister:useRun;function useGlobalCache(a,c,u,d,f){var m=reactExports.useContext(StyleContext),g=m.cache,y=[a].concat(_toConsumableArray(c)),b=pathKey(y),E=useEffectCleanupRegister([b]),C=function(M){g.opUpdate(b,function(I){var N=I||[void 0,void 0],A=_slicedToArray(N,2),P=A[0],z=P===void 0?0:P,B=A[1],j=B,L=j||u(),U=[z,L];return M?M(U):U})};reactExports.useMemo(function(){C()},[b]);var w=g.opGet(b),R=w[1];return useCompatibleInsertionEffect(function(){f==null||f(R)},function(_){return C(function(M){var I=_slicedToArray(M,2),N=I[0],A=I[1];return _&&N===0&&(f==null||f(R)),[N+1,A]}),function(){g.opUpdate(b,function(M){var I=M||[],N=_slicedToArray(I,2),A=N[0],P=A===void 0?0:A,z=N[1],B=P-1;return B===0?(E(function(){(_||!g.opGet(b))&&(d==null||d(z,!1))}),null):[P-1,z]})}},[b]),R}var EMPTY_OVERRIDE={},hashPrefix="css",tokenKeys=new Map;function recordCleanToken(a){tokenKeys.set(a,(tokenKeys.get(a)||0)+1)}function removeStyleTags(a,c){if(typeof document<"u"){var u=document.querySelectorAll("style[".concat(ATTR_TOKEN,'="').concat(a,'"]'));u.forEach(function(d){if(d[CSS_IN_JS_INSTANCE]===c){var f;(f=d.parentNode)===null||f===void 0||f.removeChild(d)}})}}var TOKEN_THRESHOLD=0;function cleanTokenStyle(a,c){tokenKeys.set(a,(tokenKeys.get(a)||0)-1);var u=Array.from(tokenKeys.keys()),d=u.filter(function(f){var m=tokenKeys.get(f)||0;return m<=0});u.length-d.length>TOKEN_THRESHOLD&&d.forEach(function(f){removeStyleTags(f,c),tokenKeys.delete(f)})}var getComputedToken$1=function(c,u,d,f){var m=d.getDerivativeToken(c),g=_objectSpread2(_objectSpread2({},m),u);return f&&(g=f(g)),g},TOKEN_PREFIX="token";function useCacheToken(a,c){var u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},d=reactExports.useContext(StyleContext),f=d.cache.instanceId,m=d.container,g=u.salt,y=g===void 0?"":g,b=u.override,E=b===void 0?EMPTY_OVERRIDE:b,C=u.formatToken,w=u.getComputedToken,R=u.cssVar,_=memoResult(function(){return Object.assign.apply(Object,[{}].concat(_toConsumableArray(c)))},c),M=flattenToken(_),I=flattenToken(E),N=R?flattenToken(R):"",A=useGlobalCache(TOKEN_PREFIX,[y,a.id,M,I,N],function(){var P,z=w?w(_,E,a):getComputedToken$1(_,E,a,C),B=_objectSpread2({},z),j="";if(R){var L=transformToken(z,R.key,{prefix:R.prefix,ignore:R.ignore,unitless:R.unitless,preserve:R.preserve}),U=_slicedToArray(L,2);z=U[0],j=U[1]}var q=token2key(z,y);z._tokenKey=q,B._tokenKey=token2key(B,y);var F=(P=R==null?void 0:R.key)!==null&&P!==void 0?P:q;z._themeKey=F,recordCleanToken(F);var K="".concat(hashPrefix,"-").concat(murmur2(q));return z._hashId=K,[z,K,B,j,(R==null?void 0:R.key)||""]},function(P){cleanTokenStyle(P[0]._themeKey,f)},function(P){var z=_slicedToArray(P,4),B=z[0],j=z[3];if(R&&j){var L=updateCSS(j,murmur2("css-variables-".concat(B._themeKey)),{mark:ATTR_MARK,prepend:"queue",attachTo:m,priority:-999});L[CSS_IN_JS_INSTANCE]=f,L.setAttribute(ATTR_TOKEN,B._themeKey)}});return A}var extract$2=function(c,u,d){var f=_slicedToArray(c,5),m=f[2],g=f[3],y=f[4],b=d||{},E=b.plain;if(!g)return null;var C=m._tokenKey,w=-999,R={"data-rc-order":"prependQueue","data-rc-priority":"".concat(w)},_=toStyleStr(g,y,C,R,E);return[w,C,_]},unitlessKeys={animationIterationCount:1,borderImageOutset:1,borderImageSlice:1,borderImageWidth:1,boxFlex:1,boxFlexGroup:1,boxOrdinalGroup:1,columnCount:1,columns:1,flex:1,flexGrow:1,flexPositive:1,flexShrink:1,flexNegative:1,flexOrder:1,gridRow:1,gridRowEnd:1,gridRowSpan:1,gridRowStart:1,gridColumn:1,gridColumnEnd:1,gridColumnSpan:1,gridColumnStart:1,msGridRow:1,msGridRowSpan:1,msGridColumn:1,msGridColumnSpan:1,fontWeight:1,lineHeight:1,opacity:1,order:1,orphans:1,tabSize:1,widows:1,zIndex:1,zoom:1,WebkitLineClamp:1,fillOpacity:1,floodOpacity:1,stopOpacity:1,strokeDasharray:1,strokeDashoffset:1,strokeMiterlimit:1,strokeOpacity:1,strokeWidth:1},COMMENT="comm",RULESET="rule",DECLARATION="decl",IMPORT="@import",NAMESPACE="@namespace",KEYFRAMES="@keyframes",LAYER="@layer",abs=Math.abs,from=String.fromCharCode;function trim$1(a){return a.trim()}function replace$1(a,c,u){return a.replace(c,u)}function indexof(a,c,u){return a.indexOf(c,u)}function charat(a,c){return a.charCodeAt(c)|0}function substr(a,c,u){return a.slice(c,u)}function strlen(a){return a.length}function sizeof(a){return a.length}function append(a,c){return c.push(a),a}var line=1,column=1,length=0,position$3=0,character=0,characters="";function node$1(a,c,u,d,f,m,g,y){return{value:a,root:c,parent:u,type:d,props:f,children:m,line,column,length:g,return:"",siblings:y}}function char(){return character}function prev(){return character=position$3>0?charat(characters,--position$3):0,column--,character===10&&(column=1,line--),character}function next(){return character=position$3<length?charat(characters,position$3++):0,column++,character===10&&(column=1,line++),character}function peek$1(){return charat(characters,position$3)}function caret(){return position$3}function slice(a,c){return substr(characters,a,c)}function token(a){switch(a){case 0:case 9:case 10:case 13:case 32:return 5;case 33:case 43:case 44:case 47:case 62:case 64:case 126:case 59:case 123:case 125:return 4;case 58:return 3;case 34:case 39:case 40:case 91:return 2;case 41:case 93:return 1}return 0}function alloc(a){return line=column=1,length=strlen(characters=a),position$3=0,[]}function dealloc(a){return characters="",a}function delimit(a){return trim$1(slice(position$3-1,delimiter$1(a===91?a+2:a===40?a+1:a)))}function whitespace$2(a){for(;(character=peek$1())&&character<33;)next();return token(a)>2||token(character)>3?"":" "}function escaping(a,c){for(;--c&&next()&&!(character<48||character>102||character>57&&character<65||character>70&&character<97););return slice(a,caret()+(c<6&&peek$1()==32&&next()==32))}function delimiter$1(a){for(;next();)switch(character){case a:return position$3;case 34:case 39:a!==34&&a!==39&&delimiter$1(character);break;case 40:a===41&&delimiter$1(a);break;case 92:next();break}return position$3}function commenter(a,c){for(;next()&&a+character!==57;)if(a+character===84&&peek$1()===47)break;return"/*"+slice(c,position$3-1)+"*"+from(a===47?a:next())}function identifier(a){for(;!token(peek$1());)next();return slice(a,position$3)}function compile(a){return dealloc(parse$3("",null,null,null,[""],a=alloc(a),0,[0],a))}function parse$3(a,c,u,d,f,m,g,y,b){for(var E=0,C=0,w=g,R=0,_=0,M=0,I=1,N=1,A=1,P=0,z="",B=f,j=m,L=d,U=z;N;)switch(M=P,P=next()){case 40:if(M!=108&&charat(U,w-1)==58){indexof(U+=replace$1(delimit(P),"&","&\f"),"&\f",abs(E?y[E-1]:0))!=-1&&(A=-1);break}case 34:case 39:case 91:U+=delimit(P);break;case 9:case 10:case 13:case 32:U+=whitespace$2(M);break;case 92:U+=escaping(caret()-1,7);continue;case 47:switch(peek$1()){case 42:case 47:append(comment$1(commenter(next(),caret()),c,u,b),b),(token(M||1)==5||token(peek$1()||1)==5)&&strlen(U)&&substr(U,-1,void 0)!==" "&&(U+=" ");break;default:U+="/"}break;case 123*I:y[E++]=strlen(U)*A;case 125*I:case 59:case 0:switch(P){case 0:case 125:N=0;case 59+C:A==-1&&(U=replace$1(U,/\f/g,"")),_>0&&(strlen(U)-w||I===0&&M===47)&&append(_>32?declaration(U+";",d,u,w-1,b):declaration(replace$1(U," ","")+";",d,u,w-2,b),b);break;case 59:U+=";";default:if(append(L=ruleset(U,c,u,E,C,f,y,z,B=[],j=[],w,m),m),P===123)if(C===0)parse$3(U,c,L,L,B,m,w,y,j);else{switch(R){case 99:if(charat(U,3)===110)break;case 108:if(charat(U,2)===97)break;default:C=0;case 100:case 109:case 115:}C?parse$3(a,L,L,d&&append(ruleset(a,L,L,0,0,f,y,z,f,B=[],w,j),j),f,j,w,y,d?B:j):parse$3(U,L,L,L,[""],j,0,y,j)}}E=C=_=0,I=A=1,z=U="",w=g;break;case 58:w=1+strlen(U),_=M;default:if(I<1){if(P==123)--I;else if(P==125&&I++==0&&prev()==125)continue}switch(U+=from(P),P*I){case 38:A=C>0?1:(U+="\f",-1);break;case 44:y[E++]=(strlen(U)-1)*A,A=1;break;case 64:peek$1()===45&&(U+=delimit(next())),R=peek$1(),C=w=strlen(z=U+=identifier(caret())),P++;break;case 45:M===45&&strlen(U)==2&&(I=0)}}return m}function ruleset(a,c,u,d,f,m,g,y,b,E,C,w){for(var R=f-1,_=f===0?m:[""],M=sizeof(_),I=0,N=0,A=0;I<d;++I)for(var P=0,z=substr(a,R+1,R=abs(N=g[I])),B=a;P<M;++P)(B=trim$1(N>0?_[P]+" "+z:replace$1(z,/&\f/g,_[P])))&&(b[A++]=B);return node$1(a,c,u,f===0?RULESET:y,b,E,C,w)}function comment$1(a,c,u,d){return node$1(a,c,u,COMMENT,from(char()),substr(a,2,-2),0,d)}function declaration(a,c,u,d,f){return node$1(a,c,u,DECLARATION,substr(a,0,d),substr(a,d+1,-1),d,f)}function serialize$2(a,c){for(var u="",d=0;d<a.length;d++)u+=c(a[d],d,a,c)||"";return u}function stringify$4(a,c,u,d){switch(a.type){case LAYER:if(a.children.length)break;case IMPORT:case NAMESPACE:case DECLARATION:return a.return=a.return||a.value;case COMMENT:return"";case KEYFRAMES:return a.return=a.value+"{"+serialize$2(a.children,d)+"}";case RULESET:if(!strlen(a.value=a.props.join(",")))return""}return strlen(u=serialize$2(a.children,d))?a.return=a.value+"{"+u+"}":""}var ATTR_CACHE_MAP="data-ant-cssinjs-cache-path",CSS_FILE_STYLE="_FILE_STYLE__",cachePathMap,fromCSSFile=!0;function prepare(){if(!cachePathMap&&(cachePathMap={},canUseDom())){var a=document.createElement("div");a.className=ATTR_CACHE_MAP,a.style.position="fixed",a.style.visibility="hidden",a.style.top="-9999px",document.body.appendChild(a);var c=getComputedStyle(a).content||"";c=c.replace(/^"/,"").replace(/"$/,""),c.split(";").forEach(function(f){var m=f.split(":"),g=_slicedToArray(m,2),y=g[0],b=g[1];cachePathMap[y]=b});var u=document.querySelector("style[".concat(ATTR_CACHE_MAP,"]"));if(u){var d;fromCSSFile=!1,(d=u.parentNode)===null||d===void 0||d.removeChild(u)}document.body.removeChild(a)}}function existPath(a){return prepare(),!!cachePathMap[a]}function getStyleAndHash(a){var c=cachePathMap[a],u=null;if(c&&canUseDom())if(fromCSSFile)u=CSS_FILE_STYLE;else{var d=document.querySelector("style[".concat(ATTR_MARK,'="').concat(cachePathMap[a],'"]'));d?u=d.innerHTML:delete cachePathMap[a]}return[u,c]}var SKIP_CHECK="_skip_check_",MULTI_VALUE="_multi_value_";function normalizeStyle(a){var c=serialize$2(compile(a),stringify$4);return c.replace(/\{%%%\:[^;];}/g,";")}function isCompoundCSSProperty(a){return _typeof(a)==="object"&&a&&(SKIP_CHECK in a||MULTI_VALUE in a)}function injectSelectorHash(a,c,u){if(!c)return a;var d=".".concat(c),f=u==="low"?":where(".concat(d,")"):d,m=a.split(",").map(function(g){var y,b=g.trim().split(/\s+/),E=b[0]||"",C=((y=E.match(/^\w+/))===null||y===void 0?void 0:y[0])||"";return E="".concat(C).concat(f).concat(E.slice(C.length)),[E].concat(_toConsumableArray(b.slice(1))).join(" ")});return m.join(",")}var parseStyle$1=function a(c){var u=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},d=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{root:!0,parentSelectors:[]},f=d.root,m=d.injectHash,g=d.parentSelectors,y=u.hashId,b=u.layer;u.path;var E=u.hashPriority,C=u.transformers,w=C===void 0?[]:C;u.linters;var R="",_={};function M(A){var P=A.getName(y);if(!_[P]){var z=a(A.style,u,{root:!1,parentSelectors:g}),B=_slicedToArray(z,1),j=B[0];_[P]="@keyframes ".concat(A.getName(y)).concat(j)}}function I(A){var P=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[];return A.forEach(function(z){Array.isArray(z)?I(z,P):z&&P.push(z)}),P}var N=I(Array.isArray(c)?c:[c]);return N.forEach(function(A){var P=typeof A=="string"&&!f?{}:A;if(typeof P=="string")R+="".concat(P,`
`);else if(P._keyframe)M(P);else{var z=w.reduce(function(B,j){var L;return(j==null||(L=j.visit)===null||L===void 0?void 0:L.call(j,B))||B},P);Object.keys(z).forEach(function(B){var j=z[B];if(_typeof(j)==="object"&&j&&(B!=="animationName"||!j._keyframe)&&!isCompoundCSSProperty(j)){var L=!1,U=B.trim(),q=!1;(f||m)&&y?U.startsWith("@")?L=!0:U==="&"?U=injectSelectorHash("",y,E):U=injectSelectorHash(B,y,E):f&&!y&&(U==="&"||U==="")&&(U="",q=!0);var F=a(j,u,{root:q,injectHash:L,parentSelectors:[].concat(_toConsumableArray(g),[U])}),K=_slicedToArray(F,2),X=K[0],Q=K[1];_=_objectSpread2(_objectSpread2({},_),Q),R+="".concat(U).concat(X)}else{let J=function(W,G){var te=W.replace(/[A-Z]/g,function(V){return"-".concat(V.toLowerCase())}),ae=G;!unitlessKeys[W]&&typeof ae=="number"&&ae!==0&&(ae="".concat(ae,"px")),W==="animationName"&&G!==null&&G!==void 0&&G._keyframe&&(M(G),ae=G.getName(y)),R+="".concat(te,":").concat(ae,";")};var Y,Z=(Y=j==null?void 0:j.value)!==null&&Y!==void 0?Y:j;_typeof(j)==="object"&&j!==null&&j!==void 0&&j[MULTI_VALUE]&&Array.isArray(Z)?Z.forEach(function(W){J(B,W)}):J(B,Z)}})}}),f?b&&(R&&(R="@layer ".concat(b.name," {").concat(R,"}")),b.dependencies&&(_["@layer ".concat(b.name)]=b.dependencies.map(function(A){return"@layer ".concat(A,", ").concat(b.name,";")}).join(`
`))):R="{".concat(R,"}"),[R,_]};function uniqueHash(a,c){return murmur2("".concat(a.join("%")).concat(c))}function Empty$2(){return null}var STYLE_PREFIX="style";function useStyleRegister(a,c){var u=a.token,d=a.path,f=a.hashId,m=a.layer,g=a.nonce,y=a.clientOnly,b=a.order,E=b===void 0?0:b,C=reactExports.useContext(StyleContext),w=C.autoClear;C.mock;var R=C.defaultCache,_=C.hashPriority,M=C.container,I=C.ssrInline,N=C.transformers,A=C.linters,P=C.cache,z=C.layer,B=u._tokenKey,j=[B];z&&j.push("layer"),j.push.apply(j,_toConsumableArray(d));var L=isClientSide,U=useGlobalCache(STYLE_PREFIX,j,function(){var Q=j.join("|");if(existPath(Q)){var Y=getStyleAndHash(Q),Z=_slicedToArray(Y,2),J=Z[0],W=Z[1];if(J)return[J,B,W,{},y,E]}var G=c(),te=parseStyle$1(G,{hashId:f,hashPriority:_,layer:z?m:void 0,path:d.join("-"),transformers:N,linters:A}),ae=_slicedToArray(te,2),V=ae[0],ne=ae[1],le=normalizeStyle(V),ee=uniqueHash(j,le);return[le,B,ee,ne,y,E]},function(Q,Y){var Z=_slicedToArray(Q,3),J=Z[2];(Y||w)&&isClientSide&&removeCSS(J,{mark:ATTR_MARK})},function(Q){var Y=_slicedToArray(Q,4),Z=Y[0];Y[1];var J=Y[2],W=Y[3];if(L&&Z!==CSS_FILE_STYLE){var G={mark:ATTR_MARK,prepend:z?!1:"queue",attachTo:M,priority:E},te=typeof g=="function"?g():g;te&&(G.csp={nonce:te});var ae=[],V=[];Object.keys(W).forEach(function(le){le.startsWith("@layer")?ae.push(le):V.push(le)}),ae.forEach(function(le){updateCSS(normalizeStyle(W[le]),"_layer-".concat(le),_objectSpread2(_objectSpread2({},G),{},{prepend:!0}))});var ne=updateCSS(Z,J,G);ne[CSS_IN_JS_INSTANCE]=P.instanceId,ne.setAttribute(ATTR_TOKEN,B),V.forEach(function(le){updateCSS(normalizeStyle(W[le]),"_effect-".concat(le),G)})}}),q=_slicedToArray(U,3),F=q[0],K=q[1],X=q[2];return function(Q){var Y;if(!I||L||!R)Y=reactExports.createElement(Empty$2,null);else{var Z;Y=reactExports.createElement("style",_extends({},(Z={},_defineProperty(Z,ATTR_TOKEN,K),_defineProperty(Z,ATTR_MARK,X),Z),{dangerouslySetInnerHTML:{__html:F}}))}return reactExports.createElement(reactExports.Fragment,null,Y,Q)}}var extract$1=function(c,u,d){var f=_slicedToArray(c,6),m=f[0],g=f[1],y=f[2],b=f[3],E=f[4],C=f[5],w=d||{},R=w.plain;if(E)return null;var _=m,M={"data-rc-order":"prependQueue","data-rc-priority":"".concat(C)};return _=toStyleStr(m,g,y,M,R),b&&Object.keys(b).forEach(function(I){if(!u[I]){u[I]=!0;var N=normalizeStyle(b[I]),A=toStyleStr(N,g,"_effect-".concat(I),M,R);I.startsWith("@layer")?_=A+_:_+=A}}),[C,y,_]},CSS_VAR_PREFIX="cssVar",useCSSVarRegister=function(c,u){var d=c.key,f=c.prefix,m=c.unitless,g=c.ignore,y=c.token,b=c.scope,E=b===void 0?"":b,C=reactExports.useContext(StyleContext),w=C.cache.instanceId,R=C.container,_=y._tokenKey,M=[].concat(_toConsumableArray(c.path),[d,E,_]),I=useGlobalCache(CSS_VAR_PREFIX,M,function(){var N=u(),A=transformToken(N,d,{prefix:f,unitless:m,ignore:g,scope:E}),P=_slicedToArray(A,2),z=P[0],B=P[1],j=uniqueHash(M,B);return[z,B,j,d]},function(N){var A=_slicedToArray(N,3),P=A[2];isClientSide&&removeCSS(P,{mark:ATTR_MARK})},function(N){var A=_slicedToArray(N,3),P=A[1],z=A[2];if(P){var B=updateCSS(P,z,{mark:ATTR_MARK,prepend:"queue",attachTo:R,priority:-999});B[CSS_IN_JS_INSTANCE]=w,B.setAttribute(ATTR_TOKEN,d)}});return I},extract=function(c,u,d){var f=_slicedToArray(c,4),m=f[1],g=f[2],y=f[3],b=d||{},E=b.plain;if(!m)return null;var C=-999,w={"data-rc-order":"prependQueue","data-rc-priority":"".concat(C)},R=toStyleStr(m,y,g,w,E);return[C,g,R]},_ExtractStyleFns;_ExtractStyleFns={},_defineProperty(_ExtractStyleFns,STYLE_PREFIX,extract$1),_defineProperty(_ExtractStyleFns,TOKEN_PREFIX,extract$2),_defineProperty(_ExtractStyleFns,CSS_VAR_PREFIX,extract);var Keyframe=function(){function a(c,u){_classCallCheck(this,a),_defineProperty(this,"name",void 0),_defineProperty(this,"style",void 0),_defineProperty(this,"_keyframe",!0),this.name=c,this.style=u}return _createClass(a,[{key:"getName",value:function(){var u=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"";return u?"".concat(u,"-").concat(this.name):this.name}}]),a}();function noSplit(a){return a.notSplit=!0,a}noSplit(["borderTop","borderBottom"]),noSplit(["borderTop"]),noSplit(["borderBottom"]),noSplit(["borderLeft","borderRight"]),noSplit(["borderLeft"]),noSplit(["borderRight"]);function _toArray(a){return _arrayWithHoles(a)||_iterableToArray(a)||_unsupportedIterableToArray(a)||_nonIterableRest()}function get(a,c){for(var u=a,d=0;d<c.length;d+=1){if(u==null)return;u=u[c[d]]}return u}function internalSet(a,c,u,d){if(!c.length)return u;var f=_toArray(c),m=f[0],g=f.slice(1),y;return!a&&typeof m=="number"?y=[]:Array.isArray(a)?y=_toConsumableArray(a):y=_objectSpread2({},a),d&&u===void 0&&g.length===1?delete y[m][g[0]]:y[m]=internalSet(y[m],g,u,d),y}function set$1(a,c,u){var d=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1;return c.length&&d&&u===void 0&&!get(a,c.slice(0,-1))?a:internalSet(a,c,u,d)}function isObject$1(a){return _typeof(a)==="object"&&a!==null&&Object.getPrototypeOf(a)===Object.prototype}function createEmpty(a){return Array.isArray(a)?[]:{}}var keys$1=typeof Reflect>"u"?Object.keys:Reflect.ownKeys;function merge$3(){for(var a=arguments.length,c=new Array(a),u=0;u<a;u++)c[u]=arguments[u];var d=createEmpty(c[0]);return c.forEach(function(f){function m(g,y){var b=new Set(y),E=get(f,g),C=Array.isArray(E);if(C||isObject$1(E)){if(!b.has(E)){b.add(E);var w=get(d,g);C?d=set$1(d,g,[]):(!w||_typeof(w)!=="object")&&(d=set$1(d,g,createEmpty(E))),keys$1(E).forEach(function(R){m([].concat(_toConsumableArray(g),[R]),b)})}}else d=set$1(d,g,E)}m([])}),d}function noop$5(){}const WarningContext=reactExports.createContext({}),devUseWarning=()=>{const a=()=>{};return a.deprecated=noop$5,a},ValidateMessagesContext=reactExports.createContext(void 0);var locale$4={items_per_page:"/ page",jump_to:"Go to",jump_to_confirm:"confirm",page:"Page",prev_page:"Previous Page",next_page:"Next Page",prev_5:"Previous 5 Pages",next_5:"Next 5 Pages",prev_3:"Previous 3 Pages",next_3:"Next 3 Pages",page_size:"Page Size"},commonLocale={yearFormat:"YYYY",dayFormat:"D",cellMeridiemFormat:"A",monthBeforeYear:!0},locale$3=_objectSpread2(_objectSpread2({},commonLocale),{},{locale:"en_US",today:"Today",now:"Now",backToToday:"Back to today",ok:"OK",clear:"Clear",week:"Week",month:"Month",year:"Year",timeSelect:"select time",dateSelect:"select date",weekSelect:"Choose a week",monthSelect:"Choose a month",yearSelect:"Choose a year",decadeSelect:"Choose a decade",dateFormat:"M/D/YYYY",dateTimeFormat:"M/D/YYYY HH:mm:ss",previousMonth:"Previous month (PageUp)",nextMonth:"Next month (PageDown)",previousYear:"Last year (Control + left)",nextYear:"Next year (Control + right)",previousDecade:"Last decade",nextDecade:"Next decade",previousCentury:"Last century",nextCentury:"Next century"});const locale$2={placeholder:"Select time",rangePlaceholder:["Start time","End time"]},locale$1={lang:Object.assign({placeholder:"Select date",yearPlaceholder:"Select year",quarterPlaceholder:"Select quarter",monthPlaceholder:"Select month",weekPlaceholder:"Select week",rangePlaceholder:["Start date","End date"],rangeYearPlaceholder:["Start year","End year"],rangeQuarterPlaceholder:["Start quarter","End quarter"],rangeMonthPlaceholder:["Start month","End month"],rangeWeekPlaceholder:["Start week","End week"]},locale$3),timePickerLocale:Object.assign({},locale$2)},typeTemplate$1="${label} is not a valid ${type}",localeValues={locale:"en",Pagination:locale$4,DatePicker:locale$1,TimePicker:locale$2,Calendar:locale$1,global:{placeholder:"Please select"},Table:{filterTitle:"Filter menu",filterConfirm:"OK",filterReset:"Reset",filterEmptyText:"No filters",filterCheckAll:"Select all items",filterSearchPlaceholder:"Search in filters",emptyText:"No data",selectAll:"Select current page",selectInvert:"Invert current page",selectNone:"Clear all data",selectionAll:"Select all data",sortTitle:"Sort",expand:"Expand row",collapse:"Collapse row",triggerDesc:"Click to sort descending",triggerAsc:"Click to sort ascending",cancelSort:"Click to cancel sorting"},Tour:{Next:"Next",Previous:"Previous",Finish:"Finish"},Modal:{okText:"OK",cancelText:"Cancel",justOkText:"OK"},Popconfirm:{okText:"OK",cancelText:"Cancel"},Transfer:{titles:["",""],searchPlaceholder:"Search here",itemUnit:"item",itemsUnit:"items",remove:"Remove",selectCurrent:"Select current page",removeCurrent:"Remove current page",selectAll:"Select all data",deselectAll:"Deselect all data",removeAll:"Remove all data",selectInvert:"Invert current page"},Upload:{uploading:"Uploading...",removeFile:"Remove file",uploadError:"Upload error",previewFile:"Preview file",downloadFile:"Download file"},Empty:{description:"No data"},Icon:{icon:"icon"},Text:{edit:"Edit",copy:"Copy",copied:"Copied",expand:"Expand",collapse:"Collapse"},Form:{optional:"(optional)",defaultValidateMessages:{default:"Field validation error for ${label}",required:"Please enter ${label}",enum:"${label} must be one of [${enum}]",whitespace:"${label} cannot be a blank character",date:{format:"${label} date format is invalid",parse:"${label} cannot be converted to a date",invalid:"${label} is an invalid date"},types:{string:typeTemplate$1,method:typeTemplate$1,array:typeTemplate$1,object:typeTemplate$1,number:typeTemplate$1,date:typeTemplate$1,boolean:typeTemplate$1,integer:typeTemplate$1,float:typeTemplate$1,regexp:typeTemplate$1,email:typeTemplate$1,url:typeTemplate$1,hex:typeTemplate$1},string:{len:"${label} must be ${len} characters",min:"${label} must be at least ${min} characters",max:"${label} must be up to ${max} characters",range:"${label} must be between ${min}-${max} characters"},number:{len:"${label} must be equal to ${len}",min:"${label} must be minimum ${min}",max:"${label} must be maximum ${max}",range:"${label} must be between ${min}-${max}"},array:{len:"Must be ${len} ${label}",min:"At least ${min} ${label}",max:"At most ${max} ${label}",range:"The amount of ${label} must be between ${min}-${max}"},pattern:{mismatch:"${label} does not match the pattern ${pattern}"}}},Image:{preview:"Preview"},QRCode:{expired:"QR code expired",refresh:"Refresh",scanned:"Scanned"},ColorPicker:{presetEmpty:"Empty",transparent:"Transparent",singleColor:"Single",gradientColor:"Gradient"}};let runtimeLocale=Object.assign({},localeValues.Modal),localeList=[];const generateLocale=()=>localeList.reduce((a,c)=>Object.assign(Object.assign({},a),c),localeValues.Modal);function changeConfirmLocale(a){if(a){const c=Object.assign({},a);return localeList.push(c),runtimeLocale=generateLocale(),()=>{localeList=localeList.filter(u=>u!==c),runtimeLocale=generateLocale()}}runtimeLocale=Object.assign({},localeValues.Modal)}function getConfirmLocale(){return runtimeLocale}const LocaleContext=reactExports.createContext(void 0),useLocale=(a,c)=>{const u=reactExports.useContext(LocaleContext),d=reactExports.useMemo(()=>{var m;const g=c||localeValues[a],y=(m=u==null?void 0:u[a])!==null&&m!==void 0?m:{};return Object.assign(Object.assign({},typeof g=="function"?g():g),y||{})},[a,c,u]),f=reactExports.useMemo(()=>{const m=u==null?void 0:u.locale;return u!=null&&u.exist&&!m?localeValues.locale:m},[u]);return[d,f]},ANT_MARK="internalMark",LocaleProvider=a=>{const{locale:c={},children:u,_ANT_MARK__:d}=a;reactExports.useEffect(()=>changeConfirmLocale(c==null?void 0:c.Modal),[c]);const f=reactExports.useMemo(()=>Object.assign(Object.assign({},c),{exist:!0}),[c]);return reactExports.createElement(LocaleContext.Provider,{value:f},u)},defaultPresetColors={blue:"#1677FF",purple:"#722ED1",cyan:"#13C2C2",green:"#52C41A",magenta:"#EB2F96",pink:"#EB2F96",red:"#F5222D",orange:"#FA8C16",yellow:"#FADB14",volcano:"#FA541C",geekblue:"#2F54EB",gold:"#FAAD14",lime:"#A0D911"},seedToken=Object.assign(Object.assign({},defaultPresetColors),{colorPrimary:"#1677ff",colorSuccess:"#52c41a",colorWarning:"#faad14",colorError:"#ff4d4f",colorInfo:"#1677ff",colorLink:"",colorTextBase:"",colorBgBase:"",fontFamily:`-apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, 'Helvetica Neue', Arial,
'Noto Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol',
'Noto Color Emoji'`,fontFamilyCode:"'SFMono-Regular', Consolas, 'Liberation Mono', Menlo, Courier, monospace",fontSize:14,lineWidth:1,lineType:"solid",motionUnit:.1,motionBase:0,motionEaseOutCirc:"cubic-bezier(0.08, 0.82, 0.17, 1)",motionEaseInOutCirc:"cubic-bezier(0.78, 0.14, 0.15, 0.86)",motionEaseOut:"cubic-bezier(0.215, 0.61, 0.355, 1)",motionEaseInOut:"cubic-bezier(0.645, 0.045, 0.355, 1)",motionEaseOutBack:"cubic-bezier(0.12, 0.4, 0.29, 1.46)",motionEaseInBack:"cubic-bezier(0.71, -0.46, 0.88, 0.6)",motionEaseInQuint:"cubic-bezier(0.755, 0.05, 0.855, 0.06)",motionEaseOutQuint:"cubic-bezier(0.23, 1, 0.32, 1)",borderRadius:6,sizeUnit:4,sizeStep:4,sizePopupArrow:16,controlHeight:32,zIndexBase:0,zIndexPopupBase:1e3,opacityImage:1,wireframe:!1,motion:!0});function genColorMapToken(a,c){let{generateColorPalettes:u,generateNeutralColorPalettes:d}=c;const{colorSuccess:f,colorWarning:m,colorError:g,colorInfo:y,colorPrimary:b,colorBgBase:E,colorTextBase:C}=a,w=u(b),R=u(f),_=u(m),M=u(g),I=u(y),N=d(E,C),A=a.colorLink||a.colorInfo,P=u(A),z=new FastColor(M[1]).mix(new FastColor(M[3]),50).toHexString();return Object.assign(Object.assign({},N),{colorPrimaryBg:w[1],colorPrimaryBgHover:w[2],colorPrimaryBorder:w[3],colorPrimaryBorderHover:w[4],colorPrimaryHover:w[5],colorPrimary:w[6],colorPrimaryActive:w[7],colorPrimaryTextHover:w[8],colorPrimaryText:w[9],colorPrimaryTextActive:w[10],colorSuccessBg:R[1],colorSuccessBgHover:R[2],colorSuccessBorder:R[3],colorSuccessBorderHover:R[4],colorSuccessHover:R[4],colorSuccess:R[6],colorSuccessActive:R[7],colorSuccessTextHover:R[8],colorSuccessText:R[9],colorSuccessTextActive:R[10],colorErrorBg:M[1],colorErrorBgHover:M[2],colorErrorBgFilledHover:z,colorErrorBgActive:M[3],colorErrorBorder:M[3],colorErrorBorderHover:M[4],colorErrorHover:M[5],colorError:M[6],colorErrorActive:M[7],colorErrorTextHover:M[8],colorErrorText:M[9],colorErrorTextActive:M[10],colorWarningBg:_[1],colorWarningBgHover:_[2],colorWarningBorder:_[3],colorWarningBorderHover:_[4],colorWarningHover:_[4],colorWarning:_[6],colorWarningActive:_[7],colorWarningTextHover:_[8],colorWarningText:_[9],colorWarningTextActive:_[10],colorInfoBg:I[1],colorInfoBgHover:I[2],colorInfoBorder:I[3],colorInfoBorderHover:I[4],colorInfoHover:I[4],colorInfo:I[6],colorInfoActive:I[7],colorInfoTextHover:I[8],colorInfoText:I[9],colorInfoTextActive:I[10],colorLinkHover:P[4],colorLink:P[6],colorLinkActive:P[7],colorBgMask:new FastColor("#000").setA(.45).toRgbString(),colorWhite:"#fff"})}const genRadius=a=>{let c=a,u=a,d=a,f=a;return a<6&&a>=5?c=a+1:a<16&&a>=6?c=a+2:a>=16&&(c=16),a<7&&a>=5?u=4:a<8&&a>=7?u=5:a<14&&a>=8?u=6:a<16&&a>=14?u=7:a>=16&&(u=8),a<6&&a>=2?d=1:a>=6&&(d=2),a>4&&a<8?f=4:a>=8&&(f=6),{borderRadius:a,borderRadiusXS:d,borderRadiusSM:u,borderRadiusLG:c,borderRadiusOuter:f}};function genCommonMapToken(a){const{motionUnit:c,motionBase:u,borderRadius:d,lineWidth:f}=a;return Object.assign({motionDurationFast:`${(u+c).toFixed(1)}s`,motionDurationMid:`${(u+c*2).toFixed(1)}s`,motionDurationSlow:`${(u+c*3).toFixed(1)}s`,lineWidthBold:f+1},genRadius(d))}const genControlHeight=a=>{const{controlHeight:c}=a;return{controlHeightSM:c*.75,controlHeightXS:c*.5,controlHeightLG:c*1.25}};function getLineHeight(a){return(a+8)/a}function getFontSizes(a){const c=Array.from({length:10}).map((u,d)=>{const f=d-1,m=a*Math.pow(Math.E,f/5),g=d>1?Math.floor(m):Math.ceil(m);return Math.floor(g/2)*2});return c[1]=a,c.map(u=>({size:u,lineHeight:getLineHeight(u)}))}const genFontMapToken=a=>{const c=getFontSizes(a),u=c.map(C=>C.size),d=c.map(C=>C.lineHeight),f=u[1],m=u[0],g=u[2],y=d[1],b=d[0],E=d[2];return{fontSizeSM:m,fontSize:f,fontSizeLG:g,fontSizeXL:u[3],fontSizeHeading1:u[6],fontSizeHeading2:u[5],fontSizeHeading3:u[4],fontSizeHeading4:u[3],fontSizeHeading5:u[2],lineHeight:y,lineHeightLG:E,lineHeightSM:b,fontHeight:Math.round(y*f),fontHeightLG:Math.round(E*g),fontHeightSM:Math.round(b*m),lineHeightHeading1:d[6],lineHeightHeading2:d[5],lineHeightHeading3:d[4],lineHeightHeading4:d[3],lineHeightHeading5:d[2]}};function genSizeMapToken$1(a){const{sizeUnit:c,sizeStep:u}=a;return{sizeXXL:c*(u+8),sizeXL:c*(u+4),sizeLG:c*(u+2),sizeMD:c*(u+1),sizeMS:c*u,size:c*u,sizeSM:c*(u-1),sizeXS:c*(u-2),sizeXXS:c*(u-3)}}const getAlphaColor$2=(a,c)=>new FastColor(a).setA(c).toRgbString(),getSolidColor$1=(a,c)=>new FastColor(a).darken(c).toHexString(),generateColorPalettes$1=a=>{const c=generate$1(a);return{1:c[0],2:c[1],3:c[2],4:c[3],5:c[4],6:c[5],7:c[6],8:c[4],9:c[5],10:c[6]}},generateNeutralColorPalettes$1=(a,c)=>{const u=a||"#fff",d=c||"#000";return{colorBgBase:u,colorTextBase:d,colorText:getAlphaColor$2(d,.88),colorTextSecondary:getAlphaColor$2(d,.65),colorTextTertiary:getAlphaColor$2(d,.45),colorTextQuaternary:getAlphaColor$2(d,.25),colorFill:getAlphaColor$2(d,.15),colorFillSecondary:getAlphaColor$2(d,.06),colorFillTertiary:getAlphaColor$2(d,.04),colorFillQuaternary:getAlphaColor$2(d,.02),colorBgSolid:getAlphaColor$2(d,1),colorBgSolidHover:getAlphaColor$2(d,.75),colorBgSolidActive:getAlphaColor$2(d,.95),colorBgLayout:getSolidColor$1(u,4),colorBgContainer:getSolidColor$1(u,0),colorBgElevated:getSolidColor$1(u,0),colorBgSpotlight:getAlphaColor$2(d,.85),colorBgBlur:"transparent",colorBorder:getSolidColor$1(u,15),colorBorderSecondary:getSolidColor$1(u,6)}};function derivative$2(a){presetPrimaryColors.pink=presetPrimaryColors.magenta,presetPalettes.pink=presetPalettes.magenta;const c=Object.keys(defaultPresetColors).map(u=>{const d=a[u]===presetPrimaryColors[u]?presetPalettes[u]:generate$1(a[u]);return Array.from({length:10},()=>1).reduce((f,m,g)=>(f[`${u}-${g+1}`]=d[g],f[`${u}${g+1}`]=d[g],f),{})}).reduce((u,d)=>(u=Object.assign(Object.assign({},u),d),u),{});return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},a),c),genColorMapToken(a,{generateColorPalettes:generateColorPalettes$1,generateNeutralColorPalettes:generateNeutralColorPalettes$1})),genFontMapToken(a.fontSize)),genSizeMapToken$1(a)),genControlHeight(a)),genCommonMapToken(a))}const defaultTheme=createTheme(derivative$2),defaultConfig={token:seedToken,override:{override:seedToken},hashed:!0},DesignTokenContext=React.createContext(defaultConfig),defaultPrefixCls="ant",defaultIconPrefixCls="anticon",Variants=["outlined","borderless","filled","underlined"],defaultGetPrefixCls=(a,c)=>c||(a?`${defaultPrefixCls}-${a}`:defaultPrefixCls),ConfigContext=reactExports.createContext({getPrefixCls:defaultGetPrefixCls,iconPrefixCls:defaultIconPrefixCls}),{Consumer:ConfigConsumer}=ConfigContext,EMPTY_OBJECT={};function useComponentConfig(a){const c=reactExports.useContext(ConfigContext),{getPrefixCls:u,direction:d,getPopupContainer:f}=c,m=c[a];return Object.assign(Object.assign({classNames:EMPTY_OBJECT,styles:EMPTY_OBJECT},m),{getPrefixCls:u,direction:d,getPopupContainer:f})}const dynamicStyleMark=`-ant-${Date.now()}-${Math.random()}`;function getStyle$1(a,c){const u={},d=(g,y)=>{let b=g.clone();return b=(y==null?void 0:y(b))||b,b.toRgbString()},f=(g,y)=>{const b=new FastColor(g),E=generate$1(b.toRgbString());u[`${y}-color`]=d(b),u[`${y}-color-disabled`]=E[1],u[`${y}-color-hover`]=E[4],u[`${y}-color-active`]=E[6],u[`${y}-color-outline`]=b.clone().setA(.2).toRgbString(),u[`${y}-color-deprecated-bg`]=E[0],u[`${y}-color-deprecated-border`]=E[2]};if(c.primaryColor){f(c.primaryColor,"primary");const g=new FastColor(c.primaryColor),y=generate$1(g.toRgbString());y.forEach((E,C)=>{u[`primary-${C+1}`]=E}),u["primary-color-deprecated-l-35"]=d(g,E=>E.lighten(35)),u["primary-color-deprecated-l-20"]=d(g,E=>E.lighten(20)),u["primary-color-deprecated-t-20"]=d(g,E=>E.tint(20)),u["primary-color-deprecated-t-50"]=d(g,E=>E.tint(50)),u["primary-color-deprecated-f-12"]=d(g,E=>E.setA(E.a*.12));const b=new FastColor(y[0]);u["primary-color-active-deprecated-f-30"]=d(b,E=>E.setA(E.a*.3)),u["primary-color-active-deprecated-d-02"]=d(b,E=>E.darken(2))}return c.successColor&&f(c.successColor,"success"),c.warningColor&&f(c.warningColor,"warning"),c.errorColor&&f(c.errorColor,"error"),c.infoColor&&f(c.infoColor,"info"),`
  :root {
    ${Object.keys(u).map(g=>`--${a}-${g}: ${u[g]};`).join(`
`)}
  }
  `.trim()}function registerTheme(a,c){const u=getStyle$1(a,c);canUseDom()&&updateCSS(u,`${dynamicStyleMark}-dynamic-theme`)}const DisabledContext=reactExports.createContext(!1),DisabledContextProvider=a=>{let{children:c,disabled:u}=a;const d=reactExports.useContext(DisabledContext);return reactExports.createElement(DisabledContext.Provider,{value:u??d},c)},SizeContext=reactExports.createContext(void 0),SizeContextProvider=a=>{let{children:c,size:u}=a;const d=reactExports.useContext(SizeContext);return reactExports.createElement(SizeContext.Provider,{value:u||d},c)};function useConfig(){const a=reactExports.useContext(DisabledContext),c=reactExports.useContext(SizeContext);return{componentDisabled:a,componentSize:c}}var AbstractCalculator=_createClass(function a(){_classCallCheck(this,a)}),CALC_UNIT="CALC_UNIT",regexp$1=new RegExp(CALC_UNIT,"g");function unit(a){return typeof a=="number"?"".concat(a).concat(CALC_UNIT):a}var CSSCalculator=function(a){_inherits(u,a);var c=_createSuper(u);function u(d,f){var m;_classCallCheck(this,u),m=c.call(this),_defineProperty(_assertThisInitialized(m),"result",""),_defineProperty(_assertThisInitialized(m),"unitlessCssVar",void 0),_defineProperty(_assertThisInitialized(m),"lowPriority",void 0);var g=_typeof(d);return m.unitlessCssVar=f,d instanceof u?m.result="(".concat(d.result,")"):g==="number"?m.result=unit(d):g==="string"&&(m.result=d),m}return _createClass(u,[{key:"add",value:function(f){return f instanceof u?this.result="".concat(this.result," + ").concat(f.getResult()):(typeof f=="number"||typeof f=="string")&&(this.result="".concat(this.result," + ").concat(unit(f))),this.lowPriority=!0,this}},{key:"sub",value:function(f){return f instanceof u?this.result="".concat(this.result," - ").concat(f.getResult()):(typeof f=="number"||typeof f=="string")&&(this.result="".concat(this.result," - ").concat(unit(f))),this.lowPriority=!0,this}},{key:"mul",value:function(f){return this.lowPriority&&(this.result="(".concat(this.result,")")),f instanceof u?this.result="".concat(this.result," * ").concat(f.getResult(!0)):(typeof f=="number"||typeof f=="string")&&(this.result="".concat(this.result," * ").concat(f)),this.lowPriority=!1,this}},{key:"div",value:function(f){return this.lowPriority&&(this.result="(".concat(this.result,")")),f instanceof u?this.result="".concat(this.result," / ").concat(f.getResult(!0)):(typeof f=="number"||typeof f=="string")&&(this.result="".concat(this.result," / ").concat(f)),this.lowPriority=!1,this}},{key:"getResult",value:function(f){return this.lowPriority||f?"(".concat(this.result,")"):this.result}},{key:"equal",value:function(f){var m=this,g=f||{},y=g.unit,b=!0;return typeof y=="boolean"?b=y:Array.from(this.unitlessCssVar).some(function(E){return m.result.includes(E)})&&(b=!1),this.result=this.result.replace(regexp$1,b?"px":""),typeof this.lowPriority<"u"?"calc(".concat(this.result,")"):this.result}}]),u}(AbstractCalculator),NumCalculator=function(a){_inherits(u,a);var c=_createSuper(u);function u(d){var f;return _classCallCheck(this,u),f=c.call(this),_defineProperty(_assertThisInitialized(f),"result",0),d instanceof u?f.result=d.result:typeof d=="number"&&(f.result=d),f}return _createClass(u,[{key:"add",value:function(f){return f instanceof u?this.result+=f.result:typeof f=="number"&&(this.result+=f),this}},{key:"sub",value:function(f){return f instanceof u?this.result-=f.result:typeof f=="number"&&(this.result-=f),this}},{key:"mul",value:function(f){return f instanceof u?this.result*=f.result:typeof f=="number"&&(this.result*=f),this}},{key:"div",value:function(f){return f instanceof u?this.result/=f.result:typeof f=="number"&&(this.result/=f),this}},{key:"equal",value:function(){return this.result}}]),u}(AbstractCalculator),genCalc=function(c,u){var d=c==="css"?CSSCalculator:NumCalculator;return function(f){return new d(f,u)}},getCompVarPrefix=function(c,u){return"".concat([u,c.replace(/([A-Z]+)([A-Z][a-z]+)/g,"$1-$2").replace(/([a-z])([A-Z])/g,"$1-$2")].filter(Boolean).join("-"))};function useEvent(a){var c=reactExports.useRef();c.current=a;var u=reactExports.useCallback(function(){for(var d,f=arguments.length,m=new Array(f),g=0;g<f;g++)m[g]=arguments[g];return(d=c.current)===null||d===void 0?void 0:d.call.apply(d,[c].concat(m))},[]);return u}function useSafeState(a){var c=reactExports.useRef(!1),u=reactExports.useState(a),d=_slicedToArray(u,2),f=d[0],m=d[1];reactExports.useEffect(function(){return c.current=!1,function(){c.current=!0}},[]);function g(y,b){b&&c.current||m(y)}return[f,g]}function hasValue$1(a){return a!==void 0}function useMergedState(a,c){var u=c||{},d=u.defaultValue,f=u.value,m=u.onChange,g=u.postState,y=useSafeState(function(){return hasValue$1(f)?f:hasValue$1(d)?typeof d=="function"?d():d:typeof a=="function"?a():a}),b=_slicedToArray(y,2),E=b[0],C=b[1],w=f!==void 0?f:E,R=g?g(w):w,_=useEvent(m),M=useSafeState([w]),I=_slicedToArray(M,2),N=I[0],A=I[1];useLayoutUpdateEffect(function(){var z=N[0];E!==z&&_(E,z)},[N]),useLayoutUpdateEffect(function(){hasValue$1(f)||C(f)},[f]);var P=useEvent(function(z,B){C(z,B),A([w],B)});return[R,P]}function getComponentToken(a,c,u,d){var f=_objectSpread2({},c[a]);if(d!=null&&d.deprecatedTokens){var m=d.deprecatedTokens;m.forEach(function(y){var b=_slicedToArray(y,2),E=b[0],C=b[1];if(f!=null&&f[E]||f!=null&&f[C]){var w;(w=f[C])!==null&&w!==void 0||(f[C]=f==null?void 0:f[E])}})}var g=_objectSpread2(_objectSpread2({},u),f);return Object.keys(g).forEach(function(y){g[y]===c[y]&&delete g[y]}),g}var enableStatistic=typeof CSSINJS_STATISTIC<"u",recording=!0;function merge$2(){for(var a=arguments.length,c=new Array(a),u=0;u<a;u++)c[u]=arguments[u];if(!enableStatistic)return Object.assign.apply(Object,[{}].concat(c));recording=!1;var d={};return c.forEach(function(f){if(_typeof(f)==="object"){var m=Object.keys(f);m.forEach(function(g){Object.defineProperty(d,g,{configurable:!0,enumerable:!0,get:function(){return f[g]}})})}}),recording=!0,d}var statistic={};function noop$4(){}var statisticToken=function(c){var u,d=c,f=noop$4;return enableStatistic&&typeof Proxy<"u"&&(u=new Set,d=new Proxy(c,{get:function(g,y){if(recording){var b;(b=u)===null||b===void 0||b.add(y)}return g[y]}}),f=function(g,y){var b;statistic[g]={global:Array.from(u),component:_objectSpread2(_objectSpread2({},(b=statistic[g])===null||b===void 0?void 0:b.component),y)}}),{token:d,keys:u,flush:f}};function getDefaultComponentToken(a,c,u){if(typeof u=="function"){var d;return u(merge$2(c,(d=c[a])!==null&&d!==void 0?d:{}))}return u??{}}function genMaxMin(a){return a==="js"?{max:Math.max,min:Math.min}:{max:function(){for(var u=arguments.length,d=new Array(u),f=0;f<u;f++)d[f]=arguments[f];return"max(".concat(d.map(function(m){return unit$1(m)}).join(","),")")},min:function(){for(var u=arguments.length,d=new Array(u),f=0;f<u;f++)d[f]=arguments[f];return"min(".concat(d.map(function(m){return unit$1(m)}).join(","),")")}}}var BEAT_LIMIT=1e3*60*10,ArrayKeyMap=function(){function a(){_classCallCheck(this,a),_defineProperty(this,"map",new Map),_defineProperty(this,"objectIDMap",new WeakMap),_defineProperty(this,"nextID",0),_defineProperty(this,"lastAccessBeat",new Map),_defineProperty(this,"accessBeat",0)}return _createClass(a,[{key:"set",value:function(u,d){this.clear();var f=this.getCompositeKey(u);this.map.set(f,d),this.lastAccessBeat.set(f,Date.now())}},{key:"get",value:function(u){var d=this.getCompositeKey(u),f=this.map.get(d);return this.lastAccessBeat.set(d,Date.now()),this.accessBeat+=1,f}},{key:"getCompositeKey",value:function(u){var d=this,f=u.map(function(m){return m&&_typeof(m)==="object"?"obj_".concat(d.getObjectID(m)):"".concat(_typeof(m),"_").concat(m)});return f.join("|")}},{key:"getObjectID",value:function(u){if(this.objectIDMap.has(u))return this.objectIDMap.get(u);var d=this.nextID;return this.objectIDMap.set(u,d),this.nextID+=1,d}},{key:"clear",value:function(){var u=this;if(this.accessBeat>1e4){var d=Date.now();this.lastAccessBeat.forEach(function(f,m){d-f>BEAT_LIMIT&&(u.map.delete(m),u.lastAccessBeat.delete(m))}),this.accessBeat=0}}}]),a}(),uniqueMap=new ArrayKeyMap;function useUniqueMemo(a,c){return React.useMemo(function(){var u=uniqueMap.get(c);if(u)return u;var d=a();return uniqueMap.set(c,d),d},c)}var useDefaultCSP=function(){return{}};function genStyleUtils(a){var c=a.useCSP,u=c===void 0?useDefaultCSP:c,d=a.useToken,f=a.usePrefix,m=a.getResetStyles,g=a.getCommonStyle,y=a.getCompUnitless;function b(R,_,M,I){var N=Array.isArray(R)?R[0]:R;function A(q){return"".concat(String(N)).concat(q.slice(0,1).toUpperCase()).concat(q.slice(1))}var P=(I==null?void 0:I.unitless)||{},z=typeof y=="function"?y(R):{},B=_objectSpread2(_objectSpread2({},z),{},_defineProperty({},A("zIndexPopup"),!0));Object.keys(P).forEach(function(q){B[A(q)]=P[q]});var j=_objectSpread2(_objectSpread2({},I),{},{unitless:B,prefixToken:A}),L=C(R,_,M,j),U=E(N,M,j);return function(q){var F=arguments.length>1&&arguments[1]!==void 0?arguments[1]:q,K=L(q,F),X=_slicedToArray(K,2),Q=X[1],Y=U(F),Z=_slicedToArray(Y,2),J=Z[0],W=Z[1];return[J,Q,W]}}function E(R,_,M){var I=M.unitless,N=M.injectStyle,A=N===void 0?!0:N,P=M.prefixToken,z=M.ignore,B=function(U){var q=U.rootCls,F=U.cssVar,K=F===void 0?{}:F,X=d(),Q=X.realToken;return useCSSVarRegister({path:[R],prefix:K.prefix,key:K.key,unitless:I,ignore:z,token:Q,scope:q},function(){var Y=getDefaultComponentToken(R,Q,_),Z=getComponentToken(R,Q,Y,{deprecatedTokens:M==null?void 0:M.deprecatedTokens});return Object.keys(Y).forEach(function(J){Z[P(J)]=Z[J],delete Z[J]}),Z}),null},j=function(U){var q=d(),F=q.cssVar;return[function(K){return A&&F?React.createElement(React.Fragment,null,React.createElement(B,{rootCls:U,cssVar:F,component:R}),K):K},F==null?void 0:F.key]};return j}function C(R,_,M){var I=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{},N=Array.isArray(R)?R:[R,R],A=_slicedToArray(N,1),P=A[0],z=N.join("-"),B=a.layer||{name:"antd"};return function(j){var L=arguments.length>1&&arguments[1]!==void 0?arguments[1]:j,U=d(),q=U.theme,F=U.realToken,K=U.hashId,X=U.token,Q=U.cssVar,Y=f(),Z=Y.rootPrefixCls,J=Y.iconPrefixCls,W=u(),G=Q?"css":"js",te=useUniqueMemo(function(){var ie=new Set;return Q&&Object.keys(I.unitless||{}).forEach(function(ce){ie.add(token2CSSVar(ce,Q.prefix)),ie.add(token2CSSVar(ce,getCompVarPrefix(P,Q.prefix)))}),genCalc(G,ie)},[G,P,Q==null?void 0:Q.prefix]),ae=genMaxMin(G),V=ae.max,ne=ae.min,le={theme:q,token:X,hashId:K,nonce:function(){return W.nonce},clientOnly:I.clientOnly,layer:B,order:I.order||-999};typeof m=="function"&&useStyleRegister(_objectSpread2(_objectSpread2({},le),{},{clientOnly:!1,path:["Shared",Z]}),function(){return m(X,{prefix:{rootPrefixCls:Z,iconPrefixCls:J},csp:W})});var ee=useStyleRegister(_objectSpread2(_objectSpread2({},le),{},{path:[z,j,J]}),function(){if(I.injectStyle===!1)return[];var ie=statisticToken(X),ce=ie.token,ue=ie.flush,me=getDefaultComponentToken(P,F,M),de=".".concat(j),ge=getComponentToken(P,F,me,{deprecatedTokens:I.deprecatedTokens});Q&&me&&_typeof(me)==="object"&&Object.keys(me).forEach(function(pe){me[pe]="var(".concat(token2CSSVar(pe,getCompVarPrefix(P,Q.prefix)),")")});var Ce=merge$2(ce,{componentCls:de,prefixCls:j,iconCls:".".concat(J),antCls:".".concat(Z),calc:te,max:V,min:ne},Q?me:ge),ve=_(Ce,{hashId:K,prefixCls:j,rootPrefixCls:Z,iconPrefixCls:J});ue(P,ge);var fe=typeof g=="function"?g(Ce,j,L,I.resetFont):null;return[I.resetStyle===!1?null:fe,ve]});return[ee,K]}}function w(R,_,M){var I=arguments.length>3&&arguments[3]!==void 0?arguments[3]:{},N=C(R,_,M,_objectSpread2({resetStyle:!1,order:-998},I)),A=function(z){var B=z.prefixCls,j=z.rootCls,L=j===void 0?B:j;return N(B,L),null};return A}return{genStyleHooks:b,genSubStyleComponent:w,genComponentStyleHook:C}}const PresetColors=["blue","purple","cyan","green","magenta","pink","red","orange","yellow","volcano","geekblue","lime","gold"],version$2="5.24.8";function isStableColor(a){return a>=0&&a<=255}function getAlphaColor$1(a,c){const{r:u,g:d,b:f,a:m}=new FastColor(a).toRgb();if(m<1)return a;const{r:g,g:y,b}=new FastColor(c).toRgb();for(let E=.01;E<=1;E+=.01){const C=Math.round((u-g*(1-E))/E),w=Math.round((d-y*(1-E))/E),R=Math.round((f-b*(1-E))/E);if(isStableColor(C)&&isStableColor(w)&&isStableColor(R))return new FastColor({r:C,g:w,b:R,a:Math.round(E*100)/100}).toRgbString()}return new FastColor({r:u,g:d,b:f,a:1}).toRgbString()}var __rest$X=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function formatToken(a){const{override:c}=a,u=__rest$X(a,["override"]),d=Object.assign({},c);Object.keys(seedToken).forEach(R=>{delete d[R]});const f=Object.assign(Object.assign({},u),d),m=480,g=576,y=768,b=992,E=1200,C=1600;if(f.motion===!1){const R="0s";f.motionDurationFast=R,f.motionDurationMid=R,f.motionDurationSlow=R}return Object.assign(Object.assign(Object.assign({},f),{colorFillContent:f.colorFillSecondary,colorFillContentHover:f.colorFill,colorFillAlter:f.colorFillQuaternary,colorBgContainerDisabled:f.colorFillTertiary,colorBorderBg:f.colorBgContainer,colorSplit:getAlphaColor$1(f.colorBorderSecondary,f.colorBgContainer),colorTextPlaceholder:f.colorTextQuaternary,colorTextDisabled:f.colorTextQuaternary,colorTextHeading:f.colorText,colorTextLabel:f.colorTextSecondary,colorTextDescription:f.colorTextTertiary,colorTextLightSolid:f.colorWhite,colorHighlight:f.colorError,colorBgTextHover:f.colorFillSecondary,colorBgTextActive:f.colorFill,colorIcon:f.colorTextTertiary,colorIconHover:f.colorText,colorErrorOutline:getAlphaColor$1(f.colorErrorBg,f.colorBgContainer),colorWarningOutline:getAlphaColor$1(f.colorWarningBg,f.colorBgContainer),fontSizeIcon:f.fontSizeSM,lineWidthFocus:f.lineWidth*3,lineWidth:f.lineWidth,controlOutlineWidth:f.lineWidth*2,controlInteractiveSize:f.controlHeight/2,controlItemBgHover:f.colorFillTertiary,controlItemBgActive:f.colorPrimaryBg,controlItemBgActiveHover:f.colorPrimaryBgHover,controlItemBgActiveDisabled:f.colorFill,controlTmpOutline:f.colorFillQuaternary,controlOutline:getAlphaColor$1(f.colorPrimaryBg,f.colorBgContainer),lineType:f.lineType,borderRadius:f.borderRadius,borderRadiusXS:f.borderRadiusXS,borderRadiusSM:f.borderRadiusSM,borderRadiusLG:f.borderRadiusLG,fontWeightStrong:600,opacityLoading:.65,linkDecoration:"none",linkHoverDecoration:"none",linkFocusDecoration:"none",controlPaddingHorizontal:12,controlPaddingHorizontalSM:8,paddingXXS:f.sizeXXS,paddingXS:f.sizeXS,paddingSM:f.sizeSM,padding:f.size,paddingMD:f.sizeMD,paddingLG:f.sizeLG,paddingXL:f.sizeXL,paddingContentHorizontalLG:f.sizeLG,paddingContentVerticalLG:f.sizeMS,paddingContentHorizontal:f.sizeMS,paddingContentVertical:f.sizeSM,paddingContentHorizontalSM:f.size,paddingContentVerticalSM:f.sizeXS,marginXXS:f.sizeXXS,marginXS:f.sizeXS,marginSM:f.sizeSM,margin:f.size,marginMD:f.sizeMD,marginLG:f.sizeLG,marginXL:f.sizeXL,marginXXL:f.sizeXXL,boxShadow:`
      0 6px 16px 0 rgba(0, 0, 0, 0.08),
      0 3px 6px -4px rgba(0, 0, 0, 0.12),
      0 9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowSecondary:`
      0 6px 16px 0 rgba(0, 0, 0, 0.08),
      0 3px 6px -4px rgba(0, 0, 0, 0.12),
      0 9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowTertiary:`
      0 1px 2px 0 rgba(0, 0, 0, 0.03),
      0 1px 6px -1px rgba(0, 0, 0, 0.02),
      0 2px 4px 0 rgba(0, 0, 0, 0.02)
    `,screenXS:m,screenXSMin:m,screenXSMax:g-1,screenSM:g,screenSMMin:g,screenSMMax:y-1,screenMD:y,screenMDMin:y,screenMDMax:b-1,screenLG:b,screenLGMin:b,screenLGMax:E-1,screenXL:E,screenXLMin:E,screenXLMax:C-1,screenXXL:C,screenXXLMin:C,boxShadowPopoverArrow:"2px 2px 5px rgba(0, 0, 0, 0.05)",boxShadowCard:`
      0 1px 2px -2px ${new FastColor("rgba(0, 0, 0, 0.16)").toRgbString()},
      0 3px 6px 0 ${new FastColor("rgba(0, 0, 0, 0.12)").toRgbString()},
      0 5px 12px 4px ${new FastColor("rgba(0, 0, 0, 0.09)").toRgbString()}
    `,boxShadowDrawerRight:`
      -6px 0 16px 0 rgba(0, 0, 0, 0.08),
      -3px 0 6px -4px rgba(0, 0, 0, 0.12),
      -9px 0 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowDrawerLeft:`
      6px 0 16px 0 rgba(0, 0, 0, 0.08),
      3px 0 6px -4px rgba(0, 0, 0, 0.12),
      9px 0 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowDrawerUp:`
      0 6px 16px 0 rgba(0, 0, 0, 0.08),
      0 3px 6px -4px rgba(0, 0, 0, 0.12),
      0 9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowDrawerDown:`
      0 -6px 16px 0 rgba(0, 0, 0, 0.08),
      0 -3px 6px -4px rgba(0, 0, 0, 0.12),
      0 -9px 28px 8px rgba(0, 0, 0, 0.05)
    `,boxShadowTabsOverflowLeft:"inset 10px 0 8px -8px rgba(0, 0, 0, 0.08)",boxShadowTabsOverflowRight:"inset -10px 0 8px -8px rgba(0, 0, 0, 0.08)",boxShadowTabsOverflowTop:"inset 0 10px 8px -8px rgba(0, 0, 0, 0.08)",boxShadowTabsOverflowBottom:"inset 0 -10px 8px -8px rgba(0, 0, 0, 0.08)"}),d)}var __rest$W=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const unitless={lineHeight:!0,lineHeightSM:!0,lineHeightLG:!0,lineHeightHeading1:!0,lineHeightHeading2:!0,lineHeightHeading3:!0,lineHeightHeading4:!0,lineHeightHeading5:!0,opacityLoading:!0,fontWeightStrong:!0,zIndexPopupBase:!0,zIndexBase:!0,opacityImage:!0},ignore$1={size:!0,sizeSM:!0,sizeLG:!0,sizeMD:!0,sizeXS:!0,sizeXXS:!0,sizeMS:!0,sizeXL:!0,sizeXXL:!0,sizeUnit:!0,sizeStep:!0,motionBase:!0,motionUnit:!0},preserve={screenXS:!0,screenXSMin:!0,screenXSMax:!0,screenSM:!0,screenSMMin:!0,screenSMMax:!0,screenMD:!0,screenMDMin:!0,screenMDMax:!0,screenLG:!0,screenLGMin:!0,screenLGMax:!0,screenXL:!0,screenXLMin:!0,screenXLMax:!0,screenXXL:!0,screenXXLMin:!0},getComputedToken=(a,c,u)=>{const d=u.getDerivativeToken(a),{override:f}=c,m=__rest$W(c,["override"]);let g=Object.assign(Object.assign({},d),{override:f});return g=formatToken(g),m&&Object.entries(m).forEach(y=>{let[b,E]=y;const{theme:C}=E,w=__rest$W(E,["theme"]);let R=w;C&&(R=getComputedToken(Object.assign(Object.assign({},g),w),{override:w},C)),g[b]=R}),g};function useToken$1(){const{token:a,hashed:c,theme:u,override:d,cssVar:f}=React.useContext(DesignTokenContext),m=`${version$2}-${c||""}`,g=u||defaultTheme,[y,b,E]=useCacheToken(g,[seedToken,a],{salt:m,override:d,getComputedToken,formatToken,cssVar:f&&{prefix:f.prefix,key:f.key,unitless,ignore:ignore$1,preserve}});return[g,E,c?b:"",y,f]}const textEllipsis={overflow:"hidden",whiteSpace:"nowrap",textOverflow:"ellipsis"},resetComponent=function(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;return{boxSizing:"border-box",margin:0,padding:0,color:a.colorText,fontSize:a.fontSize,lineHeight:a.lineHeight,listStyle:"none",fontFamily:c?"inherit":a.fontFamily}},resetIcon=()=>({display:"inline-flex",alignItems:"center",color:"inherit",fontStyle:"normal",lineHeight:0,textAlign:"center",textTransform:"none",verticalAlign:"-0.125em",textRendering:"optimizeLegibility","-webkit-font-smoothing":"antialiased","-moz-osx-font-smoothing":"grayscale","> *":{lineHeight:1},svg:{display:"inline-block"}}),clearFix=()=>({"&::before":{display:"table",content:'""'},"&::after":{display:"table",clear:"both",content:'""'}}),genLinkStyle$1=a=>({a:{color:a.colorLink,textDecoration:a.linkDecoration,backgroundColor:"transparent",outline:"none",cursor:"pointer",transition:`color ${a.motionDurationSlow}`,"-webkit-text-decoration-skip":"objects","&:hover":{color:a.colorLinkHover},"&:active":{color:a.colorLinkActive},"&:active, &:hover":{textDecoration:a.linkHoverDecoration,outline:0},"&:focus":{textDecoration:a.linkFocusDecoration,outline:0},"&[disabled]":{color:a.colorTextDisabled,cursor:"not-allowed"}}}),genCommonStyle=(a,c,u,d)=>{const f=`[class^="${c}"], [class*=" ${c}"]`,m=u?`.${u}`:f,g={boxSizing:"border-box","&::before, &::after":{boxSizing:"border-box"}};let y={};return d!==!1&&(y={fontFamily:a.fontFamily,fontSize:a.fontSize}),{[m]:Object.assign(Object.assign(Object.assign({},y),g),{[f]:g})}},genFocusOutline=(a,c)=>({outline:`${unit$1(a.lineWidthFocus)} solid ${a.colorPrimaryBorder}`,outlineOffset:c??1,transition:"outline-offset 0s, outline 0s"}),genFocusStyle=(a,c)=>({"&:focus-visible":Object.assign({},genFocusOutline(a,c))}),genIconStyle=a=>({[`.${a}`]:Object.assign(Object.assign({},resetIcon()),{[`.${a} .${a}-icon`]:{display:"block"}})}),operationUnit=a=>Object.assign(Object.assign({color:a.colorLink,textDecoration:a.linkDecoration,outline:"none",cursor:"pointer",transition:`all ${a.motionDurationSlow}`,border:0,padding:0,background:"none",userSelect:"none"},genFocusStyle(a)),{"&:focus, &:hover":{color:a.colorLinkHover},"&:active":{color:a.colorLinkActive}}),{genStyleHooks,genComponentStyleHook,genSubStyleComponent}=genStyleUtils({usePrefix:()=>{const{getPrefixCls:a,iconPrefixCls:c}=reactExports.useContext(ConfigContext);return{rootPrefixCls:a(),iconPrefixCls:c}},useToken:()=>{const[a,c,u,d,f]=useToken$1();return{theme:a,realToken:c,hashId:u,token:d,cssVar:f}},useCSP:()=>{const{csp:a}=reactExports.useContext(ConfigContext);return a??{}},getResetStyles:(a,c)=>{var u;const d=genLinkStyle$1(a);return[d,{"&":d},genIconStyle((u=c==null?void 0:c.prefix.iconPrefixCls)!==null&&u!==void 0?u:defaultIconPrefixCls)]},getCommonStyle:genCommonStyle,getCompUnitless:()=>unitless});function genPresetColor(a,c){return PresetColors.reduce((u,d)=>{const f=a[`${d}1`],m=a[`${d}3`],g=a[`${d}6`],y=a[`${d}7`];return Object.assign(Object.assign({},u),c(d,{lightColor:f,lightBorderColor:m,darkColor:g,textColor:y}))},{})}const useResetIconStyle=(a,c)=>{const[u,d]=useToken$1();return useStyleRegister({token:d,hashId:"",path:["ant-design-icons",a],nonce:()=>c==null?void 0:c.nonce,layer:{name:"antd"}},()=>[genIconStyle(a)])},fullClone$1=Object.assign({},React$1),{useId:useId$2}=fullClone$1,useEmptyId=()=>"",useThemeKey=typeof useId$2>"u"?useEmptyId:useId$2;function useTheme(a,c,u){var d;devUseWarning();const f=a||{},m=f.inherit===!1||!c?Object.assign(Object.assign({},defaultConfig),{hashed:(d=c==null?void 0:c.hashed)!==null&&d!==void 0?d:defaultConfig.hashed,cssVar:c==null?void 0:c.cssVar}):c,g=useThemeKey();return useMemo(()=>{var y,b;if(!a)return c;const E=Object.assign({},m.components);Object.keys(a.components||{}).forEach(R=>{E[R]=Object.assign(Object.assign({},E[R]),a.components[R])});const C=`css-var-${g.replace(/:/g,"")}`,w=((y=f.cssVar)!==null&&y!==void 0?y:m.cssVar)&&Object.assign(Object.assign(Object.assign({prefix:u==null?void 0:u.prefixCls},typeof m.cssVar=="object"?m.cssVar:{}),typeof f.cssVar=="object"?f.cssVar:{}),{key:typeof f.cssVar=="object"&&((b=f.cssVar)===null||b===void 0?void 0:b.key)||C});return Object.assign(Object.assign(Object.assign({},m),f),{token:Object.assign(Object.assign({},m.token),f.token),components:E,cssVar:w})},[f,m],(y,b)=>y.some((E,C)=>{const w=b[C];return!isEqual(E,w,!0)}))}var _excluded$P=["children"],Context$1=reactExports.createContext({});function MotionProvider(a){var c=a.children,u=_objectWithoutProperties(a,_excluded$P);return reactExports.createElement(Context$1.Provider,{value:u},c)}var DomWrapper=function(a){_inherits(u,a);var c=_createSuper(u);function u(){return _classCallCheck(this,u),c.apply(this,arguments)}return _createClass(u,[{key:"render",value:function(){return this.props.children}}]),u}(reactExports.Component);function useSyncState$2(a){var c=reactExports.useReducer(function(y){return y+1},0),u=_slicedToArray(c,2),d=u[1],f=reactExports.useRef(a),m=useEvent(function(){return f.current}),g=useEvent(function(y){f.current=typeof y=="function"?y(f.current):y,d()});return[m,g]}var STATUS_NONE="none",STATUS_APPEAR="appear",STATUS_ENTER="enter",STATUS_LEAVE="leave",STEP_NONE="none",STEP_PREPARE="prepare",STEP_START="start",STEP_ACTIVE="active",STEP_ACTIVATED="end",STEP_PREPARED="prepared";function makePrefixMap(a,c){var u={};return u[a.toLowerCase()]=c.toLowerCase(),u["Webkit".concat(a)]="webkit".concat(c),u["Moz".concat(a)]="moz".concat(c),u["ms".concat(a)]="MS".concat(c),u["O".concat(a)]="o".concat(c.toLowerCase()),u}function getVendorPrefixes(a,c){var u={animationend:makePrefixMap("Animation","AnimationEnd"),transitionend:makePrefixMap("Transition","TransitionEnd")};return a&&("AnimationEvent"in c||delete u.animationend.animation,"TransitionEvent"in c||delete u.transitionend.transition),u}var vendorPrefixes=getVendorPrefixes(canUseDom(),typeof window<"u"?window:{}),style$1={};if(canUseDom()){var _document$createEleme=document.createElement("div");style$1=_document$createEleme.style}var prefixedEventNames={};function getVendorPrefixedEventName(a){if(prefixedEventNames[a])return prefixedEventNames[a];var c=vendorPrefixes[a];if(c)for(var u=Object.keys(c),d=u.length,f=0;f<d;f+=1){var m=u[f];if(Object.prototype.hasOwnProperty.call(c,m)&&m in style$1)return prefixedEventNames[a]=c[m],prefixedEventNames[a]}return""}var internalAnimationEndName=getVendorPrefixedEventName("animationend"),internalTransitionEndName=getVendorPrefixedEventName("transitionend"),supportTransition=!!(internalAnimationEndName&&internalTransitionEndName),animationEndName=internalAnimationEndName||"animationend",transitionEndName=internalTransitionEndName||"transitionend";function getTransitionName$1(a,c){if(!a)return null;if(_typeof(a)==="object"){var u=c.replace(/-\w/g,function(d){return d[1].toUpperCase()});return a[u]}return"".concat(a,"-").concat(c)}const useDomMotionEvents=function(a){var c=reactExports.useRef();function u(f){f&&(f.removeEventListener(transitionEndName,a),f.removeEventListener(animationEndName,a))}function d(f){c.current&&c.current!==f&&u(c.current),f&&f!==c.current&&(f.addEventListener(transitionEndName,a),f.addEventListener(animationEndName,a),c.current=f)}return reactExports.useEffect(function(){return function(){u(c.current)}},[]),[d,u]};var useIsomorphicLayoutEffect$2=canUseDom()?reactExports.useLayoutEffect:reactExports.useEffect;const useNextFrame=function(){var a=reactExports.useRef(null);function c(){wrapperRaf.cancel(a.current)}function u(d){var f=arguments.length>1&&arguments[1]!==void 0?arguments[1]:2;c();var m=wrapperRaf(function(){f<=1?d({isCanceled:function(){return m!==a.current}}):u(d,f-1)});a.current=m}return reactExports.useEffect(function(){return function(){c()}},[]),[u,c]};var FULL_STEP_QUEUE=[STEP_PREPARE,STEP_START,STEP_ACTIVE,STEP_ACTIVATED],SIMPLE_STEP_QUEUE=[STEP_PREPARE,STEP_PREPARED],SkipStep=!1,DoStep=!0;function isActive(a){return a===STEP_ACTIVE||a===STEP_ACTIVATED}const useStepQueue=function(a,c,u){var d=useSafeState(STEP_NONE),f=_slicedToArray(d,2),m=f[0],g=f[1],y=useNextFrame(),b=_slicedToArray(y,2),E=b[0],C=b[1];function w(){g(STEP_PREPARE,!0)}var R=c?SIMPLE_STEP_QUEUE:FULL_STEP_QUEUE;return useIsomorphicLayoutEffect$2(function(){if(m!==STEP_NONE&&m!==STEP_ACTIVATED){var _=R.indexOf(m),M=R[_+1],I=u(m);I===SkipStep?g(M,!0):M&&E(function(N){function A(){N.isCanceled()||g(M,!0)}I===!0?A():Promise.resolve(I).then(A)})}},[a,m]),reactExports.useEffect(function(){return function(){C()}},[]),[w,m]};function useStatus$1(a,c,u,d){var f=d.motionEnter,m=f===void 0?!0:f,g=d.motionAppear,y=g===void 0?!0:g,b=d.motionLeave,E=b===void 0?!0:b,C=d.motionDeadline,w=d.motionLeaveImmediately,R=d.onAppearPrepare,_=d.onEnterPrepare,M=d.onLeavePrepare,I=d.onAppearStart,N=d.onEnterStart,A=d.onLeaveStart,P=d.onAppearActive,z=d.onEnterActive,B=d.onLeaveActive,j=d.onAppearEnd,L=d.onEnterEnd,U=d.onLeaveEnd,q=d.onVisibleChanged,F=useSafeState(),K=_slicedToArray(F,2),X=K[0],Q=K[1],Y=useSyncState$2(STATUS_NONE),Z=_slicedToArray(Y,2),J=Z[0],W=Z[1],G=useSafeState(null),te=_slicedToArray(G,2),ae=te[0],V=te[1],ne=J(),le=reactExports.useRef(!1),ee=reactExports.useRef(null);function ie(){return u()}var ce=reactExports.useRef(!1);function ue(){W(STATUS_NONE),V(null,!0)}var me=useEvent(function(Ee){var Ne=J();if(Ne!==STATUS_NONE){var _e=ie();if(!(Ee&&!Ee.deadline&&Ee.target!==_e)){var ke=ce.current,Ke;Ne===STATUS_APPEAR&&ke?Ke=j==null?void 0:j(_e,Ee):Ne===STATUS_ENTER&&ke?Ke=L==null?void 0:L(_e,Ee):Ne===STATUS_LEAVE&&ke&&(Ke=U==null?void 0:U(_e,Ee)),ke&&Ke!==!1&&ue()}}}),de=useDomMotionEvents(me),ge=_slicedToArray(de,1),Ce=ge[0],ve=function(Ne){switch(Ne){case STATUS_APPEAR:return _defineProperty(_defineProperty(_defineProperty({},STEP_PREPARE,R),STEP_START,I),STEP_ACTIVE,P);case STATUS_ENTER:return _defineProperty(_defineProperty(_defineProperty({},STEP_PREPARE,_),STEP_START,N),STEP_ACTIVE,z);case STATUS_LEAVE:return _defineProperty(_defineProperty(_defineProperty({},STEP_PREPARE,M),STEP_START,A),STEP_ACTIVE,B);default:return{}}},fe=reactExports.useMemo(function(){return ve(ne)},[ne]),pe=useStepQueue(ne,!a,function(Ee){if(Ee===STEP_PREPARE){var Ne=fe[STEP_PREPARE];return Ne?Ne(ie()):SkipStep}if(he in fe){var _e;V(((_e=fe[he])===null||_e===void 0?void 0:_e.call(fe,ie(),null))||null)}return he===STEP_ACTIVE&&ne!==STATUS_NONE&&(Ce(ie()),C>0&&(clearTimeout(ee.current),ee.current=setTimeout(function(){me({deadline:!0})},C))),he===STEP_PREPARED&&ue(),DoStep}),xe=_slicedToArray(pe,2),ye=xe[0],he=xe[1],we=isActive(he);ce.current=we;var Re=reactExports.useRef(null);useIsomorphicLayoutEffect$2(function(){if(!(le.current&&Re.current===c)){Q(c);var Ee=le.current;le.current=!0;var Ne;!Ee&&c&&y&&(Ne=STATUS_APPEAR),Ee&&c&&m&&(Ne=STATUS_ENTER),(Ee&&!c&&E||!Ee&&w&&!c&&E)&&(Ne=STATUS_LEAVE);var _e=ve(Ne);Ne&&(a||_e[STEP_PREPARE])?(W(Ne),ye()):W(STATUS_NONE),Re.current=c}},[c]),reactExports.useEffect(function(){(ne===STATUS_APPEAR&&!y||ne===STATUS_ENTER&&!m||ne===STATUS_LEAVE&&!E)&&W(STATUS_NONE)},[y,m,E]),reactExports.useEffect(function(){return function(){le.current=!1,clearTimeout(ee.current)}},[]);var De=reactExports.useRef(!1);reactExports.useEffect(function(){X&&(De.current=!0),X!==void 0&&ne===STATUS_NONE&&((De.current||X)&&(q==null||q(X)),De.current=!0)},[X,ne]);var Ae=ae;return fe[STEP_PREPARE]&&he===STEP_START&&(Ae=_objectSpread2({transition:"none"},Ae)),[ne,he,Ae,X??c]}function genCSSMotion(a){var c=a;_typeof(a)==="object"&&(c=a.transitionSupport);function u(f,m){return!!(f.motionName&&c&&m!==!1)}var d=reactExports.forwardRef(function(f,m){var g=f.visible,y=g===void 0?!0:g,b=f.removeOnLeave,E=b===void 0?!0:b,C=f.forceRender,w=f.children,R=f.motionName,_=f.leavedClassName,M=f.eventProps,I=reactExports.useContext(Context$1),N=I.motion,A=u(f,N),P=reactExports.useRef(),z=reactExports.useRef();function B(){try{return P.current instanceof HTMLElement?P.current:findDOMNode(z.current)}catch{return null}}var j=useStatus$1(A,y,B,f),L=_slicedToArray(j,4),U=L[0],q=L[1],F=L[2],K=L[3],X=reactExports.useRef(K);K&&(X.current=!0);var Q=reactExports.useCallback(function(te){P.current=te,fillRef(m,te)},[m]),Y,Z=_objectSpread2(_objectSpread2({},M),{},{visible:y});if(!w)Y=null;else if(U===STATUS_NONE)K?Y=w(_objectSpread2({},Z),Q):!E&&X.current&&_?Y=w(_objectSpread2(_objectSpread2({},Z),{},{className:_}),Q):C||!E&&!_?Y=w(_objectSpread2(_objectSpread2({},Z),{},{style:{display:"none"}}),Q):Y=null;else{var J;q===STEP_PREPARE?J="prepare":isActive(q)?J="active":q===STEP_START&&(J="start");var W=getTransitionName$1(R,"".concat(U,"-").concat(J));Y=w(_objectSpread2(_objectSpread2({},Z),{},{className:classNames(getTransitionName$1(R,U),_defineProperty(_defineProperty({},W,W&&J),R,typeof R=="string")),style:F}),Q)}if(reactExports.isValidElement(Y)&&supportRef(Y)){var G=getNodeRef(Y);G||(Y=reactExports.cloneElement(Y,{ref:Q}))}return reactExports.createElement(DomWrapper,{ref:z},Y)});return d.displayName="CSSMotion",d}const CSSMotion=genCSSMotion(supportTransition);var STATUS_ADD="add",STATUS_KEEP="keep",STATUS_REMOVE="remove",STATUS_REMOVED="removed";function wrapKeyToObject(a){var c;return a&&_typeof(a)==="object"&&"key"in a?c=a:c={key:a},_objectSpread2(_objectSpread2({},c),{},{key:String(c.key)})}function parseKeys(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];return a.map(wrapKeyToObject)}function diffKeys(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],u=[],d=0,f=c.length,m=parseKeys(a),g=parseKeys(c);m.forEach(function(E){for(var C=!1,w=d;w<f;w+=1){var R=g[w];if(R.key===E.key){d<w&&(u=u.concat(g.slice(d,w).map(function(_){return _objectSpread2(_objectSpread2({},_),{},{status:STATUS_ADD})})),d=w),u.push(_objectSpread2(_objectSpread2({},R),{},{status:STATUS_KEEP})),d+=1,C=!0;break}}C||u.push(_objectSpread2(_objectSpread2({},E),{},{status:STATUS_REMOVE}))}),d<f&&(u=u.concat(g.slice(d).map(function(E){return _objectSpread2(_objectSpread2({},E),{},{status:STATUS_ADD})})));var y={};u.forEach(function(E){var C=E.key;y[C]=(y[C]||0)+1});var b=Object.keys(y).filter(function(E){return y[E]>1});return b.forEach(function(E){u=u.filter(function(C){var w=C.key,R=C.status;return w!==E||R!==STATUS_REMOVE}),u.forEach(function(C){C.key===E&&(C.status=STATUS_KEEP)})}),u}var _excluded$O=["component","children","onVisibleChanged","onAllRemoved"],_excluded2$b=["status"],MOTION_PROP_NAMES=["eventProps","visible","children","motionName","motionAppear","motionEnter","motionLeave","motionLeaveImmediately","motionDeadline","removeOnLeave","leavedClassName","onAppearPrepare","onAppearStart","onAppearActive","onAppearEnd","onEnterStart","onEnterActive","onEnterEnd","onLeaveStart","onLeaveActive","onLeaveEnd"];function genCSSMotionList(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:CSSMotion,u=function(d){_inherits(m,d);var f=_createSuper(m);function m(){var g;_classCallCheck(this,m);for(var y=arguments.length,b=new Array(y),E=0;E<y;E++)b[E]=arguments[E];return g=f.call.apply(f,[this].concat(b)),_defineProperty(_assertThisInitialized(g),"state",{keyEntities:[]}),_defineProperty(_assertThisInitialized(g),"removeKey",function(C){g.setState(function(w){var R=w.keyEntities.map(function(_){return _.key!==C?_:_objectSpread2(_objectSpread2({},_),{},{status:STATUS_REMOVED})});return{keyEntities:R}},function(){var w=g.state.keyEntities,R=w.filter(function(_){var M=_.status;return M!==STATUS_REMOVED}).length;R===0&&g.props.onAllRemoved&&g.props.onAllRemoved()})}),g}return _createClass(m,[{key:"render",value:function(){var y=this,b=this.state.keyEntities,E=this.props,C=E.component,w=E.children,R=E.onVisibleChanged;E.onAllRemoved;var _=_objectWithoutProperties(E,_excluded$O),M=C||reactExports.Fragment,I={};return MOTION_PROP_NAMES.forEach(function(N){I[N]=_[N],delete _[N]}),delete _.keys,reactExports.createElement(M,_,b.map(function(N,A){var P=N.status,z=_objectWithoutProperties(N,_excluded2$b),B=P===STATUS_ADD||P===STATUS_KEEP;return reactExports.createElement(c,_extends({},I,{key:z.key,visible:B,eventProps:z,onVisibleChanged:function(L){R==null||R(L,{key:z.key}),L||y.removeKey(z.key)}}),function(j,L){return w(_objectSpread2(_objectSpread2({},j),{},{index:A}),L)})}))}}],[{key:"getDerivedStateFromProps",value:function(y,b){var E=y.keys,C=b.keyEntities,w=parseKeys(E),R=diffKeys(C,w);return{keyEntities:R.filter(function(_){var M=C.find(function(I){var N=I.key;return _.key===N});return!(M&&M.status===STATUS_REMOVED&&_.status===STATUS_REMOVE)})}}}]),m}(reactExports.Component);return _defineProperty(u,"defaultProps",{component:"div"}),u}const CSSMotionList=genCSSMotionList(supportTransition);function MotionWrapper(a){const{children:c}=a,[,u]=useToken$1(),{motion:d}=u,f=reactExports.useRef(!1);return f.current=f.current||d===!1,f.current?reactExports.createElement(MotionProvider,{motion:d},c):c}const PropWarning=()=>null;var __rest$V=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const PASSED_PROPS=["getTargetContainer","getPopupContainer","renderEmpty","input","pagination","form","select","button"];let globalPrefixCls,globalIconPrefixCls,globalTheme,globalHolderRender;function getGlobalPrefixCls(){return globalPrefixCls||defaultPrefixCls}function getGlobalIconPrefixCls(){return globalIconPrefixCls||defaultIconPrefixCls}function isLegacyTheme(a){return Object.keys(a).some(c=>c.endsWith("Color"))}const setGlobalConfig=a=>{const{prefixCls:c,iconPrefixCls:u,theme:d,holderRender:f}=a;c!==void 0&&(globalPrefixCls=c),u!==void 0&&(globalIconPrefixCls=u),"holderRender"in a&&(globalHolderRender=f),d&&(isLegacyTheme(d)?registerTheme(getGlobalPrefixCls(),d):globalTheme=d)},globalConfig=()=>({getPrefixCls:(a,c)=>c||(a?`${getGlobalPrefixCls()}-${a}`:getGlobalPrefixCls()),getIconPrefixCls:getGlobalIconPrefixCls,getRootPrefixCls:()=>globalPrefixCls||getGlobalPrefixCls(),getTheme:()=>globalTheme,holderRender:globalHolderRender}),ProviderChildren=a=>{const{children:c,csp:u,autoInsertSpaceInButton:d,alert:f,anchor:m,form:g,locale:y,componentSize:b,direction:E,space:C,splitter:w,virtual:R,dropdownMatchSelectWidth:_,popupMatchSelectWidth:M,popupOverflow:I,legacyLocale:N,parentContext:A,iconPrefixCls:P,theme:z,componentDisabled:B,segmented:j,statistic:L,spin:U,calendar:q,carousel:F,cascader:K,collapse:X,typography:Q,checkbox:Y,descriptions:Z,divider:J,drawer:W,skeleton:G,steps:te,image:ae,layout:V,list:ne,mentions:le,modal:ee,progress:ie,result:ce,slider:ue,breadcrumb:me,menu:de,pagination:ge,input:Ce,textArea:ve,empty:fe,badge:pe,radio:xe,rate:ye,switch:he,transfer:we,avatar:Re,message:De,tag:Ae,table:Ee,card:Ne,tabs:_e,timeline:ke,timePicker:Ke,upload:be,notification:Te,tree:Le,colorPicker:Oe,datePicker:Be,rangePicker:Ve,flex:Pe,wave:Ge,dropdown:qe,warning:Ue,tour:je,tooltip:We,popover:ut,popconfirm:gt,floatButtonGroup:kt,variant:Ut,inputNumber:at,treeSelect:ct}=a,bt=reactExports.useCallback((pt,Rt)=>{const{prefixCls:ft}=a;if(Rt)return Rt;const dt=ft||A.getPrefixCls("");return pt?`${dt}-${pt}`:dt},[A.getPrefixCls,a.prefixCls]),it=P||A.iconPrefixCls||defaultIconPrefixCls,vt=u||A.csp;useResetIconStyle(it,vt);const ot=useTheme(z,A.theme,{prefixCls:bt("")}),rt={csp:vt,autoInsertSpaceInButton:d,alert:f,anchor:m,locale:y||N,direction:E,space:C,splitter:w,virtual:R,popupMatchSelectWidth:M??_,popupOverflow:I,getPrefixCls:bt,iconPrefixCls:it,theme:ot,segmented:j,statistic:L,spin:U,calendar:q,carousel:F,cascader:K,collapse:X,typography:Q,checkbox:Y,descriptions:Z,divider:J,drawer:W,skeleton:G,steps:te,image:ae,input:Ce,textArea:ve,layout:V,list:ne,mentions:le,modal:ee,progress:ie,result:ce,slider:ue,breadcrumb:me,menu:de,pagination:ge,empty:fe,badge:pe,radio:xe,rate:ye,switch:he,transfer:we,avatar:Re,message:De,tag:Ae,table:Ee,card:Ne,tabs:_e,timeline:ke,timePicker:Ke,upload:be,notification:Te,tree:Le,colorPicker:Oe,datePicker:Be,rangePicker:Ve,flex:Pe,wave:Ge,dropdown:qe,warning:Ue,tour:je,tooltip:We,popover:ut,popconfirm:gt,floatButtonGroup:kt,variant:Ut,inputNumber:at,treeSelect:ct},et=Object.assign({},A);Object.keys(rt).forEach(pt=>{rt[pt]!==void 0&&(et[pt]=rt[pt])}),PASSED_PROPS.forEach(pt=>{const Rt=a[pt];Rt&&(et[pt]=Rt)}),typeof d<"u"&&(et.button=Object.assign({autoInsertSpace:d},et.button));const $t=useMemo(()=>et,et,(pt,Rt)=>{const ft=Object.keys(pt),dt=Object.keys(Rt);return ft.length!==dt.length||ft.some(xt=>pt[xt]!==Rt[xt])}),{layer:mt}=reactExports.useContext(StyleContext),Ze=reactExports.useMemo(()=>({prefixCls:it,csp:vt,layer:mt?"antd":void 0}),[it,vt,mt]);let Je=reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(PropWarning,{dropdownMatchSelectWidth:_}),c);const yt=reactExports.useMemo(()=>{var pt,Rt,ft,dt;return merge$3(((pt=localeValues.Form)===null||pt===void 0?void 0:pt.defaultValidateMessages)||{},((ft=(Rt=$t.locale)===null||Rt===void 0?void 0:Rt.Form)===null||ft===void 0?void 0:ft.defaultValidateMessages)||{},((dt=$t.form)===null||dt===void 0?void 0:dt.validateMessages)||{},(g==null?void 0:g.validateMessages)||{})},[$t,g==null?void 0:g.validateMessages]);Object.keys(yt).length>0&&(Je=reactExports.createElement(ValidateMessagesContext.Provider,{value:yt},Je)),y&&(Je=reactExports.createElement(LocaleProvider,{locale:y,_ANT_MARK__:ANT_MARK},Je)),Je=reactExports.createElement(IconContext.Provider,{value:Ze},Je),b&&(Je=reactExports.createElement(SizeContextProvider,{size:b},Je)),Je=reactExports.createElement(MotionWrapper,null,Je);const Ct=reactExports.useMemo(()=>{const pt=ot||{},{algorithm:Rt,token:ft,components:dt,cssVar:xt}=pt,Tt=__rest$V(pt,["algorithm","token","components","cssVar"]),Dt=Rt&&(!Array.isArray(Rt)||Rt.length>0)?createTheme(Rt):defaultTheme,Vt={};Object.entries(dt||{}).forEach(Kt=>{let[Zt,Gt]=Kt;const tt=Object.assign({},Gt);"algorithm"in tt&&(tt.algorithm===!0?tt.theme=Dt:(Array.isArray(tt.algorithm)||typeof tt.algorithm=="function")&&(tt.theme=createTheme(tt.algorithm)),delete tt.algorithm),Vt[Zt]=tt});const Nt=Object.assign(Object.assign({},seedToken),ft);return Object.assign(Object.assign({},Tt),{theme:Dt,token:Nt,components:Vt,override:Object.assign({override:Nt},Vt),cssVar:xt})},[ot]);return z&&(Je=reactExports.createElement(DesignTokenContext.Provider,{value:Ct},Je)),$t.warning&&(Je=reactExports.createElement(WarningContext.Provider,{value:$t.warning},Je)),B!==void 0&&(Je=reactExports.createElement(DisabledContextProvider,{disabled:B},Je)),reactExports.createElement(ConfigContext.Provider,{value:$t},Je)},ConfigProvider=a=>{const c=reactExports.useContext(ConfigContext),u=reactExports.useContext(LocaleContext);return reactExports.createElement(ProviderChildren,Object.assign({parentContext:c,legacyLocale:u},a))};ConfigProvider.ConfigContext=ConfigContext;ConfigProvider.SizeContext=SizeContext;ConfigProvider.config=setGlobalConfig;ConfigProvider.useConfig=useConfig;Object.defineProperty(ConfigProvider,"SizeContext",{get:()=>SizeContext});var attributes=`accept acceptCharset accessKey action allowFullScreen allowTransparency
    alt async autoComplete autoFocus autoPlay capture cellPadding cellSpacing challenge
    charSet checked classID className colSpan cols content contentEditable contextMenu
    controls coords crossOrigin data dateTime default defer dir disabled download draggable
    encType form formAction formEncType formMethod formNoValidate formTarget frameBorder
    headers height hidden high href hrefLang htmlFor httpEquiv icon id inputMode integrity
    is keyParams keyType kind label lang list loop low manifest marginHeight marginWidth max maxLength media
    mediaGroup method min minLength multiple muted name noValidate nonce open
    optimum pattern placeholder poster preload radioGroup readOnly rel required
    reversed role rowSpan rows sandbox scope scoped scrolling seamless selected
    shape size sizes span spellCheck src srcDoc srcLang srcSet start step style
    summary tabIndex target title type useMap value width wmode wrap`,eventsName=`onCopy onCut onPaste onCompositionEnd onCompositionStart onCompositionUpdate onKeyDown
    onKeyPress onKeyUp onFocus onBlur onChange onInput onSubmit onClick onContextMenu onDoubleClick
    onDrag onDragEnd onDragEnter onDragExit onDragLeave onDragOver onDragStart onDrop onMouseDown
    onMouseEnter onMouseLeave onMouseMove onMouseOut onMouseOver onMouseUp onSelect onTouchCancel
    onTouchEnd onTouchMove onTouchStart onScroll onWheel onAbort onCanPlay onCanPlayThrough
    onDurationChange onEmptied onEncrypted onEnded onError onLoadedData onLoadedMetadata
    onLoadStart onPause onPlay onPlaying onProgress onRateChange onSeeked onSeeking onStalled onSuspend onTimeUpdate onVolumeChange onWaiting onLoad onError`,propList="".concat(attributes," ").concat(eventsName).split(/[\s\n]+/),ariaPrefix="aria-",dataPrefix="data-";function match(a,c){return a.indexOf(c)===0}function pickAttrs(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,u;c===!1?u={aria:!0,data:!0,attr:!0}:c===!0?u={aria:!0}:u=_objectSpread2({},c);var d={};return Object.keys(a).forEach(function(f){(u.aria&&(f==="role"||match(f,ariaPrefix))||u.data&&match(f,dataPrefix)||u.attr&&propList.includes(f))&&(d[f]=a[f])}),d}function isFragment(a){return a&&React.isValidElement(a)&&a.type===React.Fragment}const replaceElement=(a,c,u)=>React.isValidElement(a)?React.cloneElement(a,typeof u=="function"?u(a.props||{}):u):c;function cloneElement(a,c){return replaceElement(a,a,c)}const t=a=>typeof a=="object"&&a!=null&&a.nodeType===1,e$1=(a,c)=>(!c||a!=="hidden")&&a!=="visible"&&a!=="clip",n=(a,c)=>{if(a.clientHeight<a.scrollHeight||a.clientWidth<a.scrollWidth){const u=getComputedStyle(a,null);return e$1(u.overflowY,c)||e$1(u.overflowX,c)||(d=>{const f=(m=>{if(!m.ownerDocument||!m.ownerDocument.defaultView)return null;try{return m.ownerDocument.defaultView.frameElement}catch{return null}})(d);return!!f&&(f.clientHeight<d.scrollHeight||f.clientWidth<d.scrollWidth)})(a)}return!1},o$1=(a,c,u,d,f,m,g,y)=>m<a&&g>c||m>a&&g<c?0:m<=a&&y<=u||g>=c&&y>=u?m-a-d:g>c&&y<u||m<a&&y>u?g-c+f:0,l=a=>{const c=a.parentElement;return c??(a.getRootNode().host||null)},r=(a,c)=>{var u,d,f,m;if(typeof document>"u")return[];const{scrollMode:g,block:y,inline:b,boundary:E,skipOverflowHiddenElements:C}=c,w=typeof E=="function"?E:W=>W!==E;if(!t(a))throw new TypeError("Invalid target");const R=document.scrollingElement||document.documentElement,_=[];let M=a;for(;t(M)&&w(M);){if(M=l(M),M===R){_.push(M);break}M!=null&&M===document.body&&n(M)&&!n(document.documentElement)||M!=null&&n(M,C)&&_.push(M)}const I=(d=(u=window.visualViewport)==null?void 0:u.width)!=null?d:innerWidth,N=(m=(f=window.visualViewport)==null?void 0:f.height)!=null?m:innerHeight,{scrollX:A,scrollY:P}=window,{height:z,width:B,top:j,right:L,bottom:U,left:q}=a.getBoundingClientRect(),{top:F,right:K,bottom:X,left:Q}=(W=>{const G=window.getComputedStyle(W);return{top:parseFloat(G.scrollMarginTop)||0,right:parseFloat(G.scrollMarginRight)||0,bottom:parseFloat(G.scrollMarginBottom)||0,left:parseFloat(G.scrollMarginLeft)||0}})(a);let Y=y==="start"||y==="nearest"?j-F:y==="end"?U+X:j+z/2-F+X,Z=b==="center"?q+B/2-Q+K:b==="end"?L+K:q-Q;const J=[];for(let W=0;W<_.length;W++){const G=_[W],{height:te,width:ae,top:V,right:ne,bottom:le,left:ee}=G.getBoundingClientRect();if(g==="if-needed"&&j>=0&&q>=0&&U<=N&&L<=I&&(G===R&&!n(G)||j>=V&&U<=le&&q>=ee&&L<=ne))return J;const ie=getComputedStyle(G),ce=parseInt(ie.borderLeftWidth,10),ue=parseInt(ie.borderTopWidth,10),me=parseInt(ie.borderRightWidth,10),de=parseInt(ie.borderBottomWidth,10);let ge=0,Ce=0;const ve="offsetWidth"in G?G.offsetWidth-G.clientWidth-ce-me:0,fe="offsetHeight"in G?G.offsetHeight-G.clientHeight-ue-de:0,pe="offsetWidth"in G?G.offsetWidth===0?0:ae/G.offsetWidth:0,xe="offsetHeight"in G?G.offsetHeight===0?0:te/G.offsetHeight:0;if(R===G)ge=y==="start"?Y:y==="end"?Y-N:y==="nearest"?o$1(P,P+N,N,ue,de,P+Y,P+Y+z,z):Y-N/2,Ce=b==="start"?Z:b==="center"?Z-I/2:b==="end"?Z-I:o$1(A,A+I,I,ce,me,A+Z,A+Z+B,B),ge=Math.max(0,ge+P),Ce=Math.max(0,Ce+A);else{ge=y==="start"?Y-V-ue:y==="end"?Y-le+de+fe:y==="nearest"?o$1(V,le,te,ue,de+fe,Y,Y+z,z):Y-(V+te/2)+fe/2,Ce=b==="start"?Z-ee-ce:b==="center"?Z-(ee+ae/2)+ve/2:b==="end"?Z-ne+me+ve:o$1(ee,ne,ae,ce,me+ve,Z,Z+B,B);const{scrollLeft:ye,scrollTop:he}=G;ge=xe===0?0:Math.max(0,Math.min(he+ge/xe,G.scrollHeight-te/xe+fe)),Ce=pe===0?0:Math.max(0,Math.min(ye+Ce/pe,G.scrollWidth-ae/pe+ve)),Y+=he-ge,Z+=ye-Ce}J.push({el:G,top:ge,left:Ce})}return J},o=a=>a===!1?{block:"end",inline:"nearest"}:(c=>c===Object(c)&&Object.keys(c).length!==0)(a)?a:{block:"start",inline:"nearest"};function e(a,c){if(!a.isConnected||!(f=>{let m=f;for(;m&&m.parentNode;){if(m.parentNode===document)return!0;m=m.parentNode instanceof ShadowRoot?m.parentNode.host:m.parentNode}return!1})(a))return;const u=(f=>{const m=window.getComputedStyle(f);return{top:parseFloat(m.scrollMarginTop)||0,right:parseFloat(m.scrollMarginRight)||0,bottom:parseFloat(m.scrollMarginBottom)||0,left:parseFloat(m.scrollMarginLeft)||0}})(a);if((f=>typeof f=="object"&&typeof f.behavior=="function")(c))return c.behavior(r(a,c));const d=typeof c=="boolean"||c==null?void 0:c.behavior;for(const{el:f,top:m,left:g}of r(a,o(c))){const y=m-u.top+u.bottom,b=g-u.left+u.right;f.scroll({top:y,left:b,behavior:d})}}function isWindow(a){return a!=null&&a===a.window}const getScroll$1=a=>{var c,u;if(typeof window>"u")return 0;let d=0;return isWindow(a)?d=a.pageYOffset:a instanceof Document?d=a.documentElement.scrollTop:(a instanceof HTMLElement||a)&&(d=a.scrollTop),a&&!isWindow(a)&&typeof d!="number"&&(d=(u=((c=a.ownerDocument)!==null&&c!==void 0?c:a).documentElement)===null||u===void 0?void 0:u.scrollTop),d};function easeInOutCubic(a,c,u,d){const f=u-c;return a/=d/2,a<1?f/2*a*a*a+c:f/2*((a-=2)*a*a+2)+c}function scrollTo(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};const{getContainer:u=()=>window,callback:d,duration:f=450}=c,m=u(),g=getScroll$1(m),y=Date.now(),b=()=>{const C=Date.now()-y,w=easeInOutCubic(C>f?f:C,g,a,f);isWindow(m)?m.scrollTo(window.pageXOffset,w):m instanceof Document||m.constructor.name==="HTMLDocument"?m.documentElement.scrollTop=w:m.scrollTop=w,C<f?wrapperRaf(b):typeof d=="function"&&d()};wrapperRaf(b)}const useCSSVarCls=a=>{const[,,,,c]=useToken$1();return c?`${a}-css-var`:""};var KeyCode={BACKSPACE:8,TAB:9,ENTER:13,SHIFT:16,CTRL:17,ALT:18,CAPS_LOCK:20,ESC:27,SPACE:32,END:35,HOME:36,LEFT:37,UP:38,RIGHT:39,DOWN:40,N:78,P:80,META:91,WIN_KEY_RIGHT:92,CONTEXT_MENU:93,F1:112,F2:113,F3:114,F4:115,F5:116,F6:117,F7:118,F8:119,F9:120,F10:121,F11:122,F12:123,SEMICOLON:186,EQUALS:187,WIN_KEY:224},Notify=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.style,f=a.className,m=a.duration,g=m===void 0?4.5:m,y=a.showProgress,b=a.pauseOnHover,E=b===void 0?!0:b,C=a.eventKey,w=a.content,R=a.closable,_=a.closeIcon,M=_===void 0?"x":_,I=a.props,N=a.onClick,A=a.onNoticeClose,P=a.times,z=a.hovering,B=reactExports.useState(!1),j=_slicedToArray(B,2),L=j[0],U=j[1],q=reactExports.useState(0),F=_slicedToArray(q,2),K=F[0],X=F[1],Q=reactExports.useState(0),Y=_slicedToArray(Q,2),Z=Y[0],J=Y[1],W=z||L,G=g>0&&y,te=function(){A(C)},ae=function(ce){(ce.key==="Enter"||ce.code==="Enter"||ce.keyCode===KeyCode.ENTER)&&te()};reactExports.useEffect(function(){if(!W&&g>0){var ie=Date.now()-Z,ce=setTimeout(function(){te()},g*1e3-Z);return function(){E&&clearTimeout(ce),J(Date.now()-ie)}}},[g,W,P]),reactExports.useEffect(function(){if(!W&&G&&(E||Z===0)){var ie=performance.now(),ce,ue=function me(){cancelAnimationFrame(ce),ce=requestAnimationFrame(function(de){var ge=de+Z-ie,Ce=Math.min(ge/(g*1e3),1);X(Ce*100),Ce<1&&me()})};return ue(),function(){E&&cancelAnimationFrame(ce)}}},[g,Z,W,G,P]);var V=reactExports.useMemo(function(){return _typeof(R)==="object"&&R!==null?R:R?{closeIcon:M}:{}},[R,M]),ne=pickAttrs(V,!0),le=100-(!K||K<0?0:K>100?100:K),ee="".concat(u,"-notice");return reactExports.createElement("div",_extends({},I,{ref:c,className:classNames(ee,f,_defineProperty({},"".concat(ee,"-closable"),R)),style:d,onMouseEnter:function(ce){var ue;U(!0),I==null||(ue=I.onMouseEnter)===null||ue===void 0||ue.call(I,ce)},onMouseLeave:function(ce){var ue;U(!1),I==null||(ue=I.onMouseLeave)===null||ue===void 0||ue.call(I,ce)},onClick:N}),reactExports.createElement("div",{className:"".concat(ee,"-content")},w),R&&reactExports.createElement("a",_extends({tabIndex:0,className:"".concat(ee,"-close"),onKeyDown:ae,"aria-label":"Close"},ne,{onClick:function(ce){ce.preventDefault(),ce.stopPropagation(),te()}}),V.closeIcon),G&&reactExports.createElement("progress",{className:"".concat(ee,"-progress"),max:"100",value:le},le+"%"))}),NotificationContext=React.createContext({}),NotificationProvider=function(c){var u=c.children,d=c.classNames;return React.createElement(NotificationContext.Provider,{value:{classNames:d}},u)},DEFAULT_OFFSET$1=8,DEFAULT_THRESHOLD=3,DEFAULT_GAP=16,useStack=function(c){var u={offset:DEFAULT_OFFSET$1,threshold:DEFAULT_THRESHOLD,gap:DEFAULT_GAP};if(c&&_typeof(c)==="object"){var d,f,m;u.offset=(d=c.offset)!==null&&d!==void 0?d:DEFAULT_OFFSET$1,u.threshold=(f=c.threshold)!==null&&f!==void 0?f:DEFAULT_THRESHOLD,u.gap=(m=c.gap)!==null&&m!==void 0?m:DEFAULT_GAP}return[!!c,u]},_excluded$N=["className","style","classNames","styles"],NoticeList=function(c){var u=c.configList,d=c.placement,f=c.prefixCls,m=c.className,g=c.style,y=c.motion,b=c.onAllNoticeRemoved,E=c.onNoticeClose,C=c.stack,w=reactExports.useContext(NotificationContext),R=w.classNames,_=reactExports.useRef({}),M=reactExports.useState(null),I=_slicedToArray(M,2),N=I[0],A=I[1],P=reactExports.useState([]),z=_slicedToArray(P,2),B=z[0],j=z[1],L=u.map(function(W){return{config:W,key:String(W.key)}}),U=useStack(C),q=_slicedToArray(U,2),F=q[0],K=q[1],X=K.offset,Q=K.threshold,Y=K.gap,Z=F&&(B.length>0||L.length<=Q),J=typeof y=="function"?y(d):y;return reactExports.useEffect(function(){F&&B.length>1&&j(function(W){return W.filter(function(G){return L.some(function(te){var ae=te.key;return G===ae})})})},[B,L,F]),reactExports.useEffect(function(){var W;if(F&&_.current[(W=L[L.length-1])===null||W===void 0?void 0:W.key]){var G;A(_.current[(G=L[L.length-1])===null||G===void 0?void 0:G.key])}},[L,F]),React.createElement(CSSMotionList,_extends({key:d,className:classNames(f,"".concat(f,"-").concat(d),R==null?void 0:R.list,m,_defineProperty(_defineProperty({},"".concat(f,"-stack"),!!F),"".concat(f,"-stack-expanded"),Z)),style:g,keys:L,motionAppear:!0},J,{onAllRemoved:function(){b(d)}}),function(W,G){var te=W.config,ae=W.className,V=W.style,ne=W.index,le=te,ee=le.key,ie=le.times,ce=String(ee),ue=te,me=ue.className,de=ue.style,ge=ue.classNames,Ce=ue.styles,ve=_objectWithoutProperties(ue,_excluded$N),fe=L.findIndex(function(ke){return ke.key===ce}),pe={};if(F){var xe=L.length-1-(fe>-1?fe:ne-1),ye=d==="top"||d==="bottom"?"-50%":"0";if(xe>0){var he,we,Re;pe.height=Z?(he=_.current[ce])===null||he===void 0?void 0:he.offsetHeight:N==null?void 0:N.offsetHeight;for(var De=0,Ae=0;Ae<xe;Ae++){var Ee;De+=((Ee=_.current[L[L.length-1-Ae].key])===null||Ee===void 0?void 0:Ee.offsetHeight)+Y}var Ne=(Z?De:xe*X)*(d.startsWith("top")?1:-1),_e=!Z&&N!==null&&N!==void 0&&N.offsetWidth&&(we=_.current[ce])!==null&&we!==void 0&&we.offsetWidth?((N==null?void 0:N.offsetWidth)-X*2*(xe<3?xe:3))/((Re=_.current[ce])===null||Re===void 0?void 0:Re.offsetWidth):1;pe.transform="translate3d(".concat(ye,", ").concat(Ne,"px, 0) scaleX(").concat(_e,")")}else pe.transform="translate3d(".concat(ye,", 0, 0)")}return React.createElement("div",{ref:G,className:classNames("".concat(f,"-notice-wrapper"),ae,ge==null?void 0:ge.wrapper),style:_objectSpread2(_objectSpread2(_objectSpread2({},V),pe),Ce==null?void 0:Ce.wrapper),onMouseEnter:function(){return j(function(Ke){return Ke.includes(ce)?Ke:[].concat(_toConsumableArray(Ke),[ce])})},onMouseLeave:function(){return j(function(Ke){return Ke.filter(function(be){return be!==ce})})}},React.createElement(Notify,_extends({},ve,{ref:function(Ke){fe>-1?_.current[ce]=Ke:delete _.current[ce]},prefixCls:f,classNames:ge,styles:Ce,className:classNames(me,R==null?void 0:R.notice),style:de,times:ie,key:ee,eventKey:ee,onNoticeClose:E,hovering:F&&B.length>0})))})},Notifications=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=u===void 0?"rc-notification":u,f=a.container,m=a.motion,g=a.maxCount,y=a.className,b=a.style,E=a.onAllRemoved,C=a.stack,w=a.renderNotifications,R=reactExports.useState([]),_=_slicedToArray(R,2),M=_[0],I=_[1],N=function(F){var K,X=M.find(function(Q){return Q.key===F});X==null||(K=X.onClose)===null||K===void 0||K.call(X),I(function(Q){return Q.filter(function(Y){return Y.key!==F})})};reactExports.useImperativeHandle(c,function(){return{open:function(F){I(function(K){var X=_toConsumableArray(K),Q=X.findIndex(function(J){return J.key===F.key}),Y=_objectSpread2({},F);if(Q>=0){var Z;Y.times=(((Z=K[Q])===null||Z===void 0?void 0:Z.times)||0)+1,X[Q]=Y}else Y.times=0,X.push(Y);return g>0&&X.length>g&&(X=X.slice(-g)),X})},close:function(F){N(F)},destroy:function(){I([])}}});var A=reactExports.useState({}),P=_slicedToArray(A,2),z=P[0],B=P[1];reactExports.useEffect(function(){var q={};M.forEach(function(F){var K=F.placement,X=K===void 0?"topRight":K;X&&(q[X]=q[X]||[],q[X].push(F))}),Object.keys(z).forEach(function(F){q[F]=q[F]||[]}),B(q)},[M]);var j=function(F){B(function(K){var X=_objectSpread2({},K),Q=X[F]||[];return Q.length||delete X[F],X})},L=reactExports.useRef(!1);if(reactExports.useEffect(function(){Object.keys(z).length>0?L.current=!0:L.current&&(E==null||E(),L.current=!1)},[z]),!f)return null;var U=Object.keys(z);return reactDomExports.createPortal(reactExports.createElement(reactExports.Fragment,null,U.map(function(q){var F=z[q],K=reactExports.createElement(NoticeList,{key:q,configList:F,placement:q,prefixCls:d,className:y==null?void 0:y(q),style:b==null?void 0:b(q),motion:m,onNoticeClose:N,onAllNoticeRemoved:j,stack:C});return w?w(K,{prefixCls:d,key:q}):K})),f)}),_excluded$M=["getContainer","motion","prefixCls","maxCount","className","style","onAllRemoved","stack","renderNotifications"],defaultGetContainer=function(){return document.body},uniqueKey=0;function mergeConfig$2(){for(var a={},c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];return u.forEach(function(f){f&&Object.keys(f).forEach(function(m){var g=f[m];g!==void 0&&(a[m]=g)})}),a}function useNotification(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},c=a.getContainer,u=c===void 0?defaultGetContainer:c,d=a.motion,f=a.prefixCls,m=a.maxCount,g=a.className,y=a.style,b=a.onAllRemoved,E=a.stack,C=a.renderNotifications,w=_objectWithoutProperties(a,_excluded$M),R=reactExports.useState(),_=_slicedToArray(R,2),M=_[0],I=_[1],N=reactExports.useRef(),A=reactExports.createElement(Notifications,{container:M,ref:N,prefixCls:f,motion:d,maxCount:m,className:g,style:y,onAllRemoved:b,stack:E,renderNotifications:C}),P=reactExports.useState([]),z=_slicedToArray(P,2),B=z[0],j=z[1],L=useEvent(function(q){var F=mergeConfig$2(w,q);(F.key===null||F.key===void 0)&&(F.key="rc-notification-".concat(uniqueKey),uniqueKey+=1),j(function(K){return[].concat(_toConsumableArray(K),[{type:"open",config:F}])})}),U=reactExports.useMemo(function(){return{open:L,close:function(F){j(function(K){return[].concat(_toConsumableArray(K),[{type:"close",key:F}])})},destroy:function(){j(function(F){return[].concat(_toConsumableArray(F),[{type:"destroy"}])})}}},[]);return reactExports.useEffect(function(){I(u())}),reactExports.useEffect(function(){if(N.current&&B.length){B.forEach(function(K){switch(K.type){case"open":N.current.open(K.config);break;case"close":N.current.close(K.key);break;case"destroy":N.current.destroy();break}});var q,F;j(function(K){return(q!==K||!F)&&(q=K,F=K.filter(function(X){return!B.includes(X)})),F})}},[B]),[U,A]}const zIndexContext=React.createContext(void 0),CONTAINER_OFFSET=100,CONTAINER_OFFSET_MAX_COUNT=10,CONTAINER_MAX_OFFSET=CONTAINER_OFFSET*CONTAINER_OFFSET_MAX_COUNT,containerBaseZIndexOffset={Modal:CONTAINER_OFFSET,Drawer:CONTAINER_OFFSET,Popover:CONTAINER_OFFSET,Popconfirm:CONTAINER_OFFSET,Tooltip:CONTAINER_OFFSET,Tour:CONTAINER_OFFSET,FloatButton:CONTAINER_OFFSET},consumerBaseZIndexOffset={SelectLike:50,Dropdown:50,DatePicker:50,Menu:50,ImagePreview:1};function isContainerType(a){return a in containerBaseZIndexOffset}const useZIndex=(a,c)=>{const[,u]=useToken$1(),d=React.useContext(zIndexContext),f=isContainerType(a);let m;if(c!==void 0)m=[c,c];else{let g=d??0;f?g+=(d?0:u.zIndexPopupBase)+containerBaseZIndexOffset[a]:g+=consumerBaseZIndexOffset[a],m=[d===void 0?c:g,g]}return m},genMessageStyle=a=>{const{componentCls:c,iconCls:u,boxShadow:d,colorText:f,colorSuccess:m,colorError:g,colorWarning:y,colorInfo:b,fontSizeLG:E,motionEaseInOutCirc:C,motionDurationSlow:w,marginXS:R,paddingXS:_,borderRadiusLG:M,zIndexPopup:I,contentPadding:N,contentBg:A}=a,P=`${c}-notice`,z=new Keyframe("MessageMoveIn",{"0%":{padding:0,transform:"translateY(-100%)",opacity:0},"100%":{padding:_,transform:"translateY(0)",opacity:1}}),B=new Keyframe("MessageMoveOut",{"0%":{maxHeight:a.height,padding:_,opacity:1},"100%":{maxHeight:0,padding:0,opacity:0}}),j={padding:_,textAlign:"center",[`${c}-custom-content`]:{display:"flex",alignItems:"center"},[`${c}-custom-content > ${u}`]:{marginInlineEnd:R,fontSize:E},[`${P}-content`]:{display:"inline-block",padding:N,background:A,borderRadius:M,boxShadow:d,pointerEvents:"all"},[`${c}-success > ${u}`]:{color:m},[`${c}-error > ${u}`]:{color:g},[`${c}-warning > ${u}`]:{color:y},[`${c}-info > ${u},
      ${c}-loading > ${u}`]:{color:b}};return[{[c]:Object.assign(Object.assign({},resetComponent(a)),{color:f,position:"fixed",top:R,width:"100%",pointerEvents:"none",zIndex:I,[`${c}-move-up`]:{animationFillMode:"forwards"},[`
        ${c}-move-up-appear,
        ${c}-move-up-enter
      `]:{animationName:z,animationDuration:w,animationPlayState:"paused",animationTimingFunction:C},[`
        ${c}-move-up-appear${c}-move-up-appear-active,
        ${c}-move-up-enter${c}-move-up-enter-active
      `]:{animationPlayState:"running"},[`${c}-move-up-leave`]:{animationName:B,animationDuration:w,animationPlayState:"paused",animationTimingFunction:C},[`${c}-move-up-leave${c}-move-up-leave-active`]:{animationPlayState:"running"},"&-rtl":{direction:"rtl",span:{direction:"rtl"}}})},{[c]:{[`${P}-wrapper`]:Object.assign({},j)}},{[`${c}-notice-pure-panel`]:Object.assign(Object.assign({},j),{padding:0,textAlign:"start"})}]},prepareComponentToken$o=a=>({zIndexPopup:a.zIndexPopupBase+CONTAINER_MAX_OFFSET+10,contentBg:a.colorBgElevated,contentPadding:`${(a.controlHeightLG-a.fontSize*a.lineHeight)/2}px ${a.paddingSM}px`}),useStyle$v=genStyleHooks("Message",a=>{const c=merge$2(a,{height:150});return[genMessageStyle(c)]},prepareComponentToken$o);var __rest$U=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const TypeIcon={info:reactExports.createElement(RefIcon$h,null),success:reactExports.createElement(RefIcon$A,null),error:reactExports.createElement(RefIcon$y,null),warning:reactExports.createElement(RefIcon$p,null),loading:reactExports.createElement(RefIcon$e,null)},PureContent=a=>{let{prefixCls:c,type:u,icon:d,children:f}=a;return reactExports.createElement("div",{className:classNames(`${c}-custom-content`,`${c}-${u}`)},d||TypeIcon[u],reactExports.createElement("span",null,f))},PurePanel$5=a=>{const{prefixCls:c,className:u,type:d,icon:f,content:m}=a,g=__rest$U(a,["prefixCls","className","type","icon","content"]),{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=c||y("message"),E=useCSSVarCls(b),[C,w,R]=useStyle$v(b,E);return C(reactExports.createElement(Notify,Object.assign({},g,{prefixCls:b,className:classNames(u,w,`${b}-notice-pure-panel`,R,E),eventKey:"pure",duration:null,content:reactExports.createElement(PureContent,{prefixCls:b,type:d,icon:f},m)})))};function getMotion$2(a,c){return{motionName:c??`${a}-move-up`}}function wrapPromiseFn(a){let c;const u=new Promise(f=>{c=a(()=>{f(!0)})}),d=()=>{c==null||c()};return d.then=(f,m)=>u.then(f,m),d.promise=u,d}var __rest$T=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const DEFAULT_OFFSET=8,DEFAULT_DURATION=3,Wrapper=a=>{let{children:c,prefixCls:u}=a;const d=useCSSVarCls(u),[f,m,g]=useStyle$v(u,d);return f(reactExports.createElement(NotificationProvider,{classNames:{list:classNames(m,g,d)}},c))},renderNotifications=(a,c)=>{let{prefixCls:u,key:d}=c;return reactExports.createElement(Wrapper,{prefixCls:u,key:d},a)},Holder=reactExports.forwardRef((a,c)=>{const{top:u,prefixCls:d,getContainer:f,maxCount:m,duration:g=DEFAULT_DURATION,rtl:y,transitionName:b,onAllRemoved:E}=a,{getPrefixCls:C,getPopupContainer:w,message:R,direction:_}=reactExports.useContext(ConfigContext),M=d||C("message"),I=()=>({left:"50%",transform:"translateX(-50%)",top:u??DEFAULT_OFFSET}),N=()=>classNames({[`${M}-rtl`]:y??_==="rtl"}),A=()=>getMotion$2(M,b),P=reactExports.createElement("span",{className:`${M}-close-x`},reactExports.createElement(RefIcon$x,{className:`${M}-close-icon`})),[z,B]=useNotification({prefixCls:M,style:I,className:N,motion:A,closable:!1,closeIcon:P,duration:g,getContainer:()=>(f==null?void 0:f())||(w==null?void 0:w())||document.body,maxCount:m,onAllRemoved:E,renderNotifications});return reactExports.useImperativeHandle(c,()=>Object.assign(Object.assign({},z),{prefixCls:M,message:R})),B});let keyIndex=0;function useInternalMessage(a){const c=reactExports.useRef(null);return devUseWarning(),[reactExports.useMemo(()=>{const d=b=>{var E;(E=c.current)===null||E===void 0||E.close(b)},f=b=>{if(!c.current){const L=()=>{};return L.then=()=>{},L}const{open:E,prefixCls:C,message:w}=c.current,R=`${C}-notice`,{content:_,icon:M,type:I,key:N,className:A,style:P,onClose:z}=b,B=__rest$T(b,["content","icon","type","key","className","style","onClose"]);let j=N;return j==null&&(keyIndex+=1,j=`antd-message-${keyIndex}`),wrapPromiseFn(L=>(E(Object.assign(Object.assign({},B),{key:j,content:reactExports.createElement(PureContent,{prefixCls:C,type:I,icon:M},_),placement:"top",className:classNames(I&&`${R}-${I}`,A,w==null?void 0:w.className),style:Object.assign(Object.assign({},w==null?void 0:w.style),P),onClose:()=>{z==null||z(),L()}})),()=>{d(j)}))},g={open:f,destroy:b=>{var E;b!==void 0?d(b):(E=c.current)===null||E===void 0||E.destroy()}};return["info","success","warning","error","loading"].forEach(b=>{const E=(C,w,R)=>{let _;C&&typeof C=="object"&&"content"in C?_=C:_={content:C};let M,I;typeof w=="function"?I=w:(M=w,I=R);const N=Object.assign(Object.assign({onClose:I,duration:M},_),{type:b});return f(N)};g[b]=E}),g},[]),reactExports.createElement(Holder,Object.assign({key:"message-holder"},a,{ref:c}))]}function useMessage(a){return useInternalMessage(a)}function _regeneratorRuntime(){_regeneratorRuntime=function(){return c};var a,c={},u=Object.prototype,d=u.hasOwnProperty,f=Object.defineProperty||function(W,G,te){W[G]=te.value},m=typeof Symbol=="function"?Symbol:{},g=m.iterator||"@@iterator",y=m.asyncIterator||"@@asyncIterator",b=m.toStringTag||"@@toStringTag";function E(W,G,te){return Object.defineProperty(W,G,{value:te,enumerable:!0,configurable:!0,writable:!0}),W[G]}try{E({},"")}catch{E=function(te,ae,V){return te[ae]=V}}function C(W,G,te,ae){var V=G&&G.prototype instanceof A?G:A,ne=Object.create(V.prototype),le=new Z(ae||[]);return f(ne,"_invoke",{value:K(W,te,le)}),ne}function w(W,G,te){try{return{type:"normal",arg:W.call(G,te)}}catch(ae){return{type:"throw",arg:ae}}}c.wrap=C;var R="suspendedStart",_="suspendedYield",M="executing",I="completed",N={};function A(){}function P(){}function z(){}var B={};E(B,g,function(){return this});var j=Object.getPrototypeOf,L=j&&j(j(J([])));L&&L!==u&&d.call(L,g)&&(B=L);var U=z.prototype=A.prototype=Object.create(B);function q(W){["next","throw","return"].forEach(function(G){E(W,G,function(te){return this._invoke(G,te)})})}function F(W,G){function te(V,ne,le,ee){var ie=w(W[V],W,ne);if(ie.type!=="throw"){var ce=ie.arg,ue=ce.value;return ue&&_typeof(ue)=="object"&&d.call(ue,"__await")?G.resolve(ue.__await).then(function(me){te("next",me,le,ee)},function(me){te("throw",me,le,ee)}):G.resolve(ue).then(function(me){ce.value=me,le(ce)},function(me){return te("throw",me,le,ee)})}ee(ie.arg)}var ae;f(this,"_invoke",{value:function(ne,le){function ee(){return new G(function(ie,ce){te(ne,le,ie,ce)})}return ae=ae?ae.then(ee,ee):ee()}})}function K(W,G,te){var ae=R;return function(V,ne){if(ae===M)throw Error("Generator is already running");if(ae===I){if(V==="throw")throw ne;return{value:a,done:!0}}for(te.method=V,te.arg=ne;;){var le=te.delegate;if(le){var ee=X(le,te);if(ee){if(ee===N)continue;return ee}}if(te.method==="next")te.sent=te._sent=te.arg;else if(te.method==="throw"){if(ae===R)throw ae=I,te.arg;te.dispatchException(te.arg)}else te.method==="return"&&te.abrupt("return",te.arg);ae=M;var ie=w(W,G,te);if(ie.type==="normal"){if(ae=te.done?I:_,ie.arg===N)continue;return{value:ie.arg,done:te.done}}ie.type==="throw"&&(ae=I,te.method="throw",te.arg=ie.arg)}}}function X(W,G){var te=G.method,ae=W.iterator[te];if(ae===a)return G.delegate=null,te==="throw"&&W.iterator.return&&(G.method="return",G.arg=a,X(W,G),G.method==="throw")||te!=="return"&&(G.method="throw",G.arg=new TypeError("The iterator does not provide a '"+te+"' method")),N;var V=w(ae,W.iterator,G.arg);if(V.type==="throw")return G.method="throw",G.arg=V.arg,G.delegate=null,N;var ne=V.arg;return ne?ne.done?(G[W.resultName]=ne.value,G.next=W.nextLoc,G.method!=="return"&&(G.method="next",G.arg=a),G.delegate=null,N):ne:(G.method="throw",G.arg=new TypeError("iterator result is not an object"),G.delegate=null,N)}function Q(W){var G={tryLoc:W[0]};1 in W&&(G.catchLoc=W[1]),2 in W&&(G.finallyLoc=W[2],G.afterLoc=W[3]),this.tryEntries.push(G)}function Y(W){var G=W.completion||{};G.type="normal",delete G.arg,W.completion=G}function Z(W){this.tryEntries=[{tryLoc:"root"}],W.forEach(Q,this),this.reset(!0)}function J(W){if(W||W===""){var G=W[g];if(G)return G.call(W);if(typeof W.next=="function")return W;if(!isNaN(W.length)){var te=-1,ae=function V(){for(;++te<W.length;)if(d.call(W,te))return V.value=W[te],V.done=!1,V;return V.value=a,V.done=!0,V};return ae.next=ae}}throw new TypeError(_typeof(W)+" is not iterable")}return P.prototype=z,f(U,"constructor",{value:z,configurable:!0}),f(z,"constructor",{value:P,configurable:!0}),P.displayName=E(z,b,"GeneratorFunction"),c.isGeneratorFunction=function(W){var G=typeof W=="function"&&W.constructor;return!!G&&(G===P||(G.displayName||G.name)==="GeneratorFunction")},c.mark=function(W){return Object.setPrototypeOf?Object.setPrototypeOf(W,z):(W.__proto__=z,E(W,b,"GeneratorFunction")),W.prototype=Object.create(U),W},c.awrap=function(W){return{__await:W}},q(F.prototype),E(F.prototype,y,function(){return this}),c.AsyncIterator=F,c.async=function(W,G,te,ae,V){V===void 0&&(V=Promise);var ne=new F(C(W,G,te,ae),V);return c.isGeneratorFunction(G)?ne:ne.next().then(function(le){return le.done?le.value:ne.next()})},q(U),E(U,b,"Generator"),E(U,g,function(){return this}),E(U,"toString",function(){return"[object Generator]"}),c.keys=function(W){var G=Object(W),te=[];for(var ae in G)te.push(ae);return te.reverse(),function V(){for(;te.length;){var ne=te.pop();if(ne in G)return V.value=ne,V.done=!1,V}return V.done=!0,V}},c.values=J,Z.prototype={constructor:Z,reset:function(G){if(this.prev=0,this.next=0,this.sent=this._sent=a,this.done=!1,this.delegate=null,this.method="next",this.arg=a,this.tryEntries.forEach(Y),!G)for(var te in this)te.charAt(0)==="t"&&d.call(this,te)&&!isNaN(+te.slice(1))&&(this[te]=a)},stop:function(){this.done=!0;var G=this.tryEntries[0].completion;if(G.type==="throw")throw G.arg;return this.rval},dispatchException:function(G){if(this.done)throw G;var te=this;function ae(ce,ue){return le.type="throw",le.arg=G,te.next=ce,ue&&(te.method="next",te.arg=a),!!ue}for(var V=this.tryEntries.length-1;V>=0;--V){var ne=this.tryEntries[V],le=ne.completion;if(ne.tryLoc==="root")return ae("end");if(ne.tryLoc<=this.prev){var ee=d.call(ne,"catchLoc"),ie=d.call(ne,"finallyLoc");if(ee&&ie){if(this.prev<ne.catchLoc)return ae(ne.catchLoc,!0);if(this.prev<ne.finallyLoc)return ae(ne.finallyLoc)}else if(ee){if(this.prev<ne.catchLoc)return ae(ne.catchLoc,!0)}else{if(!ie)throw Error("try statement without catch or finally");if(this.prev<ne.finallyLoc)return ae(ne.finallyLoc)}}}},abrupt:function(G,te){for(var ae=this.tryEntries.length-1;ae>=0;--ae){var V=this.tryEntries[ae];if(V.tryLoc<=this.prev&&d.call(V,"finallyLoc")&&this.prev<V.finallyLoc){var ne=V;break}}ne&&(G==="break"||G==="continue")&&ne.tryLoc<=te&&te<=ne.finallyLoc&&(ne=null);var le=ne?ne.completion:{};return le.type=G,le.arg=te,ne?(this.method="next",this.next=ne.finallyLoc,N):this.complete(le)},complete:function(G,te){if(G.type==="throw")throw G.arg;return G.type==="break"||G.type==="continue"?this.next=G.arg:G.type==="return"?(this.rval=this.arg=G.arg,this.method="return",this.next="end"):G.type==="normal"&&te&&(this.next=te),N},finish:function(G){for(var te=this.tryEntries.length-1;te>=0;--te){var ae=this.tryEntries[te];if(ae.finallyLoc===G)return this.complete(ae.completion,ae.afterLoc),Y(ae),N}},catch:function(G){for(var te=this.tryEntries.length-1;te>=0;--te){var ae=this.tryEntries[te];if(ae.tryLoc===G){var V=ae.completion;if(V.type==="throw"){var ne=V.arg;Y(ae)}return ne}}throw Error("illegal catch attempt")},delegateYield:function(G,te,ae){return this.delegate={iterator:J(G),resultName:te,nextLoc:ae},this.method==="next"&&(this.arg=a),N}},c}function asyncGeneratorStep(a,c,u,d,f,m,g){try{var y=a[m](g),b=y.value}catch(E){return void u(E)}y.done?c(b):Promise.resolve(b).then(d,f)}function _asyncToGenerator(a){return function(){var c=this,u=arguments;return new Promise(function(d,f){var m=a.apply(c,u);function g(b){asyncGeneratorStep(m,d,f,g,y,"next",b)}function y(b){asyncGeneratorStep(m,d,f,g,y,"throw",b)}g(void 0)})}}var fullClone=_objectSpread2({},ReactDOM$1),version$1=fullClone.version,reactRender=fullClone.render,unmountComponentAtNode=fullClone.unmountComponentAtNode,createRoot;try{var mainVersion=Number((version$1||"").split(".")[0]);mainVersion>=18&&(createRoot=fullClone.createRoot)}catch{}function toggleWarning(a){var c=fullClone.__SECRET_INTERNALS_DO_NOT_USE_OR_YOU_WILL_BE_FIRED;c&&_typeof(c)==="object"&&(c.usingClientEntryPoint=a)}var MARK="__rc_react_root__";function modernRender(a,c){toggleWarning(!0);var u=c[MARK]||createRoot(c);toggleWarning(!1),u.render(a),c[MARK]=u}function legacyRender(a,c){reactRender==null||reactRender(a,c)}function render$1(a,c){if(createRoot){modernRender(a,c);return}legacyRender(a,c)}function modernUnmount(a){return _modernUnmount.apply(this,arguments)}function _modernUnmount(){return _modernUnmount=_asyncToGenerator(_regeneratorRuntime().mark(function a(c){return _regeneratorRuntime().wrap(function(d){for(;;)switch(d.prev=d.next){case 0:return d.abrupt("return",Promise.resolve().then(function(){var f;(f=c[MARK])===null||f===void 0||f.unmount(),delete c[MARK]}));case 1:case"end":return d.stop()}},a)})),_modernUnmount.apply(this,arguments)}function legacyUnmount(a){unmountComponentAtNode(a)}function unmount(a){return _unmount.apply(this,arguments)}function _unmount(){return _unmount=_asyncToGenerator(_regeneratorRuntime().mark(function a(c){return _regeneratorRuntime().wrap(function(d){for(;;)switch(d.prev=d.next){case 0:if(createRoot===void 0){d.next=2;break}return d.abrupt("return",modernUnmount(c));case 2:legacyUnmount(c);case 3:case"end":return d.stop()}},a)})),_unmount.apply(this,arguments)}const defaultReactRender=(a,c)=>(render$1(a,c),()=>unmount(c));let unstableRender=defaultReactRender;function getReactRender(){return unstableRender}const getCollapsedHeight=()=>({height:0,opacity:0}),getRealHeight=a=>{const{scrollHeight:c}=a;return{height:c,opacity:1}},getCurrentHeight=a=>({height:a?a.offsetHeight:0}),skipOpacityTransition=(a,c)=>(c==null?void 0:c.deadline)===!0||c.propertyName==="height",initCollapseMotion=function(){return{motionName:`${arguments.length>0&&arguments[0]!==void 0?arguments[0]:defaultPrefixCls}-motion-collapse`,onAppearStart:getCollapsedHeight,onEnterStart:getCollapsedHeight,onAppearActive:getRealHeight,onEnterActive:getRealHeight,onLeaveStart:getCurrentHeight,onLeaveActive:getCollapsedHeight,onAppearEnd:skipOpacityTransition,onEnterEnd:skipOpacityTransition,onLeaveEnd:skipOpacityTransition,motionDeadline:500}},getTransitionName=(a,c,u)=>u!==void 0?u:`${a}-${c}`;function omit(a,c){var u=Object.assign({},a);return Array.isArray(c)&&c.forEach(function(d){delete u[d]}),u}const isVisible=function(a){if(!a)return!1;if(a instanceof Element){if(a.offsetParent)return!0;if(a.getBBox){var c=a.getBBox(),u=c.width,d=c.height;if(u||d)return!0}if(a.getBoundingClientRect){var f=a.getBoundingClientRect(),m=f.width,g=f.height;if(m||g)return!0}}return!1},genWaveStyle=a=>{const{componentCls:c,colorPrimary:u}=a;return{[c]:{position:"absolute",background:"transparent",pointerEvents:"none",boxSizing:"border-box",color:`var(--wave-color, ${u})`,boxShadow:"0 0 0 0 currentcolor",opacity:.2,"&.wave-motion-appear":{transition:[`box-shadow 0.4s ${a.motionEaseOutCirc}`,`opacity 2s ${a.motionEaseOutCirc}`].join(","),"&-active":{boxShadow:"0 0 0 6px currentcolor",opacity:0},"&.wave-quick":{transition:[`box-shadow ${a.motionDurationSlow} ${a.motionEaseInOut}`,`opacity ${a.motionDurationSlow} ${a.motionEaseInOut}`].join(",")}}}}},useStyle$u=genComponentStyleHook("Wave",a=>[genWaveStyle(a)]),TARGET_CLS=`${defaultPrefixCls}-wave-target`;function isValidWaveColor(a){return a&&a!=="#fff"&&a!=="#ffffff"&&a!=="rgb(255, 255, 255)"&&a!=="rgba(255, 255, 255, 1)"&&!/rgba\((?:\d*, ){3}0\)/.test(a)&&a!=="transparent"}function getTargetWaveColor(a){const{borderTopColor:c,borderColor:u,backgroundColor:d}=getComputedStyle(a);return isValidWaveColor(c)?c:isValidWaveColor(u)?u:isValidWaveColor(d)?d:null}function validateNum(a){return Number.isNaN(a)?0:a}const WaveEffect=a=>{const{className:c,target:u,component:d,registerUnmount:f}=a,m=reactExports.useRef(null),g=reactExports.useRef(null);reactExports.useEffect(()=>{g.current=f()},[]);const[y,b]=reactExports.useState(null),[E,C]=reactExports.useState([]),[w,R]=reactExports.useState(0),[_,M]=reactExports.useState(0),[I,N]=reactExports.useState(0),[A,P]=reactExports.useState(0),[z,B]=reactExports.useState(!1),j={left:w,top:_,width:I,height:A,borderRadius:E.map(q=>`${q}px`).join(" ")};y&&(j["--wave-color"]=y);function L(){const q=getComputedStyle(u);b(getTargetWaveColor(u));const F=q.position==="static",{borderLeftWidth:K,borderTopWidth:X}=q;R(F?u.offsetLeft:validateNum(-parseFloat(K))),M(F?u.offsetTop:validateNum(-parseFloat(X))),N(u.offsetWidth),P(u.offsetHeight);const{borderTopLeftRadius:Q,borderTopRightRadius:Y,borderBottomLeftRadius:Z,borderBottomRightRadius:J}=q;C([Q,Y,J,Z].map(W=>validateNum(parseFloat(W))))}if(reactExports.useEffect(()=>{if(u){const q=wrapperRaf(()=>{L(),B(!0)});let F;return typeof ResizeObserver<"u"&&(F=new ResizeObserver(L),F.observe(u)),()=>{wrapperRaf.cancel(q),F==null||F.disconnect()}}},[]),!z)return null;const U=(d==="Checkbox"||d==="Radio")&&(u==null?void 0:u.classList.contains(TARGET_CLS));return reactExports.createElement(CSSMotion,{visible:!0,motionAppear:!0,motionName:"wave-motion",motionDeadline:5e3,onAppearEnd:(q,F)=>{var K,X;if(F.deadline||F.propertyName==="opacity"){const Q=(K=m.current)===null||K===void 0?void 0:K.parentElement;(X=g.current)===null||X===void 0||X.call(g).then(()=>{Q==null||Q.remove()})}return!1}},(q,F)=>{let{className:K}=q;return reactExports.createElement("div",{ref:composeRef(m,F),className:classNames(c,K,{"wave-quick":U}),style:j})})},showWaveEffect=(a,c)=>{var u;const{component:d}=c;if(d==="Checkbox"&&!(!((u=a.querySelector("input"))===null||u===void 0)&&u.checked))return;const f=document.createElement("div");f.style.position="absolute",f.style.left="0px",f.style.top="0px",a==null||a.insertBefore(f,a==null?void 0:a.firstChild);const m=getReactRender();let g=null;function y(){return g}g=m(reactExports.createElement(WaveEffect,Object.assign({},c,{target:a,registerUnmount:y})),f)},useWave=(a,c,u)=>{const{wave:d}=reactExports.useContext(ConfigContext),[,f,m]=useToken$1(),g=useEvent(E=>{const C=a.current;if(d!=null&&d.disabled||!C)return;const w=C.querySelector(`.${TARGET_CLS}`)||C,{showEffect:R}=d||{};(R||showWaveEffect)(w,{className:c,token:f,component:u,event:E,hashId:m})}),y=reactExports.useRef(null);return E=>{wrapperRaf.cancel(y.current),y.current=wrapperRaf(()=>{g(E)})}},Wave=a=>{const{children:c,disabled:u,component:d}=a,{getPrefixCls:f}=reactExports.useContext(ConfigContext),m=reactExports.useRef(null),g=f("wave"),[,y]=useStyle$u(g),b=useWave(m,classNames(g,y),d);if(React.useEffect(()=>{const C=m.current;if(!C||C.nodeType!==1||u)return;const w=R=>{!isVisible(R.target)||!C.getAttribute||C.getAttribute("disabled")||C.disabled||C.className.includes("disabled")||C.className.includes("-leave")||b(R)};return C.addEventListener("click",w,!0),()=>{C.removeEventListener("click",w,!0)}},[u]),!React.isValidElement(c))return c??null;const E=supportRef(c)?composeRef(getNodeRef(c),m):m;return cloneElement(c,{ref:E})},useSize=a=>{const c=React.useContext(SizeContext);return React.useMemo(()=>a?typeof a=="string"?a??c:typeof a=="function"?a(c):c:c,[a,c])},genSpaceCompactStyle=a=>{const{componentCls:c}=a;return{[c]:{"&-block":{display:"flex",width:"100%"},"&-vertical":{flexDirection:"column"}}}},genSpaceStyle=a=>{const{componentCls:c,antCls:u}=a;return{[c]:{display:"inline-flex","&-rtl":{direction:"rtl"},"&-vertical":{flexDirection:"column"},"&-align":{flexDirection:"column","&-center":{alignItems:"center"},"&-start":{alignItems:"flex-start"},"&-end":{alignItems:"flex-end"},"&-baseline":{alignItems:"baseline"}},[`${c}-item:empty`]:{display:"none"},[`${c}-item > ${u}-badge-not-a-wrapper:only-child`]:{display:"block"}}}},genSpaceGapStyle=a=>{const{componentCls:c}=a;return{[c]:{"&-gap-row-small":{rowGap:a.spaceGapSmallSize},"&-gap-row-middle":{rowGap:a.spaceGapMiddleSize},"&-gap-row-large":{rowGap:a.spaceGapLargeSize},"&-gap-col-small":{columnGap:a.spaceGapSmallSize},"&-gap-col-middle":{columnGap:a.spaceGapMiddleSize},"&-gap-col-large":{columnGap:a.spaceGapLargeSize}}}},useStyle$t=genStyleHooks("Space",a=>{const c=merge$2(a,{spaceGapSmallSize:a.paddingXS,spaceGapMiddleSize:a.padding,spaceGapLargeSize:a.paddingLG});return[genSpaceStyle(c),genSpaceGapStyle(c),genSpaceCompactStyle(c)]},()=>({}),{resetStyle:!1});var __rest$S=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const SpaceCompactItemContext=reactExports.createContext(null),useCompactItemContext=(a,c)=>{const u=reactExports.useContext(SpaceCompactItemContext),d=reactExports.useMemo(()=>{if(!u)return"";const{compactDirection:f,isFirstItem:m,isLastItem:g}=u,y=f==="vertical"?"-vertical-":"-";return classNames(`${a}-compact${y}item`,{[`${a}-compact${y}first-item`]:m,[`${a}-compact${y}last-item`]:g,[`${a}-compact${y}item-rtl`]:c==="rtl"})},[a,c,u]);return{compactSize:u==null?void 0:u.compactSize,compactDirection:u==null?void 0:u.compactDirection,compactItemClassnames:d}},NoCompactStyle=a=>{const{children:c}=a;return reactExports.createElement(SpaceCompactItemContext.Provider,{value:null},c)},CompactItem=a=>{const{children:c}=a,u=__rest$S(a,["children"]);return reactExports.createElement(SpaceCompactItemContext.Provider,{value:reactExports.useMemo(()=>u,[u])},c)},Compact$1=a=>{const{getPrefixCls:c,direction:u}=reactExports.useContext(ConfigContext),{size:d,direction:f,block:m,prefixCls:g,className:y,rootClassName:b,children:E}=a,C=__rest$S(a,["size","direction","block","prefixCls","className","rootClassName","children"]),w=useSize(z=>d??z),R=c("space-compact",g),[_,M]=useStyle$t(R),I=classNames(R,M,{[`${R}-rtl`]:u==="rtl",[`${R}-block`]:m,[`${R}-vertical`]:f==="vertical"},y,b),N=reactExports.useContext(SpaceCompactItemContext),A=toArray$6(E),P=reactExports.useMemo(()=>A.map((z,B)=>{const j=(z==null?void 0:z.key)||`${R}-item-${B}`;return reactExports.createElement(CompactItem,{key:j,compactSize:w,compactDirection:f,isFirstItem:B===0&&(!N||(N==null?void 0:N.isFirstItem)),isLastItem:B===A.length-1&&(!N||(N==null?void 0:N.isLastItem))},z)}),[d,A,N]);return A.length===0?null:_(reactExports.createElement("div",Object.assign({className:I},C),P))};var __rest$R=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const GroupSizeContext=reactExports.createContext(void 0),ButtonGroup=a=>{const{getPrefixCls:c,direction:u}=reactExports.useContext(ConfigContext),{prefixCls:d,size:f,className:m}=a,g=__rest$R(a,["prefixCls","size","className"]),y=c("btn-group",d),[,,b]=useToken$1(),E=reactExports.useMemo(()=>{switch(f){case"large":return"lg";case"small":return"sm";default:return""}},[f]),C=classNames(y,{[`${y}-${E}`]:E,[`${y}-rtl`]:u==="rtl"},m,b);return reactExports.createElement(GroupSizeContext.Provider,{value:f},reactExports.createElement("div",Object.assign({},g,{className:C})))},rxTwoCNChar=/^[\u4E00-\u9FA5]{2}$/,isTwoCNChar=rxTwoCNChar.test.bind(rxTwoCNChar);function convertLegacyProps(a){return a==="danger"?{danger:!0}:{type:a}}function isString$1(a){return typeof a=="string"}function isUnBorderedButtonVariant(a){return a==="text"||a==="link"}function splitCNCharsBySpace(a,c){if(a==null)return;const u=c?" ":"";return typeof a!="string"&&typeof a!="number"&&isString$1(a.type)&&isTwoCNChar(a.props.children)?cloneElement(a,{children:a.props.children.split("").join(u)}):isString$1(a)?isTwoCNChar(a)?React.createElement("span",null,a.split("").join(u)):React.createElement("span",null,a):isFragment(a)?React.createElement("span",null,a):a}function spaceChildren(a,c){let u=!1;const d=[];return React.Children.forEach(a,f=>{const m=typeof f,g=m==="string"||m==="number";if(u&&g){const y=d.length-1,b=d[y];d[y]=`${b}${f}`}else d.push(f);u=g}),React.Children.map(d,f=>splitCNCharsBySpace(f,c))}["default","primary","danger"].concat(_toConsumableArray(PresetColors));const IconWrapper=reactExports.forwardRef((a,c)=>{const{className:u,style:d,children:f,prefixCls:m}=a,g=classNames(`${m}-icon`,u);return React.createElement("span",{ref:c,className:g,style:d},f)}),InnerLoadingIcon=reactExports.forwardRef((a,c)=>{const{prefixCls:u,className:d,style:f,iconClassName:m}=a,g=classNames(`${u}-loading-icon`,d);return React.createElement(IconWrapper,{prefixCls:u,className:g,style:f,ref:c},React.createElement(RefIcon$e,{className:m}))}),getCollapsedWidth=()=>({width:0,opacity:0,transform:"scale(0)"}),getRealWidth=a=>({width:a.scrollWidth,opacity:1,transform:"scale(1)"}),DefaultLoadingIcon=a=>{const{prefixCls:c,loading:u,existIcon:d,className:f,style:m,mount:g}=a,y=!!u;return d?React.createElement(InnerLoadingIcon,{prefixCls:c,className:f,style:m}):React.createElement(CSSMotion,{visible:y,motionName:`${c}-loading-icon-motion`,motionAppear:!g,motionEnter:!g,motionLeave:!g,removeOnLeave:!0,onAppearStart:getCollapsedWidth,onAppearActive:getRealWidth,onEnterStart:getCollapsedWidth,onEnterActive:getRealWidth,onLeaveStart:getRealWidth,onLeaveActive:getCollapsedWidth},(b,E)=>{let{className:C,style:w}=b;const R=Object.assign(Object.assign({},m),w);return React.createElement(InnerLoadingIcon,{prefixCls:c,className:classNames(f,C),style:R,ref:E})})},genButtonBorderStyle=(a,c)=>({[`> span, > ${a}`]:{"&:not(:last-child)":{[`&, & > ${a}`]:{"&:not(:disabled)":{borderInlineEndColor:c}}},"&:not(:first-child)":{[`&, & > ${a}`]:{"&:not(:disabled)":{borderInlineStartColor:c}}}}}),genGroupStyle$1=a=>{const{componentCls:c,fontSize:u,lineWidth:d,groupBorderColor:f,colorErrorHover:m}=a;return{[`${c}-group`]:[{position:"relative",display:"inline-flex",[`> span, > ${c}`]:{"&:not(:last-child)":{[`&, & > ${c}`]:{borderStartEndRadius:0,borderEndEndRadius:0}},"&:not(:first-child)":{marginInlineStart:a.calc(d).mul(-1).equal(),[`&, & > ${c}`]:{borderStartStartRadius:0,borderEndStartRadius:0}}},[c]:{position:"relative",zIndex:1,"&:hover, &:focus, &:active":{zIndex:2},"&[disabled]":{zIndex:0}},[`${c}-icon-only`]:{fontSize:u}},genButtonBorderStyle(`${c}-primary`,f),genButtonBorderStyle(`${c}-danger`,m)]}};var _excluded$L=["b"],_excluded2$a=["v"],getRoundNumber=function(c){return Math.round(Number(c||0))},convertHsb2Hsv=function(c){if(c instanceof FastColor)return c;if(c&&_typeof(c)==="object"&&"h"in c&&"b"in c){var u=c,d=u.b,f=_objectWithoutProperties(u,_excluded$L);return _objectSpread2(_objectSpread2({},f),{},{v:d})}return typeof c=="string"&&/hsb/.test(c)?c.replace(/hsb/,"hsv"):c},Color=function(a){_inherits(u,a);var c=_createSuper(u);function u(d){return _classCallCheck(this,u),c.call(this,convertHsb2Hsv(d))}return _createClass(u,[{key:"toHsbString",value:function(){var f=this.toHsb(),m=getRoundNumber(f.s*100),g=getRoundNumber(f.b*100),y=getRoundNumber(f.h),b=f.a,E="hsb(".concat(y,", ").concat(m,"%, ").concat(g,"%)"),C="hsba(".concat(y,", ").concat(m,"%, ").concat(g,"%, ").concat(b.toFixed(b===0?0:2),")");return b===1?E:C}},{key:"toHsb",value:function(){var f=this.toHsv(),m=f.v,g=_objectWithoutProperties(f,_excluded2$a);return _objectSpread2(_objectSpread2({},g),{},{b:m,a:this.a})}}]),u}(FastColor),generateColor=function(c){return c instanceof Color?c:new Color(c)};generateColor("#1677ff");const toHexFormat=(a,c)=>(a==null?void 0:a.replace(/[^\w/]/g,"").slice(0,c?8:6))||"",getHex=(a,c)=>a?toHexFormat(a,c):"";let AggregationColor=function(){function a(c){_classCallCheck(this,a);var u;if(this.cleared=!1,c instanceof a){this.metaColor=c.metaColor.clone(),this.colors=(u=c.colors)===null||u===void 0?void 0:u.map(f=>({color:new a(f.color),percent:f.percent})),this.cleared=c.cleared;return}const d=Array.isArray(c);d&&c.length?(this.colors=c.map(f=>{let{color:m,percent:g}=f;return{color:new a(m),percent:g}}),this.metaColor=new Color(this.colors[0].color.metaColor)):this.metaColor=new Color(d?"":c),(!c||d&&!this.colors)&&(this.metaColor=this.metaColor.setA(0),this.cleared=!0)}return _createClass(a,[{key:"toHsb",value:function(){return this.metaColor.toHsb()}},{key:"toHsbString",value:function(){return this.metaColor.toHsbString()}},{key:"toHex",value:function(){return getHex(this.toHexString(),this.metaColor.a<1)}},{key:"toHexString",value:function(){return this.metaColor.toHexString()}},{key:"toRgb",value:function(){return this.metaColor.toRgb()}},{key:"toRgbString",value:function(){return this.metaColor.toRgbString()}},{key:"isGradient",value:function(){return!!this.colors&&!this.cleared}},{key:"getColors",value:function(){return this.colors||[{color:this,percent:0}]}},{key:"toCssString",value:function(){const{colors:u}=this;return u?`linear-gradient(90deg, ${u.map(f=>`${f.color.toRgbString()} ${f.percent}%`).join(", ")})`:this.metaColor.toRgbString()}},{key:"equals",value:function(u){return!u||this.isGradient()!==u.isGradient()?!1:this.isGradient()?this.colors.length===u.colors.length&&this.colors.every((d,f)=>{const m=u.colors[f];return d.percent===m.percent&&d.color.equals(m.color)}):this.toHexString()===u.toHexString()}}])}();var PanelContent=React.forwardRef(function(a,c){var u=a.prefixCls,d=a.forceRender,f=a.className,m=a.style,g=a.children,y=a.isActive,b=a.role,E=a.classNames,C=a.styles,w=React.useState(y||d),R=_slicedToArray(w,2),_=R[0],M=R[1];return React.useEffect(function(){(d||y)&&M(!0)},[d,y]),_?React.createElement("div",{ref:c,className:classNames("".concat(u,"-content"),_defineProperty(_defineProperty({},"".concat(u,"-content-active"),y),"".concat(u,"-content-inactive"),!y),f),style:m,role:b},React.createElement("div",{className:classNames("".concat(u,"-content-box"),E==null?void 0:E.body),style:C==null?void 0:C.body},g)):null});PanelContent.displayName="PanelContent";var _excluded$K=["showArrow","headerClass","isActive","onItemClick","forceRender","className","classNames","styles","prefixCls","collapsible","accordion","panelKey","extra","header","expandIcon","openMotion","destroyInactivePanel","children"],CollapsePanel$1=React.forwardRef(function(a,c){var u=a.showArrow,d=u===void 0?!0:u,f=a.headerClass,m=a.isActive,g=a.onItemClick,y=a.forceRender,b=a.className,E=a.classNames,C=E===void 0?{}:E,w=a.styles,R=w===void 0?{}:w,_=a.prefixCls,M=a.collapsible,I=a.accordion,N=a.panelKey,A=a.extra,P=a.header,z=a.expandIcon,B=a.openMotion,j=a.destroyInactivePanel,L=a.children,U=_objectWithoutProperties(a,_excluded$K),q=M==="disabled",F=A!=null&&typeof A!="boolean",K=_defineProperty(_defineProperty(_defineProperty({onClick:function(){g==null||g(N)},onKeyDown:function(G){(G.key==="Enter"||G.keyCode===KeyCode.ENTER||G.which===KeyCode.ENTER)&&(g==null||g(N))},role:I?"tab":"button"},"aria-expanded",m),"aria-disabled",q),"tabIndex",q?-1:0),X=typeof z=="function"?z(a):React.createElement("i",{className:"arrow"}),Q=X&&React.createElement("div",_extends({className:"".concat(_,"-expand-icon")},["header","icon"].includes(M)?K:{}),X),Y=classNames("".concat(_,"-item"),_defineProperty(_defineProperty({},"".concat(_,"-item-active"),m),"".concat(_,"-item-disabled"),q),b),Z=classNames(f,"".concat(_,"-header"),_defineProperty({},"".concat(_,"-collapsible-").concat(M),!!M),C.header),J=_objectSpread2({className:Z,style:R.header},["header","icon"].includes(M)?{}:K);return React.createElement("div",_extends({},U,{ref:c,className:Y}),React.createElement("div",J,d&&Q,React.createElement("span",_extends({className:"".concat(_,"-header-text")},M==="header"?K:{}),P),F&&React.createElement("div",{className:"".concat(_,"-extra")},A)),React.createElement(CSSMotion,_extends({visible:m,leavedClassName:"".concat(_,"-content-hidden")},B,{forceRender:y,removeOnLeave:j}),function(W,G){var te=W.className,ae=W.style;return React.createElement(PanelContent,{ref:G,prefixCls:_,className:te,classNames:C,style:ae,styles:R,isActive:m,forceRender:y,role:I?"tabpanel":void 0},L)}))}),_excluded$J=["children","label","key","collapsible","onItemClick","destroyInactivePanel"],convertItemsToNodes$1=function(c,u){var d=u.prefixCls,f=u.accordion,m=u.collapsible,g=u.destroyInactivePanel,y=u.onItemClick,b=u.activeKey,E=u.openMotion,C=u.expandIcon;return c.map(function(w,R){var _=w.children,M=w.label,I=w.key,N=w.collapsible,A=w.onItemClick,P=w.destroyInactivePanel,z=_objectWithoutProperties(w,_excluded$J),B=String(I??R),j=N??m,L=P??g,U=function(K){j!=="disabled"&&(y(K),A==null||A(K))},q=!1;return f?q=b[0]===B:q=b.indexOf(B)>-1,React.createElement(CollapsePanel$1,_extends({},z,{prefixCls:d,key:B,panelKey:B,isActive:q,accordion:f,openMotion:E,expandIcon:C,header:M,collapsible:j,onItemClick:U,destroyInactivePanel:L}),_)})},getNewChild=function(c,u,d){if(!c)return null;var f=d.prefixCls,m=d.accordion,g=d.collapsible,y=d.destroyInactivePanel,b=d.onItemClick,E=d.activeKey,C=d.openMotion,w=d.expandIcon,R=c.key||String(u),_=c.props,M=_.header,I=_.headerClass,N=_.destroyInactivePanel,A=_.collapsible,P=_.onItemClick,z=!1;m?z=E[0]===R:z=E.indexOf(R)>-1;var B=A??g,j=function(q){B!=="disabled"&&(b(q),P==null||P(q))},L={key:R,panelKey:R,header:M,headerClass:I,isActive:z,prefixCls:f,destroyInactivePanel:N??y,openMotion:C,accordion:m,children:c.props.children,onItemClick:j,expandIcon:w,collapsible:B};return typeof c.type=="string"?c:(Object.keys(L).forEach(function(U){typeof L[U]>"u"&&delete L[U]}),React.cloneElement(c,L))};function useItems(a,c,u){return Array.isArray(a)?convertItemsToNodes$1(a,u):toArray$6(c).map(function(d,f){return getNewChild(d,f,u)})}function getActiveKeysArray(a){var c=a;if(!Array.isArray(c)){var u=_typeof(c);c=u==="number"||u==="string"?[c]:[]}return c.map(function(d){return String(d)})}var Collapse$2=React.forwardRef(function(a,c){var u=a.prefixCls,d=u===void 0?"rc-collapse":u,f=a.destroyInactivePanel,m=f===void 0?!1:f,g=a.style,y=a.accordion,b=a.className,E=a.children,C=a.collapsible,w=a.openMotion,R=a.expandIcon,_=a.activeKey,M=a.defaultActiveKey,I=a.onChange,N=a.items,A=classNames(d,b),P=useMergedState([],{value:_,onChange:function(F){return I==null?void 0:I(F)},defaultValue:M,postState:getActiveKeysArray}),z=_slicedToArray(P,2),B=z[0],j=z[1],L=function(F){return j(function(){if(y)return B[0]===F?[]:[F];var K=B.indexOf(F),X=K>-1;return X?B.filter(function(Q){return Q!==F}):[].concat(_toConsumableArray(B),[F])})};warningOnce$1(!E,"[rc-collapse] `children` will be removed in next major version. Please use `items` instead.");var U=useItems(N,E,{prefixCls:d,accordion:y,openMotion:w,expandIcon:R,collapsible:C,destroyInactivePanel:m,onItemClick:L,activeKey:B});return React.createElement("div",_extends({ref:c,className:A,style:g,role:y?"tablist":void 0},pickAttrs(a,{aria:!0,data:!0})),U)});const Collapse$3=Object.assign(Collapse$2,{Panel:CollapsePanel$1});Collapse$3.Panel;const CollapsePanel=reactExports.forwardRef((a,c)=>{const{getPrefixCls:u}=reactExports.useContext(ConfigContext),{prefixCls:d,className:f,showArrow:m=!0}=a,g=u("collapse",d),y=classNames({[`${g}-no-arrow`]:!m},f);return reactExports.createElement(Collapse$3.Panel,Object.assign({ref:c},a,{prefixCls:g,className:y}))}),genCollapseMotion=a=>({[a.componentCls]:{[`${a.antCls}-motion-collapse-legacy`]:{overflow:"hidden","&-active":{transition:`height ${a.motionDurationMid} ${a.motionEaseInOut},
        opacity ${a.motionDurationMid} ${a.motionEaseInOut} !important`}},[`${a.antCls}-motion-collapse`]:{overflow:"hidden",transition:`height ${a.motionDurationMid} ${a.motionEaseInOut},
        opacity ${a.motionDurationMid} ${a.motionEaseInOut} !important`}}}),initMotionCommon=a=>({animationDuration:a,animationFillMode:"both"}),initMotionCommonLeave=a=>({animationDuration:a,animationFillMode:"both"}),initMotion=function(a,c,u,d){const m=(arguments.length>4&&arguments[4]!==void 0?arguments[4]:!1)?"&":"";return{[`
      ${m}${a}-enter,
      ${m}${a}-appear
    `]:Object.assign(Object.assign({},initMotionCommon(d)),{animationPlayState:"paused"}),[`${m}${a}-leave`]:Object.assign(Object.assign({},initMotionCommonLeave(d)),{animationPlayState:"paused"}),[`
      ${m}${a}-enter${a}-enter-active,
      ${m}${a}-appear${a}-appear-active
    `]:{animationName:c,animationPlayState:"running"},[`${m}${a}-leave${a}-leave-active`]:{animationName:u,animationPlayState:"running",pointerEvents:"none"}}},fadeIn=new Keyframe("antFadeIn",{"0%":{opacity:0},"100%":{opacity:1}}),fadeOut=new Keyframe("antFadeOut",{"0%":{opacity:1},"100%":{opacity:0}}),initFadeMotion=function(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;const{antCls:u}=a,d=`${u}-fade`,f=c?"&":"";return[initMotion(d,fadeIn,fadeOut,a.motionDurationMid,c),{[`
        ${f}${d}-enter,
        ${f}${d}-appear
      `]:{opacity:0,animationTimingFunction:"linear"},[`${f}${d}-leave`]:{animationTimingFunction:"linear"}}]},moveDownIn=new Keyframe("antMoveDownIn",{"0%":{transform:"translate3d(0, 100%, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),moveDownOut=new Keyframe("antMoveDownOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(0, 100%, 0)",transformOrigin:"0 0",opacity:0}}),moveLeftIn=new Keyframe("antMoveLeftIn",{"0%":{transform:"translate3d(-100%, 0, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),moveLeftOut=new Keyframe("antMoveLeftOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(-100%, 0, 0)",transformOrigin:"0 0",opacity:0}}),moveRightIn=new Keyframe("antMoveRightIn",{"0%":{transform:"translate3d(100%, 0, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),moveRightOut=new Keyframe("antMoveRightOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(100%, 0, 0)",transformOrigin:"0 0",opacity:0}}),moveUpIn=new Keyframe("antMoveUpIn",{"0%":{transform:"translate3d(0, -100%, 0)",transformOrigin:"0 0",opacity:0},"100%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1}}),moveUpOut=new Keyframe("antMoveUpOut",{"0%":{transform:"translate3d(0, 0, 0)",transformOrigin:"0 0",opacity:1},"100%":{transform:"translate3d(0, -100%, 0)",transformOrigin:"0 0",opacity:0}}),moveMotion={"move-up":{inKeyframes:moveUpIn,outKeyframes:moveUpOut},"move-down":{inKeyframes:moveDownIn,outKeyframes:moveDownOut},"move-left":{inKeyframes:moveLeftIn,outKeyframes:moveLeftOut},"move-right":{inKeyframes:moveRightIn,outKeyframes:moveRightOut}},initMoveMotion=(a,c)=>{const{antCls:u}=a,d=`${u}-${c}`,{inKeyframes:f,outKeyframes:m}=moveMotion[c];return[initMotion(d,f,m,a.motionDurationMid),{[`
        ${d}-enter,
        ${d}-appear
      `]:{opacity:0,animationTimingFunction:a.motionEaseOutCirc},[`${d}-leave`]:{animationTimingFunction:a.motionEaseInOutCirc}}]},slideUpIn=new Keyframe("antSlideUpIn",{"0%":{transform:"scaleY(0.8)",transformOrigin:"0% 0%",opacity:0},"100%":{transform:"scaleY(1)",transformOrigin:"0% 0%",opacity:1}}),slideUpOut=new Keyframe("antSlideUpOut",{"0%":{transform:"scaleY(1)",transformOrigin:"0% 0%",opacity:1},"100%":{transform:"scaleY(0.8)",transformOrigin:"0% 0%",opacity:0}}),slideDownIn=new Keyframe("antSlideDownIn",{"0%":{transform:"scaleY(0.8)",transformOrigin:"100% 100%",opacity:0},"100%":{transform:"scaleY(1)",transformOrigin:"100% 100%",opacity:1}}),slideDownOut=new Keyframe("antSlideDownOut",{"0%":{transform:"scaleY(1)",transformOrigin:"100% 100%",opacity:1},"100%":{transform:"scaleY(0.8)",transformOrigin:"100% 100%",opacity:0}}),slideLeftIn=new Keyframe("antSlideLeftIn",{"0%":{transform:"scaleX(0.8)",transformOrigin:"0% 0%",opacity:0},"100%":{transform:"scaleX(1)",transformOrigin:"0% 0%",opacity:1}}),slideLeftOut=new Keyframe("antSlideLeftOut",{"0%":{transform:"scaleX(1)",transformOrigin:"0% 0%",opacity:1},"100%":{transform:"scaleX(0.8)",transformOrigin:"0% 0%",opacity:0}}),slideRightIn=new Keyframe("antSlideRightIn",{"0%":{transform:"scaleX(0.8)",transformOrigin:"100% 0%",opacity:0},"100%":{transform:"scaleX(1)",transformOrigin:"100% 0%",opacity:1}}),slideRightOut=new Keyframe("antSlideRightOut",{"0%":{transform:"scaleX(1)",transformOrigin:"100% 0%",opacity:1},"100%":{transform:"scaleX(0.8)",transformOrigin:"100% 0%",opacity:0}}),slideMotion={"slide-up":{inKeyframes:slideUpIn,outKeyframes:slideUpOut},"slide-down":{inKeyframes:slideDownIn,outKeyframes:slideDownOut},"slide-left":{inKeyframes:slideLeftIn,outKeyframes:slideLeftOut},"slide-right":{inKeyframes:slideRightIn,outKeyframes:slideRightOut}},initSlideMotion=(a,c)=>{const{antCls:u}=a,d=`${u}-${c}`,{inKeyframes:f,outKeyframes:m}=slideMotion[c];return[initMotion(d,f,m,a.motionDurationMid),{[`
      ${d}-enter,
      ${d}-appear
    `]:{transform:"scale(0)",transformOrigin:"0% 0%",opacity:0,animationTimingFunction:a.motionEaseOutQuint,"&-prepare":{transform:"scale(1)"}},[`${d}-leave`]:{animationTimingFunction:a.motionEaseInQuint}}]},zoomIn=new Keyframe("antZoomIn",{"0%":{transform:"scale(0.2)",opacity:0},"100%":{transform:"scale(1)",opacity:1}}),zoomOut=new Keyframe("antZoomOut",{"0%":{transform:"scale(1)"},"100%":{transform:"scale(0.2)",opacity:0}}),zoomBigIn=new Keyframe("antZoomBigIn",{"0%":{transform:"scale(0.8)",opacity:0},"100%":{transform:"scale(1)",opacity:1}}),zoomBigOut=new Keyframe("antZoomBigOut",{"0%":{transform:"scale(1)"},"100%":{transform:"scale(0.8)",opacity:0}}),zoomUpIn=new Keyframe("antZoomUpIn",{"0%":{transform:"scale(0.8)",transformOrigin:"50% 0%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"50% 0%"}}),zoomUpOut=new Keyframe("antZoomUpOut",{"0%":{transform:"scale(1)",transformOrigin:"50% 0%"},"100%":{transform:"scale(0.8)",transformOrigin:"50% 0%",opacity:0}}),zoomLeftIn=new Keyframe("antZoomLeftIn",{"0%":{transform:"scale(0.8)",transformOrigin:"0% 50%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"0% 50%"}}),zoomLeftOut=new Keyframe("antZoomLeftOut",{"0%":{transform:"scale(1)",transformOrigin:"0% 50%"},"100%":{transform:"scale(0.8)",transformOrigin:"0% 50%",opacity:0}}),zoomRightIn=new Keyframe("antZoomRightIn",{"0%":{transform:"scale(0.8)",transformOrigin:"100% 50%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"100% 50%"}}),zoomRightOut=new Keyframe("antZoomRightOut",{"0%":{transform:"scale(1)",transformOrigin:"100% 50%"},"100%":{transform:"scale(0.8)",transformOrigin:"100% 50%",opacity:0}}),zoomDownIn=new Keyframe("antZoomDownIn",{"0%":{transform:"scale(0.8)",transformOrigin:"50% 100%",opacity:0},"100%":{transform:"scale(1)",transformOrigin:"50% 100%"}}),zoomDownOut=new Keyframe("antZoomDownOut",{"0%":{transform:"scale(1)",transformOrigin:"50% 100%"},"100%":{transform:"scale(0.8)",transformOrigin:"50% 100%",opacity:0}}),zoomMotion={zoom:{inKeyframes:zoomIn,outKeyframes:zoomOut},"zoom-big":{inKeyframes:zoomBigIn,outKeyframes:zoomBigOut},"zoom-big-fast":{inKeyframes:zoomBigIn,outKeyframes:zoomBigOut},"zoom-left":{inKeyframes:zoomLeftIn,outKeyframes:zoomLeftOut},"zoom-right":{inKeyframes:zoomRightIn,outKeyframes:zoomRightOut},"zoom-up":{inKeyframes:zoomUpIn,outKeyframes:zoomUpOut},"zoom-down":{inKeyframes:zoomDownIn,outKeyframes:zoomDownOut}},initZoomMotion=(a,c)=>{const{antCls:u}=a,d=`${u}-${c}`,{inKeyframes:f,outKeyframes:m}=zoomMotion[c];return[initMotion(d,f,m,c==="zoom-big-fast"?a.motionDurationFast:a.motionDurationMid),{[`
        ${d}-enter,
        ${d}-appear
      `]:{transform:"scale(0)",opacity:0,animationTimingFunction:a.motionEaseOutCirc,"&-prepare":{transform:"none"}},[`${d}-leave`]:{animationTimingFunction:a.motionEaseInOutCirc}}]},genBaseStyle$7=a=>{const{componentCls:c,contentBg:u,padding:d,headerBg:f,headerPadding:m,collapseHeaderPaddingSM:g,collapseHeaderPaddingLG:y,collapsePanelBorderRadius:b,lineWidth:E,lineType:C,colorBorder:w,colorText:R,colorTextHeading:_,colorTextDisabled:M,fontSizeLG:I,lineHeight:N,lineHeightLG:A,marginSM:P,paddingSM:z,paddingLG:B,paddingXS:j,motionDurationSlow:L,fontSizeIcon:U,contentPadding:q,fontHeight:F,fontHeightLG:K}=a,X=`${unit$1(E)} ${C} ${w}`;return{[c]:Object.assign(Object.assign({},resetComponent(a)),{backgroundColor:f,border:X,borderRadius:b,"&-rtl":{direction:"rtl"},[`& > ${c}-item`]:{borderBottom:X,"&:first-child":{[`
            &,
            & > ${c}-header`]:{borderRadius:`${unit$1(b)} ${unit$1(b)} 0 0`}},"&:last-child":{[`
            &,
            & > ${c}-header`]:{borderRadius:`0 0 ${unit$1(b)} ${unit$1(b)}`}},[`> ${c}-header`]:Object.assign(Object.assign({position:"relative",display:"flex",flexWrap:"nowrap",alignItems:"flex-start",padding:m,color:_,lineHeight:N,cursor:"pointer",transition:`all ${L}, visibility 0s`},genFocusStyle(a)),{[`> ${c}-header-text`]:{flex:"auto"},[`${c}-expand-icon`]:{height:F,display:"flex",alignItems:"center",paddingInlineEnd:P},[`${c}-arrow`]:Object.assign(Object.assign({},resetIcon()),{fontSize:U,transition:`transform ${L}`,svg:{transition:`transform ${L}`}}),[`${c}-header-text`]:{marginInlineEnd:"auto"}}),[`${c}-collapsible-header`]:{cursor:"default",[`${c}-header-text`]:{flex:"none",cursor:"pointer"}},[`${c}-collapsible-icon`]:{cursor:"unset",[`${c}-expand-icon`]:{cursor:"pointer"}}},[`${c}-content`]:{color:R,backgroundColor:u,borderTop:X,[`& > ${c}-content-box`]:{padding:q},"&-hidden":{display:"none"}},"&-small":{[`> ${c}-item`]:{[`> ${c}-header`]:{padding:g,paddingInlineStart:j,[`> ${c}-expand-icon`]:{marginInlineStart:a.calc(z).sub(j).equal()}},[`> ${c}-content > ${c}-content-box`]:{padding:z}}},"&-large":{[`> ${c}-item`]:{fontSize:I,lineHeight:A,[`> ${c}-header`]:{padding:y,paddingInlineStart:d,[`> ${c}-expand-icon`]:{height:K,marginInlineStart:a.calc(B).sub(d).equal()}},[`> ${c}-content > ${c}-content-box`]:{padding:B}}},[`${c}-item:last-child`]:{borderBottom:0,[`> ${c}-content`]:{borderRadius:`0 0 ${unit$1(b)} ${unit$1(b)}`}},[`& ${c}-item-disabled > ${c}-header`]:{"\n          &,\n          & > .arrow\n        ":{color:M,cursor:"not-allowed"}},[`&${c}-icon-position-end`]:{[`& > ${c}-item`]:{[`> ${c}-header`]:{[`${c}-expand-icon`]:{order:1,paddingInlineEnd:0,paddingInlineStart:P}}}}})}},genArrowStyle=a=>{const{componentCls:c}=a,u=`> ${c}-item > ${c}-header ${c}-arrow`;return{[`${c}-rtl`]:{[u]:{transform:"rotate(180deg)"}}}},genBorderlessStyle$2=a=>{const{componentCls:c,headerBg:u,paddingXXS:d,colorBorder:f}=a;return{[`${c}-borderless`]:{backgroundColor:u,border:0,[`> ${c}-item`]:{borderBottom:`1px solid ${f}`},[`
        > ${c}-item:last-child,
        > ${c}-item:last-child ${c}-header
      `]:{borderRadius:0},[`> ${c}-item:last-child`]:{borderBottom:0},[`> ${c}-item > ${c}-content`]:{backgroundColor:"transparent",borderTop:0},[`> ${c}-item > ${c}-content > ${c}-content-box`]:{paddingTop:d}}}},genGhostStyle=a=>{const{componentCls:c,paddingSM:u}=a;return{[`${c}-ghost`]:{backgroundColor:"transparent",border:0,[`> ${c}-item`]:{borderBottom:0,[`> ${c}-content`]:{backgroundColor:"transparent",border:0,[`> ${c}-content-box`]:{paddingBlock:u}}}}}},prepareComponentToken$n=a=>({headerPadding:`${a.paddingSM}px ${a.padding}px`,headerBg:a.colorFillAlter,contentPadding:`${a.padding}px 16px`,contentBg:a.colorBgContainer}),useStyle$s=genStyleHooks("Collapse",a=>{const c=merge$2(a,{collapseHeaderPaddingSM:`${unit$1(a.paddingXS)} ${unit$1(a.paddingSM)}`,collapseHeaderPaddingLG:`${unit$1(a.padding)} ${unit$1(a.paddingLG)}`,collapsePanelBorderRadius:a.borderRadiusLG});return[genBaseStyle$7(c),genBorderlessStyle$2(c),genGhostStyle(c),genArrowStyle(c),genCollapseMotion(c)]},prepareComponentToken$n),Collapse=reactExports.forwardRef((a,c)=>{const{getPrefixCls:u,direction:d,expandIcon:f,className:m,style:g}=useComponentConfig("collapse"),{prefixCls:y,className:b,rootClassName:E,style:C,bordered:w=!0,ghost:R,size:_,expandIconPosition:M="start",children:I,expandIcon:N}=a,A=useSize(Y=>{var Z;return(Z=_??Y)!==null&&Z!==void 0?Z:"middle"}),P=u("collapse",y),z=u(),[B,j,L]=useStyle$s(P),U=reactExports.useMemo(()=>M==="left"?"start":M==="right"?"end":M,[M]),q=N??f,F=reactExports.useCallback(function(){let Y=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{};const Z=typeof q=="function"?q(Y):reactExports.createElement(RefIcon$8,{rotate:Y.isActive?d==="rtl"?-90:90:void 0,"aria-label":Y.isActive?"expanded":"collapsed"});return cloneElement(Z,()=>{var J;return{className:classNames((J=Z==null?void 0:Z.props)===null||J===void 0?void 0:J.className,`${P}-arrow`)}})},[q,P]),K=classNames(`${P}-icon-position-${U}`,{[`${P}-borderless`]:!w,[`${P}-rtl`]:d==="rtl",[`${P}-ghost`]:!!R,[`${P}-${A}`]:A!=="middle"},m,b,E,j,L),X=Object.assign(Object.assign({},initCollapseMotion(z)),{motionAppear:!1,leavedClassName:`${P}-content-hidden`}),Q=reactExports.useMemo(()=>I?toArray$6(I).map((Y,Z)=>{var J,W;const G=Y.props;if(G!=null&&G.disabled){const te=(J=Y.key)!==null&&J!==void 0?J:String(Z),ae=Object.assign(Object.assign({},omit(Y.props,["disabled"])),{key:te,collapsible:(W=G.collapsible)!==null&&W!==void 0?W:"disabled"});return cloneElement(Y,ae)}return Y}):null,[I]);return B(reactExports.createElement(Collapse$3,Object.assign({ref:c,openMotion:X},omit(a,["rootClassName"]),{expandIcon:F,prefixCls:P,className:K,style:Object.assign(Object.assign({},g),C)}),Q))}),Collapse$1=Object.assign(Collapse,{Panel:CollapsePanel}),isBright=(a,c)=>{const{r:u,g:d,b:f,a:m}=a.toRgb(),g=new Color(a.toRgbString()).onBackground(c).toHsv();return m<=.5?g.v>.5:u*.299+d*.587+f*.114>192},prepareToken$4=a=>{const{paddingInline:c,onlyIconSize:u}=a;return merge$2(a,{buttonPaddingHorizontal:c,buttonPaddingVertical:0,buttonIconOnlyFontSize:u})},prepareComponentToken$m=a=>{var c,u,d,f,m,g;const y=(c=a.contentFontSize)!==null&&c!==void 0?c:a.fontSize,b=(u=a.contentFontSizeSM)!==null&&u!==void 0?u:a.fontSize,E=(d=a.contentFontSizeLG)!==null&&d!==void 0?d:a.fontSizeLG,C=(f=a.contentLineHeight)!==null&&f!==void 0?f:getLineHeight(y),w=(m=a.contentLineHeightSM)!==null&&m!==void 0?m:getLineHeight(b),R=(g=a.contentLineHeightLG)!==null&&g!==void 0?g:getLineHeight(E),_=isBright(new AggregationColor(a.colorBgSolid),"#fff")?"#000":"#fff",M=PresetColors.reduce((I,N)=>Object.assign(Object.assign({},I),{[`${N}ShadowColor`]:`0 ${unit$1(a.controlOutlineWidth)} 0 ${getAlphaColor$1(a[`${N}1`],a.colorBgContainer)}`}),{});return Object.assign(Object.assign({},M),{fontWeight:400,defaultShadow:`0 ${a.controlOutlineWidth}px 0 ${a.controlTmpOutline}`,primaryShadow:`0 ${a.controlOutlineWidth}px 0 ${a.controlOutline}`,dangerShadow:`0 ${a.controlOutlineWidth}px 0 ${a.colorErrorOutline}`,primaryColor:a.colorTextLightSolid,dangerColor:a.colorTextLightSolid,borderColorDisabled:a.colorBorder,defaultGhostColor:a.colorBgContainer,ghostBg:"transparent",defaultGhostBorderColor:a.colorBgContainer,paddingInline:a.paddingContentHorizontal-a.lineWidth,paddingInlineLG:a.paddingContentHorizontal-a.lineWidth,paddingInlineSM:8-a.lineWidth,onlyIconSize:"inherit",onlyIconSizeSM:"inherit",onlyIconSizeLG:"inherit",groupBorderColor:a.colorPrimaryHover,linkHoverBg:"transparent",textTextColor:a.colorText,textTextHoverColor:a.colorText,textTextActiveColor:a.colorText,textHoverBg:a.colorFillTertiary,defaultColor:a.colorText,defaultBg:a.colorBgContainer,defaultBorderColor:a.colorBorder,defaultBorderColorDisabled:a.colorBorder,defaultHoverBg:a.colorBgContainer,defaultHoverColor:a.colorPrimaryHover,defaultHoverBorderColor:a.colorPrimaryHover,defaultActiveBg:a.colorBgContainer,defaultActiveColor:a.colorPrimaryActive,defaultActiveBorderColor:a.colorPrimaryActive,solidTextColor:_,contentFontSize:y,contentFontSizeSM:b,contentFontSizeLG:E,contentLineHeight:C,contentLineHeightSM:w,contentLineHeightLG:R,paddingBlock:Math.max((a.controlHeight-y*C)/2-a.lineWidth,0),paddingBlockSM:Math.max((a.controlHeightSM-b*w)/2-a.lineWidth,0),paddingBlockLG:Math.max((a.controlHeightLG-E*R)/2-a.lineWidth,0)})},genSharedButtonStyle=a=>{const{componentCls:c,iconCls:u,fontWeight:d,opacityLoading:f,motionDurationSlow:m,motionEaseInOut:g,marginXS:y,calc:b}=a;return{[c]:{outline:"none",position:"relative",display:"inline-flex",gap:a.marginXS,alignItems:"center",justifyContent:"center",fontWeight:d,whiteSpace:"nowrap",textAlign:"center",backgroundImage:"none",background:"transparent",border:`${unit$1(a.lineWidth)} ${a.lineType} transparent`,cursor:"pointer",transition:`all ${a.motionDurationMid} ${a.motionEaseInOut}`,userSelect:"none",touchAction:"manipulation",color:a.colorText,"&:disabled > *":{pointerEvents:"none"},[`${c}-icon > svg`]:resetIcon(),"> a":{color:"currentColor"},"&:not(:disabled)":genFocusStyle(a),[`&${c}-two-chinese-chars::first-letter`]:{letterSpacing:"0.34em"},[`&${c}-two-chinese-chars > *:not(${u})`]:{marginInlineEnd:"-0.34em",letterSpacing:"0.34em"},[`&${c}-icon-only`]:{paddingInline:0,[`&${c}-compact-item`]:{flex:"none"},[`&${c}-round`]:{width:"auto"}},[`&${c}-loading`]:{opacity:f,cursor:"default"},[`${c}-loading-icon`]:{transition:["width","opacity","margin"].map(E=>`${E} ${m} ${g}`).join(",")},[`&:not(${c}-icon-end)`]:{[`${c}-loading-icon-motion`]:{"&-appear-start, &-enter-start":{marginInlineEnd:b(y).mul(-1).equal()},"&-appear-active, &-enter-active":{marginInlineEnd:0},"&-leave-start":{marginInlineEnd:0},"&-leave-active":{marginInlineEnd:b(y).mul(-1).equal()}}},"&-icon-end":{flexDirection:"row-reverse",[`${c}-loading-icon-motion`]:{"&-appear-start, &-enter-start":{marginInlineStart:b(y).mul(-1).equal()},"&-appear-active, &-enter-active":{marginInlineStart:0},"&-leave-start":{marginInlineStart:0},"&-leave-active":{marginInlineStart:b(y).mul(-1).equal()}}}}}},genHoverActiveButtonStyle=(a,c,u)=>({[`&:not(:disabled):not(${a}-disabled)`]:{"&:hover":c,"&:active":u}}),genCircleButtonStyle=a=>({minWidth:a.controlHeight,paddingInlineStart:0,paddingInlineEnd:0,borderRadius:"50%"}),genRoundButtonStyle=a=>({borderRadius:a.controlHeight,paddingInlineStart:a.calc(a.controlHeight).div(2).equal(),paddingInlineEnd:a.calc(a.controlHeight).div(2).equal()}),genDisabledStyle$1=a=>({cursor:"not-allowed",borderColor:a.borderColorDisabled,color:a.colorTextDisabled,background:a.colorBgContainerDisabled,boxShadow:"none"}),genGhostButtonStyle=(a,c,u,d,f,m,g,y)=>({[`&${a}-background-ghost`]:Object.assign(Object.assign({color:u||void 0,background:c,borderColor:d||void 0,boxShadow:"none"},genHoverActiveButtonStyle(a,Object.assign({background:c},g),Object.assign({background:c},y))),{"&:disabled":{cursor:"not-allowed",color:f||void 0,borderColor:m||void 0}})}),genSolidDisabledButtonStyle=a=>({[`&:disabled, &${a.componentCls}-disabled`]:Object.assign({},genDisabledStyle$1(a))}),genPureDisabledButtonStyle=a=>({[`&:disabled, &${a.componentCls}-disabled`]:{cursor:"not-allowed",color:a.colorTextDisabled}}),genVariantButtonStyle=(a,c,u,d)=>{const m=d&&["link","text"].includes(d)?genPureDisabledButtonStyle:genSolidDisabledButtonStyle;return Object.assign(Object.assign({},m(a)),genHoverActiveButtonStyle(a.componentCls,c,u))},genSolidButtonStyle=(a,c,u,d,f)=>({[`&${a.componentCls}-variant-solid`]:Object.assign({color:c,background:u},genVariantButtonStyle(a,d,f))}),genOutlinedDashedButtonStyle=(a,c,u,d,f)=>({[`&${a.componentCls}-variant-outlined, &${a.componentCls}-variant-dashed`]:Object.assign({borderColor:c,background:u},genVariantButtonStyle(a,d,f))}),genDashedButtonStyle=a=>({[`&${a.componentCls}-variant-dashed`]:{borderStyle:"dashed"}}),genFilledButtonStyle=(a,c,u,d)=>({[`&${a.componentCls}-variant-filled`]:Object.assign({boxShadow:"none",background:c},genVariantButtonStyle(a,u,d))}),genTextLinkButtonStyle=(a,c,u,d,f)=>({[`&${a.componentCls}-variant-${u}`]:Object.assign({color:c,boxShadow:"none"},genVariantButtonStyle(a,d,f,u))}),genPresetColorStyle=a=>{const{componentCls:c}=a;return PresetColors.reduce((u,d)=>{const f=a[`${d}6`],m=a[`${d}1`],g=a[`${d}5`],y=a[`${d}2`],b=a[`${d}3`],E=a[`${d}7`];return Object.assign(Object.assign({},u),{[`&${c}-color-${d}`]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:f,boxShadow:a[`${d}ShadowColor`]},genSolidButtonStyle(a,a.colorTextLightSolid,f,{background:g},{background:E})),genOutlinedDashedButtonStyle(a,f,a.colorBgContainer,{color:g,borderColor:g,background:a.colorBgContainer},{color:E,borderColor:E,background:a.colorBgContainer})),genDashedButtonStyle(a)),genFilledButtonStyle(a,m,{background:y},{background:b})),genTextLinkButtonStyle(a,f,"link",{color:g},{color:E})),genTextLinkButtonStyle(a,f,"text",{color:g,background:m},{color:E,background:b}))})},{})},genDefaultButtonStyle=a=>Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:a.defaultColor,boxShadow:a.defaultShadow},genSolidButtonStyle(a,a.solidTextColor,a.colorBgSolid,{color:a.solidTextColor,background:a.colorBgSolidHover},{color:a.solidTextColor,background:a.colorBgSolidActive})),genDashedButtonStyle(a)),genFilledButtonStyle(a,a.colorFillTertiary,{background:a.colorFillSecondary},{background:a.colorFill})),genGhostButtonStyle(a.componentCls,a.ghostBg,a.defaultGhostColor,a.defaultGhostBorderColor,a.colorTextDisabled,a.colorBorder)),genTextLinkButtonStyle(a,a.textTextColor,"link",{color:a.colorLinkHover,background:a.linkHoverBg},{color:a.colorLinkActive})),genPrimaryButtonStyle=a=>Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:a.colorPrimary,boxShadow:a.primaryShadow},genOutlinedDashedButtonStyle(a,a.colorPrimary,a.colorBgContainer,{color:a.colorPrimaryTextHover,borderColor:a.colorPrimaryHover,background:a.colorBgContainer},{color:a.colorPrimaryTextActive,borderColor:a.colorPrimaryActive,background:a.colorBgContainer})),genDashedButtonStyle(a)),genFilledButtonStyle(a,a.colorPrimaryBg,{background:a.colorPrimaryBgHover},{background:a.colorPrimaryBorder})),genTextLinkButtonStyle(a,a.colorPrimaryText,"text",{color:a.colorPrimaryTextHover,background:a.colorPrimaryBg},{color:a.colorPrimaryTextActive,background:a.colorPrimaryBorder})),genTextLinkButtonStyle(a,a.colorPrimaryText,"link",{color:a.colorPrimaryTextHover,background:a.linkHoverBg},{color:a.colorPrimaryTextActive})),genGhostButtonStyle(a.componentCls,a.ghostBg,a.colorPrimary,a.colorPrimary,a.colorTextDisabled,a.colorBorder,{color:a.colorPrimaryHover,borderColor:a.colorPrimaryHover},{color:a.colorPrimaryActive,borderColor:a.colorPrimaryActive})),genDangerousStyle=a=>Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:a.colorError,boxShadow:a.dangerShadow},genSolidButtonStyle(a,a.dangerColor,a.colorError,{background:a.colorErrorHover},{background:a.colorErrorActive})),genOutlinedDashedButtonStyle(a,a.colorError,a.colorBgContainer,{color:a.colorErrorHover,borderColor:a.colorErrorBorderHover},{color:a.colorErrorActive,borderColor:a.colorErrorActive})),genDashedButtonStyle(a)),genFilledButtonStyle(a,a.colorErrorBg,{background:a.colorErrorBgFilledHover},{background:a.colorErrorBgActive})),genTextLinkButtonStyle(a,a.colorError,"text",{color:a.colorErrorHover,background:a.colorErrorBg},{color:a.colorErrorHover,background:a.colorErrorBgActive})),genTextLinkButtonStyle(a,a.colorError,"link",{color:a.colorErrorHover},{color:a.colorErrorActive})),genGhostButtonStyle(a.componentCls,a.ghostBg,a.colorError,a.colorError,a.colorTextDisabled,a.colorBorder,{color:a.colorErrorHover,borderColor:a.colorErrorHover},{color:a.colorErrorActive,borderColor:a.colorErrorActive})),genLinkStyle=a=>Object.assign(Object.assign({},genTextLinkButtonStyle(a,a.colorLink,"link",{color:a.colorLinkHover},{color:a.colorLinkActive})),genGhostButtonStyle(a.componentCls,a.ghostBg,a.colorInfo,a.colorInfo,a.colorTextDisabled,a.colorBorder,{color:a.colorInfoHover,borderColor:a.colorInfoHover},{color:a.colorInfoActive,borderColor:a.colorInfoActive})),genColorButtonStyle=a=>{const{componentCls:c}=a;return Object.assign({[`${c}-color-default`]:genDefaultButtonStyle(a),[`${c}-color-primary`]:genPrimaryButtonStyle(a),[`${c}-color-dangerous`]:genDangerousStyle(a),[`${c}-color-link`]:genLinkStyle(a)},genPresetColorStyle(a))},genCompatibleButtonStyle=a=>Object.assign(Object.assign(Object.assign(Object.assign({},genOutlinedDashedButtonStyle(a,a.defaultBorderColor,a.defaultBg,{color:a.defaultHoverColor,borderColor:a.defaultHoverBorderColor,background:a.defaultHoverBg},{color:a.defaultActiveColor,borderColor:a.defaultActiveBorderColor,background:a.defaultActiveBg})),genTextLinkButtonStyle(a,a.textTextColor,"text",{color:a.textTextHoverColor,background:a.textHoverBg},{color:a.textTextActiveColor,background:a.colorBgTextActive})),genSolidButtonStyle(a,a.primaryColor,a.colorPrimary,{background:a.colorPrimaryHover,color:a.primaryColor},{background:a.colorPrimaryActive,color:a.primaryColor})),genTextLinkButtonStyle(a,a.colorLink,"link",{color:a.colorLinkHover,background:a.linkHoverBg},{color:a.colorLinkActive})),genButtonStyle=function(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";const{componentCls:u,controlHeight:d,fontSize:f,borderRadius:m,buttonPaddingHorizontal:g,iconCls:y,buttonPaddingVertical:b,buttonIconOnlyFontSize:E}=a;return[{[c]:{fontSize:f,height:d,padding:`${unit$1(b)} ${unit$1(g)}`,borderRadius:m,[`&${u}-icon-only`]:{width:d,[y]:{fontSize:E}}}},{[`${u}${u}-circle${c}`]:genCircleButtonStyle(a)},{[`${u}${u}-round${c}`]:genRoundButtonStyle(a)}]},genSizeBaseButtonStyle=a=>{const c=merge$2(a,{fontSize:a.contentFontSize});return genButtonStyle(c,a.componentCls)},genSizeSmallButtonStyle=a=>{const c=merge$2(a,{controlHeight:a.controlHeightSM,fontSize:a.contentFontSizeSM,padding:a.paddingXS,buttonPaddingHorizontal:a.paddingInlineSM,buttonPaddingVertical:0,borderRadius:a.borderRadiusSM,buttonIconOnlyFontSize:a.onlyIconSizeSM});return genButtonStyle(c,`${a.componentCls}-sm`)},genSizeLargeButtonStyle=a=>{const c=merge$2(a,{controlHeight:a.controlHeightLG,fontSize:a.contentFontSizeLG,buttonPaddingHorizontal:a.paddingInlineLG,buttonPaddingVertical:0,borderRadius:a.borderRadiusLG,buttonIconOnlyFontSize:a.onlyIconSizeLG});return genButtonStyle(c,`${a.componentCls}-lg`)},genBlockButtonStyle=a=>{const{componentCls:c}=a;return{[c]:{[`&${c}-block`]:{width:"100%"}}}},useStyle$r=genStyleHooks("Button",a=>{const c=prepareToken$4(a);return[genSharedButtonStyle(c),genSizeBaseButtonStyle(c),genSizeSmallButtonStyle(c),genSizeLargeButtonStyle(c),genBlockButtonStyle(c),genColorButtonStyle(c),genCompatibleButtonStyle(c),genGroupStyle$1(c)]},prepareComponentToken$m,{unitless:{fontWeight:!0,contentLineHeight:!0,contentLineHeightSM:!0,contentLineHeightLG:!0}});function compactItemBorder(a,c,u){const{focusElCls:d,focus:f,borderElCls:m}=u,g=m?"> *":"",y=["hover",f?"focus":null,"active"].filter(Boolean).map(b=>`&:${b} ${g}`).join(",");return{[`&-item:not(${c}-last-item)`]:{marginInlineEnd:a.calc(a.lineWidth).mul(-1).equal()},"&-item":Object.assign(Object.assign({[y]:{zIndex:2}},d?{[`&${d}`]:{zIndex:2}}:{}),{[`&[disabled] ${g}`]:{zIndex:0}})}}function compactItemBorderRadius(a,c,u){const{borderElCls:d}=u,f=d?`> ${d}`:"";return{[`&-item:not(${c}-first-item):not(${c}-last-item) ${f}`]:{borderRadius:0},[`&-item:not(${c}-last-item)${c}-first-item`]:{[`& ${f}, &${a}-sm ${f}, &${a}-lg ${f}`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&-item:not(${c}-first-item)${c}-last-item`]:{[`& ${f}, &${a}-sm ${f}, &${a}-lg ${f}`]:{borderStartStartRadius:0,borderEndStartRadius:0}}}}function genCompactItemStyle(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{focus:!0};const{componentCls:u}=a,d=`${u}-compact`;return{[d]:Object.assign(Object.assign({},compactItemBorder(a,d,c)),compactItemBorderRadius(u,d,c))}}function compactItemVerticalBorder(a,c){return{[`&-item:not(${c}-last-item)`]:{marginBottom:a.calc(a.lineWidth).mul(-1).equal()},"&-item":{"&:hover,&:focus,&:active":{zIndex:2},"&[disabled]":{zIndex:0}}}}function compactItemBorderVerticalRadius(a,c){return{[`&-item:not(${c}-first-item):not(${c}-last-item)`]:{borderRadius:0},[`&-item${c}-first-item:not(${c}-last-item)`]:{[`&, &${a}-sm, &${a}-lg`]:{borderEndEndRadius:0,borderEndStartRadius:0}},[`&-item${c}-last-item:not(${c}-first-item)`]:{[`&, &${a}-sm, &${a}-lg`]:{borderStartStartRadius:0,borderStartEndRadius:0}}}}function genCompactItemVerticalStyle(a){const c=`${a.componentCls}-compact-vertical`;return{[c]:Object.assign(Object.assign({},compactItemVerticalBorder(a,c)),compactItemBorderVerticalRadius(a.componentCls,c))}}const genButtonCompactStyle=a=>{const{componentCls:c,colorPrimaryHover:u,lineWidth:d,calc:f}=a,m=f(d).mul(-1).equal(),g=y=>{const b=`${c}-compact${y?"-vertical":""}-item${c}-primary:not([disabled])`;return{[`${b} + ${b}::before`]:{position:"absolute",top:y?m:0,insetInlineStart:y?0:m,backgroundColor:u,content:'""',width:y?"100%":d,height:y?d:"100%"}}};return Object.assign(Object.assign({},g()),g(!0))},Compact=genSubStyleComponent(["Button","compact"],a=>{const c=prepareToken$4(a);return[genCompactItemStyle(c),genCompactItemVerticalStyle(c),genButtonCompactStyle(c)]},prepareComponentToken$m);var __rest$Q=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function getLoadingConfig(a){if(typeof a=="object"&&a){let c=a==null?void 0:a.delay;return c=!Number.isNaN(c)&&typeof c=="number"?c:0,{loading:c<=0,delay:c}}return{loading:!!a,delay:0}}const ButtonTypeMap={default:["default","outlined"],primary:["primary","solid"],dashed:["default","dashed"],link:["link","link"],text:["default","text"]},InternalCompoundedButton=React.forwardRef((a,c)=>{var u,d;const{loading:f=!1,prefixCls:m,color:g,variant:y,type:b,danger:E=!1,shape:C="default",size:w,styles:R,disabled:_,className:M,rootClassName:I,children:N,icon:A,iconPosition:P="start",ghost:z=!1,block:B=!1,htmlType:j="button",classNames:L,style:U={},autoInsertSpace:q,autoFocus:F}=a,K=__rest$Q(a,["loading","prefixCls","color","variant","type","danger","shape","size","styles","disabled","className","rootClassName","children","icon","iconPosition","ghost","block","htmlType","classNames","style","autoInsertSpace","autoFocus"]),X=b||"default",[Q,Y]=reactExports.useMemo(()=>{if(g&&y)return[g,y];const Ue=ButtonTypeMap[X]||[];return E?["danger",Ue[1]]:Ue},[b,g,y,E]),J=Q==="danger"?"dangerous":Q,{getPrefixCls:W,direction:G,autoInsertSpace:te,className:ae,style:V,classNames:ne,styles:le}=useComponentConfig("button"),ee=(u=q??te)!==null&&u!==void 0?u:!0,ie=W("btn",m),[ce,ue,me]=useStyle$r(ie),de=reactExports.useContext(DisabledContext),ge=_??de,Ce=reactExports.useContext(GroupSizeContext),ve=reactExports.useMemo(()=>getLoadingConfig(f),[f]),[fe,pe]=reactExports.useState(ve.loading),[xe,ye]=reactExports.useState(!1),he=reactExports.useRef(null),we=useComposeRef(c,he),Re=reactExports.Children.count(N)===1&&!A&&!isUnBorderedButtonVariant(Y),De=reactExports.useRef(!0);React.useEffect(()=>(De.current=!1,()=>{De.current=!0}),[]),reactExports.useEffect(()=>{let Ue=null;ve.delay>0?Ue=setTimeout(()=>{Ue=null,pe(!0)},ve.delay):pe(ve.loading);function je(){Ue&&(clearTimeout(Ue),Ue=null)}return je},[ve]),reactExports.useEffect(()=>{if(!he.current||!ee)return;const Ue=he.current.textContent||"";Re&&isTwoCNChar(Ue)?xe||ye(!0):xe&&ye(!1)}),reactExports.useEffect(()=>{F&&he.current&&he.current.focus()},[]);const Ae=React.useCallback(Ue=>{var je;if(fe||ge){Ue.preventDefault();return}(je=a.onClick)===null||je===void 0||je.call(a,("href"in a,Ue))},[a.onClick,fe,ge]),{compactSize:Ee,compactItemClassnames:Ne}=useCompactItemContext(ie,G),_e={large:"lg",small:"sm",middle:void 0},ke=useSize(Ue=>{var je,We;return(We=(je=w??Ee)!==null&&je!==void 0?je:Ce)!==null&&We!==void 0?We:Ue}),Ke=ke&&(d=_e[ke])!==null&&d!==void 0?d:"",be=fe?"loading":A,Te=omit(K,["navigate"]),Le=classNames(ie,ue,me,{[`${ie}-${C}`]:C!=="default"&&C,[`${ie}-${X}`]:X,[`${ie}-dangerous`]:E,[`${ie}-color-${J}`]:J,[`${ie}-variant-${Y}`]:Y,[`${ie}-${Ke}`]:Ke,[`${ie}-icon-only`]:!N&&N!==0&&!!be,[`${ie}-background-ghost`]:z&&!isUnBorderedButtonVariant(Y),[`${ie}-loading`]:fe,[`${ie}-two-chinese-chars`]:xe&&ee&&!fe,[`${ie}-block`]:B,[`${ie}-rtl`]:G==="rtl",[`${ie}-icon-end`]:P==="end"},Ne,M,I,ae),Oe=Object.assign(Object.assign({},V),U),Be=classNames(L==null?void 0:L.icon,ne.icon),Ve=Object.assign(Object.assign({},(R==null?void 0:R.icon)||{}),le.icon||{}),Pe=A&&!fe?React.createElement(IconWrapper,{prefixCls:ie,className:Be,style:Ve},A):f&&typeof f=="object"&&f.icon?React.createElement(IconWrapper,{prefixCls:ie,className:Be,style:Ve},f.icon):React.createElement(DefaultLoadingIcon,{existIcon:!!A,prefixCls:ie,loading:fe,mount:De.current}),Ge=N||N===0?spaceChildren(N,Re&&ee):null;if(Te.href!==void 0)return ce(React.createElement("a",Object.assign({},Te,{className:classNames(Le,{[`${ie}-disabled`]:ge}),href:ge?void 0:Te.href,style:Oe,onClick:Ae,ref:we,tabIndex:ge?-1:0}),Pe,Ge));let qe=React.createElement("button",Object.assign({},K,{type:j,className:Le,style:Oe,onClick:Ae,disabled:ge,ref:we}),Pe,Ge,Ne&&React.createElement(Compact,{prefixCls:ie}));return isUnBorderedButtonVariant(Y)||(qe=React.createElement(Wave,{component:"Button",disabled:fe},qe)),ce(qe)}),Button$1=InternalCompoundedButton;Button$1.Group=ButtonGroup;Button$1.__ANT_BUTTON=!0;function isThenable$1(a){return!!(a!=null&&a.then)}const ActionButton=a=>{const{type:c,children:u,prefixCls:d,buttonProps:f,close:m,autoFocus:g,emitEvent:y,isSilent:b,quitOnNullishReturnValue:E,actionFn:C}=a,w=reactExports.useRef(!1),R=reactExports.useRef(null),[_,M]=useSafeState(!1),I=function(){m==null||m.apply(void 0,arguments)};reactExports.useEffect(()=>{let P=null;return g&&(P=setTimeout(()=>{var z;(z=R.current)===null||z===void 0||z.focus({preventScroll:!0})})),()=>{P&&clearTimeout(P)}},[]);const N=P=>{isThenable$1(P)&&(M(!0),P.then(function(){M(!1,!0),I.apply(void 0,arguments),w.current=!1},z=>{if(M(!1,!0),w.current=!1,!(b!=null&&b()))return Promise.reject(z)}))},A=P=>{if(w.current)return;if(w.current=!0,!C){I();return}let z;if(y){if(z=C(P),E&&!isThenable$1(z)){w.current=!1,I(P);return}}else if(C.length)z=C(m),w.current=!1;else if(z=C(),!isThenable$1(z)){I();return}N(z)};return reactExports.createElement(Button$1,Object.assign({},convertLegacyProps(c),{onClick:A,loading:_,prefixCls:d},f,{ref:R}),u)};var OrderContext=reactExports.createContext(null),EMPTY_LIST$4=[];function useDom(a,c){var u=reactExports.useState(function(){if(!canUseDom())return null;var M=document.createElement("div");return M}),d=_slicedToArray(u,1),f=d[0],m=reactExports.useRef(!1),g=reactExports.useContext(OrderContext),y=reactExports.useState(EMPTY_LIST$4),b=_slicedToArray(y,2),E=b[0],C=b[1],w=g||(m.current?void 0:function(M){C(function(I){var N=[M].concat(_toConsumableArray(I));return N})});function R(){f.parentElement||document.body.appendChild(f),m.current=!0}function _(){var M;(M=f.parentElement)===null||M===void 0||M.removeChild(f),m.current=!1}return useLayoutEffect$1(function(){return a?g?g(R):R():_(),_},[a]),useLayoutEffect$1(function(){E.length&&(E.forEach(function(M){return M()}),C(EMPTY_LIST$4))},[E]),[f,w]}var cached;function measureScrollbarSize(a){var c="rc-scrollbar-measure-".concat(Math.random().toString(36).substring(7)),u=document.createElement("div");u.id=c;var d=u.style;d.position="absolute",d.left="0",d.top="0",d.width="100px",d.height="100px",d.overflow="scroll";var f,m;if(a){var g=getComputedStyle(a);d.scrollbarColor=g.scrollbarColor,d.scrollbarWidth=g.scrollbarWidth;var y=getComputedStyle(a,"::-webkit-scrollbar"),b=parseInt(y.width,10),E=parseInt(y.height,10);try{var C=b?"width: ".concat(y.width,";"):"",w=E?"height: ".concat(y.height,";"):"";updateCSS(`
#`.concat(c,`::-webkit-scrollbar {
`).concat(C,`
`).concat(w,`
}`),c)}catch(M){console.error(M),f=b,m=E}}document.body.appendChild(u);var R=a&&f&&!isNaN(f)?f:u.offsetWidth-u.clientWidth,_=a&&m&&!isNaN(m)?m:u.offsetHeight-u.clientHeight;return document.body.removeChild(u),removeCSS(c),{width:R,height:_}}function getScrollBarSize(a){return typeof document>"u"?0:(cached===void 0&&(cached=measureScrollbarSize()),cached.width)}function getTargetScrollBarSize(a){return typeof document>"u"||!a||!(a instanceof Element)?{width:0,height:0}:measureScrollbarSize(a)}function isBodyOverflowing(){return document.body.scrollHeight>(window.innerHeight||document.documentElement.clientHeight)&&window.innerWidth>document.body.offsetWidth}var UNIQUE_ID="rc-util-locker-".concat(Date.now()),uuid$3=0;function useScrollLocker(a){var c=!!a,u=reactExports.useState(function(){return uuid$3+=1,"".concat(UNIQUE_ID,"_").concat(uuid$3)}),d=_slicedToArray(u,1),f=d[0];useLayoutEffect$1(function(){if(c){var m=getTargetScrollBarSize(document.body).width,g=isBodyOverflowing();updateCSS(`
html body {
  overflow-y: hidden;
  `.concat(g?"width: calc(100% - ".concat(m,"px);"):"",`
}`),f)}else removeCSS(f);return function(){removeCSS(f)}},[c,f])}var inline=!1;function inlineMock(a){return inline}var getPortalContainer=function(c){return c===!1?!1:!canUseDom()||!c?null:typeof c=="string"?document.querySelector(c):typeof c=="function"?c():c},Portal=reactExports.forwardRef(function(a,c){var u=a.open,d=a.autoLock,f=a.getContainer;a.debug;var m=a.autoDestroy,g=m===void 0?!0:m,y=a.children,b=reactExports.useState(u),E=_slicedToArray(b,2),C=E[0],w=E[1],R=C||u;reactExports.useEffect(function(){(g||u)&&w(u)},[u,g]);var _=reactExports.useState(function(){return getPortalContainer(f)}),M=_slicedToArray(_,2),I=M[0],N=M[1];reactExports.useEffect(function(){var X=getPortalContainer(f);N(X??null)});var A=useDom(R&&!I),P=_slicedToArray(A,2),z=P[0],B=P[1],j=I??z;useScrollLocker(d&&u&&canUseDom()&&(j===z||j===document.body));var L=null;if(y&&supportRef(y)&&c){var U=y;L=U.ref}var q=useComposeRef(L,c);if(!R||!canUseDom()||I===void 0)return null;var F=j===!1||inlineMock(),K=y;return c&&(K=reactExports.cloneElement(y,{ref:q})),reactExports.createElement(OrderContext.Provider,{value:B},F?K:reactDomExports.createPortal(K,j))}),RefContext=reactExports.createContext({});function getUseId(){var a=_objectSpread2({},React$1);return a.useId}var uuid$2=0,useOriginId=getUseId();const useId$1=useOriginId?function(c){var u=useOriginId();return c||u}:function(c){var u=reactExports.useState("ssr-id"),d=_slicedToArray(u,2),f=d[0],m=d[1];return reactExports.useEffect(function(){var g=uuid$2;uuid$2+=1,m("rc_unique_".concat(g))},[]),c||f};function getMotionName(a,c,u){var d=c;return!d&&u&&(d="".concat(a,"-").concat(u)),d}function getScroll(a,c){var u=a["page".concat(c?"Y":"X","Offset")],d="scroll".concat(c?"Top":"Left");if(typeof u!="number"){var f=a.document;u=f.documentElement[d],typeof u!="number"&&(u=f.body[d])}return u}function offset$1(a){var c=a.getBoundingClientRect(),u={left:c.left,top:c.top},d=a.ownerDocument,f=d.defaultView||d.parentWindow;return u.left+=getScroll(f),u.top+=getScroll(f,!0),u}const MemoChildren=reactExports.memo(function(a){var c=a.children;return c},function(a,c){var u=c.shouldUpdate;return!u});var sentinelStyle={width:0,height:0,overflow:"hidden",outline:"none"},entityStyle={outline:"none"},Panel$1=React.forwardRef(function(a,c){var u=a.prefixCls,d=a.className,f=a.style,m=a.title,g=a.ariaId,y=a.footer,b=a.closable,E=a.closeIcon,C=a.onClose,w=a.children,R=a.bodyStyle,_=a.bodyProps,M=a.modalRender,I=a.onMouseDown,N=a.onMouseUp,A=a.holderRef,P=a.visible,z=a.forceRender,B=a.width,j=a.height,L=a.classNames,U=a.styles,q=React.useContext(RefContext),F=q.panel,K=useComposeRef(A,F),X=reactExports.useRef(),Q=reactExports.useRef();React.useImperativeHandle(c,function(){return{focus:function(){var le;(le=X.current)===null||le===void 0||le.focus({preventScroll:!0})},changeActive:function(le){var ee=document,ie=ee.activeElement;le&&ie===Q.current?X.current.focus({preventScroll:!0}):!le&&ie===X.current&&Q.current.focus({preventScroll:!0})}}});var Y={};B!==void 0&&(Y.width=B),j!==void 0&&(Y.height=j);var Z=y?React.createElement("div",{className:classNames("".concat(u,"-footer"),L==null?void 0:L.footer),style:_objectSpread2({},U==null?void 0:U.footer)},y):null,J=m?React.createElement("div",{className:classNames("".concat(u,"-header"),L==null?void 0:L.header),style:_objectSpread2({},U==null?void 0:U.header)},React.createElement("div",{className:"".concat(u,"-title"),id:g},m)):null,W=reactExports.useMemo(function(){return _typeof(b)==="object"&&b!==null?b:b?{closeIcon:E??React.createElement("span",{className:"".concat(u,"-close-x")})}:{}},[b,E,u]),G=pickAttrs(W,!0),te=_typeof(b)==="object"&&b.disabled,ae=b?React.createElement("button",_extends({type:"button",onClick:C,"aria-label":"Close"},G,{className:"".concat(u,"-close"),disabled:te}),W.closeIcon):null,V=React.createElement("div",{className:classNames("".concat(u,"-content"),L==null?void 0:L.content),style:U==null?void 0:U.content},ae,J,React.createElement("div",_extends({className:classNames("".concat(u,"-body"),L==null?void 0:L.body),style:_objectSpread2(_objectSpread2({},R),U==null?void 0:U.body)},_),w),Z);return React.createElement("div",{key:"dialog-element",role:"dialog","aria-labelledby":m?g:null,"aria-modal":"true",ref:K,style:_objectSpread2(_objectSpread2({},f),Y),className:classNames(u,d),onMouseDown:I,onMouseUp:N},React.createElement("div",{ref:X,tabIndex:0,style:entityStyle},React.createElement(MemoChildren,{shouldUpdate:P||z},M?M(V):V)),React.createElement("div",{tabIndex:0,ref:Q,style:sentinelStyle}))}),Content$2=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.title,f=a.style,m=a.className,g=a.visible,y=a.forceRender,b=a.destroyOnClose,E=a.motionName,C=a.ariaId,w=a.onVisibleChanged,R=a.mousePosition,_=reactExports.useRef(),M=reactExports.useState(),I=_slicedToArray(M,2),N=I[0],A=I[1],P={};N&&(P.transformOrigin=N);function z(){var B=offset$1(_.current);A(R&&(R.x||R.y)?"".concat(R.x-B.left,"px ").concat(R.y-B.top,"px"):"")}return reactExports.createElement(CSSMotion,{visible:g,onVisibleChanged:w,onAppearPrepare:z,onEnterPrepare:z,forceRender:y,motionName:E,removeOnLeave:b,ref:_},function(B,j){var L=B.className,U=B.style;return reactExports.createElement(Panel$1,_extends({},a,{ref:c,title:d,ariaId:C,prefixCls:u,holderRef:j,style:_objectSpread2(_objectSpread2(_objectSpread2({},U),f),P),className:classNames(m,L)}))})});Content$2.displayName="Content";var Mask$1=function(c){var u=c.prefixCls,d=c.style,f=c.visible,m=c.maskProps,g=c.motionName,y=c.className;return reactExports.createElement(CSSMotion,{key:"mask",visible:f,motionName:g,leavedClassName:"".concat(u,"-mask-hidden")},function(b,E){var C=b.className,w=b.style;return reactExports.createElement("div",_extends({ref:E,style:_objectSpread2(_objectSpread2({},w),d),className:classNames("".concat(u,"-mask"),C,y)},m))})},Dialog=function(c){var u=c.prefixCls,d=u===void 0?"rc-dialog":u,f=c.zIndex,m=c.visible,g=m===void 0?!1:m,y=c.keyboard,b=y===void 0?!0:y,E=c.focusTriggerAfterClose,C=E===void 0?!0:E,w=c.wrapStyle,R=c.wrapClassName,_=c.wrapProps,M=c.onClose,I=c.afterOpenChange,N=c.afterClose,A=c.transitionName,P=c.animation,z=c.closable,B=z===void 0?!0:z,j=c.mask,L=j===void 0?!0:j,U=c.maskTransitionName,q=c.maskAnimation,F=c.maskClosable,K=F===void 0?!0:F,X=c.maskStyle,Q=c.maskProps,Y=c.rootClassName,Z=c.classNames,J=c.styles,W=reactExports.useRef(),G=reactExports.useRef(),te=reactExports.useRef(),ae=reactExports.useState(g),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=useId$1();function ie(){contains$1(G.current,document.activeElement)||(W.current=document.activeElement)}function ce(){if(!contains$1(G.current,document.activeElement)){var ye;(ye=te.current)===null||ye===void 0||ye.focus()}}function ue(ye){if(ye)ce();else{if(le(!1),L&&W.current&&C){try{W.current.focus({preventScroll:!0})}catch{}W.current=null}ne&&(N==null||N())}I==null||I(ye)}function me(ye){M==null||M(ye)}var de=reactExports.useRef(!1),ge=reactExports.useRef(),Ce=function(){clearTimeout(ge.current),de.current=!0},ve=function(){ge.current=setTimeout(function(){de.current=!1})},fe=null;K&&(fe=function(he){de.current?de.current=!1:G.current===he.target&&me(he)});function pe(ye){if(b&&ye.keyCode===KeyCode.ESC){ye.stopPropagation(),me(ye);return}g&&ye.keyCode===KeyCode.TAB&&te.current.changeActive(!ye.shiftKey)}reactExports.useEffect(function(){g&&(le(!0),ie())},[g]),reactExports.useEffect(function(){return function(){clearTimeout(ge.current)}},[]);var xe=_objectSpread2(_objectSpread2(_objectSpread2({zIndex:f},w),J==null?void 0:J.wrapper),{},{display:ne?null:"none"});return reactExports.createElement("div",_extends({className:classNames("".concat(d,"-root"),Y)},pickAttrs(c,{data:!0})),reactExports.createElement(Mask$1,{prefixCls:d,visible:L&&g,motionName:getMotionName(d,U,q),style:_objectSpread2(_objectSpread2({zIndex:f},X),J==null?void 0:J.mask),maskProps:Q,className:Z==null?void 0:Z.mask}),reactExports.createElement("div",_extends({tabIndex:-1,onKeyDown:pe,className:classNames("".concat(d,"-wrap"),R,Z==null?void 0:Z.wrapper),ref:G,onClick:fe,style:xe},_),reactExports.createElement(Content$2,_extends({},c,{onMouseDown:Ce,onMouseUp:ve,ref:te,closable:B,ariaId:ee,prefixCls:d,visible:g&&ne,onClose:me,onVisibleChanged:ue,motionName:getMotionName(d,A,P)}))))},DialogWrap=function(c){var u=c.visible,d=c.getContainer,f=c.forceRender,m=c.destroyOnClose,g=m===void 0?!1:m,y=c.afterClose,b=c.panelRef,E=reactExports.useState(u),C=_slicedToArray(E,2),w=C[0],R=C[1],_=reactExports.useMemo(function(){return{panel:b}},[b]);return reactExports.useEffect(function(){u&&R(!0)},[u]),!f&&g&&!w?null:reactExports.createElement(RefContext.Provider,{value:_},reactExports.createElement(Portal,{open:u||f||w,autoDestroy:!1,getContainer:d,autoLock:u||w},reactExports.createElement(Dialog,_extends({},c,{destroyOnClose:g,afterClose:function(){y==null||y(),R(!1)}}))))};DialogWrap.displayName="Dialog";var HOOK_MARK="RC_FORM_INTERNAL_HOOKS",warningFunc=function(){warningOnce$1(!1,"Can not find FormContext. Please make sure you wrap Field under Form.")},Context=reactExports.createContext({getFieldValue:warningFunc,getFieldsValue:warningFunc,getFieldError:warningFunc,getFieldWarning:warningFunc,getFieldsError:warningFunc,isFieldsTouched:warningFunc,isFieldTouched:warningFunc,isFieldValidating:warningFunc,isFieldsValidating:warningFunc,resetFields:warningFunc,setFields:warningFunc,setFieldValue:warningFunc,setFieldsValue:warningFunc,validateFields:warningFunc,submit:warningFunc,getInternalHooks:function(){return warningFunc(),{dispatch:warningFunc,initEntityValue:warningFunc,registerField:warningFunc,useSubscribe:warningFunc,setInitialValues:warningFunc,destroyForm:warningFunc,setCallbacks:warningFunc,registerWatch:warningFunc,getFields:warningFunc,setValidateMessages:warningFunc,setPreserve:warningFunc,getInitialValue:warningFunc}}}),ListContext=reactExports.createContext(null);function toArray$5(a){return a==null?[]:Array.isArray(a)?a:[a]}function isFormInstance(a){return a&&!!a._init}function newMessages(){return{default:"Validation error on field %s",required:"%s is required",enum:"%s must be one of %s",whitespace:"%s cannot be empty",date:{format:"%s date %s is invalid for format %s",parse:"%s date could not be parsed, %s is invalid ",invalid:"%s date %s is invalid"},types:{string:"%s is not a %s",method:"%s is not a %s (function)",array:"%s is not an %s",object:"%s is not an %s",number:"%s is not a %s",date:"%s is not a %s",boolean:"%s is not a %s",integer:"%s is not an %s",float:"%s is not a %s",regexp:"%s is not a valid %s",email:"%s is not a valid %s",url:"%s is not a valid %s",hex:"%s is not a valid %s"},string:{len:"%s must be exactly %s characters",min:"%s must be at least %s characters",max:"%s cannot be longer than %s characters",range:"%s must be between %s and %s characters"},number:{len:"%s must equal %s",min:"%s cannot be less than %s",max:"%s cannot be greater than %s",range:"%s must be between %s and %s"},array:{len:"%s must be exactly %s in length",min:"%s cannot be less than %s in length",max:"%s cannot be greater than %s in length",range:"%s must be between %s and %s in length"},pattern:{mismatch:"%s value %s does not match pattern %s"},clone:function(){var c=JSON.parse(JSON.stringify(this));return c.clone=this.clone,c}}}var messages=newMessages();function _isNativeFunction(a){try{return Function.toString.call(a).indexOf("[native code]")!==-1}catch{return typeof a=="function"}}function _construct(a,c,u){if(_isNativeReflectConstruct())return Reflect.construct.apply(null,arguments);var d=[null];d.push.apply(d,c);var f=new(a.bind.apply(a,d));return u&&_setPrototypeOf(f,u.prototype),f}function _wrapNativeSuper(a){var c=typeof Map=="function"?new Map:void 0;return _wrapNativeSuper=function(d){if(d===null||!_isNativeFunction(d))return d;if(typeof d!="function")throw new TypeError("Super expression must either be null or a function");if(c!==void 0){if(c.has(d))return c.get(d);c.set(d,f)}function f(){return _construct(d,arguments,_getPrototypeOf(this).constructor)}return f.prototype=Object.create(d.prototype,{constructor:{value:f,enumerable:!1,writable:!0,configurable:!0}}),_setPrototypeOf(f,d)},_wrapNativeSuper(a)}var formatRegExp=/%[sdj%]/g,warning$1=function(){};function convertFieldsError(a){if(!a||!a.length)return null;var c={};return a.forEach(function(u){var d=u.field;c[d]=c[d]||[],c[d].push(u)}),c}function format(a){for(var c=arguments.length,u=new Array(c>1?c-1:0),d=1;d<c;d++)u[d-1]=arguments[d];var f=0,m=u.length;if(typeof a=="function")return a.apply(null,u);if(typeof a=="string"){var g=a.replace(formatRegExp,function(y){if(y==="%%")return"%";if(f>=m)return y;switch(y){case"%s":return String(u[f++]);case"%d":return Number(u[f++]);case"%j":try{return JSON.stringify(u[f++])}catch{return"[Circular]"}break;default:return y}});return g}return a}function isNativeStringType(a){return a==="string"||a==="url"||a==="hex"||a==="email"||a==="date"||a==="pattern"}function isEmptyValue(a,c){return!!(a==null||c==="array"&&Array.isArray(a)&&!a.length||isNativeStringType(c)&&typeof a=="string"&&!a)}function asyncParallelArray(a,c,u){var d=[],f=0,m=a.length;function g(y){d.push.apply(d,_toConsumableArray(y||[])),f++,f===m&&u(d)}a.forEach(function(y){c(y,g)})}function asyncSerialArray(a,c,u){var d=0,f=a.length;function m(g){if(g&&g.length){u(g);return}var y=d;d=d+1,y<f?c(a[y],m):u([])}m([])}function flattenObjArr(a){var c=[];return Object.keys(a).forEach(function(u){c.push.apply(c,_toConsumableArray(a[u]||[]))}),c}var AsyncValidationError=function(a){_inherits(u,a);var c=_createSuper(u);function u(d,f){var m;return _classCallCheck(this,u),m=c.call(this,"Async Validation Error"),_defineProperty(_assertThisInitialized(m),"errors",void 0),_defineProperty(_assertThisInitialized(m),"fields",void 0),m.errors=d,m.fields=f,m}return _createClass(u)}(_wrapNativeSuper(Error));function asyncMap(a,c,u,d,f){if(c.first){var m=new Promise(function(R,_){var M=function(A){return d(A),A.length?_(new AsyncValidationError(A,convertFieldsError(A))):R(f)},I=flattenObjArr(a);asyncSerialArray(I,u,M)});return m.catch(function(R){return R}),m}var g=c.firstFields===!0?Object.keys(a):c.firstFields||[],y=Object.keys(a),b=y.length,E=0,C=[],w=new Promise(function(R,_){var M=function(N){if(C.push.apply(C,N),E++,E===b)return d(C),C.length?_(new AsyncValidationError(C,convertFieldsError(C))):R(f)};y.length||(d(C),R(f)),y.forEach(function(I){var N=a[I];g.indexOf(I)!==-1?asyncSerialArray(N,u,M):asyncParallelArray(N,u,M)})});return w.catch(function(R){return R}),w}function isErrorObj(a){return!!(a&&a.message!==void 0)}function getValue(a,c){for(var u=a,d=0;d<c.length;d++){if(u==null)return u;u=u[c[d]]}return u}function complementError(a,c){return function(u){var d;return a.fullFields?d=getValue(c,a.fullFields):d=c[u.field||a.fullField],isErrorObj(u)?(u.field=u.field||a.fullField,u.fieldValue=d,u):{message:typeof u=="function"?u():u,fieldValue:d,field:u.field||a.fullField}}}function deepMerge(a,c){if(c){for(var u in c)if(c.hasOwnProperty(u)){var d=c[u];_typeof(d)==="object"&&_typeof(a[u])==="object"?a[u]=_objectSpread2(_objectSpread2({},a[u]),d):a[u]=d}}return a}var ENUM$1="enum",enumerable$1=function(c,u,d,f,m){c[ENUM$1]=Array.isArray(c[ENUM$1])?c[ENUM$1]:[],c[ENUM$1].indexOf(u)===-1&&f.push(format(m.messages[ENUM$1],c.fullField,c[ENUM$1].join(", ")))},pattern$2=function(c,u,d,f,m){if(c.pattern){if(c.pattern instanceof RegExp)c.pattern.lastIndex=0,c.pattern.test(u)||f.push(format(m.messages.pattern.mismatch,c.fullField,u,c.pattern));else if(typeof c.pattern=="string"){var g=new RegExp(c.pattern);g.test(u)||f.push(format(m.messages.pattern.mismatch,c.fullField,u,c.pattern))}}},range=function(c,u,d,f,m){var g=typeof c.len=="number",y=typeof c.min=="number",b=typeof c.max=="number",E=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,C=u,w=null,R=typeof u=="number",_=typeof u=="string",M=Array.isArray(u);if(R?w="number":_?w="string":M&&(w="array"),!w)return!1;M&&(C=u.length),_&&(C=u.replace(E,"_").length),g?C!==c.len&&f.push(format(m.messages[w].len,c.fullField,c.len)):y&&!b&&C<c.min?f.push(format(m.messages[w].min,c.fullField,c.min)):b&&!y&&C>c.max?f.push(format(m.messages[w].max,c.fullField,c.max)):y&&b&&(C<c.min||C>c.max)&&f.push(format(m.messages[w].range,c.fullField,c.min,c.max))},required$1=function(c,u,d,f,m,g){c.required&&(!d.hasOwnProperty(c.field)||isEmptyValue(u,g||c.type))&&f.push(format(m.messages.required,c.fullField))},urlReg;const getUrlRegex=function(){if(urlReg)return urlReg;var a="[a-fA-F\\d:]",c=function(L){return L&&L.includeBoundaries?"(?:(?<=\\s|^)(?=".concat(a,")|(?<=").concat(a,")(?=\\s|$))"):""},u="(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)(?:\\.(?:25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]\\d|\\d)){3}",d="[a-fA-F\\d]{1,4}",f=["(?:".concat(d,":){7}(?:").concat(d,"|:)"),"(?:".concat(d,":){6}(?:").concat(u,"|:").concat(d,"|:)"),"(?:".concat(d,":){5}(?::").concat(u,"|(?::").concat(d,"){1,2}|:)"),"(?:".concat(d,":){4}(?:(?::").concat(d,"){0,1}:").concat(u,"|(?::").concat(d,"){1,3}|:)"),"(?:".concat(d,":){3}(?:(?::").concat(d,"){0,2}:").concat(u,"|(?::").concat(d,"){1,4}|:)"),"(?:".concat(d,":){2}(?:(?::").concat(d,"){0,3}:").concat(u,"|(?::").concat(d,"){1,5}|:)"),"(?:".concat(d,":){1}(?:(?::").concat(d,"){0,4}:").concat(u,"|(?::").concat(d,"){1,6}|:)"),"(?::(?:(?::".concat(d,"){0,5}:").concat(u,"|(?::").concat(d,"){1,7}|:))")],m="(?:%[0-9a-zA-Z]{1,})?",g="(?:".concat(f.join("|"),")").concat(m),y=new RegExp("(?:^".concat(u,"$)|(?:^").concat(g,"$)")),b=new RegExp("^".concat(u,"$")),E=new RegExp("^".concat(g,"$")),C=function(L){return L&&L.exact?y:new RegExp("(?:".concat(c(L)).concat(u).concat(c(L),")|(?:").concat(c(L)).concat(g).concat(c(L),")"),"g")};C.v4=function(j){return j&&j.exact?b:new RegExp("".concat(c(j)).concat(u).concat(c(j)),"g")},C.v6=function(j){return j&&j.exact?E:new RegExp("".concat(c(j)).concat(g).concat(c(j)),"g")};var w="(?:(?:[a-z]+:)?//)",R="(?:\\S+(?::\\S*)?@)?",_=C.v4().source,M=C.v6().source,I="(?:(?:[a-z\\u00a1-\\uffff0-9][-_]*)*[a-z\\u00a1-\\uffff0-9]+)",N="(?:\\.(?:[a-z\\u00a1-\\uffff0-9]-*)*[a-z\\u00a1-\\uffff0-9]+)*",A="(?:\\.(?:[a-z\\u00a1-\\uffff]{2,}))",P="(?::\\d{2,5})?",z='(?:[/?#][^\\s"]*)?',B="(?:".concat(w,"|www\\.)").concat(R,"(?:localhost|").concat(_,"|").concat(M,"|").concat(I).concat(N).concat(A,")").concat(P).concat(z);return urlReg=new RegExp("(?:^".concat(B,"$)"),"i"),urlReg};var pattern$1={email:/^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+\.)+[a-zA-Z\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]{2,}))$/,hex:/^#?([a-f0-9]{6}|[a-f0-9]{3})$/i},types$1={integer:function(c){return types$1.number(c)&&parseInt(c,10)===c},float:function(c){return types$1.number(c)&&!types$1.integer(c)},array:function(c){return Array.isArray(c)},regexp:function(c){if(c instanceof RegExp)return!0;try{return!!new RegExp(c)}catch{return!1}},date:function(c){return typeof c.getTime=="function"&&typeof c.getMonth=="function"&&typeof c.getYear=="function"&&!isNaN(c.getTime())},number:function(c){return isNaN(c)?!1:typeof c=="number"},object:function(c){return _typeof(c)==="object"&&!types$1.array(c)},method:function(c){return typeof c=="function"},email:function(c){return typeof c=="string"&&c.length<=320&&!!c.match(pattern$1.email)},url:function(c){return typeof c=="string"&&c.length<=2048&&!!c.match(getUrlRegex())},hex:function(c){return typeof c=="string"&&!!c.match(pattern$1.hex)}},type$1=function(c,u,d,f,m){if(c.required&&u===void 0){required$1(c,u,d,f,m);return}var g=["integer","float","array","regexp","object","method","email","number","date","url","hex"],y=c.type;g.indexOf(y)>-1?types$1[y](u)||f.push(format(m.messages.types[y],c.fullField,c.type)):y&&_typeof(u)!==c.type&&f.push(format(m.messages.types[y],c.fullField,c.type))},whitespace$1=function(c,u,d,f,m){(/^\s+$/.test(u)||u==="")&&f.push(format(m.messages.whitespace,c.fullField))};const rules={required:required$1,whitespace:whitespace$1,type:type$1,range,enum:enumerable$1,pattern:pattern$2};var any=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m)}d(g)},array=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(u==null&&!c.required)return d();rules.required(c,u,f,g,m,"array"),u!=null&&(rules.type(c,u,f,g,m),rules.range(c,u,f,g,m))}d(g)},boolean$1=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&rules.type(c,u,f,g,m)}d(g)},date=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u,"date")&&!c.required)return d();if(rules.required(c,u,f,g,m),!isEmptyValue(u,"date")){var b;u instanceof Date?b=u:b=new Date(u),rules.type(c,b,f,g,m),b&&rules.range(c,b.getTime(),f,g,m)}}d(g)},ENUM="enum",enumerable=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&rules[ENUM](c,u,f,g,m)}d(g)},floatFn=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&(rules.type(c,u,f,g,m),rules.range(c,u,f,g,m))}d(g)},integer=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&(rules.type(c,u,f,g,m),rules.range(c,u,f,g,m))}d(g)},method=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&rules.type(c,u,f,g,m)}d(g)},number$1=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(u===""&&(u=void 0),isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&(rules.type(c,u,f,g,m),rules.range(c,u,f,g,m))}d(g)},object=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),u!==void 0&&rules.type(c,u,f,g,m)}d(g)},pattern=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u,"string")&&!c.required)return d();rules.required(c,u,f,g,m),isEmptyValue(u,"string")||rules.pattern(c,u,f,g,m)}d(g)},regexp=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u)&&!c.required)return d();rules.required(c,u,f,g,m),isEmptyValue(u)||rules.type(c,u,f,g,m)}d(g)},required=function(c,u,d,f,m){var g=[],y=Array.isArray(u)?"array":_typeof(u);rules.required(c,u,f,g,m,y),d(g)},string$2=function(c,u,d,f,m){var g=[],y=c.required||!c.required&&f.hasOwnProperty(c.field);if(y){if(isEmptyValue(u,"string")&&!c.required)return d();rules.required(c,u,f,g,m,"string"),isEmptyValue(u,"string")||(rules.type(c,u,f,g,m),rules.range(c,u,f,g,m),rules.pattern(c,u,f,g,m),c.whitespace===!0&&rules.whitespace(c,u,f,g,m))}d(g)},type=function(c,u,d,f,m){var g=c.type,y=[],b=c.required||!c.required&&f.hasOwnProperty(c.field);if(b){if(isEmptyValue(u,g)&&!c.required)return d();rules.required(c,u,f,y,m,g),isEmptyValue(u,g)||rules.type(c,u,f,y,m)}d(y)};const validators$2={string:string$2,method,number:number$1,boolean:boolean$1,regexp,integer,float:floatFn,array,object,enum:enumerable,pattern,date,url:type,hex:type,email:type,required,any};var Schema$1=function(){function a(c){_classCallCheck(this,a),_defineProperty(this,"rules",null),_defineProperty(this,"_messages",messages),this.define(c)}return _createClass(a,[{key:"define",value:function(u){var d=this;if(!u)throw new Error("Cannot configure a schema with no rules");if(_typeof(u)!=="object"||Array.isArray(u))throw new Error("Rules must be an object");this.rules={},Object.keys(u).forEach(function(f){var m=u[f];d.rules[f]=Array.isArray(m)?m:[m]})}},{key:"messages",value:function(u){return u&&(this._messages=deepMerge(newMessages(),u)),this._messages}},{key:"validate",value:function(u){var d=this,f=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},m=arguments.length>2&&arguments[2]!==void 0?arguments[2]:function(){},g=u,y=f,b=m;if(typeof y=="function"&&(b=y,y={}),!this.rules||Object.keys(this.rules).length===0)return b&&b(null,g),Promise.resolve(g);function E(M){var I=[],N={};function A(z){if(Array.isArray(z)){var B;I=(B=I).concat.apply(B,_toConsumableArray(z))}else I.push(z)}for(var P=0;P<M.length;P++)A(M[P]);I.length?(N=convertFieldsError(I),b(I,N)):b(null,g)}if(y.messages){var C=this.messages();C===messages&&(C=newMessages()),deepMerge(C,y.messages),y.messages=C}else y.messages=this.messages();var w={},R=y.keys||Object.keys(this.rules);R.forEach(function(M){var I=d.rules[M],N=g[M];I.forEach(function(A){var P=A;typeof P.transform=="function"&&(g===u&&(g=_objectSpread2({},g)),N=g[M]=P.transform(N),N!=null&&(P.type=P.type||(Array.isArray(N)?"array":_typeof(N)))),typeof P=="function"?P={validator:P}:P=_objectSpread2({},P),P.validator=d.getValidationMethod(P),P.validator&&(P.field=M,P.fullField=P.fullField||M,P.type=d.getType(P),w[M]=w[M]||[],w[M].push({rule:P,value:N,source:g,field:M}))})});var _={};return asyncMap(w,y,function(M,I){var N=M.rule,A=(N.type==="object"||N.type==="array")&&(_typeof(N.fields)==="object"||_typeof(N.defaultField)==="object");A=A&&(N.required||!N.required&&M.value),N.field=M.field;function P(U,q){return _objectSpread2(_objectSpread2({},q),{},{fullField:"".concat(N.fullField,".").concat(U),fullFields:N.fullFields?[].concat(_toConsumableArray(N.fullFields),[U]):[U]})}function z(){var U=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],q=Array.isArray(U)?U:[U];!y.suppressWarning&&q.length&&a.warning("async-validator:",q),q.length&&N.message!==void 0&&(q=[].concat(N.message));var F=q.map(complementError(N,g));if(y.first&&F.length)return _[N.field]=1,I(F);if(!A)I(F);else{if(N.required&&!M.value)return N.message!==void 0?F=[].concat(N.message).map(complementError(N,g)):y.error&&(F=[y.error(N,format(y.messages.required,N.field))]),I(F);var K={};N.defaultField&&Object.keys(M.value).map(function(Y){K[Y]=N.defaultField}),K=_objectSpread2(_objectSpread2({},K),M.rule.fields);var X={};Object.keys(K).forEach(function(Y){var Z=K[Y],J=Array.isArray(Z)?Z:[Z];X[Y]=J.map(P.bind(null,Y))});var Q=new a(X);Q.messages(y.messages),M.rule.options&&(M.rule.options.messages=y.messages,M.rule.options.error=y.error),Q.validate(M.value,M.rule.options||y,function(Y){var Z=[];F&&F.length&&Z.push.apply(Z,_toConsumableArray(F)),Y&&Y.length&&Z.push.apply(Z,_toConsumableArray(Y)),I(Z.length?Z:null)})}}var B;if(N.asyncValidator)B=N.asyncValidator(N,M.value,z,M.source,y);else if(N.validator){try{B=N.validator(N,M.value,z,M.source,y)}catch(U){var j,L;(j=(L=console).error)===null||j===void 0||j.call(L,U),y.suppressValidatorError||setTimeout(function(){throw U},0),z(U.message)}B===!0?z():B===!1?z(typeof N.message=="function"?N.message(N.fullField||N.field):N.message||"".concat(N.fullField||N.field," fails")):B instanceof Array?z(B):B instanceof Error&&z(B.message)}B&&B.then&&B.then(function(){return z()},function(U){return z(U)})},function(M){E(M)},g)}},{key:"getType",value:function(u){if(u.type===void 0&&u.pattern instanceof RegExp&&(u.type="pattern"),typeof u.validator!="function"&&u.type&&!validators$2.hasOwnProperty(u.type))throw new Error(format("Unknown rule type %s",u.type));return u.type||"string"}},{key:"getValidationMethod",value:function(u){if(typeof u.validator=="function")return u.validator;var d=Object.keys(u),f=d.indexOf("message");return f!==-1&&d.splice(f,1),d.length===1&&d[0]==="required"?validators$2.required:validators$2[this.getType(u)]||void 0}}]),a}();_defineProperty(Schema$1,"register",function(c,u){if(typeof u!="function")throw new Error("Cannot register a validator by type, validator is not a function");validators$2[c]=u});_defineProperty(Schema$1,"warning",warning$1);_defineProperty(Schema$1,"messages",messages);_defineProperty(Schema$1,"validators",validators$2);var typeTemplate="'${name}' is not a valid ${type}",defaultValidateMessages={default:"Validation error on field '${name}'",required:"'${name}' is required",enum:"'${name}' must be one of [${enum}]",whitespace:"'${name}' cannot be empty",date:{format:"'${name}' is invalid for format date",parse:"'${name}' could not be parsed as date",invalid:"'${name}' is invalid date"},types:{string:typeTemplate,method:typeTemplate,array:typeTemplate,object:typeTemplate,number:typeTemplate,date:typeTemplate,boolean:typeTemplate,integer:typeTemplate,float:typeTemplate,regexp:typeTemplate,email:typeTemplate,url:typeTemplate,hex:typeTemplate},string:{len:"'${name}' must be exactly ${len} characters",min:"'${name}' must be at least ${min} characters",max:"'${name}' cannot be longer than ${max} characters",range:"'${name}' must be between ${min} and ${max} characters"},number:{len:"'${name}' must equal ${len}",min:"'${name}' cannot be less than ${min}",max:"'${name}' cannot be greater than ${max}",range:"'${name}' must be between ${min} and ${max}"},array:{len:"'${name}' must be exactly ${len} in length",min:"'${name}' cannot be less than ${min} in length",max:"'${name}' cannot be greater than ${max} in length",range:"'${name}' must be between ${min} and ${max} in length"},pattern:{mismatch:"'${name}' does not match pattern ${pattern}"}},AsyncValidator=Schema$1;function replaceMessage(a,c){return a.replace(/\\?\$\{\w+\}/g,function(u){if(u.startsWith("\\"))return u.slice(1);var d=u.slice(2,-1);return c[d]})}var CODE_LOGIC_ERROR="CODE_LOGIC_ERROR";function validateRule(a,c,u,d,f){return _validateRule.apply(this,arguments)}function _validateRule(){return _validateRule=_asyncToGenerator(_regeneratorRuntime().mark(function a(c,u,d,f,m){var g,y,b,E,C,w,R,_,M;return _regeneratorRuntime().wrap(function(N){for(;;)switch(N.prev=N.next){case 0:return g=_objectSpread2({},d),delete g.ruleIndex,AsyncValidator.warning=function(){},g.validator&&(y=g.validator,g.validator=function(){try{return y.apply(void 0,arguments)}catch(A){return console.error(A),Promise.reject(CODE_LOGIC_ERROR)}}),b=null,g&&g.type==="array"&&g.defaultField&&(b=g.defaultField,delete g.defaultField),E=new AsyncValidator(_defineProperty({},c,[g])),C=merge$3(defaultValidateMessages,f.validateMessages),E.messages(C),w=[],N.prev=10,N.next=13,Promise.resolve(E.validate(_defineProperty({},c,u),_objectSpread2({},f)));case 13:N.next=18;break;case 15:N.prev=15,N.t0=N.catch(10),N.t0.errors&&(w=N.t0.errors.map(function(A,P){var z=A.message,B=z===CODE_LOGIC_ERROR?C.default:z;return reactExports.isValidElement(B)?reactExports.cloneElement(B,{key:"error_".concat(P)}):B}));case 18:if(!(!w.length&&b)){N.next=23;break}return N.next=21,Promise.all(u.map(function(A,P){return validateRule("".concat(c,".").concat(P),A,b,f,m)}));case 21:return R=N.sent,N.abrupt("return",R.reduce(function(A,P){return[].concat(_toConsumableArray(A),_toConsumableArray(P))},[]));case 23:return _=_objectSpread2(_objectSpread2({},d),{},{name:c,enum:(d.enum||[]).join(", ")},m),M=w.map(function(A){return typeof A=="string"?replaceMessage(A,_):A}),N.abrupt("return",M);case 26:case"end":return N.stop()}},a,null,[[10,15]])})),_validateRule.apply(this,arguments)}function validateRules(a,c,u,d,f,m){var g=a.join("."),y=u.map(function(C,w){var R=C.validator,_=_objectSpread2(_objectSpread2({},C),{},{ruleIndex:w});return R&&(_.validator=function(M,I,N){var A=!1,P=function(){for(var j=arguments.length,L=new Array(j),U=0;U<j;U++)L[U]=arguments[U];Promise.resolve().then(function(){warningOnce$1(!A,"Your validator function has already return a promise. `callback` will be ignored."),A||N.apply(void 0,L)})},z=R(M,I,P);A=z&&typeof z.then=="function"&&typeof z.catch=="function",warningOnce$1(A,"`callback` is deprecated. Please return a promise instead."),A&&z.then(function(){N()}).catch(function(B){N(B||" ")})}),_}).sort(function(C,w){var R=C.warningOnly,_=C.ruleIndex,M=w.warningOnly,I=w.ruleIndex;return!!R==!!M?_-I:R?1:-1}),b;if(f===!0)b=new Promise(function(){var C=_asyncToGenerator(_regeneratorRuntime().mark(function w(R,_){var M,I,N;return _regeneratorRuntime().wrap(function(P){for(;;)switch(P.prev=P.next){case 0:M=0;case 1:if(!(M<y.length)){P.next=12;break}return I=y[M],P.next=5,validateRule(g,c,I,d,m);case 5:if(N=P.sent,!N.length){P.next=9;break}return _([{errors:N,rule:I}]),P.abrupt("return");case 9:M+=1,P.next=1;break;case 12:R([]);case 13:case"end":return P.stop()}},w)}));return function(w,R){return C.apply(this,arguments)}}());else{var E=y.map(function(C){return validateRule(g,c,C,d,m).then(function(w){return{errors:w,rule:C}})});b=(f?finishOnFirstFailed(E):finishOnAllFailed(E)).then(function(C){return Promise.reject(C)})}return b.catch(function(C){return C}),b}function finishOnAllFailed(a){return _finishOnAllFailed.apply(this,arguments)}function _finishOnAllFailed(){return _finishOnAllFailed=_asyncToGenerator(_regeneratorRuntime().mark(function a(c){return _regeneratorRuntime().wrap(function(d){for(;;)switch(d.prev=d.next){case 0:return d.abrupt("return",Promise.all(c).then(function(f){var m,g=(m=[]).concat.apply(m,_toConsumableArray(f));return g}));case 1:case"end":return d.stop()}},a)})),_finishOnAllFailed.apply(this,arguments)}function finishOnFirstFailed(a){return _finishOnFirstFailed.apply(this,arguments)}function _finishOnFirstFailed(){return _finishOnFirstFailed=_asyncToGenerator(_regeneratorRuntime().mark(function a(c){var u;return _regeneratorRuntime().wrap(function(f){for(;;)switch(f.prev=f.next){case 0:return u=0,f.abrupt("return",new Promise(function(m){c.forEach(function(g){g.then(function(y){y.errors.length&&m([y]),u+=1,u===c.length&&m([])})})}));case 2:case"end":return f.stop()}},a)})),_finishOnFirstFailed.apply(this,arguments)}function getNamePath(a){return toArray$5(a)}function cloneByNamePathList(a,c){var u={};return c.forEach(function(d){var f=get(a,d);u=set$1(u,d,f)}),u}function containsNamePath(a,c){var u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1;return a&&a.some(function(d){return matchNamePath(c,d,u)})}function matchNamePath(a,c){var u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1;return!a||!c||!u&&a.length!==c.length?!1:c.every(function(d,f){return a[f]===d})}function isSimilar(a,c){if(a===c)return!0;if(!a&&c||a&&!c||!a||!c||_typeof(a)!=="object"||_typeof(c)!=="object")return!1;var u=Object.keys(a),d=Object.keys(c),f=new Set([].concat(u,d));return _toConsumableArray(f).every(function(m){var g=a[m],y=c[m];return typeof g=="function"&&typeof y=="function"?!0:g===y})}function defaultGetValueFromEvent(a){var c=arguments.length<=1?void 0:arguments[1];return c&&c.target&&_typeof(c.target)==="object"&&a in c.target?c.target[a]:c}function move(a,c,u){var d=a.length;if(c<0||c>=d||u<0||u>=d)return a;var f=a[c],m=c-u;return m>0?[].concat(_toConsumableArray(a.slice(0,u)),[f],_toConsumableArray(a.slice(u,c)),_toConsumableArray(a.slice(c+1,d))):m<0?[].concat(_toConsumableArray(a.slice(0,c)),_toConsumableArray(a.slice(c+1,u+1)),[f],_toConsumableArray(a.slice(u+1,d))):a}var _excluded$I=["name"],EMPTY_ERRORS=[];function requireUpdate(a,c,u,d,f,m){return typeof a=="function"?a(c,u,"source"in m?{source:m.source}:{}):d!==f}var Field=function(a){_inherits(u,a);var c=_createSuper(u);function u(d){var f;if(_classCallCheck(this,u),f=c.call(this,d),_defineProperty(_assertThisInitialized(f),"state",{resetCount:0}),_defineProperty(_assertThisInitialized(f),"cancelRegisterFunc",null),_defineProperty(_assertThisInitialized(f),"mounted",!1),_defineProperty(_assertThisInitialized(f),"touched",!1),_defineProperty(_assertThisInitialized(f),"dirty",!1),_defineProperty(_assertThisInitialized(f),"validatePromise",void 0),_defineProperty(_assertThisInitialized(f),"prevValidating",void 0),_defineProperty(_assertThisInitialized(f),"errors",EMPTY_ERRORS),_defineProperty(_assertThisInitialized(f),"warnings",EMPTY_ERRORS),_defineProperty(_assertThisInitialized(f),"cancelRegister",function(){var b=f.props,E=b.preserve,C=b.isListField,w=b.name;f.cancelRegisterFunc&&f.cancelRegisterFunc(C,E,getNamePath(w)),f.cancelRegisterFunc=null}),_defineProperty(_assertThisInitialized(f),"getNamePath",function(){var b=f.props,E=b.name,C=b.fieldContext,w=C.prefixName,R=w===void 0?[]:w;return E!==void 0?[].concat(_toConsumableArray(R),_toConsumableArray(E)):[]}),_defineProperty(_assertThisInitialized(f),"getRules",function(){var b=f.props,E=b.rules,C=E===void 0?[]:E,w=b.fieldContext;return C.map(function(R){return typeof R=="function"?R(w):R})}),_defineProperty(_assertThisInitialized(f),"refresh",function(){f.mounted&&f.setState(function(b){var E=b.resetCount;return{resetCount:E+1}})}),_defineProperty(_assertThisInitialized(f),"metaCache",null),_defineProperty(_assertThisInitialized(f),"triggerMetaEvent",function(b){var E=f.props.onMetaChange;if(E){var C=_objectSpread2(_objectSpread2({},f.getMeta()),{},{destroy:b});isEqual(f.metaCache,C)||E(C),f.metaCache=C}else f.metaCache=null}),_defineProperty(_assertThisInitialized(f),"onStoreChange",function(b,E,C){var w=f.props,R=w.shouldUpdate,_=w.dependencies,M=_===void 0?[]:_,I=w.onReset,N=C.store,A=f.getNamePath(),P=f.getValue(b),z=f.getValue(N),B=E&&containsNamePath(E,A);switch(C.type==="valueUpdate"&&C.source==="external"&&!isEqual(P,z)&&(f.touched=!0,f.dirty=!0,f.validatePromise=null,f.errors=EMPTY_ERRORS,f.warnings=EMPTY_ERRORS,f.triggerMetaEvent()),C.type){case"reset":if(!E||B){f.touched=!1,f.dirty=!1,f.validatePromise=void 0,f.errors=EMPTY_ERRORS,f.warnings=EMPTY_ERRORS,f.triggerMetaEvent(),I==null||I(),f.refresh();return}break;case"remove":{if(R&&requireUpdate(R,b,N,P,z,C)){f.reRender();return}break}case"setField":{var j=C.data;if(B){"touched"in j&&(f.touched=j.touched),"validating"in j&&!("originRCField"in j)&&(f.validatePromise=j.validating?Promise.resolve([]):null),"errors"in j&&(f.errors=j.errors||EMPTY_ERRORS),"warnings"in j&&(f.warnings=j.warnings||EMPTY_ERRORS),f.dirty=!0,f.triggerMetaEvent(),f.reRender();return}else if("value"in j&&containsNamePath(E,A,!0)){f.reRender();return}if(R&&!A.length&&requireUpdate(R,b,N,P,z,C)){f.reRender();return}break}case"dependenciesUpdate":{var L=M.map(getNamePath);if(L.some(function(U){return containsNamePath(C.relatedFields,U)})){f.reRender();return}break}default:if(B||(!M.length||A.length||R)&&requireUpdate(R,b,N,P,z,C)){f.reRender();return}break}R===!0&&f.reRender()}),_defineProperty(_assertThisInitialized(f),"validateRules",function(b){var E=f.getNamePath(),C=f.getValue(),w=b||{},R=w.triggerName,_=w.validateOnly,M=_===void 0?!1:_,I=Promise.resolve().then(_asyncToGenerator(_regeneratorRuntime().mark(function N(){var A,P,z,B,j,L,U;return _regeneratorRuntime().wrap(function(F){for(;;)switch(F.prev=F.next){case 0:if(f.mounted){F.next=2;break}return F.abrupt("return",[]);case 2:if(A=f.props,P=A.validateFirst,z=P===void 0?!1:P,B=A.messageVariables,j=A.validateDebounce,L=f.getRules(),R&&(L=L.filter(function(K){return K}).filter(function(K){var X=K.validateTrigger;if(!X)return!0;var Q=toArray$5(X);return Q.includes(R)})),!(j&&R)){F.next=10;break}return F.next=8,new Promise(function(K){setTimeout(K,j)});case 8:if(f.validatePromise===I){F.next=10;break}return F.abrupt("return",[]);case 10:return U=validateRules(E,C,L,b,z,B),U.catch(function(K){return K}).then(function(){var K=arguments.length>0&&arguments[0]!==void 0?arguments[0]:EMPTY_ERRORS;if(f.validatePromise===I){var X;f.validatePromise=null;var Q=[],Y=[];(X=K.forEach)===null||X===void 0||X.call(K,function(Z){var J=Z.rule.warningOnly,W=Z.errors,G=W===void 0?EMPTY_ERRORS:W;J?Y.push.apply(Y,_toConsumableArray(G)):Q.push.apply(Q,_toConsumableArray(G))}),f.errors=Q,f.warnings=Y,f.triggerMetaEvent(),f.reRender()}}),F.abrupt("return",U);case 13:case"end":return F.stop()}},N)})));return M||(f.validatePromise=I,f.dirty=!0,f.errors=EMPTY_ERRORS,f.warnings=EMPTY_ERRORS,f.triggerMetaEvent(),f.reRender()),I}),_defineProperty(_assertThisInitialized(f),"isFieldValidating",function(){return!!f.validatePromise}),_defineProperty(_assertThisInitialized(f),"isFieldTouched",function(){return f.touched}),_defineProperty(_assertThisInitialized(f),"isFieldDirty",function(){if(f.dirty||f.props.initialValue!==void 0)return!0;var b=f.props.fieldContext,E=b.getInternalHooks(HOOK_MARK),C=E.getInitialValue;return C(f.getNamePath())!==void 0}),_defineProperty(_assertThisInitialized(f),"getErrors",function(){return f.errors}),_defineProperty(_assertThisInitialized(f),"getWarnings",function(){return f.warnings}),_defineProperty(_assertThisInitialized(f),"isListField",function(){return f.props.isListField}),_defineProperty(_assertThisInitialized(f),"isList",function(){return f.props.isList}),_defineProperty(_assertThisInitialized(f),"isPreserve",function(){return f.props.preserve}),_defineProperty(_assertThisInitialized(f),"getMeta",function(){f.prevValidating=f.isFieldValidating();var b={touched:f.isFieldTouched(),validating:f.prevValidating,errors:f.errors,warnings:f.warnings,name:f.getNamePath(),validated:f.validatePromise===null};return b}),_defineProperty(_assertThisInitialized(f),"getOnlyChild",function(b){if(typeof b=="function"){var E=f.getMeta();return _objectSpread2(_objectSpread2({},f.getOnlyChild(b(f.getControlled(),E,f.props.fieldContext))),{},{isFunction:!0})}var C=toArray$6(b);return C.length!==1||!reactExports.isValidElement(C[0])?{child:C,isFunction:!1}:{child:C[0],isFunction:!1}}),_defineProperty(_assertThisInitialized(f),"getValue",function(b){var E=f.props.fieldContext.getFieldsValue,C=f.getNamePath();return get(b||E(!0),C)}),_defineProperty(_assertThisInitialized(f),"getControlled",function(){var b=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},E=f.props,C=E.name,w=E.trigger,R=E.validateTrigger,_=E.getValueFromEvent,M=E.normalize,I=E.valuePropName,N=E.getValueProps,A=E.fieldContext,P=R!==void 0?R:A.validateTrigger,z=f.getNamePath(),B=A.getInternalHooks,j=A.getFieldsValue,L=B(HOOK_MARK),U=L.dispatch,q=f.getValue(),F=N||function(Z){return _defineProperty({},I,Z)},K=b[w],X=C!==void 0?F(q):{},Q=_objectSpread2(_objectSpread2({},b),X);Q[w]=function(){f.touched=!0,f.dirty=!0,f.triggerMetaEvent();for(var Z,J=arguments.length,W=new Array(J),G=0;G<J;G++)W[G]=arguments[G];_?Z=_.apply(void 0,W):Z=defaultGetValueFromEvent.apply(void 0,[I].concat(W)),M&&(Z=M(Z,q,j(!0))),Z!==q&&U({type:"updateValue",namePath:z,value:Z}),K&&K.apply(void 0,W)};var Y=toArray$5(P||[]);return Y.forEach(function(Z){var J=Q[Z];Q[Z]=function(){J&&J.apply(void 0,arguments);var W=f.props.rules;W&&W.length&&U({type:"validateField",namePath:z,triggerName:Z})}}),Q}),d.fieldContext){var m=d.fieldContext.getInternalHooks,g=m(HOOK_MARK),y=g.initEntityValue;y(_assertThisInitialized(f))}return f}return _createClass(u,[{key:"componentDidMount",value:function(){var f=this.props,m=f.shouldUpdate,g=f.fieldContext;if(this.mounted=!0,g){var y=g.getInternalHooks,b=y(HOOK_MARK),E=b.registerField;this.cancelRegisterFunc=E(this)}m===!0&&this.reRender()}},{key:"componentWillUnmount",value:function(){this.cancelRegister(),this.triggerMetaEvent(!0),this.mounted=!1}},{key:"reRender",value:function(){this.mounted&&this.forceUpdate()}},{key:"render",value:function(){var f=this.state.resetCount,m=this.props.children,g=this.getOnlyChild(m),y=g.child,b=g.isFunction,E;return b?E=y:reactExports.isValidElement(y)?E=reactExports.cloneElement(y,this.getControlled(y.props)):(warningOnce$1(!y,"`children` of Field is not validate ReactElement."),E=y),reactExports.createElement(reactExports.Fragment,{key:f},E)}}]),u}(reactExports.Component);_defineProperty(Field,"contextType",Context);_defineProperty(Field,"defaultProps",{trigger:"onChange",valuePropName:"value"});function WrapperField(a){var c,u=a.name,d=_objectWithoutProperties(a,_excluded$I),f=reactExports.useContext(Context),m=reactExports.useContext(ListContext),g=u!==void 0?getNamePath(u):void 0,y=(c=d.isListField)!==null&&c!==void 0?c:!!m,b="keep";return y||(b="_".concat((g||[]).join("_"))),reactExports.createElement(Field,_extends({key:b,name:g,isListField:y},d,{fieldContext:f}))}function List$1(a){var c=a.name,u=a.initialValue,d=a.children,f=a.rules,m=a.validateTrigger,g=a.isListField,y=reactExports.useContext(Context),b=reactExports.useContext(ListContext),E=reactExports.useRef({keys:[],id:0}),C=E.current,w=reactExports.useMemo(function(){var I=getNamePath(y.prefixName)||[];return[].concat(_toConsumableArray(I),_toConsumableArray(getNamePath(c)))},[y.prefixName,c]),R=reactExports.useMemo(function(){return _objectSpread2(_objectSpread2({},y),{},{prefixName:w})},[y,w]),_=reactExports.useMemo(function(){return{getKey:function(N){var A=w.length,P=N[A];return[C.keys[P],N.slice(A+1)]}}},[w]);if(typeof d!="function")return warningOnce$1(!1,"Form.List only accepts function as children."),null;var M=function(N,A,P){var z=P.source;return z==="internal"?!1:N!==A};return reactExports.createElement(ListContext.Provider,{value:_},reactExports.createElement(Context.Provider,{value:R},reactExports.createElement(WrapperField,{name:[],shouldUpdate:M,rules:f,validateTrigger:m,initialValue:u,isList:!0,isListField:g??!!b},function(I,N){var A=I.value,P=A===void 0?[]:A,z=I.onChange,B=y.getFieldValue,j=function(){var F=B(w||[]);return F||[]},L={add:function(F,K){var X=j();K>=0&&K<=X.length?(C.keys=[].concat(_toConsumableArray(C.keys.slice(0,K)),[C.id],_toConsumableArray(C.keys.slice(K))),z([].concat(_toConsumableArray(X.slice(0,K)),[F],_toConsumableArray(X.slice(K))))):(C.keys=[].concat(_toConsumableArray(C.keys),[C.id]),z([].concat(_toConsumableArray(X),[F]))),C.id+=1},remove:function(F){var K=j(),X=new Set(Array.isArray(F)?F:[F]);X.size<=0||(C.keys=C.keys.filter(function(Q,Y){return!X.has(Y)}),z(K.filter(function(Q,Y){return!X.has(Y)})))},move:function(F,K){if(F!==K){var X=j();F<0||F>=X.length||K<0||K>=X.length||(C.keys=move(C.keys,F,K),z(move(X,F,K)))}}},U=P||[];return Array.isArray(U)||(U=[]),d(U.map(function(q,F){var K=C.keys[F];return K===void 0&&(C.keys[F]=C.id,K=C.keys[F],C.id+=1),{name:F,key:K,isListField:!0}}),L,N)})))}function allPromiseFinish(a){var c=!1,u=a.length,d=[];return a.length?new Promise(function(f,m){a.forEach(function(g,y){g.catch(function(b){return c=!0,b}).then(function(b){u-=1,d[y]=b,!(u>0)&&(c&&m(d),f(d))})})}):Promise.resolve([])}var SPLIT="__@field_split__";function normalize$2(a){return a.map(function(c){return"".concat(_typeof(c),":").concat(c)}).join(SPLIT)}var NameMap=function(){function a(){_classCallCheck(this,a),_defineProperty(this,"kvs",new Map)}return _createClass(a,[{key:"set",value:function(u,d){this.kvs.set(normalize$2(u),d)}},{key:"get",value:function(u){return this.kvs.get(normalize$2(u))}},{key:"update",value:function(u,d){var f=this.get(u),m=d(f);m?this.set(u,m):this.delete(u)}},{key:"delete",value:function(u){this.kvs.delete(normalize$2(u))}},{key:"map",value:function(u){return _toConsumableArray(this.kvs.entries()).map(function(d){var f=_slicedToArray(d,2),m=f[0],g=f[1],y=m.split(SPLIT);return u({key:y.map(function(b){var E=b.match(/^([^:]*):(.*)$/),C=_slicedToArray(E,3),w=C[1],R=C[2];return w==="number"?Number(R):R}),value:g})})}},{key:"toJSON",value:function(){var u={};return this.map(function(d){var f=d.key,m=d.value;return u[f.join(".")]=m,null}),u}}]),a}(),_excluded$H=["name"],FormStore=_createClass(function a(c){var u=this;_classCallCheck(this,a),_defineProperty(this,"formHooked",!1),_defineProperty(this,"forceRootUpdate",void 0),_defineProperty(this,"subscribable",!0),_defineProperty(this,"store",{}),_defineProperty(this,"fieldEntities",[]),_defineProperty(this,"initialValues",{}),_defineProperty(this,"callbacks",{}),_defineProperty(this,"validateMessages",null),_defineProperty(this,"preserve",null),_defineProperty(this,"lastValidatePromise",null),_defineProperty(this,"getForm",function(){return{getFieldValue:u.getFieldValue,getFieldsValue:u.getFieldsValue,getFieldError:u.getFieldError,getFieldWarning:u.getFieldWarning,getFieldsError:u.getFieldsError,isFieldsTouched:u.isFieldsTouched,isFieldTouched:u.isFieldTouched,isFieldValidating:u.isFieldValidating,isFieldsValidating:u.isFieldsValidating,resetFields:u.resetFields,setFields:u.setFields,setFieldValue:u.setFieldValue,setFieldsValue:u.setFieldsValue,validateFields:u.validateFields,submit:u.submit,_init:!0,getInternalHooks:u.getInternalHooks}}),_defineProperty(this,"getInternalHooks",function(d){return d===HOOK_MARK?(u.formHooked=!0,{dispatch:u.dispatch,initEntityValue:u.initEntityValue,registerField:u.registerField,useSubscribe:u.useSubscribe,setInitialValues:u.setInitialValues,destroyForm:u.destroyForm,setCallbacks:u.setCallbacks,setValidateMessages:u.setValidateMessages,getFields:u.getFields,setPreserve:u.setPreserve,getInitialValue:u.getInitialValue,registerWatch:u.registerWatch}):(warningOnce$1(!1,"`getInternalHooks` is internal usage. Should not call directly."),null)}),_defineProperty(this,"useSubscribe",function(d){u.subscribable=d}),_defineProperty(this,"prevWithoutPreserves",null),_defineProperty(this,"setInitialValues",function(d,f){if(u.initialValues=d||{},f){var m,g=merge$3(d,u.store);(m=u.prevWithoutPreserves)===null||m===void 0||m.map(function(y){var b=y.key;g=set$1(g,b,get(d,b))}),u.prevWithoutPreserves=null,u.updateStore(g)}}),_defineProperty(this,"destroyForm",function(d){if(d)u.updateStore({});else{var f=new NameMap;u.getFieldEntities(!0).forEach(function(m){u.isMergedPreserve(m.isPreserve())||f.set(m.getNamePath(),!0)}),u.prevWithoutPreserves=f}}),_defineProperty(this,"getInitialValue",function(d){var f=get(u.initialValues,d);return d.length?merge$3(f):f}),_defineProperty(this,"setCallbacks",function(d){u.callbacks=d}),_defineProperty(this,"setValidateMessages",function(d){u.validateMessages=d}),_defineProperty(this,"setPreserve",function(d){u.preserve=d}),_defineProperty(this,"watchList",[]),_defineProperty(this,"registerWatch",function(d){return u.watchList.push(d),function(){u.watchList=u.watchList.filter(function(f){return f!==d})}}),_defineProperty(this,"notifyWatch",function(){var d=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];if(u.watchList.length){var f=u.getFieldsValue(),m=u.getFieldsValue(!0);u.watchList.forEach(function(g){g(f,m,d)})}}),_defineProperty(this,"timeoutId",null),_defineProperty(this,"warningUnhooked",function(){}),_defineProperty(this,"updateStore",function(d){u.store=d}),_defineProperty(this,"getFieldEntities",function(){var d=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1;return d?u.fieldEntities.filter(function(f){return f.getNamePath().length}):u.fieldEntities}),_defineProperty(this,"getFieldsMap",function(){var d=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1,f=new NameMap;return u.getFieldEntities(d).forEach(function(m){var g=m.getNamePath();f.set(g,m)}),f}),_defineProperty(this,"getFieldEntitiesForNamePathList",function(d){if(!d)return u.getFieldEntities(!0);var f=u.getFieldsMap(!0);return d.map(function(m){var g=getNamePath(m);return f.get(g)||{INVALIDATE_NAME_PATH:getNamePath(m)}})}),_defineProperty(this,"getFieldsValue",function(d,f){u.warningUnhooked();var m,g,y;if(d===!0||Array.isArray(d)?(m=d,g=f):d&&_typeof(d)==="object"&&(y=d.strict,g=d.filter),m===!0&&!g)return u.store;var b=u.getFieldEntitiesForNamePathList(Array.isArray(m)?m:null),E=[];return b.forEach(function(C){var w,R,_="INVALIDATE_NAME_PATH"in C?C.INVALIDATE_NAME_PATH:C.getNamePath();if(y){var M,I;if((M=(I=C).isList)!==null&&M!==void 0&&M.call(I))return}else if(!m&&(w=(R=C).isListField)!==null&&w!==void 0&&w.call(R))return;if(!g)E.push(_);else{var N="getMeta"in C?C.getMeta():null;g(N)&&E.push(_)}}),cloneByNamePathList(u.store,E.map(getNamePath))}),_defineProperty(this,"getFieldValue",function(d){u.warningUnhooked();var f=getNamePath(d);return get(u.store,f)}),_defineProperty(this,"getFieldsError",function(d){u.warningUnhooked();var f=u.getFieldEntitiesForNamePathList(d);return f.map(function(m,g){return m&&!("INVALIDATE_NAME_PATH"in m)?{name:m.getNamePath(),errors:m.getErrors(),warnings:m.getWarnings()}:{name:getNamePath(d[g]),errors:[],warnings:[]}})}),_defineProperty(this,"getFieldError",function(d){u.warningUnhooked();var f=getNamePath(d),m=u.getFieldsError([f])[0];return m.errors}),_defineProperty(this,"getFieldWarning",function(d){u.warningUnhooked();var f=getNamePath(d),m=u.getFieldsError([f])[0];return m.warnings}),_defineProperty(this,"isFieldsTouched",function(){u.warningUnhooked();for(var d=arguments.length,f=new Array(d),m=0;m<d;m++)f[m]=arguments[m];var g=f[0],y=f[1],b,E=!1;f.length===0?b=null:f.length===1?Array.isArray(g)?(b=g.map(getNamePath),E=!1):(b=null,E=g):(b=g.map(getNamePath),E=y);var C=u.getFieldEntities(!0),w=function(N){return N.isFieldTouched()};if(!b)return E?C.every(function(I){return w(I)||I.isList()}):C.some(w);var R=new NameMap;b.forEach(function(I){R.set(I,[])}),C.forEach(function(I){var N=I.getNamePath();b.forEach(function(A){A.every(function(P,z){return N[z]===P})&&R.update(A,function(P){return[].concat(_toConsumableArray(P),[I])})})});var _=function(N){return N.some(w)},M=R.map(function(I){var N=I.value;return N});return E?M.every(_):M.some(_)}),_defineProperty(this,"isFieldTouched",function(d){return u.warningUnhooked(),u.isFieldsTouched([d])}),_defineProperty(this,"isFieldsValidating",function(d){u.warningUnhooked();var f=u.getFieldEntities();if(!d)return f.some(function(g){return g.isFieldValidating()});var m=d.map(getNamePath);return f.some(function(g){var y=g.getNamePath();return containsNamePath(m,y)&&g.isFieldValidating()})}),_defineProperty(this,"isFieldValidating",function(d){return u.warningUnhooked(),u.isFieldsValidating([d])}),_defineProperty(this,"resetWithFieldInitialValue",function(){var d=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{},f=new NameMap,m=u.getFieldEntities(!0);m.forEach(function(b){var E=b.props.initialValue,C=b.getNamePath();if(E!==void 0){var w=f.get(C)||new Set;w.add({entity:b,value:E}),f.set(C,w)}});var g=function(E){E.forEach(function(C){var w=C.props.initialValue;if(w!==void 0){var R=C.getNamePath(),_=u.getInitialValue(R);if(_!==void 0)warningOnce$1(!1,"Form already set 'initialValues' with path '".concat(R.join("."),"'. Field can not overwrite it."));else{var M=f.get(R);if(M&&M.size>1)warningOnce$1(!1,"Multiple Field with path '".concat(R.join("."),"' set 'initialValue'. Can not decide which one to pick."));else if(M){var I=u.getFieldValue(R),N=C.isListField();!N&&(!d.skipExist||I===void 0)&&u.updateStore(set$1(u.store,R,_toConsumableArray(M)[0].value))}}}})},y;d.entities?y=d.entities:d.namePathList?(y=[],d.namePathList.forEach(function(b){var E=f.get(b);if(E){var C;(C=y).push.apply(C,_toConsumableArray(_toConsumableArray(E).map(function(w){return w.entity})))}})):y=m,g(y)}),_defineProperty(this,"resetFields",function(d){u.warningUnhooked();var f=u.store;if(!d){u.updateStore(merge$3(u.initialValues)),u.resetWithFieldInitialValue(),u.notifyObservers(f,null,{type:"reset"}),u.notifyWatch();return}var m=d.map(getNamePath);m.forEach(function(g){var y=u.getInitialValue(g);u.updateStore(set$1(u.store,g,y))}),u.resetWithFieldInitialValue({namePathList:m}),u.notifyObservers(f,m,{type:"reset"}),u.notifyWatch(m)}),_defineProperty(this,"setFields",function(d){u.warningUnhooked();var f=u.store,m=[];d.forEach(function(g){var y=g.name,b=_objectWithoutProperties(g,_excluded$H),E=getNamePath(y);m.push(E),"value"in b&&u.updateStore(set$1(u.store,E,b.value)),u.notifyObservers(f,[E],{type:"setField",data:g})}),u.notifyWatch(m)}),_defineProperty(this,"getFields",function(){var d=u.getFieldEntities(!0),f=d.map(function(m){var g=m.getNamePath(),y=m.getMeta(),b=_objectSpread2(_objectSpread2({},y),{},{name:g,value:u.getFieldValue(g)});return Object.defineProperty(b,"originRCField",{value:!0}),b});return f}),_defineProperty(this,"initEntityValue",function(d){var f=d.props.initialValue;if(f!==void 0){var m=d.getNamePath(),g=get(u.store,m);g===void 0&&u.updateStore(set$1(u.store,m,f))}}),_defineProperty(this,"isMergedPreserve",function(d){var f=d!==void 0?d:u.preserve;return f??!0}),_defineProperty(this,"registerField",function(d){u.fieldEntities.push(d);var f=d.getNamePath();if(u.notifyWatch([f]),d.props.initialValue!==void 0){var m=u.store;u.resetWithFieldInitialValue({entities:[d],skipExist:!0}),u.notifyObservers(m,[d.getNamePath()],{type:"valueUpdate",source:"internal"})}return function(g,y){var b=arguments.length>2&&arguments[2]!==void 0?arguments[2]:[];if(u.fieldEntities=u.fieldEntities.filter(function(w){return w!==d}),!u.isMergedPreserve(y)&&(!g||b.length>1)){var E=g?void 0:u.getInitialValue(f);if(f.length&&u.getFieldValue(f)!==E&&u.fieldEntities.every(function(w){return!matchNamePath(w.getNamePath(),f)})){var C=u.store;u.updateStore(set$1(C,f,E,!0)),u.notifyObservers(C,[f],{type:"remove"}),u.triggerDependenciesUpdate(C,f)}}u.notifyWatch([f])}}),_defineProperty(this,"dispatch",function(d){switch(d.type){case"updateValue":{var f=d.namePath,m=d.value;u.updateValue(f,m);break}case"validateField":{var g=d.namePath,y=d.triggerName;u.validateFields([g],{triggerName:y});break}}}),_defineProperty(this,"notifyObservers",function(d,f,m){if(u.subscribable){var g=_objectSpread2(_objectSpread2({},m),{},{store:u.getFieldsValue(!0)});u.getFieldEntities().forEach(function(y){var b=y.onStoreChange;b(d,f,g)})}else u.forceRootUpdate()}),_defineProperty(this,"triggerDependenciesUpdate",function(d,f){var m=u.getDependencyChildrenFields(f);return m.length&&u.validateFields(m),u.notifyObservers(d,m,{type:"dependenciesUpdate",relatedFields:[f].concat(_toConsumableArray(m))}),m}),_defineProperty(this,"updateValue",function(d,f){var m=getNamePath(d),g=u.store;u.updateStore(set$1(u.store,m,f)),u.notifyObservers(g,[m],{type:"valueUpdate",source:"internal"}),u.notifyWatch([m]);var y=u.triggerDependenciesUpdate(g,m),b=u.callbacks.onValuesChange;if(b){var E=cloneByNamePathList(u.store,[m]);b(E,u.getFieldsValue())}u.triggerOnFieldsChange([m].concat(_toConsumableArray(y)))}),_defineProperty(this,"setFieldsValue",function(d){u.warningUnhooked();var f=u.store;if(d){var m=merge$3(u.store,d);u.updateStore(m)}u.notifyObservers(f,null,{type:"valueUpdate",source:"external"}),u.notifyWatch()}),_defineProperty(this,"setFieldValue",function(d,f){u.setFields([{name:d,value:f,errors:[],warnings:[]}])}),_defineProperty(this,"getDependencyChildrenFields",function(d){var f=new Set,m=[],g=new NameMap;u.getFieldEntities().forEach(function(b){var E=b.props.dependencies;(E||[]).forEach(function(C){var w=getNamePath(C);g.update(w,function(){var R=arguments.length>0&&arguments[0]!==void 0?arguments[0]:new Set;return R.add(b),R})})});var y=function b(E){var C=g.get(E)||new Set;C.forEach(function(w){if(!f.has(w)){f.add(w);var R=w.getNamePath();w.isFieldDirty()&&R.length&&(m.push(R),b(R))}})};return y(d),m}),_defineProperty(this,"triggerOnFieldsChange",function(d,f){var m=u.callbacks.onFieldsChange;if(m){var g=u.getFields();if(f){var y=new NameMap;f.forEach(function(E){var C=E.name,w=E.errors;y.set(C,w)}),g.forEach(function(E){E.errors=y.get(E.name)||E.errors})}var b=g.filter(function(E){var C=E.name;return containsNamePath(d,C)});b.length&&m(b,g)}}),_defineProperty(this,"validateFields",function(d,f){u.warningUnhooked();var m,g;Array.isArray(d)||typeof d=="string"||typeof f=="string"?(m=d,g=f):g=d;var y=!!m,b=y?m.map(getNamePath):[],E=[],C=String(Date.now()),w=new Set,R=g||{},_=R.recursive,M=R.dirty;u.getFieldEntities(!0).forEach(function(P){if(y||b.push(P.getNamePath()),!(!P.props.rules||!P.props.rules.length)&&!(M&&!P.isFieldDirty())){var z=P.getNamePath();if(w.add(z.join(C)),!y||containsNamePath(b,z,_)){var B=P.validateRules(_objectSpread2({validateMessages:_objectSpread2(_objectSpread2({},defaultValidateMessages),u.validateMessages)},g));E.push(B.then(function(){return{name:z,errors:[],warnings:[]}}).catch(function(j){var L,U=[],q=[];return(L=j.forEach)===null||L===void 0||L.call(j,function(F){var K=F.rule.warningOnly,X=F.errors;K?q.push.apply(q,_toConsumableArray(X)):U.push.apply(U,_toConsumableArray(X))}),U.length?Promise.reject({name:z,errors:U,warnings:q}):{name:z,errors:U,warnings:q}}))}}});var I=allPromiseFinish(E);u.lastValidatePromise=I,I.catch(function(P){return P}).then(function(P){var z=P.map(function(B){var j=B.name;return j});u.notifyObservers(u.store,z,{type:"validateFinish"}),u.triggerOnFieldsChange(z,P)});var N=I.then(function(){return u.lastValidatePromise===I?Promise.resolve(u.getFieldsValue(b)):Promise.reject([])}).catch(function(P){var z=P.filter(function(B){return B&&B.errors.length});return Promise.reject({values:u.getFieldsValue(b),errorFields:z,outOfDate:u.lastValidatePromise!==I})});N.catch(function(P){return P});var A=b.filter(function(P){return w.has(P.join(C))});return u.triggerOnFieldsChange(A),N}),_defineProperty(this,"submit",function(){u.warningUnhooked(),u.validateFields().then(function(d){var f=u.callbacks.onFinish;if(f)try{f(d)}catch(m){console.error(m)}}).catch(function(d){var f=u.callbacks.onFinishFailed;f&&f(d)})}),this.forceRootUpdate=c});function useForm$1(a){var c=reactExports.useRef(),u=reactExports.useState({}),d=_slicedToArray(u,2),f=d[1];if(!c.current)if(a)c.current=a;else{var m=function(){f({})},g=new FormStore(m);c.current=g.getForm()}return[c.current]}var FormContext$1=reactExports.createContext({triggerFormChange:function(){},triggerFormFinish:function(){},registerForm:function(){},unregisterForm:function(){}}),FormProvider$1=function(c){var u=c.validateMessages,d=c.onFormChange,f=c.onFormFinish,m=c.children,g=reactExports.useContext(FormContext$1),y=reactExports.useRef({});return reactExports.createElement(FormContext$1.Provider,{value:_objectSpread2(_objectSpread2({},g),{},{validateMessages:_objectSpread2(_objectSpread2({},g.validateMessages),u),triggerFormChange:function(E,C){d&&d(E,{changedFields:C,forms:y.current}),g.triggerFormChange(E,C)},triggerFormFinish:function(E,C){f&&f(E,{values:C,forms:y.current}),g.triggerFormFinish(E,C)},registerForm:function(E,C){E&&(y.current=_objectSpread2(_objectSpread2({},y.current),{},_defineProperty({},E,C))),g.registerForm(E,C)},unregisterForm:function(E){var C=_objectSpread2({},y.current);delete C[E],y.current=C,g.unregisterForm(E)}})},m)},_excluded$G=["name","initialValues","fields","form","preserve","children","component","validateMessages","validateTrigger","onValuesChange","onFieldsChange","onFinish","onFinishFailed","clearOnDestroy"],Form$3=function(c,u){var d=c.name,f=c.initialValues,m=c.fields,g=c.form,y=c.preserve,b=c.children,E=c.component,C=E===void 0?"form":E,w=c.validateMessages,R=c.validateTrigger,_=R===void 0?"onChange":R,M=c.onValuesChange,I=c.onFieldsChange,N=c.onFinish,A=c.onFinishFailed,P=c.clearOnDestroy,z=_objectWithoutProperties(c,_excluded$G),B=reactExports.useRef(null),j=reactExports.useContext(FormContext$1),L=useForm$1(g),U=_slicedToArray(L,1),q=U[0],F=q.getInternalHooks(HOOK_MARK),K=F.useSubscribe,X=F.setInitialValues,Q=F.setCallbacks,Y=F.setValidateMessages,Z=F.setPreserve,J=F.destroyForm;reactExports.useImperativeHandle(u,function(){return _objectSpread2(_objectSpread2({},q),{},{nativeElement:B.current})}),reactExports.useEffect(function(){return j.registerForm(d,q),function(){j.unregisterForm(d)}},[j,q,d]),Y(_objectSpread2(_objectSpread2({},j.validateMessages),w)),Q({onValuesChange:M,onFieldsChange:function(ie){if(j.triggerFormChange(d,ie),I){for(var ce=arguments.length,ue=new Array(ce>1?ce-1:0),me=1;me<ce;me++)ue[me-1]=arguments[me];I.apply(void 0,[ie].concat(ue))}},onFinish:function(ie){j.triggerFormFinish(d,ie),N&&N(ie)},onFinishFailed:A}),Z(y);var W=reactExports.useRef(null);X(f,!W.current),W.current||(W.current=!0),reactExports.useEffect(function(){return function(){return J(P)}},[]);var G,te=typeof b=="function";if(te){var ae=q.getFieldsValue(!0);G=b(ae,q)}else G=b;K(!te);var V=reactExports.useRef();reactExports.useEffect(function(){isSimilar(V.current||[],m||[])||q.setFields(m||[]),V.current=m},[m,q]);var ne=reactExports.useMemo(function(){return _objectSpread2(_objectSpread2({},q),{},{validateTrigger:_})},[q,_]),le=reactExports.createElement(ListContext.Provider,{value:null},reactExports.createElement(Context.Provider,{value:ne},G));return C===!1?le:reactExports.createElement(C,_extends({},z,{ref:B,onSubmit:function(ie){ie.preventDefault(),ie.stopPropagation(),q.submit()},onReset:function(ie){var ce;ie.preventDefault(),q.resetFields(),(ce=z.onReset)===null||ce===void 0||ce.call(z,ie)}}),le)};function stringify$3(a){try{return JSON.stringify(a)}catch{return Math.random()}}function useWatch$1(){for(var a=arguments.length,c=new Array(a),u=0;u<a;u++)c[u]=arguments[u];var d=c[0],f=c[1],m=f===void 0?{}:f,g=isFormInstance(m)?{form:m}:m,y=g.form,b=reactExports.useState(),E=_slicedToArray(b,2),C=E[0],w=E[1],R=reactExports.useMemo(function(){return stringify$3(C)},[C]),_=reactExports.useRef(R);_.current=R;var M=reactExports.useContext(Context),I=y||M,N=I&&I._init,A=getNamePath(d),P=reactExports.useRef(A);return P.current=A,reactExports.useEffect(function(){if(N){var z=I.getFieldsValue,B=I.getInternalHooks,j=B(HOOK_MARK),L=j.registerWatch,U=function(X,Q){var Y=g.preserve?Q:X;return typeof d=="function"?d(Y):get(Y,P.current)},q=L(function(K,X){var Q=U(K,X),Y=stringify$3(Q);_.current!==Y&&(_.current=Y,w(Q))}),F=U(z(),z(!0));return C!==F&&w(F),q}},[N]),C}var InternalForm$1=reactExports.forwardRef(Form$3),RefForm=InternalForm$1;RefForm.FormProvider=FormProvider$1;RefForm.Field=WrapperField;RefForm.List=List$1;RefForm.useForm=useForm$1;RefForm.useWatch=useWatch$1;const FormContext=reactExports.createContext({labelAlign:"right",vertical:!1,itemRef:()=>{}}),NoStyleItemContext=reactExports.createContext(null),FormProvider=a=>{const c=omit(a,["prefixCls"]);return reactExports.createElement(FormProvider$1,Object.assign({},c))},FormItemPrefixContext=reactExports.createContext({prefixCls:""}),FormItemInputContext=reactExports.createContext({}),NoFormStyle=a=>{let{children:c,status:u,override:d}=a;const f=reactExports.useContext(FormItemInputContext),m=reactExports.useMemo(()=>{const g=Object.assign({},f);return d&&delete g.isFormItemInput,u&&(delete g.status,delete g.hasFeedback,delete g.feedbackIcon),g},[u,d,f]);return reactExports.createElement(FormItemInputContext.Provider,{value:m},c)},VariantContext=reactExports.createContext(void 0),ContextIsolator=a=>{const{space:c,form:u,children:d}=a;if(d==null)return null;let f=d;return u&&(f=React.createElement(NoFormStyle,{override:!0,status:!0},f)),c&&(f=React.createElement(NoCompactStyle,null,f)),f};function pickClosable(a){if(a)return{closable:a.closable,closeIcon:a.closeIcon}}function useClosableConfig(a){const{closable:c,closeIcon:u}=a||{};return React.useMemo(()=>{if(!c&&(c===!1||u===!1||u===null))return!1;if(c===void 0&&u===void 0)return null;let d={closeIcon:typeof u!="boolean"&&u!==null?u:void 0};return c&&typeof c=="object"&&(d=Object.assign(Object.assign({},d),c)),d},[c,u])}function assignWithoutUndefined(){const a={};for(var c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];return u.forEach(f=>{f&&Object.keys(f).forEach(m=>{f[m]!==void 0&&(a[m]=f[m])})}),a}const EmptyFallbackCloseCollection={};function useClosable(a,c){let u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:EmptyFallbackCloseCollection;const d=useClosableConfig(a),f=useClosableConfig(c),m=typeof d!="boolean"?!!(d!=null&&d.disabled):!1,g=React.useMemo(()=>Object.assign({closeIcon:React.createElement(RefIcon$x,null)},u),[u]),y=React.useMemo(()=>d===!1?!1:d?assignWithoutUndefined(g,f,d):f===!1?!1:f?assignWithoutUndefined(g,f):g.closable?g:!1,[d,f,g]);return React.useMemo(()=>{if(y===!1)return[!1,null,m];const{closeIconRender:b}=g,{closeIcon:E}=y;let C=E;if(C!=null){b&&(C=b(E));const w=pickAttrs(y,!0);Object.keys(w).length&&(C=React.isValidElement(C)?React.cloneElement(C,w):React.createElement("span",Object.assign({},w),C))}return[!0,C,m]},[y,g])}var isStyleNameSupport=function(c){if(canUseDom()&&window.document.documentElement){var u=Array.isArray(c)?c:[c],d=window.document.documentElement;return u.some(function(f){return f in d.style})}return!1},isStyleValueSupport=function(c,u){if(!isStyleNameSupport(c))return!1;var d=document.createElement("div"),f=d.style[c];return d.style[c]=u,d.style[c]!==f};function isStyleSupport(a,c){return!Array.isArray(a)&&c!==void 0?isStyleValueSupport(a,c):isStyleNameSupport(a)}const Element$1=a=>{const{prefixCls:c,className:u,style:d,size:f,shape:m}=a,g=classNames({[`${c}-lg`]:f==="large",[`${c}-sm`]:f==="small"}),y=classNames({[`${c}-circle`]:m==="circle",[`${c}-square`]:m==="square",[`${c}-round`]:m==="round"}),b=reactExports.useMemo(()=>typeof f=="number"?{width:f,height:f,lineHeight:`${f}px`}:{},[f]);return reactExports.createElement("span",{className:classNames(c,g,y,u),style:Object.assign(Object.assign({},b),d)})},skeletonClsLoading=new Keyframe("ant-skeleton-loading",{"0%":{backgroundPosition:"100% 50%"},"100%":{backgroundPosition:"0 50%"}}),genSkeletonElementCommonSize=a=>({height:a,lineHeight:unit$1(a)}),genSkeletonElementAvatarSize=a=>Object.assign({width:a},genSkeletonElementCommonSize(a)),genSkeletonColor=a=>({background:a.skeletonLoadingBackground,backgroundSize:"400% 100%",animationName:skeletonClsLoading,animationDuration:a.skeletonLoadingMotionDuration,animationTimingFunction:"ease",animationIterationCount:"infinite"}),genSkeletonElementInputSize=(a,c)=>Object.assign({width:c(a).mul(5).equal(),minWidth:c(a).mul(5).equal()},genSkeletonElementCommonSize(a)),genSkeletonElementAvatar=a=>{const{skeletonAvatarCls:c,gradientFromColor:u,controlHeight:d,controlHeightLG:f,controlHeightSM:m}=a;return{[c]:Object.assign({display:"inline-block",verticalAlign:"top",background:u},genSkeletonElementAvatarSize(d)),[`${c}${c}-circle`]:{borderRadius:"50%"},[`${c}${c}-lg`]:Object.assign({},genSkeletonElementAvatarSize(f)),[`${c}${c}-sm`]:Object.assign({},genSkeletonElementAvatarSize(m))}},genSkeletonElementInput=a=>{const{controlHeight:c,borderRadiusSM:u,skeletonInputCls:d,controlHeightLG:f,controlHeightSM:m,gradientFromColor:g,calc:y}=a;return{[d]:Object.assign({display:"inline-block",verticalAlign:"top",background:g,borderRadius:u},genSkeletonElementInputSize(c,y)),[`${d}-lg`]:Object.assign({},genSkeletonElementInputSize(f,y)),[`${d}-sm`]:Object.assign({},genSkeletonElementInputSize(m,y))}},genSkeletonElementImageSize=a=>Object.assign({width:a},genSkeletonElementCommonSize(a)),genSkeletonElementImage=a=>{const{skeletonImageCls:c,imageSizeBase:u,gradientFromColor:d,borderRadiusSM:f,calc:m}=a;return{[c]:Object.assign(Object.assign({display:"inline-flex",alignItems:"center",justifyContent:"center",verticalAlign:"middle",background:d,borderRadius:f},genSkeletonElementImageSize(m(u).mul(2).equal())),{[`${c}-path`]:{fill:"#bfbfbf"},[`${c}-svg`]:Object.assign(Object.assign({},genSkeletonElementImageSize(u)),{maxWidth:m(u).mul(4).equal(),maxHeight:m(u).mul(4).equal()}),[`${c}-svg${c}-svg-circle`]:{borderRadius:"50%"}}),[`${c}${c}-circle`]:{borderRadius:"50%"}}},genSkeletonElementButtonShape=(a,c,u)=>{const{skeletonButtonCls:d}=a;return{[`${u}${d}-circle`]:{width:c,minWidth:c,borderRadius:"50%"},[`${u}${d}-round`]:{borderRadius:c}}},genSkeletonElementButtonSize=(a,c)=>Object.assign({width:c(a).mul(2).equal(),minWidth:c(a).mul(2).equal()},genSkeletonElementCommonSize(a)),genSkeletonElementButton=a=>{const{borderRadiusSM:c,skeletonButtonCls:u,controlHeight:d,controlHeightLG:f,controlHeightSM:m,gradientFromColor:g,calc:y}=a;return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({[u]:Object.assign({display:"inline-block",verticalAlign:"top",background:g,borderRadius:c,width:y(d).mul(2).equal(),minWidth:y(d).mul(2).equal()},genSkeletonElementButtonSize(d,y))},genSkeletonElementButtonShape(a,d,u)),{[`${u}-lg`]:Object.assign({},genSkeletonElementButtonSize(f,y))}),genSkeletonElementButtonShape(a,f,`${u}-lg`)),{[`${u}-sm`]:Object.assign({},genSkeletonElementButtonSize(m,y))}),genSkeletonElementButtonShape(a,m,`${u}-sm`))},genBaseStyle$6=a=>{const{componentCls:c,skeletonAvatarCls:u,skeletonTitleCls:d,skeletonParagraphCls:f,skeletonButtonCls:m,skeletonInputCls:g,skeletonImageCls:y,controlHeight:b,controlHeightLG:E,controlHeightSM:C,gradientFromColor:w,padding:R,marginSM:_,borderRadius:M,titleHeight:I,blockRadius:N,paragraphLiHeight:A,controlHeightXS:P,paragraphMarginTop:z}=a;return{[c]:{display:"table",width:"100%",[`${c}-header`]:{display:"table-cell",paddingInlineEnd:R,verticalAlign:"top",[u]:Object.assign({display:"inline-block",verticalAlign:"top",background:w},genSkeletonElementAvatarSize(b)),[`${u}-circle`]:{borderRadius:"50%"},[`${u}-lg`]:Object.assign({},genSkeletonElementAvatarSize(E)),[`${u}-sm`]:Object.assign({},genSkeletonElementAvatarSize(C))},[`${c}-content`]:{display:"table-cell",width:"100%",verticalAlign:"top",[d]:{width:"100%",height:I,background:w,borderRadius:N,[`+ ${f}`]:{marginBlockStart:C}},[f]:{padding:0,"> li":{width:"100%",height:A,listStyle:"none",background:w,borderRadius:N,"+ li":{marginBlockStart:P}}},[`${f}> li:last-child:not(:first-child):not(:nth-child(2))`]:{width:"61%"}},[`&-round ${c}-content`]:{[`${d}, ${f} > li`]:{borderRadius:M}}},[`${c}-with-avatar ${c}-content`]:{[d]:{marginBlockStart:_,[`+ ${f}`]:{marginBlockStart:z}}},[`${c}${c}-element`]:Object.assign(Object.assign(Object.assign(Object.assign({display:"inline-block",width:"auto"},genSkeletonElementButton(a)),genSkeletonElementAvatar(a)),genSkeletonElementInput(a)),genSkeletonElementImage(a)),[`${c}${c}-block`]:{width:"100%",[m]:{width:"100%"},[g]:{width:"100%"}},[`${c}${c}-active`]:{[`
        ${d},
        ${f} > li,
        ${u},
        ${m},
        ${g},
        ${y}
      `]:Object.assign({},genSkeletonColor(a))}}},prepareComponentToken$l=a=>{const{colorFillContent:c,colorFill:u}=a,d=c,f=u;return{color:d,colorGradientEnd:f,gradientFromColor:d,gradientToColor:f,titleHeight:a.controlHeight/2,blockRadius:a.borderRadiusSM,paragraphMarginTop:a.marginLG+a.marginXXS,paragraphLiHeight:a.controlHeight/2}},useStyle$q=genStyleHooks("Skeleton",a=>{const{componentCls:c,calc:u}=a,d=merge$2(a,{skeletonAvatarCls:`${c}-avatar`,skeletonTitleCls:`${c}-title`,skeletonParagraphCls:`${c}-paragraph`,skeletonButtonCls:`${c}-button`,skeletonInputCls:`${c}-input`,skeletonImageCls:`${c}-image`,imageSizeBase:u(a.controlHeight).mul(1.5).equal(),borderRadius:100,skeletonLoadingBackground:`linear-gradient(90deg, ${a.gradientFromColor} 25%, ${a.gradientToColor} 37%, ${a.gradientFromColor} 63%)`,skeletonLoadingMotionDuration:"1.4s"});return[genBaseStyle$6(d)]},prepareComponentToken$l,{deprecatedTokens:[["color","gradientFromColor"],["colorGradientEnd","gradientToColor"]]}),SkeletonAvatar=a=>{const{prefixCls:c,className:u,rootClassName:d,active:f,shape:m="circle",size:g="default"}=a,{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("skeleton",c),[E,C,w]=useStyle$q(b),R=omit(a,["prefixCls","className"]),_=classNames(b,`${b}-element`,{[`${b}-active`]:f},u,d,C,w);return E(reactExports.createElement("div",{className:_},reactExports.createElement(Element$1,Object.assign({prefixCls:`${b}-avatar`,shape:m,size:g},R))))},SkeletonButton=a=>{const{prefixCls:c,className:u,rootClassName:d,active:f,block:m=!1,size:g="default"}=a,{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("skeleton",c),[E,C,w]=useStyle$q(b),R=omit(a,["prefixCls"]),_=classNames(b,`${b}-element`,{[`${b}-active`]:f,[`${b}-block`]:m},u,d,C,w);return E(reactExports.createElement("div",{className:_},reactExports.createElement(Element$1,Object.assign({prefixCls:`${b}-button`,size:g},R))))},path$2="M365.714286 329.142857q0 45.714286-32.036571 77.677714t-77.677714 32.036571-77.677714-32.036571-32.036571-77.677714 32.036571-77.677714 77.677714-32.036571 77.677714 32.036571 32.036571 77.677714zM950.857143 548.571429l0 256-804.571429 0 0-109.714286 182.857143-182.857143 91.428571 91.428571 292.571429-292.571429zM1005.714286 146.285714l-914.285714 0q-7.460571 0-12.873143 5.412571t-5.412571 12.873143l0 694.857143q0 7.460571 5.412571 12.873143t12.873143 5.412571l914.285714 0q7.460571 0 12.873143-5.412571t5.412571-12.873143l0-694.857143q0-7.460571-5.412571-12.873143t-12.873143-5.412571zM1097.142857 164.571429l0 694.857143q0 37.741714-26.843429 64.585143t-64.585143 26.843429l-914.285714 0q-37.741714 0-64.585143-26.843429t-26.843429-64.585143l0-694.857143q0-37.741714 26.843429-64.585143t64.585143-26.843429l914.285714 0q37.741714 0 64.585143 26.843429t26.843429 64.585143z",SkeletonImage=a=>{const{prefixCls:c,className:u,rootClassName:d,style:f,active:m}=a,{getPrefixCls:g}=reactExports.useContext(ConfigContext),y=g("skeleton",c),[b,E,C]=useStyle$q(y),w=classNames(y,`${y}-element`,{[`${y}-active`]:m},u,d,E,C);return b(reactExports.createElement("div",{className:w},reactExports.createElement("div",{className:classNames(`${y}-image`,u),style:f},reactExports.createElement("svg",{viewBox:"0 0 1098 1024",xmlns:"http://www.w3.org/2000/svg",className:`${y}-image-svg`},reactExports.createElement("title",null,"Image placeholder"),reactExports.createElement("path",{d:path$2,className:`${y}-image-path`})))))},SkeletonInput=a=>{const{prefixCls:c,className:u,rootClassName:d,active:f,block:m,size:g="default"}=a,{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("skeleton",c),[E,C,w]=useStyle$q(b),R=omit(a,["prefixCls"]),_=classNames(b,`${b}-element`,{[`${b}-active`]:f,[`${b}-block`]:m},u,d,C,w);return E(reactExports.createElement("div",{className:_},reactExports.createElement(Element$1,Object.assign({prefixCls:`${b}-input`,size:g},R))))},SkeletonNode=a=>{const{prefixCls:c,className:u,rootClassName:d,style:f,active:m,children:g}=a,{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("skeleton",c),[E,C,w]=useStyle$q(b),R=classNames(b,`${b}-element`,{[`${b}-active`]:m},C,u,d,w);return E(reactExports.createElement("div",{className:R},reactExports.createElement("div",{className:classNames(`${b}-image`,u),style:f},g)))},getWidth=(a,c)=>{const{width:u,rows:d=2}=c;if(Array.isArray(u))return u[a];if(d-1===a)return u},Paragraph$2=a=>{const{prefixCls:c,className:u,style:d,rows:f=0}=a,m=Array.from({length:f}).map((g,y)=>reactExports.createElement("li",{key:y,style:{width:getWidth(y,a)}}));return reactExports.createElement("ul",{className:classNames(c,u),style:d},m)},Title$1=a=>{let{prefixCls:c,className:u,width:d,style:f}=a;return reactExports.createElement("h3",{className:classNames(c,u),style:Object.assign({width:d},f)})};function getComponentProps(a){return a&&typeof a=="object"?a:{}}function getAvatarBasicProps(a,c){return a&&!c?{size:"large",shape:"square"}:{size:"large",shape:"circle"}}function getTitleBasicProps(a,c){return!a&&c?{width:"38%"}:a&&c?{width:"50%"}:{}}function getParagraphBasicProps(a,c){const u={};return(!a||!c)&&(u.width="61%"),!a&&c?u.rows=3:u.rows=2,u}const Skeleton=a=>{const{prefixCls:c,loading:u,className:d,rootClassName:f,style:m,children:g,avatar:y=!1,title:b=!0,paragraph:E=!0,active:C,round:w}=a,{getPrefixCls:R,direction:_,className:M,style:I}=useComponentConfig("skeleton"),N=R("skeleton",c),[A,P,z]=useStyle$q(N);if(u||!("loading"in a)){const B=!!y,j=!!b,L=!!E;let U;if(B){const K=Object.assign(Object.assign({prefixCls:`${N}-avatar`},getAvatarBasicProps(j,L)),getComponentProps(y));U=reactExports.createElement("div",{className:`${N}-header`},reactExports.createElement(Element$1,Object.assign({},K)))}let q;if(j||L){let K;if(j){const Q=Object.assign(Object.assign({prefixCls:`${N}-title`},getTitleBasicProps(B,L)),getComponentProps(b));K=reactExports.createElement(Title$1,Object.assign({},Q))}let X;if(L){const Q=Object.assign(Object.assign({prefixCls:`${N}-paragraph`},getParagraphBasicProps(B,j)),getComponentProps(E));X=reactExports.createElement(Paragraph$2,Object.assign({},Q))}q=reactExports.createElement("div",{className:`${N}-content`},K,X)}const F=classNames(N,{[`${N}-with-avatar`]:B,[`${N}-active`]:C,[`${N}-rtl`]:_==="rtl",[`${N}-round`]:w},M,d,f,P,z);return A(reactExports.createElement("div",{className:F,style:Object.assign(Object.assign({},I),m)},U,q))}return g??null};Skeleton.Button=SkeletonButton;Skeleton.Avatar=SkeletonAvatar;Skeleton.Input=SkeletonInput;Skeleton.Image=SkeletonImage;Skeleton.Node=SkeletonNode;const genGridRowStyle=a=>{const{componentCls:c}=a;return{[c]:{display:"flex",flexFlow:"row wrap",minWidth:0,"&::before, &::after":{display:"flex"},"&-no-wrap":{flexWrap:"nowrap"},"&-start":{justifyContent:"flex-start"},"&-center":{justifyContent:"center"},"&-end":{justifyContent:"flex-end"},"&-space-between":{justifyContent:"space-between"},"&-space-around":{justifyContent:"space-around"},"&-space-evenly":{justifyContent:"space-evenly"},"&-top":{alignItems:"flex-start"},"&-middle":{alignItems:"center"},"&-bottom":{alignItems:"flex-end"}}}},genGridColStyle=a=>{const{componentCls:c}=a;return{[c]:{position:"relative",maxWidth:"100%",minHeight:1}}},genLoopGridColumnsStyle=(a,c)=>{const{prefixCls:u,componentCls:d,gridColumns:f}=a,m={};for(let g=f;g>=0;g--)g===0?(m[`${d}${c}-${g}`]={display:"none"},m[`${d}-push-${g}`]={insetInlineStart:"auto"},m[`${d}-pull-${g}`]={insetInlineEnd:"auto"},m[`${d}${c}-push-${g}`]={insetInlineStart:"auto"},m[`${d}${c}-pull-${g}`]={insetInlineEnd:"auto"},m[`${d}${c}-offset-${g}`]={marginInlineStart:0},m[`${d}${c}-order-${g}`]={order:0}):(m[`${d}${c}-${g}`]=[{"--ant-display":"block",display:"block"},{display:"var(--ant-display)",flex:`0 0 ${g/f*100}%`,maxWidth:`${g/f*100}%`}],m[`${d}${c}-push-${g}`]={insetInlineStart:`${g/f*100}%`},m[`${d}${c}-pull-${g}`]={insetInlineEnd:`${g/f*100}%`},m[`${d}${c}-offset-${g}`]={marginInlineStart:`${g/f*100}%`},m[`${d}${c}-order-${g}`]={order:g});return m[`${d}${c}-flex`]={flex:`var(--${u}${c}-flex)`},m},genGridStyle=(a,c)=>genLoopGridColumnsStyle(a,c),genGridMediaStyle=(a,c,u)=>({[`@media (min-width: ${unit$1(c)})`]:Object.assign({},genGridStyle(a,u))}),prepareRowComponentToken=()=>({}),prepareColComponentToken=()=>({}),useRowStyle=genStyleHooks("Grid",genGridRowStyle,prepareRowComponentToken),getMediaSize=a=>({xs:a.screenXSMin,sm:a.screenSMMin,md:a.screenMDMin,lg:a.screenLGMin,xl:a.screenXLMin,xxl:a.screenXXLMin}),useColStyle=genStyleHooks("Grid",a=>{const c=merge$2(a,{gridColumns:24}),u=getMediaSize(c);return delete u.xs,[genGridColStyle(c),genGridStyle(c,""),genGridStyle(c,"-xs"),Object.keys(u).map(d=>genGridMediaStyle(c,u[d],`-${d}`)).reduce((d,f)=>Object.assign(Object.assign({},d),f),{})]},prepareColComponentToken);function box(a){return{position:a,inset:0}}const genModalMaskStyle=a=>{const{componentCls:c,antCls:u}=a;return[{[`${c}-root`]:{[`${c}${u}-zoom-enter, ${c}${u}-zoom-appear`]:{transform:"none",opacity:0,animationDuration:a.motionDurationSlow,userSelect:"none"},[`${c}${u}-zoom-leave ${c}-content`]:{pointerEvents:"none"},[`${c}-mask`]:Object.assign(Object.assign({},box("fixed")),{zIndex:a.zIndexPopupBase,height:"100%",backgroundColor:a.colorBgMask,pointerEvents:"none",[`${c}-hidden`]:{display:"none"}}),[`${c}-wrap`]:Object.assign(Object.assign({},box("fixed")),{zIndex:a.zIndexPopupBase,overflow:"auto",outline:0,WebkitOverflowScrolling:"touch"})}},{[`${c}-root`]:initFadeMotion(a)}]},genModalStyle=a=>{const{componentCls:c}=a;return[{[`${c}-root`]:{[`${c}-wrap-rtl`]:{direction:"rtl"},[`${c}-centered`]:{textAlign:"center","&::before":{display:"inline-block",width:0,height:"100%",verticalAlign:"middle",content:'""'},[c]:{top:0,display:"inline-block",paddingBottom:0,textAlign:"start",verticalAlign:"middle"}},[`@media (max-width: ${a.screenSMMax}px)`]:{[c]:{maxWidth:"calc(100vw - 16px)",margin:`${unit$1(a.marginXS)} auto`},[`${c}-centered`]:{[c]:{flex:1}}}}},{[c]:Object.assign(Object.assign({},resetComponent(a)),{pointerEvents:"none",position:"relative",top:100,width:"auto",maxWidth:`calc(100vw - ${unit$1(a.calc(a.margin).mul(2).equal())})`,margin:"0 auto",paddingBottom:a.paddingLG,[`${c}-title`]:{margin:0,color:a.titleColor,fontWeight:a.fontWeightStrong,fontSize:a.titleFontSize,lineHeight:a.titleLineHeight,wordWrap:"break-word"},[`${c}-content`]:{position:"relative",backgroundColor:a.contentBg,backgroundClip:"padding-box",border:0,borderRadius:a.borderRadiusLG,boxShadow:a.boxShadow,pointerEvents:"auto",padding:a.contentPadding},[`${c}-close`]:Object.assign({position:"absolute",top:a.calc(a.modalHeaderHeight).sub(a.modalCloseBtnSize).div(2).equal(),insetInlineEnd:a.calc(a.modalHeaderHeight).sub(a.modalCloseBtnSize).div(2).equal(),zIndex:a.calc(a.zIndexPopupBase).add(10).equal(),padding:0,color:a.modalCloseIconColor,fontWeight:a.fontWeightStrong,lineHeight:1,textDecoration:"none",background:"transparent",borderRadius:a.borderRadiusSM,width:a.modalCloseBtnSize,height:a.modalCloseBtnSize,border:0,outline:0,cursor:"pointer",transition:`color ${a.motionDurationMid}, background-color ${a.motionDurationMid}`,"&-x":{display:"flex",fontSize:a.fontSizeLG,fontStyle:"normal",lineHeight:unit$1(a.modalCloseBtnSize),justifyContent:"center",textTransform:"none",textRendering:"auto"},"&:disabled":{pointerEvents:"none"},"&:hover":{color:a.modalCloseIconHoverColor,backgroundColor:a.colorBgTextHover,textDecoration:"none"},"&:active":{backgroundColor:a.colorBgTextActive}},genFocusStyle(a)),[`${c}-header`]:{color:a.colorText,background:a.headerBg,borderRadius:`${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0 0`,marginBottom:a.headerMarginBottom,padding:a.headerPadding,borderBottom:a.headerBorderBottom},[`${c}-body`]:{fontSize:a.fontSize,lineHeight:a.lineHeight,wordWrap:"break-word",padding:a.bodyPadding,[`${c}-body-skeleton`]:{width:"100%",height:"100%",display:"flex",justifyContent:"center",alignItems:"center",margin:`${unit$1(a.margin)} auto`}},[`${c}-footer`]:{textAlign:"end",background:a.footerBg,marginTop:a.footerMarginTop,padding:a.footerPadding,borderTop:a.footerBorderTop,borderRadius:a.footerBorderRadius,[`> ${a.antCls}-btn + ${a.antCls}-btn`]:{marginInlineStart:a.marginXS}},[`${c}-open`]:{overflow:"hidden"}})},{[`${c}-pure-panel`]:{top:"auto",padding:0,display:"flex",flexDirection:"column",[`${c}-content,
          ${c}-body,
          ${c}-confirm-body-wrapper`]:{display:"flex",flexDirection:"column",flex:"auto"},[`${c}-confirm-body`]:{marginBottom:"auto"}}}]},genRTLStyle=a=>{const{componentCls:c}=a;return{[`${c}-root`]:{[`${c}-wrap-rtl`]:{direction:"rtl",[`${c}-confirm-body`]:{direction:"rtl"}}}}},genResponsiveWidthStyle=a=>{const{componentCls:c}=a,u=getMediaSize(a);delete u.xs;const d=Object.keys(u).map(f=>({[`@media (min-width: ${unit$1(u[f])})`]:{width:`var(--${c.replace(".","")}-${f}-width)`}}));return{[`${c}-root`]:{[c]:[{width:`var(--${c.replace(".","")}-xs-width)`}].concat(_toConsumableArray(d))}}},prepareToken$3=a=>{const c=a.padding,u=a.fontSizeHeading5,d=a.lineHeightHeading5;return merge$2(a,{modalHeaderHeight:a.calc(a.calc(d).mul(u).equal()).add(a.calc(c).mul(2).equal()).equal(),modalFooterBorderColorSplit:a.colorSplit,modalFooterBorderStyle:a.lineType,modalFooterBorderWidth:a.lineWidth,modalCloseIconColor:a.colorIcon,modalCloseIconHoverColor:a.colorIconHover,modalCloseBtnSize:a.controlHeight,modalConfirmIconSize:a.fontHeight,modalTitleHeight:a.calc(a.titleFontSize).mul(a.titleLineHeight).equal()})},prepareComponentToken$k=a=>({footerBg:"transparent",headerBg:a.colorBgElevated,titleLineHeight:a.lineHeightHeading5,titleFontSize:a.fontSizeHeading5,contentBg:a.colorBgElevated,titleColor:a.colorTextHeading,contentPadding:a.wireframe?0:`${unit$1(a.paddingMD)} ${unit$1(a.paddingContentHorizontalLG)}`,headerPadding:a.wireframe?`${unit$1(a.padding)} ${unit$1(a.paddingLG)}`:0,headerBorderBottom:a.wireframe?`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorSplit}`:"none",headerMarginBottom:a.wireframe?0:a.marginXS,bodyPadding:a.wireframe?a.paddingLG:0,footerPadding:a.wireframe?`${unit$1(a.paddingXS)} ${unit$1(a.padding)}`:0,footerBorderTop:a.wireframe?`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorSplit}`:"none",footerBorderRadius:a.wireframe?`0 0 ${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)}`:0,footerMarginTop:a.wireframe?0:a.marginSM,confirmBodyPadding:a.wireframe?`${unit$1(a.padding*2)} ${unit$1(a.padding*2)} ${unit$1(a.paddingLG)}`:0,confirmIconMarginInlineEnd:a.wireframe?a.margin:a.marginSM,confirmBtnsMarginTop:a.wireframe?a.marginLG:a.marginSM}),useStyle$p=genStyleHooks("Modal",a=>{const c=prepareToken$3(a);return[genModalStyle(c),genRTLStyle(c),genModalMaskStyle(c),initZoomMotion(c,"zoom"),genResponsiveWidthStyle(c)]},prepareComponentToken$k,{unitless:{titleLineHeight:!0}}),AppConfigContext=React.createContext({});function withPureRenderTheme(a){return c=>reactExports.createElement(ConfigProvider,{theme:{token:{motion:!1,zIndexPopupBase:0}}},reactExports.createElement(a,Object.assign({},c)))}const genPurePanel=(a,c,u,d,f)=>withPureRenderTheme(g=>{const{prefixCls:y,style:b}=g,E=reactExports.useRef(null),[C,w]=reactExports.useState(0),[R,_]=reactExports.useState(0),[M,I]=useMergedState(!1,{value:g.open}),{getPrefixCls:N}=reactExports.useContext(ConfigContext),A=N(d||"select",y);reactExports.useEffect(()=>{if(I(!0),typeof ResizeObserver<"u"){const B=new ResizeObserver(L=>{const U=L[0].target;w(U.offsetHeight+8),_(U.offsetWidth)}),j=setInterval(()=>{var L;const U=f?`.${f(A)}`:`.${A}-dropdown`,q=(L=E.current)===null||L===void 0?void 0:L.querySelector(U);q&&(clearInterval(j),B.observe(q))},10);return()=>{clearInterval(j),B.disconnect()}}},[]);let P=Object.assign(Object.assign({},g),{style:Object.assign(Object.assign({},b),{margin:0}),open:M,visible:M,getPopupContainer:()=>E.current});c&&Object.assign(P,{[c]:{overflow:{adjustX:!1,adjustY:!1}}});const z={paddingBottom:C,position:"relative",minWidth:R};return reactExports.createElement("div",{ref:E,style:z},reactExports.createElement(a,Object.assign({},P)))}),isMobile=function(){if(typeof navigator>"u"||typeof window>"u")return!1;var a=navigator.userAgent||navigator.vendor||window.opera;return/(android|bb\d+|meego).+mobile|avantgo|bada\/|blackberry|blazer|compal|elaine|fennec|hiptop|iemobile|ip(hone|od)|iris|kindle|lge |maemo|midp|mmp|mobile.+firefox|netfront|opera m(ob|in)i|palm( os)?|phone|p(ixi|re)\/|plucker|pocket|psp|series(4|6)0|symbian|treo|up\.(browser|link)|vodafone|wap|windows ce|xda|xiino|android|ipad|playbook|silk/i.test(a)||/1207|6310|6590|3gso|4thp|50[1-6]i|770s|802s|a wa|abac|ac(er|oo|s-)|ai(ko|rn)|al(av|ca|co)|amoi|an(ex|ny|yw)|aptu|ar(ch|go)|as(te|us)|attw|au(di|-m|r |s )|avan|be(ck|ll|nq)|bi(lb|rd)|bl(ac|az)|br(e|v)w|bumb|bw-(n|u)|c55\/|capi|ccwa|cdm-|cell|chtm|cldc|cmd-|co(mp|nd)|craw|da(it|ll|ng)|dbte|dc-s|devi|dica|dmob|do(c|p)o|ds(12|-d)|el(49|ai)|em(l2|ul)|er(ic|k0)|esl8|ez([4-7]0|os|wa|ze)|fetc|fly(-|_)|g1 u|g560|gene|gf-5|g-mo|go(\.w|od)|gr(ad|un)|haie|hcit|hd-(m|p|t)|hei-|hi(pt|ta)|hp( i|ip)|hs-c|ht(c(-| |_|a|g|p|s|t)|tp)|hu(aw|tc)|i-(20|go|ma)|i230|iac( |-|\/)|ibro|idea|ig01|ikom|im1k|inno|ipaq|iris|ja(t|v)a|jbro|jemu|jigs|kddi|keji|kgt( |\/)|klon|kpt |kwc-|kyo(c|k)|le(no|xi)|lg( g|\/(k|l|u)|50|54|-[a-w])|libw|lynx|m1-w|m3ga|m50\/|ma(te|ui|xo)|mc(01|21|ca)|m-cr|me(rc|ri)|mi(o8|oa|ts)|mmef|mo(01|02|bi|de|do|t(-| |o|v)|zz)|mt(50|p1|v )|mwbp|mywa|n10[0-2]|n20[2-3]|n30(0|2)|n50(0|2|5)|n7(0(0|1)|10)|ne((c|m)-|on|tf|wf|wg|wt)|nok(6|i)|nzph|o2im|op(ti|wv)|oran|owg1|p800|pan(a|d|t)|pdxg|pg(13|-([1-8]|c))|phil|pire|pl(ay|uc)|pn-2|po(ck|rt|se)|prox|psio|pt-g|qa-a|qc(07|12|21|32|60|-[2-7]|i-)|qtek|r380|r600|raks|rim9|ro(ve|zo)|s55\/|sa(ge|ma|mm|ms|ny|va)|sc(01|h-|oo|p-)|sdk\/|se(c(-|0|1)|47|mc|nd|ri)|sgh-|shar|sie(-|m)|sk-0|sl(45|id)|sm(al|ar|b3|it|t5)|so(ft|ny)|sp(01|h-|v-|v )|sy(01|mb)|t2(18|50)|t6(00|10|18)|ta(gt|lk)|tcl-|tdg-|tel(i|m)|tim-|t-mo|to(pl|sh)|ts(70|m-|m3|m5)|tx-9|up(\.b|g1|si)|utst|v400|v750|veri|vi(rg|te)|vk(40|5[0-3]|-v)|vm40|voda|vulc|vx(52|53|60|61|70|80|81|83|85|98)|w3c(-| )|webc|whit|wi(g |nc|nw)|wmlb|wonu|x700|yas-|your|zeto|zte-/i.test(a==null?void 0:a.substr(0,4))};var TransBtn=function(c){var u=c.className,d=c.customizeIcon,f=c.customizeIconProps,m=c.children,g=c.onMouseDown,y=c.onClick,b=typeof d=="function"?d(f):d;return reactExports.createElement("span",{className:u,onMouseDown:function(C){C.preventDefault(),g==null||g(C)},style:{userSelect:"none",WebkitUserSelect:"none"},unselectable:"on",onClick:y,"aria-hidden":!0},b!==void 0?b:reactExports.createElement("span",{className:classNames(u.split(/\s+/).map(function(E){return"".concat(E,"-icon")}))},m))},useAllowClear=function(c,u,d,f,m){var g=arguments.length>5&&arguments[5]!==void 0?arguments[5]:!1,y=arguments.length>6?arguments[6]:void 0,b=arguments.length>7?arguments[7]:void 0,E=React.useMemo(function(){if(_typeof(f)==="object")return f.clearIcon;if(m)return m},[f,m]),C=React.useMemo(function(){return!!(!g&&f&&(d.length||y)&&!(b==="combobox"&&y===""))},[f,g,d.length,y,b]);return{allowClear:C,clearIcon:React.createElement(TransBtn,{className:"".concat(c,"-clear"),onMouseDown:u,customizeIcon:E},"×")}},BaseSelectContext=reactExports.createContext(null);function useBaseProps(){return reactExports.useContext(BaseSelectContext)}function useDelayReset(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:10,c=reactExports.useState(!1),u=_slicedToArray(c,2),d=u[0],f=u[1],m=reactExports.useRef(null),g=function(){window.clearTimeout(m.current)};reactExports.useEffect(function(){return g},[]);var y=function(E,C){g(),m.current=window.setTimeout(function(){f(E),C&&C()},a)};return[d,y,g]}function useLock(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:250,c=reactExports.useRef(null),u=reactExports.useRef(null);reactExports.useEffect(function(){return function(){window.clearTimeout(u.current)}},[]);function d(f){(f||c.current===null)&&(c.current=f),window.clearTimeout(u.current),u.current=window.setTimeout(function(){c.current=null},a)}return[function(){return c.current},d]}function useSelectTriggerControl(a,c,u,d){var f=reactExports.useRef(null);f.current={open:c,triggerOpen:u,customizedTrigger:d},reactExports.useEffect(function(){function m(g){var y;if(!((y=f.current)!==null&&y!==void 0&&y.customizedTrigger)){var b=g.target;b.shadowRoot&&g.composed&&(b=g.composedPath()[0]||b),f.current.open&&a().filter(function(E){return E}).every(function(E){return!E.contains(b)&&E!==b})&&f.current.triggerOpen(!1)}}return window.addEventListener("mousedown",m),function(){return window.removeEventListener("mousedown",m)}},[])}function isValidateOpenKey(a){return a&&![KeyCode.ESC,KeyCode.SHIFT,KeyCode.BACKSPACE,KeyCode.TAB,KeyCode.WIN_KEY,KeyCode.ALT,KeyCode.META,KeyCode.WIN_KEY_RIGHT,KeyCode.CTRL,KeyCode.SEMICOLON,KeyCode.EQUALS,KeyCode.CAPS_LOCK,KeyCode.CONTEXT_MENU,KeyCode.F1,KeyCode.F2,KeyCode.F3,KeyCode.F4,KeyCode.F5,KeyCode.F6,KeyCode.F7,KeyCode.F8,KeyCode.F9,KeyCode.F10,KeyCode.F11,KeyCode.F12].includes(a)}var _excluded$F=["prefixCls","invalidate","item","renderItem","responsive","responsiveDisabled","registerSize","itemKey","className","style","children","display","order","component"],UNDEFINED=void 0;function InternalItem(a,c){var u=a.prefixCls,d=a.invalidate,f=a.item,m=a.renderItem,g=a.responsive,y=a.responsiveDisabled,b=a.registerSize,E=a.itemKey,C=a.className,w=a.style,R=a.children,_=a.display,M=a.order,I=a.component,N=I===void 0?"div":I,A=_objectWithoutProperties(a,_excluded$F),P=g&&!_;function z(q){b(E,q)}reactExports.useEffect(function(){return function(){z(null)}},[]);var B=m&&f!==UNDEFINED?m(f,{index:M}):R,j;d||(j={opacity:P?0:1,height:P?0:UNDEFINED,overflowY:P?"hidden":UNDEFINED,order:g?M:UNDEFINED,pointerEvents:P?"none":UNDEFINED,position:P?"absolute":UNDEFINED});var L={};P&&(L["aria-hidden"]=!0);var U=reactExports.createElement(N,_extends({className:classNames(!d&&u,C),style:_objectSpread2(_objectSpread2({},j),w)},L,A,{ref:c}),B);return g&&(U=reactExports.createElement(RefResizeObserver,{onResize:function(F){var K=F.offsetWidth;z(K)},disabled:y},U)),U}var Item$2=reactExports.forwardRef(InternalItem);Item$2.displayName="Item";function channelUpdate(a){if(typeof MessageChannel>"u")wrapperRaf(a);else{var c=new MessageChannel;c.port1.onmessage=function(){return a()},c.port2.postMessage(void 0)}}function useBatcher(){var a=reactExports.useRef(null),c=function(d){a.current||(a.current=[],channelUpdate(function(){reactDomExports.unstable_batchedUpdates(function(){a.current.forEach(function(f){f()}),a.current=null})})),a.current.push(d)};return c}function useEffectState(a,c){var u=reactExports.useState(c),d=_slicedToArray(u,2),f=d[0],m=d[1],g=useEvent(function(y){a(function(){m(y)})});return[f,g]}var OverflowContext=React.createContext(null),_excluded$E=["component"],_excluded2$9=["className"],_excluded3$1=["className"],InternalRawItem=function(c,u){var d=reactExports.useContext(OverflowContext);if(!d){var f=c.component,m=f===void 0?"div":f,g=_objectWithoutProperties(c,_excluded$E);return reactExports.createElement(m,_extends({},g,{ref:u}))}var y=d.className,b=_objectWithoutProperties(d,_excluded2$9),E=c.className,C=_objectWithoutProperties(c,_excluded3$1);return reactExports.createElement(OverflowContext.Provider,{value:null},reactExports.createElement(Item$2,_extends({ref:u,className:classNames(y,E)},b,C)))},RawItem=reactExports.forwardRef(InternalRawItem);RawItem.displayName="RawItem";var _excluded$D=["prefixCls","data","renderItem","renderRawItem","itemKey","itemWidth","ssr","style","className","maxCount","renderRest","renderRawRest","suffix","component","itemComponent","onVisibleChange"],RESPONSIVE="responsive",INVALIDATE="invalidate";function defaultRenderRest(a){return"+ ".concat(a.length," ...")}function Overflow(a,c){var u=a.prefixCls,d=u===void 0?"rc-overflow":u,f=a.data,m=f===void 0?[]:f,g=a.renderItem,y=a.renderRawItem,b=a.itemKey,E=a.itemWidth,C=E===void 0?10:E,w=a.ssr,R=a.style,_=a.className,M=a.maxCount,I=a.renderRest,N=a.renderRawRest,A=a.suffix,P=a.component,z=P===void 0?"div":P,B=a.itemComponent,j=a.onVisibleChange,L=_objectWithoutProperties(a,_excluded$D),U=w==="full",q=useBatcher(),F=useEffectState(q,null),K=_slicedToArray(F,2),X=K[0],Q=K[1],Y=X||0,Z=useEffectState(q,new Map),J=_slicedToArray(Z,2),W=J[0],G=J[1],te=useEffectState(q,0),ae=_slicedToArray(te,2),V=ae[0],ne=ae[1],le=useEffectState(q,0),ee=_slicedToArray(le,2),ie=ee[0],ce=ee[1],ue=useEffectState(q,0),me=_slicedToArray(ue,2),de=me[0],ge=me[1],Ce=reactExports.useState(null),ve=_slicedToArray(Ce,2),fe=ve[0],pe=ve[1],xe=reactExports.useState(null),ye=_slicedToArray(xe,2),he=ye[0],we=ye[1],Re=reactExports.useMemo(function(){return he===null&&U?Number.MAX_SAFE_INTEGER:he||0},[he,X]),De=reactExports.useState(!1),Ae=_slicedToArray(De,2),Ee=Ae[0],Ne=Ae[1],_e="".concat(d,"-item"),ke=Math.max(V,ie),Ke=M===RESPONSIVE,be=m.length&&Ke,Te=M===INVALIDATE,Le=be||typeof M=="number"&&m.length>M,Oe=reactExports.useMemo(function(){var ot=m;return be?X===null&&U?ot=m:ot=m.slice(0,Math.min(m.length,Y/C)):typeof M=="number"&&(ot=m.slice(0,M)),ot},[m,C,X,M,be]),Be=reactExports.useMemo(function(){return be?m.slice(Re+1):m.slice(Oe.length)},[m,Oe,be,Re]),Ve=reactExports.useCallback(function(ot,rt){var et;return typeof b=="function"?b(ot):(et=b&&(ot==null?void 0:ot[b]))!==null&&et!==void 0?et:rt},[b]),Pe=reactExports.useCallback(g||function(ot){return ot},[g]);function Ge(ot,rt,et){he===ot&&(rt===void 0||rt===fe)||(we(ot),et||(Ne(ot<m.length-1),j==null||j(ot)),rt!==void 0&&pe(rt))}function qe(ot,rt){Q(rt.clientWidth)}function Ue(ot,rt){G(function(et){var $t=new Map(et);return rt===null?$t.delete(ot):$t.set(ot,rt),$t})}function je(ot,rt){ce(rt),ne(ie)}function We(ot,rt){ge(rt)}function ut(ot){return W.get(Ve(Oe[ot],ot))}useLayoutEffect$1(function(){if(Y&&typeof ke=="number"&&Oe){var ot=de,rt=Oe.length,et=rt-1;if(!rt){Ge(0,null);return}for(var $t=0;$t<rt;$t+=1){var mt=ut($t);if(U&&(mt=mt||0),mt===void 0){Ge($t-1,void 0,!0);break}if(ot+=mt,et===0&&ot<=Y||$t===et-1&&ot+ut(et)<=Y){Ge(et,null);break}else if(ot+ke>Y){Ge($t-1,ot-mt-de+ie);break}}A&&ut(0)+de>Y&&pe(null)}},[Y,W,ie,de,Ve,Oe]);var gt=Ee&&!!Be.length,kt={};fe!==null&&be&&(kt={position:"absolute",left:fe,top:0});var Ut={prefixCls:_e,responsive:be,component:B,invalidate:Te},at=y?function(ot,rt){var et=Ve(ot,rt);return reactExports.createElement(OverflowContext.Provider,{key:et,value:_objectSpread2(_objectSpread2({},Ut),{},{order:rt,item:ot,itemKey:et,registerSize:Ue,display:rt<=Re})},y(ot,rt))}:function(ot,rt){var et=Ve(ot,rt);return reactExports.createElement(Item$2,_extends({},Ut,{order:rt,key:et,item:ot,renderItem:Pe,itemKey:et,registerSize:Ue,display:rt<=Re}))},ct={order:gt?Re:Number.MAX_SAFE_INTEGER,className:"".concat(_e,"-rest"),registerSize:je,display:gt},bt=I||defaultRenderRest,it=N?reactExports.createElement(OverflowContext.Provider,{value:_objectSpread2(_objectSpread2({},Ut),ct)},N(Be)):reactExports.createElement(Item$2,_extends({},Ut,ct),typeof bt=="function"?bt(Be):bt),vt=reactExports.createElement(z,_extends({className:classNames(!Te&&d,_),style:R,ref:c},L),Oe.map(at),Le?it:null,A&&reactExports.createElement(Item$2,_extends({},Ut,{responsive:Ke,responsiveDisabled:!be,order:Re,className:"".concat(_e,"-suffix"),registerSize:We,display:!0,style:kt}),A));return Ke?reactExports.createElement(RefResizeObserver,{onResize:qe,disabled:!be},vt):vt}var ForwardOverflow=reactExports.forwardRef(Overflow);ForwardOverflow.displayName="Overflow";ForwardOverflow.Item=RawItem;ForwardOverflow.RESPONSIVE=RESPONSIVE;ForwardOverflow.INVALIDATE=INVALIDATE;var Input$3=function(c,u){var d,f=c.prefixCls,m=c.id,g=c.inputElement,y=c.disabled,b=c.tabIndex,E=c.autoFocus,C=c.autoComplete,w=c.editable,R=c.activeDescendantId,_=c.value,M=c.maxLength,I=c.onKeyDown,N=c.onMouseDown,A=c.onChange,P=c.onPaste,z=c.onCompositionStart,B=c.onCompositionEnd,j=c.onBlur,L=c.open,U=c.attrs,q=g||reactExports.createElement("input",null),F=q,K=F.ref,X=F.props,Q=X.onKeyDown,Y=X.onChange,Z=X.onMouseDown,J=X.onCompositionStart,W=X.onCompositionEnd,G=X.onBlur,te=X.style;return"maxLength"in q.props,q=reactExports.cloneElement(q,_objectSpread2(_objectSpread2(_objectSpread2({type:"search"},X),{},{id:m,ref:composeRef(u,K),disabled:y,tabIndex:b,autoComplete:C||"off",autoFocus:E,className:classNames("".concat(f,"-selection-search-input"),(d=q)===null||d===void 0||(d=d.props)===null||d===void 0?void 0:d.className),role:"combobox","aria-expanded":L||!1,"aria-haspopup":"listbox","aria-owns":"".concat(m,"_list"),"aria-autocomplete":"list","aria-controls":"".concat(m,"_list"),"aria-activedescendant":L?R:void 0},U),{},{value:w?_:"",maxLength:M,readOnly:!w,unselectable:w?null:"on",style:_objectSpread2(_objectSpread2({},te),{},{opacity:w?null:0}),onKeyDown:function(V){I(V),Q&&Q(V)},onMouseDown:function(V){N(V),Z&&Z(V)},onChange:function(V){A(V),Y&&Y(V)},onCompositionStart:function(V){z(V),J&&J(V)},onCompositionEnd:function(V){B(V),W&&W(V)},onPaste:P,onBlur:function(V){j(V),G&&G(V)}})),q},RefInput=reactExports.forwardRef(Input$3);function toArray$4(a){return Array.isArray(a)?a:a!==void 0?[a]:[]}var isClient=typeof window<"u"&&window.document&&window.document.documentElement,isBrowserClient$1=isClient;function hasValue(a){return a!=null}function isComboNoValue(a){return!a&&a!==0}function isTitleType$1(a){return["string","number"].includes(_typeof(a))}function getTitle(a){var c=void 0;return a&&(isTitleType$1(a.title)?c=a.title.toString():isTitleType$1(a.label)&&(c=a.label.toString())),c}function useLayoutEffect(a,c){isBrowserClient$1?reactExports.useLayoutEffect(a,c):reactExports.useEffect(a,c)}function itemKey$1(a){var c;return(c=a.key)!==null&&c!==void 0?c:a.value}var onPreventMouseDown=function(c){c.preventDefault(),c.stopPropagation()},SelectSelector=function(c){var u=c.id,d=c.prefixCls,f=c.values,m=c.open,g=c.searchValue,y=c.autoClearSearchValue,b=c.inputRef,E=c.placeholder,C=c.disabled,w=c.mode,R=c.showSearch,_=c.autoFocus,M=c.autoComplete,I=c.activeDescendantId,N=c.tabIndex,A=c.removeIcon,P=c.maxTagCount,z=c.maxTagTextLength,B=c.maxTagPlaceholder,j=B===void 0?function(xe){return"+ ".concat(xe.length," ...")}:B,L=c.tagRender,U=c.onToggleOpen,q=c.onRemove,F=c.onInputChange,K=c.onInputPaste,X=c.onInputKeyDown,Q=c.onInputMouseDown,Y=c.onInputCompositionStart,Z=c.onInputCompositionEnd,J=c.onInputBlur,W=reactExports.useRef(null),G=reactExports.useState(0),te=_slicedToArray(G,2),ae=te[0],V=te[1],ne=reactExports.useState(!1),le=_slicedToArray(ne,2),ee=le[0],ie=le[1],ce="".concat(d,"-selection"),ue=m||w==="multiple"&&y===!1||w==="tags"?g:"",me=w==="tags"||w==="multiple"&&y===!1||R&&(m||ee);useLayoutEffect(function(){V(W.current.scrollWidth)},[ue]);var de=function(ye,he,we,Re,De){return reactExports.createElement("span",{title:getTitle(ye),className:classNames("".concat(ce,"-item"),_defineProperty({},"".concat(ce,"-item-disabled"),we))},reactExports.createElement("span",{className:"".concat(ce,"-item-content")},he),Re&&reactExports.createElement(TransBtn,{className:"".concat(ce,"-item-remove"),onMouseDown:onPreventMouseDown,onClick:De,customizeIcon:A},"×"))},ge=function(ye,he,we,Re,De,Ae){var Ee=function(_e){onPreventMouseDown(_e),U(!m)};return reactExports.createElement("span",{onMouseDown:Ee},L({label:he,value:ye,disabled:we,closable:Re,onClose:De,isMaxTag:!!Ae}))},Ce=function(ye){var he=ye.disabled,we=ye.label,Re=ye.value,De=!C&&!he,Ae=we;if(typeof z=="number"&&(typeof we=="string"||typeof we=="number")){var Ee=String(Ae);Ee.length>z&&(Ae="".concat(Ee.slice(0,z),"..."))}var Ne=function(ke){ke&&ke.stopPropagation(),q(ye)};return typeof L=="function"?ge(Re,Ae,he,De,Ne):de(ye,Ae,he,De,Ne)},ve=function(ye){if(!f.length)return null;var he=typeof j=="function"?j(ye):j;return typeof L=="function"?ge(void 0,he,!1,!1,void 0,!0):de({title:he},he,!1)},fe=reactExports.createElement("div",{className:"".concat(ce,"-search"),style:{width:ae},onFocus:function(){ie(!0)},onBlur:function(){ie(!1)}},reactExports.createElement(RefInput,{ref:b,open:m,prefixCls:d,id:u,inputElement:null,disabled:C,autoFocus:_,autoComplete:M,editable:me,activeDescendantId:I,value:ue,onKeyDown:X,onMouseDown:Q,onChange:F,onPaste:K,onCompositionStart:Y,onCompositionEnd:Z,onBlur:J,tabIndex:N,attrs:pickAttrs(c,!0)}),reactExports.createElement("span",{ref:W,className:"".concat(ce,"-search-mirror"),"aria-hidden":!0},ue," ")),pe=reactExports.createElement(ForwardOverflow,{prefixCls:"".concat(ce,"-overflow"),data:f,renderItem:Ce,renderRest:ve,suffix:fe,itemKey:itemKey$1,maxCount:P});return reactExports.createElement("span",{className:"".concat(ce,"-wrap")},pe,!f.length&&!ue&&reactExports.createElement("span",{className:"".concat(ce,"-placeholder")},E))},SingleSelector=function(c){var u=c.inputElement,d=c.prefixCls,f=c.id,m=c.inputRef,g=c.disabled,y=c.autoFocus,b=c.autoComplete,E=c.activeDescendantId,C=c.mode,w=c.open,R=c.values,_=c.placeholder,M=c.tabIndex,I=c.showSearch,N=c.searchValue,A=c.activeValue,P=c.maxLength,z=c.onInputKeyDown,B=c.onInputMouseDown,j=c.onInputChange,L=c.onInputPaste,U=c.onInputCompositionStart,q=c.onInputCompositionEnd,F=c.onInputBlur,K=c.title,X=reactExports.useState(!1),Q=_slicedToArray(X,2),Y=Q[0],Z=Q[1],J=C==="combobox",W=J||I,G=R[0],te=N||"";J&&A&&!Y&&(te=A),reactExports.useEffect(function(){J&&Z(!1)},[J,A]);var ae=C!=="combobox"&&!w&&!I?!1:!!te,V=K===void 0?getTitle(G):K,ne=reactExports.useMemo(function(){return G?null:reactExports.createElement("span",{className:"".concat(d,"-selection-placeholder"),style:ae?{visibility:"hidden"}:void 0},_)},[G,ae,_,d]);return reactExports.createElement("span",{className:"".concat(d,"-selection-wrap")},reactExports.createElement("span",{className:"".concat(d,"-selection-search")},reactExports.createElement(RefInput,{ref:m,prefixCls:d,id:f,open:w,inputElement:u,disabled:g,autoFocus:y,autoComplete:b,editable:W,activeDescendantId:E,value:te,onKeyDown:z,onMouseDown:B,onChange:function(ee){Z(!0),j(ee)},onPaste:L,onCompositionStart:U,onCompositionEnd:q,onBlur:F,tabIndex:M,attrs:pickAttrs(c,!0),maxLength:J?P:void 0})),!J&&G?reactExports.createElement("span",{className:"".concat(d,"-selection-item"),title:V,style:ae?{visibility:"hidden"}:void 0},G.label):null,ne)},Selector=function(c,u){var d=reactExports.useRef(null),f=reactExports.useRef(!1),m=c.prefixCls,g=c.open,y=c.mode,b=c.showSearch,E=c.tokenWithEnter,C=c.disabled,w=c.prefix,R=c.autoClearSearchValue,_=c.onSearch,M=c.onSearchSubmit,I=c.onToggleOpen,N=c.onInputKeyDown,A=c.onInputBlur,P=c.domRef;reactExports.useImperativeHandle(u,function(){return{focus:function(V){d.current.focus(V)},blur:function(){d.current.blur()}}});var z=useLock(0),B=_slicedToArray(z,2),j=B[0],L=B[1],U=function(V){var ne=V.which,le=d.current instanceof HTMLTextAreaElement;!le&&g&&(ne===KeyCode.UP||ne===KeyCode.DOWN)&&V.preventDefault(),N&&N(V),ne===KeyCode.ENTER&&y==="tags"&&!f.current&&!g&&(M==null||M(V.target.value)),!(le&&!g&&~[KeyCode.UP,KeyCode.DOWN,KeyCode.LEFT,KeyCode.RIGHT].indexOf(ne))&&isValidateOpenKey(ne)&&I(!0)},q=function(){L(!0)},F=reactExports.useRef(null),K=function(V){_(V,!0,f.current)!==!1&&I(!0)},X=function(){f.current=!0},Q=function(V){f.current=!1,y!=="combobox"&&K(V.target.value)},Y=function(V){var ne=V.target.value;if(E&&F.current&&/[\r\n]/.test(F.current)){var le=F.current.replace(/[\r\n]+$/,"").replace(/\r\n/g," ").replace(/[\r\n]/g," ");ne=ne.replace(le,F.current)}F.current=null,K(ne)},Z=function(V){var ne=V.clipboardData,le=ne==null?void 0:ne.getData("text");F.current=le||""},J=function(V){var ne=V.target;if(ne!==d.current){var le=document.body.style.msTouchAction!==void 0;le?setTimeout(function(){d.current.focus()}):d.current.focus()}},W=function(V){var ne=j();V.target!==d.current&&!ne&&!(y==="combobox"&&C)&&V.preventDefault(),(y!=="combobox"&&(!b||!ne)||!g)&&(g&&R!==!1&&_("",!0,!1),I())},G={inputRef:d,onInputKeyDown:U,onInputMouseDown:q,onInputChange:Y,onInputPaste:Z,onInputCompositionStart:X,onInputCompositionEnd:Q,onInputBlur:A},te=y==="multiple"||y==="tags"?reactExports.createElement(SelectSelector,_extends({},c,G)):reactExports.createElement(SingleSelector,_extends({},c,G));return reactExports.createElement("div",{ref:P,className:"".concat(m,"-selector"),onClick:J,onMouseDown:W},w&&reactExports.createElement("div",{className:"".concat(m,"-prefix")},w),te)},ForwardSelector=reactExports.forwardRef(Selector);function Arrow(a){var c=a.prefixCls,u=a.align,d=a.arrow,f=a.arrowPos,m=d||{},g=m.className,y=m.content,b=f.x,E=b===void 0?0:b,C=f.y,w=C===void 0?0:C,R=reactExports.useRef();if(!u||!u.points)return null;var _={position:"absolute"};if(u.autoArrow!==!1){var M=u.points[0],I=u.points[1],N=M[0],A=M[1],P=I[0],z=I[1];N===P||!["t","b"].includes(N)?_.top=w:N==="t"?_.top=0:_.bottom=0,A===z||!["l","r"].includes(A)?_.left=E:A==="l"?_.left=0:_.right=0}return reactExports.createElement("div",{ref:R,className:classNames("".concat(c,"-arrow"),g),style:_},y)}function Mask(a){var c=a.prefixCls,u=a.open,d=a.zIndex,f=a.mask,m=a.motion;return f?reactExports.createElement(CSSMotion,_extends({},m,{motionAppear:!0,visible:u,removeOnLeave:!0}),function(g){var y=g.className;return reactExports.createElement("div",{style:{zIndex:d},className:classNames("".concat(c,"-mask"),y)})}):null}var PopupContent=reactExports.memo(function(a){var c=a.children;return c},function(a,c){return c.cache}),Popup$1=reactExports.forwardRef(function(a,c){var u=a.popup,d=a.className,f=a.prefixCls,m=a.style,g=a.target,y=a.onVisibleChanged,b=a.open,E=a.keepDom,C=a.fresh,w=a.onClick,R=a.mask,_=a.arrow,M=a.arrowPos,I=a.align,N=a.motion,A=a.maskMotion,P=a.forceRender,z=a.getPopupContainer,B=a.autoDestroy,j=a.portal,L=a.zIndex,U=a.onMouseEnter,q=a.onMouseLeave,F=a.onPointerEnter,K=a.onPointerDownCapture,X=a.ready,Q=a.offsetX,Y=a.offsetY,Z=a.offsetR,J=a.offsetB,W=a.onAlign,G=a.onPrepare,te=a.stretch,ae=a.targetWidth,V=a.targetHeight,ne=typeof u=="function"?u():u,le=b||E,ee=(z==null?void 0:z.length)>0,ie=reactExports.useState(!z||!ee),ce=_slicedToArray(ie,2),ue=ce[0],me=ce[1];if(useLayoutEffect$1(function(){!ue&&ee&&g&&me(!0)},[ue,ee,g]),!ue)return null;var de="auto",ge={left:"-1000vw",top:"-1000vh",right:de,bottom:de};if(X||!b){var Ce,ve=I.points,fe=I.dynamicInset||((Ce=I._experimental)===null||Ce===void 0?void 0:Ce.dynamicInset),pe=fe&&ve[0][1]==="r",xe=fe&&ve[0][0]==="b";pe?(ge.right=Z,ge.left=de):(ge.left=Q,ge.right=de),xe?(ge.bottom=J,ge.top=de):(ge.top=Y,ge.bottom=de)}var ye={};return te&&(te.includes("height")&&V?ye.height=V:te.includes("minHeight")&&V&&(ye.minHeight=V),te.includes("width")&&ae?ye.width=ae:te.includes("minWidth")&&ae&&(ye.minWidth=ae)),b||(ye.pointerEvents="none"),reactExports.createElement(j,{open:P||le,getContainer:z&&function(){return z(g)},autoDestroy:B},reactExports.createElement(Mask,{prefixCls:f,open:b,zIndex:L,mask:R,motion:A}),reactExports.createElement(RefResizeObserver,{onResize:W,disabled:!b},function(he){return reactExports.createElement(CSSMotion,_extends({motionAppear:!0,motionEnter:!0,motionLeave:!0,removeOnLeave:!1,forceRender:P,leavedClassName:"".concat(f,"-hidden")},N,{onAppearPrepare:G,onEnterPrepare:G,visible:b,onVisibleChanged:function(Re){var De;N==null||(De=N.onVisibleChanged)===null||De===void 0||De.call(N,Re),y(Re)}}),function(we,Re){var De=we.className,Ae=we.style,Ee=classNames(f,De,d);return reactExports.createElement("div",{ref:composeRef(he,c,Re),className:Ee,style:_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({"--arrow-x":"".concat(M.x||0,"px"),"--arrow-y":"".concat(M.y||0,"px")},ge),ye),Ae),{},{boxSizing:"border-box",zIndex:L},m),onMouseEnter:U,onMouseLeave:q,onPointerEnter:F,onClick:w,onPointerDownCapture:K},_&&reactExports.createElement(Arrow,{prefixCls:f,arrow:_,arrowPos:M,align:I}),reactExports.createElement(PopupContent,{cache:!b&&!C},ne))})}))}),TriggerWrapper=reactExports.forwardRef(function(a,c){var u=a.children,d=a.getTriggerDOMNode,f=supportRef(u),m=reactExports.useCallback(function(y){fillRef(c,d?d(y):y)},[d]),g=useComposeRef(m,getNodeRef(u));return f?reactExports.cloneElement(u,{ref:g}):u}),TriggerContext=reactExports.createContext(null);function toArray$3(a){return a?Array.isArray(a)?a:[a]:[]}function useAction(a,c,u,d){return reactExports.useMemo(function(){var f=toArray$3(u??c),m=toArray$3(d??c),g=new Set(f),y=new Set(m);return a&&(g.has("hover")&&(g.delete("hover"),g.add("click")),y.has("hover")&&(y.delete("hover"),y.add("click"))),[g,y]},[a,c,u,d])}function isPointsEq(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],u=arguments.length>2?arguments[2]:void 0;return u?a[0]===c[0]:a[0]===c[0]&&a[1]===c[1]}function getAlignPopupClassName(a,c,u,d){for(var f=u.points,m=Object.keys(a),g=0;g<m.length;g+=1){var y,b=m[g];if(isPointsEq((y=a[b])===null||y===void 0?void 0:y.points,f,d))return"".concat(c,"-placement-").concat(b)}return""}function getMotion$1(a,c,u,d){return c||(u?{motionName:"".concat(a,"-").concat(u)}:d?{motionName:d}:null)}function getWin(a){return a.ownerDocument.defaultView}function collectScroller(a){for(var c=[],u=a==null?void 0:a.parentElement,d=["hidden","scroll","clip","auto"];u;){var f=getWin(u).getComputedStyle(u),m=f.overflowX,g=f.overflowY,y=f.overflow;[m,g,y].some(function(b){return d.includes(b)})&&c.push(u),u=u.parentElement}return c}function toNum(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1;return Number.isNaN(a)?c:a}function getPxValue(a){return toNum(parseFloat(a),0)}function getVisibleArea(a,c){var u=_objectSpread2({},a);return(c||[]).forEach(function(d){if(!(d instanceof HTMLBodyElement||d instanceof HTMLHtmlElement)){var f=getWin(d).getComputedStyle(d),m=f.overflow,g=f.overflowClipMargin,y=f.borderTopWidth,b=f.borderBottomWidth,E=f.borderLeftWidth,C=f.borderRightWidth,w=d.getBoundingClientRect(),R=d.offsetHeight,_=d.clientHeight,M=d.offsetWidth,I=d.clientWidth,N=getPxValue(y),A=getPxValue(b),P=getPxValue(E),z=getPxValue(C),B=toNum(Math.round(w.width/M*1e3)/1e3),j=toNum(Math.round(w.height/R*1e3)/1e3),L=(M-I-P-z)*B,U=(R-_-N-A)*j,q=N*j,F=A*j,K=P*B,X=z*B,Q=0,Y=0;if(m==="clip"){var Z=getPxValue(g);Q=Z*B,Y=Z*j}var J=w.x+K-Q,W=w.y+q-Y,G=J+w.width+2*Q-K-X-L,te=W+w.height+2*Y-q-F-U;u.left=Math.max(u.left,J),u.top=Math.max(u.top,W),u.right=Math.min(u.right,G),u.bottom=Math.min(u.bottom,te)}}),u}function getUnitOffset(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0,u="".concat(c),d=u.match(/^(.*)\%$/);return d?a*(parseFloat(d[1])/100):parseFloat(u)}function getNumberOffset(a,c){var u=c||[],d=_slicedToArray(u,2),f=d[0],m=d[1];return[getUnitOffset(a.width,f),getUnitOffset(a.height,m)]}function splitPoints(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"";return[a[0],a[1]]}function getAlignPoint(a,c){var u=c[0],d=c[1],f,m;return u==="t"?m=a.y:u==="b"?m=a.y+a.height:m=a.y+a.height/2,d==="l"?f=a.x:d==="r"?f=a.x+a.width:f=a.x+a.width/2,{x:f,y:m}}function reversePoints(a,c){var u={t:"b",b:"t",l:"r",r:"l"};return a.map(function(d,f){return f===c?u[d]||"c":d}).join("")}function useAlign(a,c,u,d,f,m,g){var y=reactExports.useState({ready:!1,offsetX:0,offsetY:0,offsetR:0,offsetB:0,arrowX:0,arrowY:0,scaleX:1,scaleY:1,align:f[d]||{}}),b=_slicedToArray(y,2),E=b[0],C=b[1],w=reactExports.useRef(0),R=reactExports.useMemo(function(){return c?collectScroller(c):[]},[c]),_=reactExports.useRef({}),M=function(){_.current={}};a||M();var I=useEvent(function(){if(c&&u&&a){let vr=function(Gr,Lr){var Mr=arguments.length>2&&arguments[2]!==void 0?arguments[2]:ke,Ur=ie.x+Gr,Cn=ie.y+Lr,ha=Ur+pe,Aa=Cn+fe,In=Math.max(Ur,Mr.left),Et=Math.max(Cn,Mr.top),jt=Math.min(ha,Mr.right),ur=Math.min(Aa,Mr.bottom);return Math.max(0,(jt-In)*(ur-Et))},yr=function(){Dt=ie.y+et,Vt=Dt+fe,Nt=ie.x+rt,Kt=Nt+pe};var P,z,B,j,L=c,U=L.ownerDocument,q=getWin(L),F=q.getComputedStyle(L),K=F.width,X=F.height,Q=F.position,Y=L.style.left,Z=L.style.top,J=L.style.right,W=L.style.bottom,G=L.style.overflow,te=_objectSpread2(_objectSpread2({},f[d]),m),ae=U.createElement("div");(P=L.parentElement)===null||P===void 0||P.appendChild(ae),ae.style.left="".concat(L.offsetLeft,"px"),ae.style.top="".concat(L.offsetTop,"px"),ae.style.position=Q,ae.style.height="".concat(L.offsetHeight,"px"),ae.style.width="".concat(L.offsetWidth,"px"),L.style.left="0",L.style.top="0",L.style.right="auto",L.style.bottom="auto",L.style.overflow="hidden";var V;if(Array.isArray(u))V={x:u[0],y:u[1],width:0,height:0};else{var ne,le,ee=u.getBoundingClientRect();ee.x=(ne=ee.x)!==null&&ne!==void 0?ne:ee.left,ee.y=(le=ee.y)!==null&&le!==void 0?le:ee.top,V={x:ee.x,y:ee.y,width:ee.width,height:ee.height}}var ie=L.getBoundingClientRect();ie.x=(z=ie.x)!==null&&z!==void 0?z:ie.left,ie.y=(B=ie.y)!==null&&B!==void 0?B:ie.top;var ce=U.documentElement,ue=ce.clientWidth,me=ce.clientHeight,de=ce.scrollWidth,ge=ce.scrollHeight,Ce=ce.scrollTop,ve=ce.scrollLeft,fe=ie.height,pe=ie.width,xe=V.height,ye=V.width,he={left:0,top:0,right:ue,bottom:me},we={left:-ve,top:-Ce,right:de-ve,bottom:ge-Ce},Re=te.htmlRegion,De="visible",Ae="visibleFirst";Re!=="scroll"&&Re!==Ae&&(Re=De);var Ee=Re===Ae,Ne=getVisibleArea(we,R),_e=getVisibleArea(he,R),ke=Re===De?_e:Ne,Ke=Ee?_e:ke;L.style.left="auto",L.style.top="auto",L.style.right="0",L.style.bottom="0";var be=L.getBoundingClientRect();L.style.left=Y,L.style.top=Z,L.style.right=J,L.style.bottom=W,L.style.overflow=G,(j=L.parentElement)===null||j===void 0||j.removeChild(ae);var Te=toNum(Math.round(pe/parseFloat(K)*1e3)/1e3),Le=toNum(Math.round(fe/parseFloat(X)*1e3)/1e3);if(Te===0||Le===0||isDOM$1(u)&&!isVisible(u))return;var Oe=te.offset,Be=te.targetOffset,Ve=getNumberOffset(ie,Oe),Pe=_slicedToArray(Ve,2),Ge=Pe[0],qe=Pe[1],Ue=getNumberOffset(V,Be),je=_slicedToArray(Ue,2),We=je[0],ut=je[1];V.x-=We,V.y-=ut;var gt=te.points||[],kt=_slicedToArray(gt,2),Ut=kt[0],at=kt[1],ct=splitPoints(at),bt=splitPoints(Ut),it=getAlignPoint(V,ct),vt=getAlignPoint(ie,bt),ot=_objectSpread2({},te),rt=it.x-vt.x+Ge,et=it.y-vt.y+qe,$t=vr(rt,et),mt=vr(rt,et,_e),Ze=getAlignPoint(V,["t","l"]),Je=getAlignPoint(ie,["t","l"]),yt=getAlignPoint(V,["b","r"]),Ct=getAlignPoint(ie,["b","r"]),pt=te.overflow||{},Rt=pt.adjustX,ft=pt.adjustY,dt=pt.shiftX,xt=pt.shiftY,Tt=function(Lr){return typeof Lr=="boolean"?Lr:Lr>=0},Dt,Vt,Nt,Kt;yr();var Zt=Tt(ft),Gt=bt[0]===ct[0];if(Zt&&bt[0]==="t"&&(Vt>Ke.bottom||_.current.bt)){var tt=et;Gt?tt-=fe-xe:tt=Ze.y-Ct.y-qe;var ht=vr(rt,tt),lt=vr(rt,tt,_e);ht>$t||ht===$t&&(!Ee||lt>=mt)?(_.current.bt=!0,et=tt,qe=-qe,ot.points=[reversePoints(bt,0),reversePoints(ct,0)]):_.current.bt=!1}if(Zt&&bt[0]==="b"&&(Dt<Ke.top||_.current.tb)){var nt=et;Gt?nt+=fe-xe:nt=yt.y-Je.y-qe;var Ot=vr(rt,nt),Bt=vr(rt,nt,_e);Ot>$t||Ot===$t&&(!Ee||Bt>=mt)?(_.current.tb=!0,et=nt,qe=-qe,ot.points=[reversePoints(bt,0),reversePoints(ct,0)]):_.current.tb=!1}var qt=Tt(Rt),er=bt[1]===ct[1];if(qt&&bt[1]==="l"&&(Kt>Ke.right||_.current.rl)){var St=rt;er?St-=pe-ye:St=Ze.x-Ct.x-Ge;var _t=vr(St,et),zt=vr(St,et,_e);_t>$t||_t===$t&&(!Ee||zt>=mt)?(_.current.rl=!0,rt=St,Ge=-Ge,ot.points=[reversePoints(bt,1),reversePoints(ct,1)]):_.current.rl=!1}if(qt&&bt[1]==="r"&&(Nt<Ke.left||_.current.lr)){var nr=rt;er?nr+=pe-ye:nr=yt.x-Je.x-Ge;var Rr=vr(nr,et),Jr=vr(nr,et,_e);Rr>$t||Rr===$t&&(!Ee||Jr>=mt)?(_.current.lr=!0,rt=nr,Ge=-Ge,ot.points=[reversePoints(bt,1),reversePoints(ct,1)]):_.current.lr=!1}yr();var Tr=dt===!0?0:dt;typeof Tr=="number"&&(Nt<_e.left&&(rt-=Nt-_e.left-Ge,V.x+ye<_e.left+Tr&&(rt+=V.x-_e.left+ye-Tr)),Kt>_e.right&&(rt-=Kt-_e.right-Ge,V.x>_e.right-Tr&&(rt+=V.x-_e.right+Tr)));var lr=xt===!0?0:xt;typeof lr=="number"&&(Dt<_e.top&&(et-=Dt-_e.top-qe,V.y+xe<_e.top+lr&&(et+=V.y-_e.top+xe-lr)),Vt>_e.bottom&&(et-=Vt-_e.bottom-qe,V.y>_e.bottom-lr&&(et+=V.y-_e.bottom+lr)));var en=ie.x+rt,tn=en+pe,wr=ie.y+et,rn=wr+fe,Wt=V.x,wt=Wt+ye,st=V.y,Xt=st+xe,Qt=Math.max(en,Wt),or=Math.min(tn,wt),ar=(Qt+or)/2,Ir=ar-en,_r=Math.max(wr,st),Sr=Math.min(rn,Xt),kr=(_r+Sr)/2,jr=kr-wr;g==null||g(c,ot);var Pt=be.right-ie.x-(rt+ie.width),It=be.bottom-ie.y-(et+ie.height);Te===1&&(rt=Math.round(rt),Pt=Math.round(Pt)),Le===1&&(et=Math.round(et),It=Math.round(It));var Or={ready:!0,offsetX:rt/Te,offsetY:et/Le,offsetR:Pt/Te,offsetB:It/Le,arrowX:Ir/Te,arrowY:jr/Le,scaleX:Te,scaleY:Le,align:ot};C(Or)}}),N=function(){w.current+=1;var z=w.current;Promise.resolve().then(function(){w.current===z&&I()})},A=function(){C(function(z){return _objectSpread2(_objectSpread2({},z),{},{ready:!1})})};return useLayoutEffect$1(A,[d]),useLayoutEffect$1(function(){a||A()},[a]),[E.ready,E.offsetX,E.offsetY,E.offsetR,E.offsetB,E.arrowX,E.arrowY,E.scaleX,E.scaleY,E.align,N]}function useWatch(a,c,u,d,f){useLayoutEffect$1(function(){if(a&&c&&u){let w=function(){d(),f()};var m=c,g=u,y=collectScroller(m),b=collectScroller(g),E=getWin(g),C=new Set([E].concat(_toConsumableArray(y),_toConsumableArray(b)));return C.forEach(function(R){R.addEventListener("scroll",w,{passive:!0})}),E.addEventListener("resize",w,{passive:!0}),d(),function(){C.forEach(function(R){R.removeEventListener("scroll",w),E.removeEventListener("resize",w)})}}},[a,c,u])}function useWinClick(a,c,u,d,f,m,g,y){var b=reactExports.useRef(a);b.current=a;var E=reactExports.useRef(!1);reactExports.useEffect(function(){if(c&&d&&(!f||m)){var w=function(){E.current=!1},R=function(N){var A;b.current&&!g(((A=N.composedPath)===null||A===void 0||(A=A.call(N))===null||A===void 0?void 0:A[0])||N.target)&&!E.current&&y(!1)},_=getWin(d);_.addEventListener("pointerdown",w,!0),_.addEventListener("mousedown",R,!0),_.addEventListener("contextmenu",R,!0);var M=getShadowRoot(u);return M&&(M.addEventListener("mousedown",R,!0),M.addEventListener("contextmenu",R,!0)),function(){_.removeEventListener("pointerdown",w,!0),_.removeEventListener("mousedown",R,!0),_.removeEventListener("contextmenu",R,!0),M&&(M.removeEventListener("mousedown",R,!0),M.removeEventListener("contextmenu",R,!0))}}},[c,u,d,f,m]);function C(){E.current=!0}return C}var _excluded$C=["prefixCls","children","action","showAction","hideAction","popupVisible","defaultPopupVisible","onPopupVisibleChange","afterPopupVisibleChange","mouseEnterDelay","mouseLeaveDelay","focusDelay","blurDelay","mask","maskClosable","getPopupContainer","forceRender","autoDestroy","destroyPopupOnHide","popup","popupClassName","popupStyle","popupPlacement","builtinPlacements","popupAlign","zIndex","stretch","getPopupClassNameFromAlign","fresh","alignPoint","onPopupClick","onPopupAlign","arrow","popupMotion","maskMotion","popupTransitionName","popupAnimation","maskTransitionName","maskAnimation","className","getTriggerDOMNode"];function generateTrigger(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:Portal,c=reactExports.forwardRef(function(u,d){var f=u.prefixCls,m=f===void 0?"rc-trigger-popup":f,g=u.children,y=u.action,b=y===void 0?"hover":y,E=u.showAction,C=u.hideAction,w=u.popupVisible,R=u.defaultPopupVisible,_=u.onPopupVisibleChange,M=u.afterPopupVisibleChange,I=u.mouseEnterDelay,N=u.mouseLeaveDelay,A=N===void 0?.1:N,P=u.focusDelay,z=u.blurDelay,B=u.mask,j=u.maskClosable,L=j===void 0?!0:j,U=u.getPopupContainer,q=u.forceRender,F=u.autoDestroy,K=u.destroyPopupOnHide,X=u.popup,Q=u.popupClassName,Y=u.popupStyle,Z=u.popupPlacement,J=u.builtinPlacements,W=J===void 0?{}:J,G=u.popupAlign,te=u.zIndex,ae=u.stretch,V=u.getPopupClassNameFromAlign,ne=u.fresh,le=u.alignPoint,ee=u.onPopupClick,ie=u.onPopupAlign,ce=u.arrow,ue=u.popupMotion,me=u.maskMotion,de=u.popupTransitionName,ge=u.popupAnimation,Ce=u.maskTransitionName,ve=u.maskAnimation,fe=u.className,pe=u.getTriggerDOMNode,xe=_objectWithoutProperties(u,_excluded$C),ye=F||K||!1,he=reactExports.useState(!1),we=_slicedToArray(he,2),Re=we[0],De=we[1];useLayoutEffect$1(function(){De(isMobile())},[]);var Ae=reactExports.useRef({}),Ee=reactExports.useContext(TriggerContext),Ne=reactExports.useMemo(function(){return{registerSubPopup:function(jt,ur){Ae.current[jt]=ur,Ee==null||Ee.registerSubPopup(jt,ur)}}},[Ee]),_e=useId$1(),ke=reactExports.useState(null),Ke=_slicedToArray(ke,2),be=Ke[0],Te=Ke[1],Le=reactExports.useRef(null),Oe=useEvent(function(Et){Le.current=Et,isDOM$1(Et)&&be!==Et&&Te(Et),Ee==null||Ee.registerSubPopup(_e,Et)}),Be=reactExports.useState(null),Ve=_slicedToArray(Be,2),Pe=Ve[0],Ge=Ve[1],qe=reactExports.useRef(null),Ue=useEvent(function(Et){isDOM$1(Et)&&Pe!==Et&&(Ge(Et),qe.current=Et)}),je=reactExports.Children.only(g),We=(je==null?void 0:je.props)||{},ut={},gt=useEvent(function(Et){var jt,ur,mr=Pe;return(mr==null?void 0:mr.contains(Et))||((jt=getShadowRoot(mr))===null||jt===void 0?void 0:jt.host)===Et||Et===mr||(be==null?void 0:be.contains(Et))||((ur=getShadowRoot(be))===null||ur===void 0?void 0:ur.host)===Et||Et===be||Object.values(Ae.current).some(function(Er){return(Er==null?void 0:Er.contains(Et))||Et===Er})}),kt=getMotion$1(m,ue,ge,de),Ut=getMotion$1(m,me,ve,Ce),at=reactExports.useState(R||!1),ct=_slicedToArray(at,2),bt=ct[0],it=ct[1],vt=w??bt,ot=useEvent(function(Et){w===void 0&&it(Et)});useLayoutEffect$1(function(){it(w||!1)},[w]);var rt=reactExports.useRef(vt);rt.current=vt;var et=reactExports.useRef([]);et.current=[];var $t=useEvent(function(Et){var jt;ot(Et),((jt=et.current[et.current.length-1])!==null&&jt!==void 0?jt:vt)!==Et&&(et.current.push(Et),_==null||_(Et))}),mt=reactExports.useRef(),Ze=function(){clearTimeout(mt.current)},Je=function(jt){var ur=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0;Ze(),ur===0?$t(jt):mt.current=setTimeout(function(){$t(jt)},ur*1e3)};reactExports.useEffect(function(){return Ze},[]);var yt=reactExports.useState(!1),Ct=_slicedToArray(yt,2),pt=Ct[0],Rt=Ct[1];useLayoutEffect$1(function(Et){(!Et||vt)&&Rt(!0)},[vt]);var ft=reactExports.useState(null),dt=_slicedToArray(ft,2),xt=dt[0],Tt=dt[1],Dt=reactExports.useState(null),Vt=_slicedToArray(Dt,2),Nt=Vt[0],Kt=Vt[1],Zt=function(jt){Kt([jt.clientX,jt.clientY])},Gt=useAlign(vt,be,le&&Nt!==null?Nt:Pe,Z,W,G,ie),tt=_slicedToArray(Gt,11),ht=tt[0],lt=tt[1],nt=tt[2],Ot=tt[3],Bt=tt[4],qt=tt[5],er=tt[6],St=tt[7],_t=tt[8],zt=tt[9],nr=tt[10],Rr=useAction(Re,b,E,C),Jr=_slicedToArray(Rr,2),Tr=Jr[0],lr=Jr[1],en=Tr.has("click"),tn=lr.has("click")||lr.has("contextMenu"),wr=useEvent(function(){pt||nr()}),rn=function(){rt.current&&le&&tn&&Je(!1)};useWatch(vt,Pe,be,wr,rn),useLayoutEffect$1(function(){wr()},[Nt,Z]),useLayoutEffect$1(function(){vt&&!(W!=null&&W[Z])&&wr()},[JSON.stringify(G)]);var Wt=reactExports.useMemo(function(){var Et=getAlignPopupClassName(W,m,zt,le);return classNames(Et,V==null?void 0:V(zt))},[zt,V,W,m,le]);reactExports.useImperativeHandle(d,function(){return{nativeElement:qe.current,popupElement:Le.current,forceAlign:wr}});var wt=reactExports.useState(0),st=_slicedToArray(wt,2),Xt=st[0],Qt=st[1],or=reactExports.useState(0),ar=_slicedToArray(or,2),Ir=ar[0],_r=ar[1],Sr=function(){if(ae&&Pe){var jt=Pe.getBoundingClientRect();Qt(jt.width),_r(jt.height)}},kr=function(){Sr(),wr()},jr=function(jt){Rt(!1),nr(),M==null||M(jt)},Pt=function(){return new Promise(function(jt){Sr(),Tt(function(){return jt})})};useLayoutEffect$1(function(){xt&&(nr(),xt(),Tt(null))},[xt]);function It(Et,jt,ur,mr){ut[Et]=function(Er){var An;mr==null||mr(Er),Je(jt,ur);for(var Pa=arguments.length,ga=new Array(Pa>1?Pa-1:0),Pn=1;Pn<Pa;Pn++)ga[Pn-1]=arguments[Pn];(An=We[Et])===null||An===void 0||An.call.apply(An,[We,Er].concat(ga))}}(en||tn)&&(ut.onClick=function(Et){var jt;rt.current&&tn?Je(!1):!rt.current&&en&&(Zt(Et),Je(!0));for(var ur=arguments.length,mr=new Array(ur>1?ur-1:0),Er=1;Er<ur;Er++)mr[Er-1]=arguments[Er];(jt=We.onClick)===null||jt===void 0||jt.call.apply(jt,[We,Et].concat(mr))});var Or=useWinClick(vt,tn,Pe,be,B,L,gt,Je),vr=Tr.has("hover"),yr=lr.has("hover"),Gr,Lr;vr&&(It("onMouseEnter",!0,I,function(Et){Zt(Et)}),It("onPointerEnter",!0,I,function(Et){Zt(Et)}),Gr=function(jt){(vt||pt)&&be!==null&&be!==void 0&&be.contains(jt.target)&&Je(!0,I)},le&&(ut.onMouseMove=function(Et){var jt;(jt=We.onMouseMove)===null||jt===void 0||jt.call(We,Et)})),yr&&(It("onMouseLeave",!1,A),It("onPointerLeave",!1,A),Lr=function(){Je(!1,A)}),Tr.has("focus")&&It("onFocus",!0,P),lr.has("focus")&&It("onBlur",!1,z),Tr.has("contextMenu")&&(ut.onContextMenu=function(Et){var jt;rt.current&&lr.has("contextMenu")?Je(!1):(Zt(Et),Je(!0)),Et.preventDefault();for(var ur=arguments.length,mr=new Array(ur>1?ur-1:0),Er=1;Er<ur;Er++)mr[Er-1]=arguments[Er];(jt=We.onContextMenu)===null||jt===void 0||jt.call.apply(jt,[We,Et].concat(mr))}),fe&&(ut.className=classNames(We.className,fe));var Mr=_objectSpread2(_objectSpread2({},We),ut),Ur={},Cn=["onContextMenu","onClick","onMouseDown","onTouchStart","onMouseEnter","onMouseLeave","onFocus","onBlur"];Cn.forEach(function(Et){xe[Et]&&(Ur[Et]=function(){for(var jt,ur=arguments.length,mr=new Array(ur),Er=0;Er<ur;Er++)mr[Er]=arguments[Er];(jt=Mr[Et])===null||jt===void 0||jt.call.apply(jt,[Mr].concat(mr)),xe[Et].apply(xe,mr)})});var ha=reactExports.cloneElement(je,_objectSpread2(_objectSpread2({},Mr),Ur)),Aa={x:qt,y:er},In=ce?_objectSpread2({},ce!==!0?ce:{}):null;return reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(RefResizeObserver,{disabled:!vt,ref:Ue,onResize:kr},reactExports.createElement(TriggerWrapper,{getTriggerDOMNode:pe},ha)),reactExports.createElement(TriggerContext.Provider,{value:Ne},reactExports.createElement(Popup$1,{portal:a,ref:Oe,prefixCls:m,popup:X,className:classNames(Q,Wt),style:Y,target:Pe,onMouseEnter:Gr,onMouseLeave:Lr,onPointerEnter:Gr,zIndex:te,open:vt,keepDom:pt,fresh:ne,onClick:ee,onPointerDownCapture:Or,mask:B,motion:kt,maskMotion:Ut,onVisibleChanged:jr,onPrepare:Pt,forceRender:q,autoDestroy:ye,getPopupContainer:U,align:zt,arrow:In,arrowPos:Aa,ready:ht,offsetX:lt,offsetY:nt,offsetR:Ot,offsetB:Bt,onAlign:wr,stretch:ae,targetWidth:Xt/St,targetHeight:Ir/_t})))});return c}const Trigger=generateTrigger(Portal);var _excluded$B=["prefixCls","disabled","visible","children","popupElement","animation","transitionName","dropdownStyle","dropdownClassName","direction","placement","builtinPlacements","dropdownMatchSelectWidth","dropdownRender","dropdownAlign","getPopupContainer","empty","getTriggerDOMNode","onPopupVisibleChange","onPopupMouseEnter"],getBuiltInPlacements$1=function(c){var u=c===!0?0:1;return{bottomLeft:{points:["tl","bl"],offset:[0,4],overflow:{adjustX:u,adjustY:1},htmlRegion:"scroll"},bottomRight:{points:["tr","br"],offset:[0,4],overflow:{adjustX:u,adjustY:1},htmlRegion:"scroll"},topLeft:{points:["bl","tl"],offset:[0,-4],overflow:{adjustX:u,adjustY:1},htmlRegion:"scroll"},topRight:{points:["br","tr"],offset:[0,-4],overflow:{adjustX:u,adjustY:1},htmlRegion:"scroll"}}},SelectTrigger=function(c,u){var d=c.prefixCls;c.disabled;var f=c.visible,m=c.children,g=c.popupElement,y=c.animation,b=c.transitionName,E=c.dropdownStyle,C=c.dropdownClassName,w=c.direction,R=w===void 0?"ltr":w,_=c.placement,M=c.builtinPlacements,I=c.dropdownMatchSelectWidth,N=c.dropdownRender,A=c.dropdownAlign,P=c.getPopupContainer,z=c.empty,B=c.getTriggerDOMNode,j=c.onPopupVisibleChange,L=c.onPopupMouseEnter,U=_objectWithoutProperties(c,_excluded$B),q="".concat(d,"-dropdown"),F=g;N&&(F=N(g));var K=reactExports.useMemo(function(){return M||getBuiltInPlacements$1(I)},[M,I]),X=y?"".concat(q,"-").concat(y):b,Q=typeof I=="number",Y=reactExports.useMemo(function(){return Q?null:I===!1?"minWidth":"width"},[I,Q]),Z=E;Q&&(Z=_objectSpread2(_objectSpread2({},Z),{},{width:I}));var J=reactExports.useRef(null);return reactExports.useImperativeHandle(u,function(){return{getPopupElement:function(){var G;return(G=J.current)===null||G===void 0?void 0:G.popupElement}}}),reactExports.createElement(Trigger,_extends({},U,{showAction:j?["click"]:[],hideAction:j?["click"]:[],popupPlacement:_||(R==="rtl"?"bottomRight":"bottomLeft"),builtinPlacements:K,prefixCls:q,popupTransitionName:X,popup:reactExports.createElement("div",{onMouseEnter:L},F),ref:J,stretch:Y,popupAlign:A,popupVisible:f,getPopupContainer:P,popupClassName:classNames(C,_defineProperty({},"".concat(q,"-empty"),z)),popupStyle:Z,getTriggerDOMNode:B,onPopupVisibleChange:j}),m)},RefSelectTrigger=reactExports.forwardRef(SelectTrigger);function getKey$1(a,c){var u=a.key,d;return"value"in a&&(d=a.value),u??(d!==void 0?d:"rc-index-key-".concat(c))}function isValidCount(a){return typeof a<"u"&&!Number.isNaN(a)}function fillFieldNames$1(a,c){var u=a||{},d=u.label,f=u.value,m=u.options,g=u.groupLabel,y=d||(c?"children":"label");return{label:y,value:f||"value",options:m||"options",groupLabel:g||y}}function flattenOptions(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},u=c.fieldNames,d=c.childrenAsData,f=[],m=fillFieldNames$1(u,!1),g=m.label,y=m.value,b=m.options,E=m.groupLabel;function C(w,R){Array.isArray(w)&&w.forEach(function(_){if(R||!(b in _)){var M=_[y];f.push({key:getKey$1(_,f.length),groupOption:R,data:_,label:_[g],value:M})}else{var I=_[E];I===void 0&&d&&(I=_.label),f.push({key:getKey$1(_,f.length),group:!0,data:_,label:I}),C(_[b],!0)}})}return C(a,!1),f}function injectPropsWithOption(a){var c=_objectSpread2({},a);return"props"in c||Object.defineProperty(c,"props",{get:function(){return warningOnce$1(!1,"Return type is option instead of Option instance. Please read value directly instead of reading from `props`."),c}}),c}var getSeparatedContent=function(c,u,d){if(!u||!u.length)return null;var f=!1,m=function y(b,E){var C=_toArray(E),w=C[0],R=C.slice(1);if(!w)return[b];var _=b.split(w);return f=f||_.length>1,_.reduce(function(M,I){return[].concat(_toConsumableArray(M),_toConsumableArray(y(I,R)))},[]).filter(Boolean)},g=m(c,u);return f?typeof d<"u"?g.slice(0,d):g:null},SelectContext=reactExports.createContext(null);function Polite(a){var c=a.visible,u=a.values;if(!c)return null;var d=50;return reactExports.createElement("span",{"aria-live":"polite",style:{width:0,height:0,position:"absolute",overflow:"hidden",opacity:0}},"".concat(u.slice(0,d).map(function(f){var m=f.label,g=f.value;return["number","string"].includes(_typeof(m))?m:g}).join(", ")),u.length>d?", ...":null)}var _excluded$A=["id","prefixCls","className","showSearch","tagRender","direction","omitDomProps","displayValues","onDisplayValuesChange","emptyOptions","notFoundContent","onClear","mode","disabled","loading","getInputElement","getRawInputElement","open","defaultOpen","onDropdownVisibleChange","activeValue","onActiveValueChange","activeDescendantId","searchValue","autoClearSearchValue","onSearch","onSearchSplit","tokenSeparators","allowClear","prefix","suffixIcon","clearIcon","OptionList","animation","transitionName","dropdownStyle","dropdownClassName","dropdownMatchSelectWidth","dropdownRender","dropdownAlign","placement","builtinPlacements","getPopupContainer","showAction","onFocus","onBlur","onKeyUp","onKeyDown","onMouseDown"],DEFAULT_OMIT_PROPS=["value","onChange","removeIcon","placeholder","autoFocus","maxTagCount","maxTagTextLength","maxTagPlaceholder","choiceTransitionName","onInputKeyDown","onPopupScroll","tabIndex"],isMultiple=function(c){return c==="tags"||c==="multiple"},BaseSelect$1=reactExports.forwardRef(function(a,c){var u,d=a.id,f=a.prefixCls,m=a.className,g=a.showSearch,y=a.tagRender,b=a.direction,E=a.omitDomProps,C=a.displayValues,w=a.onDisplayValuesChange,R=a.emptyOptions,_=a.notFoundContent,M=_===void 0?"Not Found":_,I=a.onClear,N=a.mode,A=a.disabled,P=a.loading,z=a.getInputElement,B=a.getRawInputElement,j=a.open,L=a.defaultOpen,U=a.onDropdownVisibleChange,q=a.activeValue,F=a.onActiveValueChange,K=a.activeDescendantId,X=a.searchValue,Q=a.autoClearSearchValue,Y=a.onSearch,Z=a.onSearchSplit,J=a.tokenSeparators,W=a.allowClear,G=a.prefix,te=a.suffixIcon,ae=a.clearIcon,V=a.OptionList,ne=a.animation,le=a.transitionName,ee=a.dropdownStyle,ie=a.dropdownClassName,ce=a.dropdownMatchSelectWidth,ue=a.dropdownRender,me=a.dropdownAlign,de=a.placement,ge=a.builtinPlacements,Ce=a.getPopupContainer,ve=a.showAction,fe=ve===void 0?[]:ve,pe=a.onFocus,xe=a.onBlur,ye=a.onKeyUp,he=a.onKeyDown,we=a.onMouseDown,Re=_objectWithoutProperties(a,_excluded$A),De=isMultiple(N),Ae=(g!==void 0?g:De)||N==="combobox",Ee=_objectSpread2({},Re);DEFAULT_OMIT_PROPS.forEach(function(wt){delete Ee[wt]}),E==null||E.forEach(function(wt){delete Ee[wt]});var Ne=reactExports.useState(!1),_e=_slicedToArray(Ne,2),ke=_e[0],Ke=_e[1];reactExports.useEffect(function(){Ke(isMobile())},[]);var be=reactExports.useRef(null),Te=reactExports.useRef(null),Le=reactExports.useRef(null),Oe=reactExports.useRef(null),Be=reactExports.useRef(null),Ve=reactExports.useRef(!1),Pe=useDelayReset(),Ge=_slicedToArray(Pe,3),qe=Ge[0],Ue=Ge[1],je=Ge[2];reactExports.useImperativeHandle(c,function(){var wt,st;return{focus:(wt=Oe.current)===null||wt===void 0?void 0:wt.focus,blur:(st=Oe.current)===null||st===void 0?void 0:st.blur,scrollTo:function(Qt){var or;return(or=Be.current)===null||or===void 0?void 0:or.scrollTo(Qt)},nativeElement:be.current||Te.current}});var We=reactExports.useMemo(function(){var wt;if(N!=="combobox")return X;var st=(wt=C[0])===null||wt===void 0?void 0:wt.value;return typeof st=="string"||typeof st=="number"?String(st):""},[X,N,C]),ut=N==="combobox"&&typeof z=="function"&&z()||null,gt=typeof B=="function"&&B(),kt=useComposeRef(Te,gt==null||(u=gt.props)===null||u===void 0?void 0:u.ref),Ut=reactExports.useState(!1),at=_slicedToArray(Ut,2),ct=at[0],bt=at[1];useLayoutEffect$1(function(){bt(!0)},[]);var it=useMergedState(!1,{defaultValue:L,value:j}),vt=_slicedToArray(it,2),ot=vt[0],rt=vt[1],et=ct?ot:!1,$t=!M&&R;(A||$t&&et&&N==="combobox")&&(et=!1);var mt=$t?!1:et,Ze=reactExports.useCallback(function(wt){var st=wt!==void 0?wt:!et;A||(rt(st),et!==st&&(U==null||U(st)))},[A,et,rt,U]),Je=reactExports.useMemo(function(){return(J||[]).some(function(wt){return[`
`,`\r
`].includes(wt)})},[J]),yt=reactExports.useContext(SelectContext)||{},Ct=yt.maxCount,pt=yt.rawValues,Rt=function(st,Xt,Qt){if(!(De&&isValidCount(Ct)&&(pt==null?void 0:pt.size)>=Ct)){var or=!0,ar=st;F==null||F(null);var Ir=getSeparatedContent(st,J,isValidCount(Ct)?Ct-pt.size:void 0),_r=Qt?null:Ir;return N!=="combobox"&&_r&&(ar="",Z==null||Z(_r),Ze(!1),or=!1),Y&&We!==ar&&Y(ar,{source:Xt?"typing":"effect"}),or}},ft=function(st){!st||!st.trim()||Y(st,{source:"submit"})};reactExports.useEffect(function(){!et&&!De&&N!=="combobox"&&Rt("",!1,!1)},[et]),reactExports.useEffect(function(){ot&&A&&rt(!1),A&&!Ve.current&&Ue(!1)},[A]);var dt=useLock(),xt=_slicedToArray(dt,2),Tt=xt[0],Dt=xt[1],Vt=reactExports.useRef(!1),Nt=function(st){var Xt=Tt(),Qt=st.key,or=Qt==="Enter";if(or&&(N!=="combobox"&&st.preventDefault(),et||Ze(!0)),Dt(!!We),Qt==="Backspace"&&!Xt&&De&&!We&&C.length){for(var ar=_toConsumableArray(C),Ir=null,_r=ar.length-1;_r>=0;_r-=1){var Sr=ar[_r];if(!Sr.disabled){ar.splice(_r,1),Ir=Sr;break}}Ir&&w(ar,{type:"remove",values:[Ir]})}for(var kr=arguments.length,jr=new Array(kr>1?kr-1:0),Pt=1;Pt<kr;Pt++)jr[Pt-1]=arguments[Pt];if(et&&(!or||!Vt.current)){var It;or&&(Vt.current=!0),(It=Be.current)===null||It===void 0||It.onKeyDown.apply(It,[st].concat(jr))}he==null||he.apply(void 0,[st].concat(jr))},Kt=function(st){for(var Xt=arguments.length,Qt=new Array(Xt>1?Xt-1:0),or=1;or<Xt;or++)Qt[or-1]=arguments[or];if(et){var ar;(ar=Be.current)===null||ar===void 0||ar.onKeyUp.apply(ar,[st].concat(Qt))}st.key==="Enter"&&(Vt.current=!1),ye==null||ye.apply(void 0,[st].concat(Qt))},Zt=function(st){var Xt=C.filter(function(Qt){return Qt!==st});w(Xt,{type:"remove",values:[st]})},Gt=function(){Vt.current=!1},tt=reactExports.useRef(!1),ht=function(){Ue(!0),A||(pe&&!tt.current&&pe.apply(void 0,arguments),fe.includes("focus")&&Ze(!0)),tt.current=!0},lt=function(){Ve.current=!0,Ue(!1,function(){tt.current=!1,Ve.current=!1,Ze(!1)}),!A&&(We&&(N==="tags"?Y(We,{source:"submit"}):N==="multiple"&&Y("",{source:"blur"})),xe&&xe.apply(void 0,arguments))},nt=[];reactExports.useEffect(function(){return function(){nt.forEach(function(wt){return clearTimeout(wt)}),nt.splice(0,nt.length)}},[]);var Ot=function(st){var Xt,Qt=st.target,or=(Xt=Le.current)===null||Xt===void 0?void 0:Xt.getPopupElement();if(or&&or.contains(Qt)){var ar=setTimeout(function(){var kr=nt.indexOf(ar);if(kr!==-1&&nt.splice(kr,1),je(),!ke&&!or.contains(document.activeElement)){var jr;(jr=Oe.current)===null||jr===void 0||jr.focus()}});nt.push(ar)}for(var Ir=arguments.length,_r=new Array(Ir>1?Ir-1:0),Sr=1;Sr<Ir;Sr++)_r[Sr-1]=arguments[Sr];we==null||we.apply(void 0,[st].concat(_r))},Bt=reactExports.useState({}),qt=_slicedToArray(Bt,2),er=qt[1];function St(){er({})}var _t;gt&&(_t=function(st){Ze(st)}),useSelectTriggerControl(function(){var wt;return[be.current,(wt=Le.current)===null||wt===void 0?void 0:wt.getPopupElement()]},mt,Ze,!!gt);var zt=reactExports.useMemo(function(){return _objectSpread2(_objectSpread2({},a),{},{notFoundContent:M,open:et,triggerOpen:mt,id:d,showSearch:Ae,multiple:De,toggleOpen:Ze})},[a,M,mt,et,d,Ae,De,Ze]),nr=!!te||P,Rr;nr&&(Rr=reactExports.createElement(TransBtn,{className:classNames("".concat(f,"-arrow"),_defineProperty({},"".concat(f,"-arrow-loading"),P)),customizeIcon:te,customizeIconProps:{loading:P,searchValue:We,open:et,focused:qe,showSearch:Ae}}));var Jr=function(){var st;I==null||I(),(st=Oe.current)===null||st===void 0||st.focus(),w([],{type:"clear",values:C}),Rt("",!1,!1)},Tr=useAllowClear(f,Jr,C,W,ae,A,We,N),lr=Tr.allowClear,en=Tr.clearIcon,tn=reactExports.createElement(V,{ref:Be}),wr=classNames(f,m,_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(f,"-focused"),qe),"".concat(f,"-multiple"),De),"".concat(f,"-single"),!De),"".concat(f,"-allow-clear"),W),"".concat(f,"-show-arrow"),nr),"".concat(f,"-disabled"),A),"".concat(f,"-loading"),P),"".concat(f,"-open"),et),"".concat(f,"-customize-input"),ut),"".concat(f,"-show-search"),Ae)),rn=reactExports.createElement(RefSelectTrigger,{ref:Le,disabled:A,prefixCls:f,visible:mt,popupElement:tn,animation:ne,transitionName:le,dropdownStyle:ee,dropdownClassName:ie,direction:b,dropdownMatchSelectWidth:ce,dropdownRender:ue,dropdownAlign:me,placement:de,builtinPlacements:ge,getPopupContainer:Ce,empty:R,getTriggerDOMNode:function(st){return Te.current||st},onPopupVisibleChange:_t,onPopupMouseEnter:St},gt?reactExports.cloneElement(gt,{ref:kt}):reactExports.createElement(ForwardSelector,_extends({},a,{domRef:Te,prefixCls:f,inputElement:ut,ref:Oe,id:d,prefix:G,showSearch:Ae,autoClearSearchValue:Q,mode:N,activeDescendantId:K,tagRender:y,values:C,open:et,onToggleOpen:Ze,activeValue:q,searchValue:We,onSearch:Rt,onSearchSubmit:ft,onRemove:Zt,tokenWithEnter:Je,onInputBlur:Gt}))),Wt;return gt?Wt=rn:Wt=reactExports.createElement("div",_extends({className:wr},Ee,{ref:be,onMouseDown:Ot,onKeyDown:Nt,onKeyUp:Kt,onFocus:ht,onBlur:lt}),reactExports.createElement(Polite,{visible:qe&&!et,values:C}),rn,Rr,lr&&en),reactExports.createElement(BaseSelectContext.Provider,{value:zt},Wt)}),OptGroup=function(){return null};OptGroup.isSelectOptGroup=!0;var Option=function(){return null};Option.isSelectOption=!0;var Filler=reactExports.forwardRef(function(a,c){var u=a.height,d=a.offsetY,f=a.offsetX,m=a.children,g=a.prefixCls,y=a.onInnerResize,b=a.innerProps,E=a.rtl,C=a.extra,w={},R={display:"flex",flexDirection:"column"};return d!==void 0&&(w={height:u,position:"relative",overflow:"hidden"},R=_objectSpread2(_objectSpread2({},R),{},_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({transform:"translateY(".concat(d,"px)")},E?"marginRight":"marginLeft",-f),"position","absolute"),"left",0),"right",0),"top",0))),reactExports.createElement("div",{style:w},reactExports.createElement(RefResizeObserver,{onResize:function(M){var I=M.offsetHeight;I&&y&&y()}},reactExports.createElement("div",_extends({style:R,className:classNames(_defineProperty({},"".concat(g,"-holder-inner"),g)),ref:c},b),m,C)))});Filler.displayName="Filler";function Item$1(a){var c=a.children,u=a.setRef,d=reactExports.useCallback(function(f){u(f)},[]);return reactExports.cloneElement(c,{ref:d})}function useChildren$1(a,c,u,d,f,m,g,y){var b=y.getKey;return a.slice(c,u+1).map(function(E,C){var w=c+C,R=g(E,w,{style:{width:d},offsetX:f}),_=b(E);return reactExports.createElement(Item$1,{key:_,setRef:function(I){return m(E,I)}},R)})}function findListDiffIndex(a,c,u){var d=a.length,f=c.length,m,g;if(d===0&&f===0)return null;d<f?(m=a,g=c):(m=c,g=a);var y={__EMPTY_ITEM__:!0};function b(M){return M!==void 0?u(M):y}for(var E=null,C=Math.abs(d-f)!==1,w=0;w<g.length;w+=1){var R=b(m[w]),_=b(g[w]);if(R!==_){E=w,C=C||R!==b(g[w+1]);break}}return E===null?null:{index:E,multiple:C}}function useDiffItem(a,c,u){var d=reactExports.useState(a),f=_slicedToArray(d,2),m=f[0],g=f[1],y=reactExports.useState(null),b=_slicedToArray(y,2),E=b[0],C=b[1];return reactExports.useEffect(function(){var w=findListDiffIndex(m||[],a||[],c);(w==null?void 0:w.index)!==void 0&&C(a[w.index]),g(a)},[a]),[E]}var isFF=(typeof navigator>"u"?"undefined":_typeof(navigator))==="object"&&/Firefox/i.test(navigator.userAgent);const useOriginScroll=function(a,c,u,d){var f=reactExports.useRef(!1),m=reactExports.useRef(null);function g(){clearTimeout(m.current),f.current=!0,m.current=setTimeout(function(){f.current=!1},50)}var y=reactExports.useRef({top:a,bottom:c,left:u,right:d});return y.current.top=a,y.current.bottom=c,y.current.left=u,y.current.right=d,function(b,E){var C=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1,w=b?E<0&&y.current.left||E>0&&y.current.right:E<0&&y.current.top||E>0&&y.current.bottom;return C&&w?(clearTimeout(m.current),f.current=!1):(!w||f.current)&&g(),!f.current&&w}};function useFrameWheel(a,c,u,d,f,m,g){var y=reactExports.useRef(0),b=reactExports.useRef(null),E=reactExports.useRef(null),C=reactExports.useRef(!1),w=useOriginScroll(c,u,d,f);function R(P,z){if(wrapperRaf.cancel(b.current),!w(!1,z)){var B=P;if(!B._virtualHandled)B._virtualHandled=!0;else return;y.current+=z,E.current=z,isFF||B.preventDefault(),b.current=wrapperRaf(function(){var j=C.current?10:1;g(y.current*j,!1),y.current=0})}}function _(P,z){g(z,!0),isFF||P.preventDefault()}var M=reactExports.useRef(null),I=reactExports.useRef(null);function N(P){if(a){wrapperRaf.cancel(I.current),I.current=wrapperRaf(function(){M.current=null},2);var z=P.deltaX,B=P.deltaY,j=P.shiftKey,L=z,U=B;(M.current==="sx"||!M.current&&j&&B&&!z)&&(L=B,U=0,M.current="sx");var q=Math.abs(L),F=Math.abs(U);M.current===null&&(M.current=m&&q>F?"x":"y"),M.current==="y"?R(P,U):_(P,L)}}function A(P){a&&(C.current=P.detail===E.current)}return[N,A]}function useGetSize(a,c,u,d){var f=reactExports.useMemo(function(){return[new Map,[]]},[a,u.id,d]),m=_slicedToArray(f,2),g=m[0],y=m[1],b=function(C){var w=arguments.length>1&&arguments[1]!==void 0?arguments[1]:C,R=g.get(C),_=g.get(w);if(R===void 0||_===void 0)for(var M=a.length,I=y.length;I<M;I+=1){var N,A=a[I],P=c(A);g.set(P,I);var z=(N=u.get(P))!==null&&N!==void 0?N:d;if(y[I]=(y[I-1]||0)+z,P===C&&(R=I),P===w&&(_=I),R!==void 0&&_!==void 0)break}return{top:y[R-1]||0,bottom:y[_]}};return b}var CacheMap=function(){function a(){_classCallCheck(this,a),_defineProperty(this,"maps",void 0),_defineProperty(this,"id",0),_defineProperty(this,"diffKeys",new Set),this.maps=Object.create(null)}return _createClass(a,[{key:"set",value:function(u,d){this.maps[u]=d,this.id+=1,this.diffKeys.add(u)}},{key:"get",value:function(u){return this.maps[u]}},{key:"resetRecord",value:function(){this.diffKeys.clear()}},{key:"getRecord",value:function(){return this.diffKeys}}]),a}();function parseNumber(a){var c=parseFloat(a);return isNaN(c)?0:c}function useHeights(a,c,u){var d=reactExports.useState(0),f=_slicedToArray(d,2),m=f[0],g=f[1],y=reactExports.useRef(new Map),b=reactExports.useRef(new CacheMap),E=reactExports.useRef(0);function C(){E.current+=1}function w(){var _=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1;C();var M=function(){var A=!1;y.current.forEach(function(P,z){if(P&&P.offsetParent){var B=P.offsetHeight,j=getComputedStyle(P),L=j.marginTop,U=j.marginBottom,q=parseNumber(L),F=parseNumber(U),K=B+q+F;b.current.get(z)!==K&&(b.current.set(z,K),A=!0)}}),A&&g(function(P){return P+1})};if(_)M();else{E.current+=1;var I=E.current;Promise.resolve().then(function(){I===E.current&&M()})}}function R(_,M){var I=a(_);y.current.get(I),M?(y.current.set(I,M),w()):y.current.delete(I)}return reactExports.useEffect(function(){return C},[]),[R,w,b.current,m]}var SMOOTH_PTG=14/15;function useMobileTouchMove(a,c,u){var d=reactExports.useRef(!1),f=reactExports.useRef(0),m=reactExports.useRef(0),g=reactExports.useRef(null),y=reactExports.useRef(null),b,E=function(_){if(d.current){var M=Math.ceil(_.touches[0].pageX),I=Math.ceil(_.touches[0].pageY),N=f.current-M,A=m.current-I,P=Math.abs(N)>Math.abs(A);P?f.current=M:m.current=I;var z=u(P,P?N:A,!1,_);z&&_.preventDefault(),clearInterval(y.current),z&&(y.current=setInterval(function(){P?N*=SMOOTH_PTG:A*=SMOOTH_PTG;var B=Math.floor(P?N:A);(!u(P,B,!0)||Math.abs(B)<=.1)&&clearInterval(y.current)},16))}},C=function(){d.current=!1,b()},w=function(_){b(),_.touches.length===1&&!d.current&&(d.current=!0,f.current=Math.ceil(_.touches[0].pageX),m.current=Math.ceil(_.touches[0].pageY),g.current=_.target,g.current.addEventListener("touchmove",E,{passive:!1}),g.current.addEventListener("touchend",C,{passive:!0}))};b=function(){g.current&&(g.current.removeEventListener("touchmove",E),g.current.removeEventListener("touchend",C))},useLayoutEffect$1(function(){return a&&c.current.addEventListener("touchstart",w,{passive:!0}),function(){var R;(R=c.current)===null||R===void 0||R.removeEventListener("touchstart",w),b(),clearInterval(y.current)}},[a])}function smoothScrollOffset(a){return Math.floor(Math.pow(a,.5))}function getPageXY(a,c){var u="touches"in a?a.touches[0]:a;return u[c?"pageX":"pageY"]-window[c?"scrollX":"scrollY"]}function useScrollDrag(a,c,u){reactExports.useEffect(function(){var d=c.current;if(a&&d){var f=!1,m,g,y=function(){wrapperRaf.cancel(m)},b=function R(){y(),m=wrapperRaf(function(){u(g),R()})},E=function(_){if(!(_.target.draggable||_.button!==0)){var M=_;M._virtualHandled||(M._virtualHandled=!0,f=!0)}},C=function(){f=!1,y()},w=function(_){if(f){var M=getPageXY(_,!1),I=d.getBoundingClientRect(),N=I.top,A=I.bottom;if(M<=N){var P=N-M;g=-smoothScrollOffset(P),b()}else if(M>=A){var z=M-A;g=smoothScrollOffset(z),b()}else y()}};return d.addEventListener("mousedown",E),d.ownerDocument.addEventListener("mouseup",C),d.ownerDocument.addEventListener("mousemove",w),function(){d.removeEventListener("mousedown",E),d.ownerDocument.removeEventListener("mouseup",C),d.ownerDocument.removeEventListener("mousemove",w),y()}}},[a])}var MAX_TIMES=10;function useScrollTo(a,c,u,d,f,m,g,y){var b=reactExports.useRef(),E=reactExports.useState(null),C=_slicedToArray(E,2),w=C[0],R=C[1];return useLayoutEffect$1(function(){if(w&&w.times<MAX_TIMES){if(!a.current){R(function(ae){return _objectSpread2({},ae)});return}m();var _=w.targetAlign,M=w.originAlign,I=w.index,N=w.offset,A=a.current.clientHeight,P=!1,z=_,B=null;if(A){for(var j=_||M,L=0,U=0,q=0,F=Math.min(c.length-1,I),K=0;K<=F;K+=1){var X=f(c[K]);U=L;var Q=u.get(X);q=U+(Q===void 0?d:Q),L=q}for(var Y=j==="top"?N:A-N,Z=F;Z>=0;Z-=1){var J=f(c[Z]),W=u.get(J);if(W===void 0){P=!0;break}if(Y-=W,Y<=0)break}switch(j){case"top":B=U-N;break;case"bottom":B=q-A+N;break;default:{var G=a.current.scrollTop,te=G+A;U<G?z="top":q>te&&(z="bottom")}}B!==null&&g(B),B!==w.lastTop&&(P=!0)}P&&R(_objectSpread2(_objectSpread2({},w),{},{times:w.times+1,targetAlign:z,lastTop:B}))}},[w,a.current]),function(_){if(_==null){y();return}if(wrapperRaf.cancel(b.current),typeof _=="number")g(_);else if(_&&_typeof(_)==="object"){var M,I=_.align;"index"in _?M=_.index:M=c.findIndex(function(P){return f(P)===_.key});var N=_.offset,A=N===void 0?0:N;R({times:0,index:M,offset:A,originAlign:I})}}}var ScrollBar=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.rtl,f=a.scrollOffset,m=a.scrollRange,g=a.onStartMove,y=a.onStopMove,b=a.onScroll,E=a.horizontal,C=a.spinSize,w=a.containerSize,R=a.style,_=a.thumbStyle,M=a.showScrollBar,I=reactExports.useState(!1),N=_slicedToArray(I,2),A=N[0],P=N[1],z=reactExports.useState(null),B=_slicedToArray(z,2),j=B[0],L=B[1],U=reactExports.useState(null),q=_slicedToArray(U,2),F=q[0],K=q[1],X=!d,Q=reactExports.useRef(),Y=reactExports.useRef(),Z=reactExports.useState(M),J=_slicedToArray(Z,2),W=J[0],G=J[1],te=reactExports.useRef(),ae=function(){M===!0||M===!1||(clearTimeout(te.current),G(!0),te.current=setTimeout(function(){G(!1)},3e3))},V=m-w||0,ne=w-C||0,le=reactExports.useMemo(function(){if(f===0||V===0)return 0;var ve=f/V;return ve*ne},[f,V,ne]),ee=function(fe){fe.stopPropagation(),fe.preventDefault()},ie=reactExports.useRef({top:le,dragging:A,pageY:j,startTop:F});ie.current={top:le,dragging:A,pageY:j,startTop:F};var ce=function(fe){P(!0),L(getPageXY(fe,E)),K(ie.current.top),g(),fe.stopPropagation(),fe.preventDefault()};reactExports.useEffect(function(){var ve=function(ye){ye.preventDefault()},fe=Q.current,pe=Y.current;return fe.addEventListener("touchstart",ve,{passive:!1}),pe.addEventListener("touchstart",ce,{passive:!1}),function(){fe.removeEventListener("touchstart",ve),pe.removeEventListener("touchstart",ce)}},[]);var ue=reactExports.useRef();ue.current=V;var me=reactExports.useRef();me.current=ne,reactExports.useEffect(function(){if(A){var ve,fe=function(ye){var he=ie.current,we=he.dragging,Re=he.pageY,De=he.startTop;wrapperRaf.cancel(ve);var Ae=Q.current.getBoundingClientRect(),Ee=w/(E?Ae.width:Ae.height);if(we){var Ne=(getPageXY(ye,E)-Re)*Ee,_e=De;!X&&E?_e-=Ne:_e+=Ne;var ke=ue.current,Ke=me.current,be=Ke?_e/Ke:0,Te=Math.ceil(be*ke);Te=Math.max(Te,0),Te=Math.min(Te,ke),ve=wrapperRaf(function(){b(Te,E)})}},pe=function(){P(!1),y()};return window.addEventListener("mousemove",fe,{passive:!0}),window.addEventListener("touchmove",fe,{passive:!0}),window.addEventListener("mouseup",pe,{passive:!0}),window.addEventListener("touchend",pe,{passive:!0}),function(){window.removeEventListener("mousemove",fe),window.removeEventListener("touchmove",fe),window.removeEventListener("mouseup",pe),window.removeEventListener("touchend",pe),wrapperRaf.cancel(ve)}}},[A]),reactExports.useEffect(function(){return ae(),function(){clearTimeout(te.current)}},[f]),reactExports.useImperativeHandle(c,function(){return{delayHidden:ae}});var de="".concat(u,"-scrollbar"),ge={position:"absolute",visibility:W?null:"hidden"},Ce={position:"absolute",background:"rgba(0, 0, 0, 0.5)",borderRadius:99,cursor:"pointer",userSelect:"none"};return E?(ge.height=8,ge.left=0,ge.right=0,ge.bottom=0,Ce.height="100%",Ce.width=C,X?Ce.left=le:Ce.right=le):(ge.width=8,ge.top=0,ge.bottom=0,X?ge.right=0:ge.left=0,Ce.width="100%",Ce.height=C,Ce.top=le),reactExports.createElement("div",{ref:Q,className:classNames(de,_defineProperty(_defineProperty(_defineProperty({},"".concat(de,"-horizontal"),E),"".concat(de,"-vertical"),!E),"".concat(de,"-visible"),W)),style:_objectSpread2(_objectSpread2({},ge),R),onMouseDown:ee,onMouseMove:ae},reactExports.createElement("div",{ref:Y,className:classNames("".concat(de,"-thumb"),_defineProperty({},"".concat(de,"-thumb-moving"),A)),style:_objectSpread2(_objectSpread2({},Ce),_),onMouseDown:ce}))}),MIN_SIZE=20;function getSpinSize(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:0,c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:0,u=a/c*a;return isNaN(u)&&(u=0),u=Math.max(u,MIN_SIZE),Math.floor(u)}var _excluded$z=["prefixCls","className","height","itemHeight","fullHeight","style","data","children","itemKey","virtual","direction","scrollWidth","component","onScroll","onVirtualScroll","onVisibleChange","innerProps","extraRender","styles","showScrollBar"],EMPTY_DATA$1=[],ScrollStyle={overflowY:"auto",overflowAnchor:"none"};function RawList(a,c){var u=a.prefixCls,d=u===void 0?"rc-virtual-list":u,f=a.className,m=a.height,g=a.itemHeight,y=a.fullHeight,b=y===void 0?!0:y,E=a.style,C=a.data,w=a.children,R=a.itemKey,_=a.virtual,M=a.direction,I=a.scrollWidth,N=a.component,A=N===void 0?"div":N,P=a.onScroll,z=a.onVirtualScroll,B=a.onVisibleChange,j=a.innerProps,L=a.extraRender,U=a.styles,q=a.showScrollBar,F=q===void 0?"optional":q,K=_objectWithoutProperties(a,_excluded$z),X=reactExports.useCallback(function(tt){return typeof R=="function"?R(tt):tt==null?void 0:tt[R]},[R]),Q=useHeights(X),Y=_slicedToArray(Q,4),Z=Y[0],J=Y[1],W=Y[2],G=Y[3],te=!!(_!==!1&&m&&g),ae=reactExports.useMemo(function(){return Object.values(W.maps).reduce(function(tt,ht){return tt+ht},0)},[W.id,W.maps]),V=te&&C&&(Math.max(g*C.length,ae)>m||!!I),ne=M==="rtl",le=classNames(d,_defineProperty({},"".concat(d,"-rtl"),ne),f),ee=C||EMPTY_DATA$1,ie=reactExports.useRef(),ce=reactExports.useRef(),ue=reactExports.useRef(),me=reactExports.useState(0),de=_slicedToArray(me,2),ge=de[0],Ce=de[1],ve=reactExports.useState(0),fe=_slicedToArray(ve,2),pe=fe[0],xe=fe[1],ye=reactExports.useState(!1),he=_slicedToArray(ye,2),we=he[0],Re=he[1],De=function(){Re(!0)},Ae=function(){Re(!1)},Ee={getKey:X};function Ne(tt){Ce(function(ht){var lt;typeof tt=="function"?lt=tt(ht):lt=tt;var nt=bt(lt);return ie.current.scrollTop=nt,nt})}var _e=reactExports.useRef({start:0,end:ee.length}),ke=reactExports.useRef(),Ke=useDiffItem(ee,X),be=_slicedToArray(Ke,1),Te=be[0];ke.current=Te;var Le=reactExports.useMemo(function(){if(!te)return{scrollHeight:void 0,start:0,end:ee.length-1,offset:void 0};if(!V){var tt;return{scrollHeight:((tt=ce.current)===null||tt===void 0?void 0:tt.offsetHeight)||0,start:0,end:ee.length-1,offset:void 0}}for(var ht=0,lt,nt,Ot,Bt=ee.length,qt=0;qt<Bt;qt+=1){var er=ee[qt],St=X(er),_t=W.get(St),zt=ht+(_t===void 0?g:_t);zt>=ge&&lt===void 0&&(lt=qt,nt=ht),zt>ge+m&&Ot===void 0&&(Ot=qt),ht=zt}return lt===void 0&&(lt=0,nt=0,Ot=Math.ceil(m/g)),Ot===void 0&&(Ot=ee.length-1),Ot=Math.min(Ot+1,ee.length-1),{scrollHeight:ht,start:lt,end:Ot,offset:nt}},[V,te,ge,ee,G,m]),Oe=Le.scrollHeight,Be=Le.start,Ve=Le.end,Pe=Le.offset;_e.current.start=Be,_e.current.end=Ve,reactExports.useLayoutEffect(function(){var tt=W.getRecord();if(tt.size===1){var ht=Array.from(tt)[0],lt=ee[Be];if(lt){var nt=X(lt);if(nt===ht){var Ot=W.get(ht),Bt=Ot-g;Ne(function(qt){return qt+Bt})}}}W.resetRecord()},[Oe]);var Ge=reactExports.useState({width:0,height:m}),qe=_slicedToArray(Ge,2),Ue=qe[0],je=qe[1],We=function(ht){je({width:ht.offsetWidth,height:ht.offsetHeight})},ut=reactExports.useRef(),gt=reactExports.useRef(),kt=reactExports.useMemo(function(){return getSpinSize(Ue.width,I)},[Ue.width,I]),Ut=reactExports.useMemo(function(){return getSpinSize(Ue.height,Oe)},[Ue.height,Oe]),at=Oe-m,ct=reactExports.useRef(at);ct.current=at;function bt(tt){var ht=tt;return Number.isNaN(ct.current)||(ht=Math.min(ht,ct.current)),ht=Math.max(ht,0),ht}var it=ge<=0,vt=ge>=at,ot=pe<=0,rt=pe>=I,et=useOriginScroll(it,vt,ot,rt),$t=function(){return{x:ne?-pe:pe,y:ge}},mt=reactExports.useRef($t()),Ze=useEvent(function(tt){if(z){var ht=_objectSpread2(_objectSpread2({},$t()),tt);(mt.current.x!==ht.x||mt.current.y!==ht.y)&&(z(ht),mt.current=ht)}});function Je(tt,ht){var lt=tt;ht?(reactDomExports.flushSync(function(){xe(lt)}),Ze()):Ne(lt)}function yt(tt){var ht=tt.currentTarget.scrollTop;ht!==ge&&Ne(ht),P==null||P(tt),Ze()}var Ct=function(ht){var lt=ht,nt=I?I-Ue.width:0;return lt=Math.max(lt,0),lt=Math.min(lt,nt),lt},pt=useEvent(function(tt,ht){ht?(reactDomExports.flushSync(function(){xe(function(lt){var nt=lt+(ne?-tt:tt);return Ct(nt)})}),Ze()):Ne(function(lt){var nt=lt+tt;return nt})}),Rt=useFrameWheel(te,it,vt,ot,rt,!!I,pt),ft=_slicedToArray(Rt,2),dt=ft[0],xt=ft[1];useMobileTouchMove(te,ie,function(tt,ht,lt,nt){var Ot=nt;return et(tt,ht,lt)?!1:!Ot||!Ot._virtualHandled?(Ot&&(Ot._virtualHandled=!0),dt({preventDefault:function(){},deltaX:tt?ht:0,deltaY:tt?0:ht}),!0):!1}),useScrollDrag(V,ie,function(tt){Ne(function(ht){return ht+tt})}),useLayoutEffect$1(function(){function tt(lt){var nt=it&&lt.detail<0,Ot=vt&&lt.detail>0;te&&!nt&&!Ot&&lt.preventDefault()}var ht=ie.current;return ht.addEventListener("wheel",dt,{passive:!1}),ht.addEventListener("DOMMouseScroll",xt,{passive:!0}),ht.addEventListener("MozMousePixelScroll",tt,{passive:!1}),function(){ht.removeEventListener("wheel",dt),ht.removeEventListener("DOMMouseScroll",xt),ht.removeEventListener("MozMousePixelScroll",tt)}},[te,it,vt]),useLayoutEffect$1(function(){if(I){var tt=Ct(pe);xe(tt),Ze({x:tt})}},[Ue.width,I]);var Tt=function(){var ht,lt;(ht=ut.current)===null||ht===void 0||ht.delayHidden(),(lt=gt.current)===null||lt===void 0||lt.delayHidden()},Dt=useScrollTo(ie,ee,W,g,X,function(){return J(!0)},Ne,Tt);reactExports.useImperativeHandle(c,function(){return{nativeElement:ue.current,getScrollInfo:$t,scrollTo:function(ht){function lt(nt){return nt&&_typeof(nt)==="object"&&("left"in nt||"top"in nt)}lt(ht)?(ht.left!==void 0&&xe(Ct(ht.left)),Dt(ht.top)):Dt(ht)}}}),useLayoutEffect$1(function(){if(B){var tt=ee.slice(Be,Ve+1);B(tt,ee)}},[Be,Ve,ee]);var Vt=useGetSize(ee,X,W,g),Nt=L==null?void 0:L({start:Be,end:Ve,virtual:V,offsetX:pe,offsetY:Pe,rtl:ne,getSize:Vt}),Kt=useChildren$1(ee,Be,Ve,I,pe,Z,w,Ee),Zt=null;m&&(Zt=_objectSpread2(_defineProperty({},b?"height":"maxHeight",m),ScrollStyle),te&&(Zt.overflowY="hidden",I&&(Zt.overflowX="hidden"),we&&(Zt.pointerEvents="none")));var Gt={};return ne&&(Gt.dir="rtl"),reactExports.createElement("div",_extends({ref:ue,style:_objectSpread2(_objectSpread2({},E),{},{position:"relative"}),className:le},Gt,K),reactExports.createElement(RefResizeObserver,{onResize:We},reactExports.createElement(A,{className:"".concat(d,"-holder"),style:Zt,ref:ie,onScroll:yt,onMouseEnter:Tt},reactExports.createElement(Filler,{prefixCls:d,height:Oe,offsetX:pe,offsetY:Pe,scrollWidth:I,onInnerResize:J,ref:ce,innerProps:j,rtl:ne,extra:Nt},Kt))),V&&Oe>m&&reactExports.createElement(ScrollBar,{ref:ut,prefixCls:d,scrollOffset:ge,scrollRange:Oe,rtl:ne,onScroll:Je,onStartMove:De,onStopMove:Ae,spinSize:Ut,containerSize:Ue.height,style:U==null?void 0:U.verticalScrollBar,thumbStyle:U==null?void 0:U.verticalScrollBarThumb,showScrollBar:F}),V&&I>Ue.width&&reactExports.createElement(ScrollBar,{ref:gt,prefixCls:d,scrollOffset:pe,scrollRange:I,rtl:ne,onScroll:Je,onStartMove:De,onStopMove:Ae,spinSize:kt,containerSize:Ue.width,horizontal:!0,style:U==null?void 0:U.horizontalScrollBar,thumbStyle:U==null?void 0:U.horizontalScrollBarThumb,showScrollBar:F}))}var List=reactExports.forwardRef(RawList);List.displayName="List";function isPlatformMac(){return/(mac\sos|macintosh)/i.test(navigator.appVersion)}var _excluded$y=["disabled","title","children","style","className"];function isTitleType(a){return typeof a=="string"||typeof a=="number"}var OptionList=function(c,u){var d=useBaseProps(),f=d.prefixCls,m=d.id,g=d.open,y=d.multiple,b=d.mode,E=d.searchValue,C=d.toggleOpen,w=d.notFoundContent,R=d.onPopupScroll,_=reactExports.useContext(SelectContext),M=_.maxCount,I=_.flattenOptions,N=_.onActiveValue,A=_.defaultActiveFirstOption,P=_.onSelect,z=_.menuItemSelectedIcon,B=_.rawValues,j=_.fieldNames,L=_.virtual,U=_.direction,q=_.listHeight,F=_.listItemHeight,K=_.optionRender,X="".concat(f,"-item"),Q=useMemo(function(){return I},[g,I],function(ve,fe){return fe[0]&&ve[1]!==fe[1]}),Y=reactExports.useRef(null),Z=reactExports.useMemo(function(){return y&&isValidCount(M)&&(B==null?void 0:B.size)>=M},[y,M,B==null?void 0:B.size]),J=function(fe){fe.preventDefault()},W=function(fe){var pe;(pe=Y.current)===null||pe===void 0||pe.scrollTo(typeof fe=="number"?{index:fe}:fe)},G=reactExports.useCallback(function(ve){return b==="combobox"?!1:B.has(ve)},[b,_toConsumableArray(B).toString(),B.size]),te=function(fe){for(var pe=arguments.length>1&&arguments[1]!==void 0?arguments[1]:1,xe=Q.length,ye=0;ye<xe;ye+=1){var he=(fe+ye*pe+xe)%xe,we=Q[he]||{},Re=we.group,De=we.data;if(!Re&&!(De!=null&&De.disabled)&&(G(De.value)||!Z))return he}return-1},ae=reactExports.useState(function(){return te(0)}),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=function(fe){var pe=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;le(fe);var xe={source:pe?"keyboard":"mouse"},ye=Q[fe];if(!ye){N(null,-1,xe);return}N(ye.value,fe,xe)};reactExports.useEffect(function(){ee(A!==!1?te(0):-1)},[Q.length,E]);var ie=reactExports.useCallback(function(ve){return b==="combobox"?String(ve).toLowerCase()===E.toLowerCase():B.has(ve)},[b,E,_toConsumableArray(B).toString(),B.size]);reactExports.useEffect(function(){var ve=setTimeout(function(){if(!y&&g&&B.size===1){var pe=Array.from(B)[0],xe=Q.findIndex(function(ye){var he=ye.data;return he.value===pe});xe!==-1&&(ee(xe),W(xe))}});if(g){var fe;(fe=Y.current)===null||fe===void 0||fe.scrollTo(void 0)}return function(){return clearTimeout(ve)}},[g,E]);var ce=function(fe){fe!==void 0&&P(fe,{selected:!B.has(fe)}),y||C(!1)};if(reactExports.useImperativeHandle(u,function(){return{onKeyDown:function(fe){var pe=fe.which,xe=fe.ctrlKey;switch(pe){case KeyCode.N:case KeyCode.P:case KeyCode.UP:case KeyCode.DOWN:{var ye=0;if(pe===KeyCode.UP?ye=-1:pe===KeyCode.DOWN?ye=1:isPlatformMac()&&xe&&(pe===KeyCode.N?ye=1:pe===KeyCode.P&&(ye=-1)),ye!==0){var he=te(ne+ye,ye);W(he),ee(he,!0)}break}case KeyCode.TAB:case KeyCode.ENTER:{var we,Re=Q[ne];Re&&!(Re!=null&&(we=Re.data)!==null&&we!==void 0&&we.disabled)&&!Z?ce(Re.value):ce(void 0),g&&fe.preventDefault();break}case KeyCode.ESC:C(!1),g&&fe.stopPropagation()}},onKeyUp:function(){},scrollTo:function(fe){W(fe)}}}),Q.length===0)return reactExports.createElement("div",{role:"listbox",id:"".concat(m,"_list"),className:"".concat(X,"-empty"),onMouseDown:J},w);var ue=Object.keys(j).map(function(ve){return j[ve]}),me=function(fe){return fe.label};function de(ve,fe){var pe=ve.group;return{role:pe?"presentation":"option",id:"".concat(m,"_list_").concat(fe)}}var ge=function(fe){var pe=Q[fe];if(!pe)return null;var xe=pe.data||{},ye=xe.value,he=pe.group,we=pickAttrs(xe,!0),Re=me(pe);return pe?reactExports.createElement("div",_extends({"aria-label":typeof Re=="string"&&!he?Re:null},we,{key:fe},de(pe,fe),{"aria-selected":ie(ye)}),ye):null},Ce={role:"listbox",id:"".concat(m,"_list")};return reactExports.createElement(reactExports.Fragment,null,L&&reactExports.createElement("div",_extends({},Ce,{style:{height:0,width:0,overflow:"hidden"}}),ge(ne-1),ge(ne),ge(ne+1)),reactExports.createElement(List,{itemKey:"key",ref:Y,data:Q,height:q,itemHeight:F,fullHeight:!1,onMouseDown:J,onScroll:R,virtual:L,direction:U,innerProps:L?null:Ce},function(ve,fe){var pe=ve.group,xe=ve.groupOption,ye=ve.data,he=ve.label,we=ve.value,Re=ye.key;if(pe){var De,Ae=(De=ye.title)!==null&&De!==void 0?De:isTitleType(he)?he.toString():void 0;return reactExports.createElement("div",{className:classNames(X,"".concat(X,"-group"),ye.className),title:Ae},he!==void 0?he:Re)}var Ee=ye.disabled,Ne=ye.title;ye.children;var _e=ye.style,ke=ye.className,Ke=_objectWithoutProperties(ye,_excluded$y),be=omit(Ke,ue),Te=G(we),Le=Ee||!Te&&Z,Oe="".concat(X,"-option"),Be=classNames(X,Oe,ke,_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(Oe,"-grouped"),xe),"".concat(Oe,"-active"),ne===fe&&!Le),"".concat(Oe,"-disabled"),Le),"".concat(Oe,"-selected"),Te)),Ve=me(ve),Pe=!z||typeof z=="function"||Te,Ge=typeof Ve=="number"?Ve:Ve||we,qe=isTitleType(Ge)?Ge.toString():void 0;return Ne!==void 0&&(qe=Ne),reactExports.createElement("div",_extends({},pickAttrs(be),L?{}:de(ve,fe),{"aria-selected":ie(we),className:Be,title:qe,onMouseMove:function(){ne===fe||Le||ee(fe)},onClick:function(){Le||ce(we)},style:_e}),reactExports.createElement("div",{className:"".concat(Oe,"-content")},typeof K=="function"?K(ve,{index:fe}):Ge),reactExports.isValidElement(z)||Te,Pe&&reactExports.createElement(TransBtn,{className:"".concat(X,"-option-state"),customizeIcon:z,customizeIconProps:{value:we,disabled:Le,isSelected:Te}},Te?"✓":null))}))},RefOptionList=reactExports.forwardRef(OptionList);const useCache=function(a,c){var u=reactExports.useRef({values:new Map,options:new Map}),d=reactExports.useMemo(function(){var m=u.current,g=m.values,y=m.options,b=a.map(function(w){if(w.label===void 0){var R;return _objectSpread2(_objectSpread2({},w),{},{label:(R=g.get(w.value))===null||R===void 0?void 0:R.label})}return w}),E=new Map,C=new Map;return b.forEach(function(w){E.set(w.value,w),C.set(w.value,c.get(w.value)||y.get(w.value))}),u.current.values=E,u.current.options=C,b},[a,c]),f=reactExports.useCallback(function(m){return c.get(m)||u.current.options.get(m)},[c]);return[d,f]};function includes(a,c){return toArray$4(a).join("").toUpperCase().includes(c)}const useFilterOptions=function(a,c,u,d,f){return reactExports.useMemo(function(){if(!u||d===!1)return a;var m=c.options,g=c.label,y=c.value,b=[],E=typeof d=="function",C=u.toUpperCase(),w=E?d:function(_,M){return f?includes(M[f],C):M[m]?includes(M[g!=="children"?g:"label"],C):includes(M[y],C)},R=E?function(_){return injectPropsWithOption(_)}:function(_){return _};return a.forEach(function(_){if(_[m]){var M=w(u,R(_));if(M)b.push(_);else{var I=_[m].filter(function(N){return w(u,R(N))});I.length&&b.push(_objectSpread2(_objectSpread2({},_),{},_defineProperty({},m,I)))}return}w(u,R(_))&&b.push(_)}),b},[a,d,f,u,c])};var uuid$1=0,isBrowserClient=canUseDom();function getUUID(){var a;return isBrowserClient?(a=uuid$1,uuid$1+=1):a="TEST_OR_SSR",a}function useId(a){var c=reactExports.useState(),u=_slicedToArray(c,2),d=u[0],f=u[1];return reactExports.useEffect(function(){f("rc_select_".concat(getUUID()))},[]),a||d}var _excluded$x=["children","value"],_excluded2$8=["children"];function convertNodeToOption(a){var c=a,u=c.key,d=c.props,f=d.children,m=d.value,g=_objectWithoutProperties(d,_excluded$x);return _objectSpread2({key:u,value:m!==void 0?m:u,children:f},g)}function convertChildrenToData(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;return toArray$6(a).map(function(u,d){if(!reactExports.isValidElement(u)||!u.type)return null;var f=u,m=f.type.isSelectOptGroup,g=f.key,y=f.props,b=y.children,E=_objectWithoutProperties(y,_excluded2$8);return c||!m?convertNodeToOption(u):_objectSpread2(_objectSpread2({key:"__RC_SELECT_GRP__".concat(g===null?d:g,"__"),label:g},E),{},{options:convertChildrenToData(b)})}).filter(function(u){return u})}var useOptions=function(c,u,d,f,m){return reactExports.useMemo(function(){var g=c,y=!c;y&&(g=convertChildrenToData(u));var b=new Map,E=new Map,C=function(_,M,I){I&&typeof I=="string"&&_.set(M[I],M)},w=function R(_){for(var M=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,I=0;I<_.length;I+=1){var N=_[I];!N[d.options]||M?(b.set(N[d.value],N),C(E,N,d.label),C(E,N,f),C(E,N,m)):R(N[d.options],!0)}};return w(g),{options:g,valueOptions:b,labelOptions:E}},[c,u,d,f,m])};function useRefFunc(a){var c=reactExports.useRef();c.current=a;var u=reactExports.useCallback(function(){return c.current.apply(c,arguments)},[]);return u}var _excluded$w=["id","mode","prefixCls","backfill","fieldNames","inputValue","searchValue","onSearch","autoClearSearchValue","onSelect","onDeselect","dropdownMatchSelectWidth","filterOption","filterSort","optionFilterProp","optionLabelProp","options","optionRender","children","defaultActiveFirstOption","menuItemSelectedIcon","virtual","direction","listHeight","listItemHeight","labelRender","value","defaultValue","labelInValue","onChange","maxCount"],OMIT_DOM_PROPS=["inputValue"];function isRawValue(a){return!a||_typeof(a)!=="object"}var Select$1=reactExports.forwardRef(function(a,c){var u=a.id,d=a.mode,f=a.prefixCls,m=f===void 0?"rc-select":f,g=a.backfill,y=a.fieldNames,b=a.inputValue,E=a.searchValue,C=a.onSearch,w=a.autoClearSearchValue,R=w===void 0?!0:w,_=a.onSelect,M=a.onDeselect,I=a.dropdownMatchSelectWidth,N=I===void 0?!0:I,A=a.filterOption,P=a.filterSort,z=a.optionFilterProp,B=a.optionLabelProp,j=a.options,L=a.optionRender,U=a.children,q=a.defaultActiveFirstOption,F=a.menuItemSelectedIcon,K=a.virtual,X=a.direction,Q=a.listHeight,Y=Q===void 0?200:Q,Z=a.listItemHeight,J=Z===void 0?20:Z,W=a.labelRender,G=a.value,te=a.defaultValue,ae=a.labelInValue,V=a.onChange,ne=a.maxCount,le=_objectWithoutProperties(a,_excluded$w),ee=useId(u),ie=isMultiple(d),ce=!!(!j&&U),ue=reactExports.useMemo(function(){return A===void 0&&d==="combobox"?!1:A},[A,d]),me=reactExports.useMemo(function(){return fillFieldNames$1(y,ce)},[JSON.stringify(y),ce]),de=useMergedState("",{value:E!==void 0?E:b,postState:function(Je){return Je||""}}),ge=_slicedToArray(de,2),Ce=ge[0],ve=ge[1],fe=useOptions(j,U,me,z,B),pe=fe.valueOptions,xe=fe.labelOptions,ye=fe.options,he=reactExports.useCallback(function(Ze){var Je=toArray$4(Ze);return Je.map(function(yt){var Ct,pt,Rt,ft,dt;if(isRawValue(yt))Ct=yt;else{var xt;Rt=yt.key,pt=yt.label,Ct=(xt=yt.value)!==null&&xt!==void 0?xt:Rt}var Tt=pe.get(Ct);if(Tt){var Dt;pt===void 0&&(pt=Tt==null?void 0:Tt[B||me.label]),Rt===void 0&&(Rt=(Dt=Tt==null?void 0:Tt.key)!==null&&Dt!==void 0?Dt:Ct),ft=Tt==null?void 0:Tt.disabled,dt=Tt==null?void 0:Tt.title}return{label:pt,value:Ct,key:Rt,disabled:ft,title:dt}})},[me,B,pe]),we=useMergedState(te,{value:G}),Re=_slicedToArray(we,2),De=Re[0],Ae=Re[1],Ee=reactExports.useMemo(function(){var Ze,Je=ie&&De===null?[]:De,yt=he(Je);return d==="combobox"&&isComboNoValue((Ze=yt[0])===null||Ze===void 0?void 0:Ze.value)?[]:yt},[De,he,d,ie]),Ne=useCache(Ee,pe),_e=_slicedToArray(Ne,2),ke=_e[0],Ke=_e[1],be=reactExports.useMemo(function(){if(!d&&ke.length===1){var Ze=ke[0];if(Ze.value===null&&(Ze.label===null||Ze.label===void 0))return[]}return ke.map(function(Je){var yt;return _objectSpread2(_objectSpread2({},Je),{},{label:(yt=typeof W=="function"?W(Je):Je.label)!==null&&yt!==void 0?yt:Je.value})})},[d,ke,W]),Te=reactExports.useMemo(function(){return new Set(ke.map(function(Ze){return Ze.value}))},[ke]);reactExports.useEffect(function(){if(d==="combobox"){var Ze,Je=(Ze=ke[0])===null||Ze===void 0?void 0:Ze.value;ve(hasValue(Je)?String(Je):"")}},[ke]);var Le=useRefFunc(function(Ze,Je){var yt=Je??Ze;return _defineProperty(_defineProperty({},me.value,Ze),me.label,yt)}),Oe=reactExports.useMemo(function(){if(d!=="tags")return ye;var Ze=_toConsumableArray(ye),Je=function(Ct){return pe.has(Ct)};return _toConsumableArray(ke).sort(function(yt,Ct){return yt.value<Ct.value?-1:1}).forEach(function(yt){var Ct=yt.value;Je(Ct)||Ze.push(Le(Ct,yt.label))}),Ze},[Le,ye,pe,ke,d]),Be=useFilterOptions(Oe,me,Ce,ue,z),Ve=reactExports.useMemo(function(){return d!=="tags"||!Ce||Be.some(function(Ze){return Ze[z||"value"]===Ce})||Be.some(function(Ze){return Ze[me.value]===Ce})?Be:[Le(Ce)].concat(_toConsumableArray(Be))},[Le,z,d,Be,Ce,me]),Pe=function Ze(Je){var yt=_toConsumableArray(Je).sort(function(Ct,pt){return P(Ct,pt,{searchValue:Ce})});return yt.map(function(Ct){return Array.isArray(Ct.options)?_objectSpread2(_objectSpread2({},Ct),{},{options:Ct.options.length>0?Ze(Ct.options):Ct.options}):Ct})},Ge=reactExports.useMemo(function(){return P?Pe(Ve):Ve},[Ve,P,Ce]),qe=reactExports.useMemo(function(){return flattenOptions(Ge,{fieldNames:me,childrenAsData:ce})},[Ge,me,ce]),Ue=function(Je){var yt=he(Je);if(Ae(yt),V&&(yt.length!==ke.length||yt.some(function(Rt,ft){var dt;return((dt=ke[ft])===null||dt===void 0?void 0:dt.value)!==(Rt==null?void 0:Rt.value)}))){var Ct=ae?yt:yt.map(function(Rt){return Rt.value}),pt=yt.map(function(Rt){return injectPropsWithOption(Ke(Rt.value))});V(ie?Ct:Ct[0],ie?pt:pt[0])}},je=reactExports.useState(null),We=_slicedToArray(je,2),ut=We[0],gt=We[1],kt=reactExports.useState(0),Ut=_slicedToArray(kt,2),at=Ut[0],ct=Ut[1],bt=q!==void 0?q:d!=="combobox",it=reactExports.useCallback(function(Ze,Je){var yt=arguments.length>2&&arguments[2]!==void 0?arguments[2]:{},Ct=yt.source,pt=Ct===void 0?"keyboard":Ct;ct(Je),g&&d==="combobox"&&Ze!==null&&pt==="keyboard"&&gt(String(Ze))},[g,d]),vt=function(Je,yt,Ct){var pt=function(){var Zt,Gt=Ke(Je);return[ae?{label:Gt==null?void 0:Gt[me.label],value:Je,key:(Zt=Gt==null?void 0:Gt.key)!==null&&Zt!==void 0?Zt:Je}:Je,injectPropsWithOption(Gt)]};if(yt&&_){var Rt=pt(),ft=_slicedToArray(Rt,2),dt=ft[0],xt=ft[1];_(dt,xt)}else if(!yt&&M&&Ct!=="clear"){var Tt=pt(),Dt=_slicedToArray(Tt,2),Vt=Dt[0],Nt=Dt[1];M(Vt,Nt)}},ot=useRefFunc(function(Ze,Je){var yt,Ct=ie?Je.selected:!0;Ct?yt=ie?[].concat(_toConsumableArray(ke),[Ze]):[Ze]:yt=ke.filter(function(pt){return pt.value!==Ze}),Ue(yt),vt(Ze,Ct),d==="combobox"?gt(""):(!isMultiple||R)&&(ve(""),gt(""))}),rt=function(Je,yt){Ue(Je);var Ct=yt.type,pt=yt.values;(Ct==="remove"||Ct==="clear")&&pt.forEach(function(Rt){vt(Rt.value,!1,Ct)})},et=function(Je,yt){if(ve(Je),gt(null),yt.source==="submit"){var Ct=(Je||"").trim();if(Ct){var pt=Array.from(new Set([].concat(_toConsumableArray(Te),[Ct])));Ue(pt),vt(Ct,!0),ve("")}return}yt.source!=="blur"&&(d==="combobox"&&Ue(Je),C==null||C(Je))},$t=function(Je){var yt=Je;d!=="tags"&&(yt=Je.map(function(pt){var Rt=xe.get(pt);return Rt==null?void 0:Rt.value}).filter(function(pt){return pt!==void 0}));var Ct=Array.from(new Set([].concat(_toConsumableArray(Te),_toConsumableArray(yt))));Ue(Ct),Ct.forEach(function(pt){vt(pt,!0)})},mt=reactExports.useMemo(function(){var Ze=K!==!1&&N!==!1;return _objectSpread2(_objectSpread2({},fe),{},{flattenOptions:qe,onActiveValue:it,defaultActiveFirstOption:bt,onSelect:ot,menuItemSelectedIcon:F,rawValues:Te,fieldNames:me,virtual:Ze,direction:X,listHeight:Y,listItemHeight:J,childrenAsData:ce,maxCount:ne,optionRender:L})},[ne,fe,qe,it,bt,ot,F,Te,me,K,N,X,Y,J,ce,L]);return reactExports.createElement(SelectContext.Provider,{value:mt},reactExports.createElement(BaseSelect$1,_extends({},le,{id:ee,prefixCls:m,ref:c,omitDomProps:OMIT_DOM_PROPS,mode:d,displayValues:be,onDisplayValuesChange:rt,direction:X,searchValue:Ce,onSearch:et,autoClearSearchValue:R,onSearchSplit:$t,dropdownMatchSelectWidth:N,OptionList:RefOptionList,emptyOptions:!qe.length,activeValue:ut,activeDescendantId:"".concat(ee,"_list_").concat(at)})))}),TypedSelect=Select$1;TypedSelect.Option=Option;TypedSelect.OptGroup=OptGroup;function getStatusClassNames(a,c,u){return classNames({[`${a}-status-success`]:c==="success",[`${a}-status-warning`]:c==="warning",[`${a}-status-error`]:c==="error",[`${a}-status-validating`]:c==="validating",[`${a}-has-feedback`]:u})}const getMergedStatus=(a,c)=>c||a,Empty$1=()=>{const[,a]=useToken$1(),[c]=useLocale("Empty"),d=new FastColor(a.colorBgBase).toHsl().l<.5?{opacity:.65}:{};return reactExports.createElement("svg",{style:d,width:"184",height:"152",viewBox:"0 0 184 152",xmlns:"http://www.w3.org/2000/svg"},reactExports.createElement("title",null,(c==null?void 0:c.description)||"Empty"),reactExports.createElement("g",{fill:"none",fillRule:"evenodd"},reactExports.createElement("g",{transform:"translate(24 31.67)"},reactExports.createElement("ellipse",{fillOpacity:".8",fill:"#F5F5F7",cx:"67.797",cy:"106.89",rx:"67.797",ry:"12.668"}),reactExports.createElement("path",{d:"M122.034 69.674L98.109 40.229c-1.148-1.386-2.826-2.225-4.593-2.225h-51.44c-1.766 0-3.444.839-4.592 2.225L13.56 69.674v15.383h108.475V69.674z",fill:"#AEB8C2"}),reactExports.createElement("path",{d:"M101.537 86.214L80.63 61.102c-1.001-1.207-2.507-1.867-4.048-1.867H31.724c-1.54 0-3.047.66-4.048 1.867L6.769 86.214v13.792h94.768V86.214z",fill:"url(#linearGradient-1)",transform:"translate(13.56)"}),reactExports.createElement("path",{d:"M33.83 0h67.933a4 4 0 0 1 4 4v93.344a4 4 0 0 1-4 4H33.83a4 4 0 0 1-4-4V4a4 4 0 0 1 4-4z",fill:"#F5F5F7"}),reactExports.createElement("path",{d:"M42.678 9.953h50.237a2 2 0 0 1 2 2V36.91a2 2 0 0 1-2 2H42.678a2 2 0 0 1-2-2V11.953a2 2 0 0 1 2-2zM42.94 49.767h49.713a2.262 2.262 0 1 1 0 4.524H42.94a2.262 2.262 0 0 1 0-4.524zM42.94 61.53h49.713a2.262 2.262 0 1 1 0 4.525H42.94a2.262 2.262 0 0 1 0-4.525zM121.813 105.032c-.775 3.071-3.497 5.36-6.735 5.36H20.515c-3.238 0-5.96-2.29-6.734-5.36a7.309 7.309 0 0 1-.222-1.79V69.675h26.318c2.907 0 5.25 2.448 5.25 5.42v.04c0 2.971 2.37 5.37 5.277 5.37h34.785c2.907 0 5.277-2.421 5.277-5.393V75.1c0-2.972 2.343-5.426 5.25-5.426h26.318v33.569c0 .617-.077 1.216-.221 1.789z",fill:"#DCE0E6"})),reactExports.createElement("path",{d:"M149.121 33.292l-6.83 2.65a1 1 0 0 1-1.317-1.23l1.937-6.207c-2.589-2.944-4.109-6.534-4.109-10.408C138.802 8.102 148.92 0 161.402 0 173.881 0 184 8.102 184 18.097c0 9.995-10.118 18.097-22.599 18.097-4.528 0-8.744-1.066-12.28-2.902z",fill:"#DCE0E6"}),reactExports.createElement("g",{transform:"translate(149.65 15.383)",fill:"#FFF"},reactExports.createElement("ellipse",{cx:"20.654",cy:"3.167",rx:"2.849",ry:"2.815"}),reactExports.createElement("path",{d:"M5.698 5.63H0L2.898.704zM9.259.704h4.985V5.63H9.259z"}))))},Simple=()=>{const[,a]=useToken$1(),[c]=useLocale("Empty"),{colorFill:u,colorFillTertiary:d,colorFillQuaternary:f,colorBgContainer:m}=a,{borderColor:g,shadowColor:y,contentColor:b}=reactExports.useMemo(()=>({borderColor:new FastColor(u).onBackground(m).toHexString(),shadowColor:new FastColor(d).onBackground(m).toHexString(),contentColor:new FastColor(f).onBackground(m).toHexString()}),[u,d,f,m]);return reactExports.createElement("svg",{width:"64",height:"41",viewBox:"0 0 64 41",xmlns:"http://www.w3.org/2000/svg"},reactExports.createElement("title",null,(c==null?void 0:c.description)||"Empty"),reactExports.createElement("g",{transform:"translate(0 1)",fill:"none",fillRule:"evenodd"},reactExports.createElement("ellipse",{fill:y,cx:"32",cy:"33",rx:"32",ry:"7"}),reactExports.createElement("g",{fillRule:"nonzero",stroke:g},reactExports.createElement("path",{d:"M55 12.76L44.854 1.258C44.367.474 43.656 0 42.907 0H21.093c-.749 0-1.46.474-1.947 1.257L9 12.761V22h46v-9.24z"}),reactExports.createElement("path",{d:"M41.613 15.931c0-1.605.994-2.93 2.227-2.931H55v18.137C55 33.26 53.68 35 52.05 35h-40.1C10.32 35 9 33.259 9 31.137V13h11.16c1.233 0 2.227 1.323 2.227 2.928v.022c0 1.605 1.005 2.901 2.237 2.901h14.752c1.232 0 2.237-1.308 2.237-2.913v-.007z",fill:b}))))},genSharedEmptyStyle=a=>{const{componentCls:c,margin:u,marginXS:d,marginXL:f,fontSize:m,lineHeight:g}=a;return{[c]:{marginInline:d,fontSize:m,lineHeight:g,textAlign:"center",[`${c}-image`]:{height:a.emptyImgHeight,marginBottom:d,opacity:a.opacityImage,img:{height:"100%"},svg:{maxWidth:"100%",height:"100%",margin:"auto"}},[`${c}-description`]:{color:a.colorTextDescription},[`${c}-footer`]:{marginTop:u},"&-normal":{marginBlock:f,color:a.colorTextDescription,[`${c}-description`]:{color:a.colorTextDescription},[`${c}-image`]:{height:a.emptyImgHeightMD}},"&-small":{marginBlock:d,color:a.colorTextDescription,[`${c}-image`]:{height:a.emptyImgHeightSM}}}}},useStyle$o=genStyleHooks("Empty",a=>{const{componentCls:c,controlHeightLG:u,calc:d}=a,f=merge$2(a,{emptyImgCls:`${c}-img`,emptyImgHeight:d(u).mul(2.5).equal(),emptyImgHeightMD:u,emptyImgHeightSM:d(u).mul(.875).equal()});return[genSharedEmptyStyle(f)]});var __rest$P=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const defaultEmptyImg=reactExports.createElement(Empty$1,null),simpleEmptyImg=reactExports.createElement(Simple,null),Empty=a=>{const{className:c,rootClassName:u,prefixCls:d,image:f=defaultEmptyImg,description:m,children:g,imageStyle:y,style:b,classNames:E,styles:C}=a,w=__rest$P(a,["className","rootClassName","prefixCls","image","description","children","imageStyle","style","classNames","styles"]),{getPrefixCls:R,direction:_,className:M,style:I,classNames:N,styles:A}=useComponentConfig("empty"),P=R("empty",d),[z,B,j]=useStyle$o(P),[L]=useLocale("Empty"),U=typeof m<"u"?m:L==null?void 0:L.description,q=typeof U=="string"?U:"empty";let F=null;return typeof f=="string"?F=reactExports.createElement("img",{alt:q,src:f}):F=f,z(reactExports.createElement("div",Object.assign({className:classNames(B,j,P,M,{[`${P}-normal`]:f===simpleEmptyImg,[`${P}-rtl`]:_==="rtl"},c,u,N.root,E==null?void 0:E.root),style:Object.assign(Object.assign(Object.assign(Object.assign({},A.root),I),C==null?void 0:C.root),b)},w),reactExports.createElement("div",{className:classNames(`${P}-image`,N.image,E==null?void 0:E.image),style:Object.assign(Object.assign(Object.assign({},y),A.image),C==null?void 0:C.image)},F),U&&reactExports.createElement("div",{className:classNames(`${P}-description`,N.description,E==null?void 0:E.description),style:Object.assign(Object.assign({},A.description),C==null?void 0:C.description)},U),g&&reactExports.createElement("div",{className:classNames(`${P}-footer`,N.footer,E==null?void 0:E.footer),style:Object.assign(Object.assign({},A.footer),C==null?void 0:C.footer)},g)))};Empty.PRESENTED_IMAGE_DEFAULT=defaultEmptyImg;Empty.PRESENTED_IMAGE_SIMPLE=simpleEmptyImg;const DefaultRenderEmpty=a=>{const{componentName:c}=a,{getPrefixCls:u}=reactExports.useContext(ConfigContext),d=u("empty");switch(c){case"Table":case"List":return React.createElement(Empty,{image:Empty.PRESENTED_IMAGE_SIMPLE});case"Select":case"TreeSelect":case"Cascader":case"Transfer":case"Mentions":return React.createElement(Empty,{image:Empty.PRESENTED_IMAGE_SIMPLE,className:`${d}-small`});case"Table.filter":return null;default:return React.createElement(Empty,null)}},useVariant=function(a,c){let u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:void 0;var d,f;const{variant:m,[a]:g}=reactExports.useContext(ConfigContext),y=reactExports.useContext(VariantContext),b=g==null?void 0:g.variant;let E;typeof c<"u"?E=c:u===!1?E="borderless":E=(f=(d=y??b)!==null&&d!==void 0?d:m)!==null&&f!==void 0?f:"outlined";const C=Variants.includes(E);return[E,C]},getBuiltInPlacements=a=>{const u={overflow:{adjustX:!0,adjustY:!0,shiftY:!0},htmlRegion:a==="scroll"?"scroll":"visible",dynamicInset:!0};return{bottomLeft:Object.assign(Object.assign({},u),{points:["tl","bl"],offset:[0,4]}),bottomRight:Object.assign(Object.assign({},u),{points:["tr","br"],offset:[0,4]}),topLeft:Object.assign(Object.assign({},u),{points:["bl","tl"],offset:[0,-4]}),topRight:Object.assign(Object.assign({},u),{points:["br","tr"],offset:[0,-4]})}};function mergedBuiltinPlacements(a,c){return a||getBuiltInPlacements(c)}const genItemStyle=a=>{const{optionHeight:c,optionFontSize:u,optionLineHeight:d,optionPadding:f}=a;return{position:"relative",display:"block",minHeight:c,padding:f,color:a.colorText,fontWeight:"normal",fontSize:u,lineHeight:d,boxSizing:"border-box"}},genSingleStyle$1=a=>{const{antCls:c,componentCls:u}=a,d=`${u}-item`,f=`&${c}-slide-up-enter${c}-slide-up-enter-active`,m=`&${c}-slide-up-appear${c}-slide-up-appear-active`,g=`&${c}-slide-up-leave${c}-slide-up-leave-active`,y=`${u}-dropdown-placement-`,b=`${d}-option-selected`;return[{[`${u}-dropdown`]:Object.assign(Object.assign({},resetComponent(a)),{position:"absolute",top:-9999,zIndex:a.zIndexPopup,boxSizing:"border-box",padding:a.paddingXXS,overflow:"hidden",fontSize:a.fontSize,fontVariant:"initial",backgroundColor:a.colorBgElevated,borderRadius:a.borderRadiusLG,outline:"none",boxShadow:a.boxShadowSecondary,[`
          ${f}${y}bottomLeft,
          ${m}${y}bottomLeft
        `]:{animationName:slideUpIn},[`
          ${f}${y}topLeft,
          ${m}${y}topLeft,
          ${f}${y}topRight,
          ${m}${y}topRight
        `]:{animationName:slideDownIn},[`${g}${y}bottomLeft`]:{animationName:slideUpOut},[`
          ${g}${y}topLeft,
          ${g}${y}topRight
        `]:{animationName:slideDownOut},"&-hidden":{display:"none"},[d]:Object.assign(Object.assign({},genItemStyle(a)),{cursor:"pointer",transition:`background ${a.motionDurationSlow} ease`,borderRadius:a.borderRadiusSM,"&-group":{color:a.colorTextDescription,fontSize:a.fontSizeSM,cursor:"default"},"&-option":{display:"flex","&-content":Object.assign({flex:"auto"},textEllipsis),"&-state":{flex:"none",display:"flex",alignItems:"center"},[`&-active:not(${d}-option-disabled)`]:{backgroundColor:a.optionActiveBg},[`&-selected:not(${d}-option-disabled)`]:{color:a.optionSelectedColor,fontWeight:a.optionSelectedFontWeight,backgroundColor:a.optionSelectedBg,[`${d}-option-state`]:{color:a.colorPrimary}},"&-disabled":{[`&${d}-option-selected`]:{backgroundColor:a.colorBgContainerDisabled},color:a.colorTextDisabled,cursor:"not-allowed"},"&-grouped":{paddingInlineStart:a.calc(a.controlPaddingHorizontal).mul(2).equal()}},"&-empty":Object.assign(Object.assign({},genItemStyle(a)),{color:a.colorTextDisabled})}),[`${b}:has(+ ${b})`]:{borderEndStartRadius:0,borderEndEndRadius:0,[`& + ${b}`]:{borderStartStartRadius:0,borderStartEndRadius:0}},"&-rtl":{direction:"rtl"}})},initSlideMotion(a,"slide-up"),initSlideMotion(a,"slide-down"),initMoveMotion(a,"move-up"),initMoveMotion(a,"move-down")]},getMultipleSelectorUnit=a=>{const{multipleSelectItemHeight:c,paddingXXS:u,lineWidth:d,INTERNAL_FIXED_ITEM_MARGIN:f}=a,m=a.max(a.calc(u).sub(d).equal(),0),g=a.max(a.calc(m).sub(f).equal(),0);return{basePadding:m,containerPadding:g,itemHeight:unit$1(c),itemLineHeight:unit$1(a.calc(c).sub(a.calc(a.lineWidth).mul(2)).equal())}},getSelectItemStyle=a=>{const{multipleSelectItemHeight:c,selectHeight:u,lineWidth:d}=a;return a.calc(u).sub(c).div(2).sub(d).equal()},genOverflowStyle=a=>{const{componentCls:c,iconCls:u,borderRadiusSM:d,motionDurationSlow:f,paddingXS:m,multipleItemColorDisabled:g,multipleItemBorderColorDisabled:y,colorIcon:b,colorIconHover:E,INTERNAL_FIXED_ITEM_MARGIN:C}=a;return{[`${c}-selection-overflow`]:{position:"relative",display:"flex",flex:"auto",flexWrap:"wrap",maxWidth:"100%","&-item":{flex:"none",alignSelf:"center",maxWidth:"100%",display:"inline-flex"},[`${c}-selection-item`]:{display:"flex",alignSelf:"center",flex:"none",boxSizing:"border-box",maxWidth:"100%",marginBlock:C,borderRadius:d,cursor:"default",transition:`font-size ${f}, line-height ${f}, height ${f}`,marginInlineEnd:a.calc(C).mul(2).equal(),paddingInlineStart:m,paddingInlineEnd:a.calc(m).div(2).equal(),[`${c}-disabled&`]:{color:g,borderColor:y,cursor:"not-allowed"},"&-content":{display:"inline-block",marginInlineEnd:a.calc(m).div(2).equal(),overflow:"hidden",whiteSpace:"pre",textOverflow:"ellipsis"},"&-remove":Object.assign(Object.assign({},resetIcon()),{display:"inline-flex",alignItems:"center",color:b,fontWeight:"bold",fontSize:10,lineHeight:"inherit",cursor:"pointer",[`> ${u}`]:{verticalAlign:"-0.2em"},"&:hover":{color:E}})}}}},genSelectionStyle$1=(a,c)=>{const{componentCls:u,INTERNAL_FIXED_ITEM_MARGIN:d}=a,f=`${u}-selection-overflow`,m=a.multipleSelectItemHeight,g=getSelectItemStyle(a),y=c?`${u}-${c}`:"",b=getMultipleSelectorUnit(a);return{[`${u}-multiple${y}`]:Object.assign(Object.assign({},genOverflowStyle(a)),{[`${u}-selector`]:{display:"flex",alignItems:"center",width:"100%",height:"100%",paddingInline:b.basePadding,paddingBlock:b.containerPadding,borderRadius:a.borderRadius,[`${u}-disabled&`]:{background:a.multipleSelectorBgDisabled,cursor:"not-allowed"},"&:after":{display:"inline-block",width:0,margin:`${unit$1(d)} 0`,lineHeight:unit$1(m),visibility:"hidden",content:'"\\a0"'}},[`${u}-selection-item`]:{height:b.itemHeight,lineHeight:unit$1(b.itemLineHeight)},[`${u}-selection-wrap`]:{alignSelf:"flex-start","&:after":{lineHeight:unit$1(m),marginBlock:d}},[`${u}-prefix`]:{marginInlineStart:a.calc(a.inputPaddingHorizontalBase).sub(b.basePadding).equal()},[`${f}-item + ${f}-item,
        ${u}-prefix + ${u}-selection-wrap
      `]:{[`${u}-selection-search`]:{marginInlineStart:0},[`${u}-selection-placeholder`]:{insetInlineStart:0}},[`${f}-item-suffix`]:{minHeight:b.itemHeight,marginBlock:d},[`${u}-selection-search`]:{display:"inline-flex",position:"relative",maxWidth:"100%",marginInlineStart:a.calc(a.inputPaddingHorizontalBase).sub(g).equal(),"\n          &-input,\n          &-mirror\n        ":{height:m,fontFamily:a.fontFamily,lineHeight:unit$1(m),transition:`all ${a.motionDurationSlow}`},"&-input":{width:"100%",minWidth:4.1},"&-mirror":{position:"absolute",top:0,insetInlineStart:0,insetInlineEnd:"auto",zIndex:999,whiteSpace:"pre",visibility:"hidden"}},[`${u}-selection-placeholder`]:{position:"absolute",top:"50%",insetInlineStart:a.calc(a.inputPaddingHorizontalBase).sub(b.basePadding).equal(),insetInlineEnd:a.inputPaddingHorizontalBase,transform:"translateY(-50%)",transition:`all ${a.motionDurationSlow}`}})}};function genSizeStyle$3(a,c){const{componentCls:u}=a,d=c?`${u}-${c}`:"",f={[`${u}-multiple${d}`]:{fontSize:a.fontSize,[`${u}-selector`]:{[`${u}-show-search&`]:{cursor:"text"}},[`
        &${u}-show-arrow ${u}-selector,
        &${u}-allow-clear ${u}-selector
      `]:{paddingInlineEnd:a.calc(a.fontSizeIcon).add(a.controlPaddingHorizontal).equal()}}};return[genSelectionStyle$1(a,c),f]}const genMultipleStyle=a=>{const{componentCls:c}=a,u=merge$2(a,{selectHeight:a.controlHeightSM,multipleSelectItemHeight:a.multipleItemHeightSM,borderRadius:a.borderRadiusSM,borderRadiusSM:a.borderRadiusXS}),d=merge$2(a,{fontSize:a.fontSizeLG,selectHeight:a.controlHeightLG,multipleSelectItemHeight:a.multipleItemHeightLG,borderRadius:a.borderRadiusLG,borderRadiusSM:a.borderRadius});return[genSizeStyle$3(a),genSizeStyle$3(u,"sm"),{[`${c}-multiple${c}-sm`]:{[`${c}-selection-placeholder`]:{insetInline:a.calc(a.controlPaddingHorizontalSM).sub(a.lineWidth).equal()},[`${c}-selection-search`]:{marginInlineStart:2}}},genSizeStyle$3(d,"lg")]};function genSizeStyle$2(a,c){const{componentCls:u,inputPaddingHorizontalBase:d,borderRadius:f}=a,m=a.calc(a.controlHeight).sub(a.calc(a.lineWidth).mul(2)).equal(),g=c?`${u}-${c}`:"";return{[`${u}-single${g}`]:{fontSize:a.fontSize,height:a.controlHeight,[`${u}-selector`]:Object.assign(Object.assign({},resetComponent(a,!0)),{display:"flex",borderRadius:f,flex:"1 1 auto",[`${u}-selection-wrap:after`]:{lineHeight:unit$1(m)},[`${u}-selection-search`]:{position:"absolute",inset:0,width:"100%","&-input":{width:"100%",WebkitAppearance:"textfield"}},[`
          ${u}-selection-item,
          ${u}-selection-placeholder
        `]:{display:"block",padding:0,lineHeight:unit$1(m),transition:`all ${a.motionDurationSlow}, visibility 0s`,alignSelf:"center"},[`${u}-selection-placeholder`]:{transition:"none",pointerEvents:"none"},[["&:after",`${u}-selection-item:empty:after`,`${u}-selection-placeholder:empty:after`].join(",")]:{display:"inline-block",width:0,visibility:"hidden",content:'"\\a0"'}}),[`
        &${u}-show-arrow ${u}-selection-item,
        &${u}-show-arrow ${u}-selection-search,
        &${u}-show-arrow ${u}-selection-placeholder
      `]:{paddingInlineEnd:a.showArrowPaddingInlineEnd},[`&${u}-open ${u}-selection-item`]:{color:a.colorTextPlaceholder},[`&:not(${u}-customize-input)`]:{[`${u}-selector`]:{width:"100%",height:"100%",alignItems:"center",padding:`0 ${unit$1(d)}`,[`${u}-selection-search-input`]:{height:m,fontSize:a.fontSize},"&:after":{lineHeight:unit$1(m)}}},[`&${u}-customize-input`]:{[`${u}-selector`]:{"&:after":{display:"none"},[`${u}-selection-search`]:{position:"static",width:"100%"},[`${u}-selection-placeholder`]:{position:"absolute",insetInlineStart:0,insetInlineEnd:0,padding:`0 ${unit$1(d)}`,"&:after":{display:"none"}}}}}}}function genSingleStyle(a){const{componentCls:c}=a,u=a.calc(a.controlPaddingHorizontalSM).sub(a.lineWidth).equal();return[genSizeStyle$2(a),genSizeStyle$2(merge$2(a,{controlHeight:a.controlHeightSM,borderRadius:a.borderRadiusSM}),"sm"),{[`${c}-single${c}-sm`]:{[`&:not(${c}-customize-input)`]:{[`${c}-selector`]:{padding:`0 ${unit$1(u)}`},[`&${c}-show-arrow ${c}-selection-search`]:{insetInlineEnd:a.calc(u).add(a.calc(a.fontSize).mul(1.5)).equal()},[`
            &${c}-show-arrow ${c}-selection-item,
            &${c}-show-arrow ${c}-selection-placeholder
          `]:{paddingInlineEnd:a.calc(a.fontSize).mul(1.5).equal()}}}},genSizeStyle$2(merge$2(a,{controlHeight:a.singleItemHeightLG,fontSize:a.fontSizeLG,borderRadius:a.borderRadiusLG}),"lg")]}const prepareComponentToken$j=a=>{const{fontSize:c,lineHeight:u,lineWidth:d,controlHeight:f,controlHeightSM:m,controlHeightLG:g,paddingXXS:y,controlPaddingHorizontal:b,zIndexPopupBase:E,colorText:C,fontWeightStrong:w,controlItemBgActive:R,controlItemBgHover:_,colorBgContainer:M,colorFillSecondary:I,colorBgContainerDisabled:N,colorTextDisabled:A,colorPrimaryHover:P,colorPrimary:z,controlOutline:B}=a,j=y*2,L=d*2,U=Math.min(f-j,f-L),q=Math.min(m-j,m-L),F=Math.min(g-j,g-L);return{INTERNAL_FIXED_ITEM_MARGIN:Math.floor(y/2),zIndexPopup:E+50,optionSelectedColor:C,optionSelectedFontWeight:w,optionSelectedBg:R,optionActiveBg:_,optionPadding:`${(f-c*u)/2}px ${b}px`,optionFontSize:c,optionLineHeight:u,optionHeight:f,selectorBg:M,clearBg:M,singleItemHeightLG:g,multipleItemBg:I,multipleItemBorderColor:"transparent",multipleItemHeight:U,multipleItemHeightSM:q,multipleItemHeightLG:F,multipleSelectorBgDisabled:N,multipleItemColorDisabled:A,multipleItemBorderColorDisabled:"transparent",showArrowPaddingInlineEnd:Math.ceil(a.fontSize*1.25),hoverBorderColor:P,activeBorderColor:z,activeOutlineColor:B,selectAffixPadding:y}},genBaseOutlinedStyle$1=(a,c)=>{const{componentCls:u,antCls:d,controlOutlineWidth:f}=a;return{[`&:not(${u}-customize-input) ${u}-selector`]:{border:`${unit$1(a.lineWidth)} ${a.lineType} ${c.borderColor}`,background:a.selectorBg},[`&:not(${u}-disabled):not(${u}-customize-input):not(${d}-pagination-size-changer)`]:{[`&:hover ${u}-selector`]:{borderColor:c.hoverBorderHover},[`${u}-focused& ${u}-selector`]:{borderColor:c.activeBorderColor,boxShadow:`0 0 0 ${unit$1(f)} ${c.activeOutlineColor}`,outline:0},[`${u}-prefix`]:{color:c.color}}}},genOutlinedStatusStyle$1=(a,c)=>({[`&${a.componentCls}-status-${c.status}`]:Object.assign({},genBaseOutlinedStyle$1(a,c))}),genOutlinedStyle$1=a=>({"&-outlined":Object.assign(Object.assign(Object.assign(Object.assign({},genBaseOutlinedStyle$1(a,{borderColor:a.colorBorder,hoverBorderHover:a.hoverBorderColor,activeBorderColor:a.activeBorderColor,activeOutlineColor:a.activeOutlineColor,color:a.colorText})),genOutlinedStatusStyle$1(a,{status:"error",borderColor:a.colorError,hoverBorderHover:a.colorErrorHover,activeBorderColor:a.colorError,activeOutlineColor:a.colorErrorOutline,color:a.colorError})),genOutlinedStatusStyle$1(a,{status:"warning",borderColor:a.colorWarning,hoverBorderHover:a.colorWarningHover,activeBorderColor:a.colorWarning,activeOutlineColor:a.colorWarningOutline,color:a.colorWarning})),{[`&${a.componentCls}-disabled`]:{[`&:not(${a.componentCls}-customize-input) ${a.componentCls}-selector`]:{background:a.colorBgContainerDisabled,color:a.colorTextDisabled}},[`&${a.componentCls}-multiple ${a.componentCls}-selection-item`]:{background:a.multipleItemBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.multipleItemBorderColor}`}})}),genBaseFilledStyle$1=(a,c)=>{const{componentCls:u,antCls:d}=a;return{[`&:not(${u}-customize-input) ${u}-selector`]:{background:c.bg,border:`${unit$1(a.lineWidth)} ${a.lineType} transparent`,color:c.color},[`&:not(${u}-disabled):not(${u}-customize-input):not(${d}-pagination-size-changer)`]:{[`&:hover ${u}-selector`]:{background:c.hoverBg},[`${u}-focused& ${u}-selector`]:{background:a.selectorBg,borderColor:c.activeBorderColor,outline:0}}}},genFilledStatusStyle$1=(a,c)=>({[`&${a.componentCls}-status-${c.status}`]:Object.assign({},genBaseFilledStyle$1(a,c))}),genFilledStyle$1=a=>({"&-filled":Object.assign(Object.assign(Object.assign(Object.assign({},genBaseFilledStyle$1(a,{bg:a.colorFillTertiary,hoverBg:a.colorFillSecondary,activeBorderColor:a.activeBorderColor,color:a.colorText})),genFilledStatusStyle$1(a,{status:"error",bg:a.colorErrorBg,hoverBg:a.colorErrorBgHover,activeBorderColor:a.colorError,color:a.colorError})),genFilledStatusStyle$1(a,{status:"warning",bg:a.colorWarningBg,hoverBg:a.colorWarningBgHover,activeBorderColor:a.colorWarning,color:a.colorWarning})),{[`&${a.componentCls}-disabled`]:{[`&:not(${a.componentCls}-customize-input) ${a.componentCls}-selector`]:{borderColor:a.colorBorder,background:a.colorBgContainerDisabled,color:a.colorTextDisabled}},[`&${a.componentCls}-multiple ${a.componentCls}-selection-item`]:{background:a.colorBgContainer,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorSplit}`}})}),genBorderlessStyle$1=a=>({"&-borderless":{[`${a.componentCls}-selector`]:{background:"transparent",border:`${unit$1(a.lineWidth)} ${a.lineType} transparent`},[`&${a.componentCls}-disabled`]:{[`&:not(${a.componentCls}-customize-input) ${a.componentCls}-selector`]:{color:a.colorTextDisabled}},[`&${a.componentCls}-multiple ${a.componentCls}-selection-item`]:{background:a.multipleItemBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.multipleItemBorderColor}`},[`&${a.componentCls}-status-error`]:{[`${a.componentCls}-prefix, ${a.componentCls}-selection-item`]:{color:a.colorError}},[`&${a.componentCls}-status-warning`]:{[`${a.componentCls}-prefix, ${a.componentCls}-selection-item`]:{color:a.colorWarning}}}}),genBaseUnderlinedStyle$1=(a,c)=>{const{componentCls:u,antCls:d}=a;return{[`&:not(${u}-customize-input) ${u}-selector`]:{borderWidth:`0 0 ${unit$1(a.lineWidth)} 0`,borderStyle:`none none ${a.lineType} none`,borderColor:c.borderColor,background:a.selectorBg,borderRadius:0},[`&:not(${u}-disabled):not(${u}-customize-input):not(${d}-pagination-size-changer)`]:{[`&:hover ${u}-selector`]:{borderColor:c.hoverBorderHover},[`${u}-focused& ${u}-selector`]:{borderColor:c.activeBorderColor,outline:0},[`${u}-prefix`]:{color:c.color}}}},genUnderlinedStatusStyle$1=(a,c)=>({[`&${a.componentCls}-status-${c.status}`]:Object.assign({},genBaseUnderlinedStyle$1(a,c))}),genUnderlinedStyle$1=a=>({"&-underlined":Object.assign(Object.assign(Object.assign(Object.assign({},genBaseUnderlinedStyle$1(a,{borderColor:a.colorBorder,hoverBorderHover:a.hoverBorderColor,activeBorderColor:a.activeBorderColor,activeOutlineColor:a.activeOutlineColor,color:a.colorText})),genUnderlinedStatusStyle$1(a,{status:"error",borderColor:a.colorError,hoverBorderHover:a.colorErrorHover,activeBorderColor:a.colorError,activeOutlineColor:a.colorErrorOutline,color:a.colorError})),genUnderlinedStatusStyle$1(a,{status:"warning",borderColor:a.colorWarning,hoverBorderHover:a.colorWarningHover,activeBorderColor:a.colorWarning,activeOutlineColor:a.colorWarningOutline,color:a.colorWarning})),{[`&${a.componentCls}-disabled`]:{[`&:not(${a.componentCls}-customize-input) ${a.componentCls}-selector`]:{color:a.colorTextDisabled}},[`&${a.componentCls}-multiple ${a.componentCls}-selection-item`]:{background:a.multipleItemBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.multipleItemBorderColor}`}})}),genVariantsStyle=a=>({[a.componentCls]:Object.assign(Object.assign(Object.assign(Object.assign({},genOutlinedStyle$1(a)),genFilledStyle$1(a)),genBorderlessStyle$1(a)),genUnderlinedStyle$1(a))}),genSelectorStyle=a=>{const{componentCls:c}=a;return{position:"relative",transition:`all ${a.motionDurationMid} ${a.motionEaseInOut}`,input:{cursor:"pointer"},[`${c}-show-search&`]:{cursor:"text",input:{cursor:"auto",color:"inherit",height:"100%"}},[`${c}-disabled&`]:{cursor:"not-allowed",input:{cursor:"not-allowed"}}}},getSearchInputWithoutBorderStyle=a=>{const{componentCls:c}=a;return{[`${c}-selection-search-input`]:{margin:0,padding:0,background:"transparent",border:"none",outline:"none",appearance:"none",fontFamily:"inherit","&::-webkit-search-cancel-button":{display:"none",appearance:"none"}}}},genBaseStyle$5=a=>{const{antCls:c,componentCls:u,inputPaddingHorizontalBase:d,iconCls:f}=a;return{[u]:Object.assign(Object.assign({},resetComponent(a)),{position:"relative",display:"inline-flex",cursor:"pointer",[`&:not(${u}-customize-input) ${u}-selector`]:Object.assign(Object.assign({},genSelectorStyle(a)),getSearchInputWithoutBorderStyle(a)),[`${u}-selection-item`]:Object.assign(Object.assign({flex:1,fontWeight:"normal",position:"relative",userSelect:"none"},textEllipsis),{[`> ${c}-typography`]:{display:"inline"}}),[`${u}-selection-placeholder`]:Object.assign(Object.assign({},textEllipsis),{flex:1,color:a.colorTextPlaceholder,pointerEvents:"none"}),[`${u}-arrow`]:Object.assign(Object.assign({},resetIcon()),{position:"absolute",top:"50%",insetInlineStart:"auto",insetInlineEnd:d,height:a.fontSizeIcon,marginTop:a.calc(a.fontSizeIcon).mul(-1).div(2).equal(),color:a.colorTextQuaternary,fontSize:a.fontSizeIcon,lineHeight:1,textAlign:"center",pointerEvents:"none",display:"flex",alignItems:"center",transition:`opacity ${a.motionDurationSlow} ease`,[f]:{verticalAlign:"top",transition:`transform ${a.motionDurationSlow}`,"> svg":{verticalAlign:"top"},[`&:not(${u}-suffix)`]:{pointerEvents:"auto"}},[`${u}-disabled &`]:{cursor:"not-allowed"},"> *:not(:last-child)":{marginInlineEnd:8}}),[`${u}-selection-wrap`]:{display:"flex",width:"100%",position:"relative",minWidth:0,"&:after":{content:'"\\a0"',width:0,overflow:"hidden"}},[`${u}-prefix`]:{flex:"none",marginInlineEnd:a.selectAffixPadding},[`${u}-clear`]:{position:"absolute",top:"50%",insetInlineStart:"auto",insetInlineEnd:d,zIndex:1,display:"inline-block",width:a.fontSizeIcon,height:a.fontSizeIcon,marginTop:a.calc(a.fontSizeIcon).mul(-1).div(2).equal(),color:a.colorTextQuaternary,fontSize:a.fontSizeIcon,fontStyle:"normal",lineHeight:1,textAlign:"center",textTransform:"none",cursor:"pointer",opacity:0,transition:`color ${a.motionDurationMid} ease, opacity ${a.motionDurationSlow} ease`,textRendering:"auto","&:before":{display:"block"},"&:hover":{color:a.colorIcon}},[`&:hover ${u}-clear`]:{opacity:1,background:a.colorBgBase,borderRadius:"50%"}}),[`${u}-status`]:{"&-error, &-warning, &-success, &-validating":{[`&${u}-has-feedback`]:{[`${u}-clear`]:{insetInlineEnd:a.calc(d).add(a.fontSize).add(a.paddingXS).equal()}}}}}},genSelectStyle=a=>{const{componentCls:c}=a;return[{[c]:{[`&${c}-in-form-item`]:{width:"100%"}}},genBaseStyle$5(a),genSingleStyle(a),genMultipleStyle(a),genSingleStyle$1(a),{[`${c}-rtl`]:{direction:"rtl"}},genCompactItemStyle(a,{borderElCls:`${c}-selector`,focusElCls:`${c}-focused`})]},useSelectStyle=genStyleHooks("Select",(a,c)=>{let{rootPrefixCls:u}=c;const d=merge$2(a,{rootPrefixCls:u,inputPaddingHorizontalBase:a.calc(a.paddingSM).sub(1).equal(),multipleSelectItemHeight:a.multipleItemHeight,selectHeight:a.controlHeight});return[genSelectStyle(d),genVariantsStyle(d)]},prepareComponentToken$j,{unitless:{optionLineHeight:!0,optionSelectedFontWeight:!0}});function useIcons(a){let{suffixIcon:c,clearIcon:u,menuItemSelectedIcon:d,removeIcon:f,loading:m,multiple:g,hasFeedback:y,prefixCls:b,showSuffixIcon:E,feedbackIcon:C,showArrow:w,componentName:R}=a;const _=u??reactExports.createElement(RefIcon$y,null),M=P=>c===null&&!y&&!w?null:reactExports.createElement(reactExports.Fragment,null,E!==!1&&P,y&&C);let I=null;if(c!==void 0)I=M(c);else if(m)I=M(reactExports.createElement(RefIcon$e,{spin:!0}));else{const P=`${b}-suffix`;I=z=>{let{open:B,showSearch:j}=z;return M(B&&j?reactExports.createElement(RefIcon$5,{className:P}):reactExports.createElement(RefIcon$t,{className:P}))}}let N=null;d!==void 0?N=d:g?N=reactExports.createElement(RefIcon$z,null):N=null;let A=null;return f!==void 0?A=f:A=reactExports.createElement(RefIcon$x,null),{clearIcon:_,suffixIcon:I,itemIcon:N,removeIcon:A}}function useShowArrow(a,c){return c!==void 0?c:a!==null}var __rest$O=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const SECRET_COMBOBOX_MODE_DO_NOT_USE="SECRET_COMBOBOX_MODE_DO_NOT_USE",InternalSelect=(a,c)=>{var u;const{prefixCls:d,bordered:f,className:m,rootClassName:g,getPopupContainer:y,popupClassName:b,dropdownClassName:E,listHeight:C=256,placement:w,listItemHeight:R,size:_,disabled:M,notFoundContent:I,status:N,builtinPlacements:A,dropdownMatchSelectWidth:P,popupMatchSelectWidth:z,direction:B,style:j,allowClear:L,variant:U,dropdownStyle:q,transitionName:F,tagRender:K,maxCount:X,prefix:Q}=a,Y=__rest$O(a,["prefixCls","bordered","className","rootClassName","getPopupContainer","popupClassName","dropdownClassName","listHeight","placement","listItemHeight","size","disabled","notFoundContent","status","builtinPlacements","dropdownMatchSelectWidth","popupMatchSelectWidth","direction","style","allowClear","variant","dropdownStyle","transitionName","tagRender","maxCount","prefix"]),{getPopupContainer:Z,getPrefixCls:J,renderEmpty:W,direction:G,virtual:te,popupMatchSelectWidth:ae,popupOverflow:V}=reactExports.useContext(ConfigContext),ne=useComponentConfig("select"),[,le]=useToken$1(),ee=R??(le==null?void 0:le.controlHeight),ie=J("select",d),ce=J(),ue=B??G,{compactSize:me,compactItemClassnames:de}=useCompactItemContext(ie,ue),[ge,Ce]=useVariant("select",U,f),ve=useCSSVarCls(ie),[fe,pe,xe]=useSelectStyle(ie,ve),ye=reactExports.useMemo(()=>{const{mode:ut}=a;if(ut!=="combobox")return ut===SECRET_COMBOBOX_MODE_DO_NOT_USE?"combobox":ut},[a.mode]),he=ye==="multiple"||ye==="tags",we=useShowArrow(a.suffixIcon,a.showArrow),Re=(u=z??P)!==null&&u!==void 0?u:ae,{status:De,hasFeedback:Ae,isFormItemInput:Ee,feedbackIcon:Ne}=reactExports.useContext(FormItemInputContext),_e=getMergedStatus(De,N);let ke;I!==void 0?ke=I:ye==="combobox"?ke=null:ke=(W==null?void 0:W("Select"))||reactExports.createElement(DefaultRenderEmpty,{componentName:"Select"});const{suffixIcon:Ke,itemIcon:be,removeIcon:Te,clearIcon:Le}=useIcons(Object.assign(Object.assign({},Y),{multiple:he,hasFeedback:Ae,feedbackIcon:Ne,showSuffixIcon:we,prefixCls:ie,componentName:"Select"})),Oe=L===!0?{clearIcon:Le}:L,Be=omit(Y,["suffixIcon","itemIcon"]),Ve=classNames(b||E,{[`${ie}-dropdown-${ue}`]:ue==="rtl"},g,xe,ve,pe),Pe=useSize(ut=>{var gt;return(gt=_??me)!==null&&gt!==void 0?gt:ut}),Ge=reactExports.useContext(DisabledContext),qe=M??Ge,Ue=classNames({[`${ie}-lg`]:Pe==="large",[`${ie}-sm`]:Pe==="small",[`${ie}-rtl`]:ue==="rtl",[`${ie}-${ge}`]:Ce,[`${ie}-in-form-item`]:Ee},getStatusClassNames(ie,_e,Ae),de,ne.className,m,g,xe,ve,pe),je=reactExports.useMemo(()=>w!==void 0?w:ue==="rtl"?"bottomRight":"bottomLeft",[w,ue]),[We]=useZIndex("SelectLike",q==null?void 0:q.zIndex);return fe(reactExports.createElement(TypedSelect,Object.assign({ref:c,virtual:te,showSearch:ne.showSearch},Be,{style:Object.assign(Object.assign({},ne.style),j),dropdownMatchSelectWidth:Re,transitionName:getTransitionName(ce,"slide-up",F),builtinPlacements:mergedBuiltinPlacements(A,V),listHeight:C,listItemHeight:ee,mode:ye,prefixCls:ie,placement:je,direction:ue,prefix:Q,suffixIcon:Ke,menuItemSelectedIcon:be,removeIcon:Te,allowClear:Oe,notFoundContent:ke,className:Ue,getPopupContainer:y||Z,dropdownClassName:Ve,disabled:qe,dropdownStyle:Object.assign(Object.assign({},q),{zIndex:We}),maxCount:he?X:void 0,tagRender:he?K:void 0})))},Select=reactExports.forwardRef(InternalSelect),PurePanel$4=genPurePanel(Select,"dropdownAlign");Select.SECRET_COMBOBOX_MODE_DO_NOT_USE=SECRET_COMBOBOX_MODE_DO_NOT_USE;Select.Option=Option;Select.OptGroup=OptGroup;Select._InternalPanelDoNotUseOrYouWillBeFired=PurePanel$4;const responsiveArray=["xxl","xl","lg","md","sm","xs"],getResponsiveMap=a=>({xs:`(max-width: ${a.screenXSMax}px)`,sm:`(min-width: ${a.screenSM}px)`,md:`(min-width: ${a.screenMD}px)`,lg:`(min-width: ${a.screenLG}px)`,xl:`(min-width: ${a.screenXL}px)`,xxl:`(min-width: ${a.screenXXL}px)`}),validateBreakpoints=a=>{const c=a,u=[].concat(responsiveArray).reverse();return u.forEach((d,f)=>{const m=d.toUpperCase(),g=`screen${m}Min`,y=`screen${m}`;if(!(c[g]<=c[y]))throw new Error(`${g}<=${y} fails : !(${c[g]}<=${c[y]})`);if(f<u.length-1){const b=`screen${m}Max`;if(!(c[y]<=c[b]))throw new Error(`${y}<=${b} fails : !(${c[y]}<=${c[b]})`);const C=`screen${u[f+1].toUpperCase()}Min`;if(!(c[b]<=c[C]))throw new Error(`${b}<=${C} fails : !(${c[b]}<=${c[C]})`)}}),a},useResponsiveObserver=()=>{const[,a]=useToken$1(),c=getResponsiveMap(validateBreakpoints(a));return React.useMemo(()=>{const u=new Map;let d=-1,f={};return{responsiveMap:c,matchHandlers:{},dispatch(m){return f=m,u.forEach(g=>g(f)),u.size>=1},subscribe(m){return u.size||this.register(),d+=1,u.set(d,m),m(f),d},unsubscribe(m){u.delete(m),u.size||this.unregister()},register(){Object.keys(c).forEach(m=>{const g=c[m],y=E=>{let{matches:C}=E;this.dispatch(Object.assign(Object.assign({},f),{[m]:C}))},b=window.matchMedia(g);b.addListener(y),this.matchHandlers[g]={mql:b,listener:y},y(b)})},unregister(){Object.keys(c).forEach(m=>{const g=c[m],y=this.matchHandlers[g];y==null||y.mql.removeListener(y==null?void 0:y.listener)}),u.clear()}}},[a])};function useForceUpdate(){const[,a]=reactExports.useReducer(c=>c+1,0);return a}function useBreakpoint(){let a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!0,c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};const u=reactExports.useRef(c),d=useForceUpdate(),f=useResponsiveObserver();return useLayoutEffect$1(()=>{const m=f.subscribe(g=>{u.current=g,a&&d()});return()=>f.unsubscribe(m)},[]),u.current}const getRenderPropValue=a=>a?typeof a=="function"?a():a:null;function Popup(a){var c=a.children,u=a.prefixCls,d=a.id,f=a.overlayInnerStyle,m=a.bodyClassName,g=a.className,y=a.style;return reactExports.createElement("div",{className:classNames("".concat(u,"-content"),g),style:y},reactExports.createElement("div",{className:classNames("".concat(u,"-inner"),m),id:d,role:"tooltip",style:f},typeof c=="function"?c():c))}var autoAdjustOverflowTopBottom={shiftX:64,adjustY:1},autoAdjustOverflowLeftRight={adjustX:1,shiftY:!0},targetOffset$1=[0,0],placements$2={left:{points:["cr","cl"],overflow:autoAdjustOverflowLeftRight,offset:[-4,0],targetOffset:targetOffset$1},right:{points:["cl","cr"],overflow:autoAdjustOverflowLeftRight,offset:[4,0],targetOffset:targetOffset$1},top:{points:["bc","tc"],overflow:autoAdjustOverflowTopBottom,offset:[0,-4],targetOffset:targetOffset$1},bottom:{points:["tc","bc"],overflow:autoAdjustOverflowTopBottom,offset:[0,4],targetOffset:targetOffset$1},topLeft:{points:["bl","tl"],overflow:autoAdjustOverflowTopBottom,offset:[0,-4],targetOffset:targetOffset$1},leftTop:{points:["tr","tl"],overflow:autoAdjustOverflowLeftRight,offset:[-4,0],targetOffset:targetOffset$1},topRight:{points:["br","tr"],overflow:autoAdjustOverflowTopBottom,offset:[0,-4],targetOffset:targetOffset$1},rightTop:{points:["tl","tr"],overflow:autoAdjustOverflowLeftRight,offset:[4,0],targetOffset:targetOffset$1},bottomRight:{points:["tr","br"],overflow:autoAdjustOverflowTopBottom,offset:[0,4],targetOffset:targetOffset$1},rightBottom:{points:["bl","br"],overflow:autoAdjustOverflowLeftRight,offset:[4,0],targetOffset:targetOffset$1},bottomLeft:{points:["tl","bl"],overflow:autoAdjustOverflowTopBottom,offset:[0,4],targetOffset:targetOffset$1},leftBottom:{points:["br","bl"],overflow:autoAdjustOverflowLeftRight,offset:[-4,0],targetOffset:targetOffset$1}},_excluded$v=["overlayClassName","trigger","mouseEnterDelay","mouseLeaveDelay","overlayStyle","prefixCls","children","onVisibleChange","afterVisibleChange","transitionName","animation","motion","placement","align","destroyTooltipOnHide","defaultVisible","getTooltipContainer","overlayInnerStyle","arrowContent","overlay","id","showArrow","classNames","styles"],Tooltip$1=function(c,u){var d=c.overlayClassName,f=c.trigger,m=f===void 0?["hover"]:f,g=c.mouseEnterDelay,y=g===void 0?0:g,b=c.mouseLeaveDelay,E=b===void 0?.1:b,C=c.overlayStyle,w=c.prefixCls,R=w===void 0?"rc-tooltip":w,_=c.children,M=c.onVisibleChange,I=c.afterVisibleChange,N=c.transitionName,A=c.animation,P=c.motion,z=c.placement,B=z===void 0?"right":z,j=c.align,L=j===void 0?{}:j,U=c.destroyTooltipOnHide,q=U===void 0?!1:U,F=c.defaultVisible,K=c.getTooltipContainer,X=c.overlayInnerStyle;c.arrowContent;var Q=c.overlay,Y=c.id,Z=c.showArrow,J=Z===void 0?!0:Z,W=c.classNames,G=c.styles,te=_objectWithoutProperties(c,_excluded$v),ae=useId$1(Y),V=reactExports.useRef(null);reactExports.useImperativeHandle(u,function(){return V.current});var ne=_objectSpread2({},te);"visible"in c&&(ne.popupVisible=c.visible);var le=function(){return reactExports.createElement(Popup,{key:"content",prefixCls:R,id:ae,bodyClassName:W==null?void 0:W.body,overlayInnerStyle:_objectSpread2(_objectSpread2({},X),G==null?void 0:G.body)},Q)},ee=function(){var ce=reactExports.Children.only(_),ue=(ce==null?void 0:ce.props)||{},me=_objectSpread2(_objectSpread2({},ue),{},{"aria-describedby":Q?ae:null});return reactExports.cloneElement(_,me)};return reactExports.createElement(Trigger,_extends({popupClassName:classNames(d,W==null?void 0:W.root),prefixCls:R,popup:le,action:m,builtinPlacements:placements$2,popupPlacement:B,ref:V,popupAlign:L,getPopupContainer:K,onPopupVisibleChange:M,afterPopupVisibleChange:I,popupTransitionName:N,popupAnimation:A,popupMotion:P,defaultPopupVisible:F,autoDestroy:q,mouseLeaveDelay:E,popupStyle:_objectSpread2(_objectSpread2({},C),G==null?void 0:G.root),mouseEnterDelay:y,arrow:J},ne),ee())};const Tooltip$2=reactExports.forwardRef(Tooltip$1);function getArrowToken(a){const{sizePopupArrow:c,borderRadiusXS:u,borderRadiusOuter:d}=a,f=c/2,m=0,g=f,y=d*1/Math.sqrt(2),b=f-d*(1-1/Math.sqrt(2)),E=f-u*(1/Math.sqrt(2)),C=d*(Math.sqrt(2)-1)+u*(1/Math.sqrt(2)),w=2*f-E,R=C,_=2*f-y,M=b,I=2*f-m,N=g,A=f*Math.sqrt(2)+d*(Math.sqrt(2)-2),P=d*(Math.sqrt(2)-1),z=`polygon(${P}px 100%, 50% ${P}px, ${2*f-P}px 100%, ${P}px 100%)`,B=`path('M ${m} ${g} A ${d} ${d} 0 0 0 ${y} ${b} L ${E} ${C} A ${u} ${u} 0 0 1 ${w} ${R} L ${_} ${M} A ${d} ${d} 0 0 0 ${I} ${N} Z')`;return{arrowShadowWidth:A,arrowPath:B,arrowPolygon:z}}const genRoundedArrow=(a,c,u)=>{const{sizePopupArrow:d,arrowPolygon:f,arrowPath:m,arrowShadowWidth:g,borderRadiusXS:y,calc:b}=a;return{pointerEvents:"none",width:d,height:d,overflow:"hidden","&::before":{position:"absolute",bottom:0,insetInlineStart:0,width:d,height:b(d).div(2).equal(),background:c,clipPath:{_multi_value_:!0,value:[f,m]},content:'""'},"&::after":{content:'""',position:"absolute",width:g,height:g,bottom:0,insetInline:0,margin:"auto",borderRadius:{_skip_check_:!0,value:`0 0 ${unit$1(y)} 0`},transform:"translateY(50%) rotate(-135deg)",boxShadow:u,zIndex:0,background:"transparent"}}},MAX_VERTICAL_CONTENT_RADIUS=8;function getArrowOffsetToken(a){const{contentRadius:c,limitVerticalRadius:u}=a,d=c>12?c+2:12;return{arrowOffsetHorizontal:d,arrowOffsetVertical:u?MAX_VERTICAL_CONTENT_RADIUS:d}}function isInject(a,c){return a?c:{}}function getArrowStyle(a,c,u){const{componentCls:d,boxShadowPopoverArrow:f,arrowOffsetVertical:m,arrowOffsetHorizontal:g}=a,{arrowDistance:y=0,arrowPlacement:b={left:!0,right:!0,top:!0,bottom:!0}}=u||{};return{[d]:Object.assign(Object.assign(Object.assign(Object.assign({[`${d}-arrow`]:[Object.assign(Object.assign({position:"absolute",zIndex:1,display:"block"},genRoundedArrow(a,c,f)),{"&:before":{background:c}})]},isInject(!!b.top,{[[`&-placement-top > ${d}-arrow`,`&-placement-topLeft > ${d}-arrow`,`&-placement-topRight > ${d}-arrow`].join(",")]:{bottom:y,transform:"translateY(100%) rotate(180deg)"},[`&-placement-top > ${d}-arrow`]:{left:{_skip_check_:!0,value:"50%"},transform:"translateX(-50%) translateY(100%) rotate(180deg)"},"&-placement-topLeft":{"--arrow-offset-horizontal":g,[`> ${d}-arrow`]:{left:{_skip_check_:!0,value:g}}},"&-placement-topRight":{"--arrow-offset-horizontal":`calc(100% - ${unit$1(g)})`,[`> ${d}-arrow`]:{right:{_skip_check_:!0,value:g}}}})),isInject(!!b.bottom,{[[`&-placement-bottom > ${d}-arrow`,`&-placement-bottomLeft > ${d}-arrow`,`&-placement-bottomRight > ${d}-arrow`].join(",")]:{top:y,transform:"translateY(-100%)"},[`&-placement-bottom > ${d}-arrow`]:{left:{_skip_check_:!0,value:"50%"},transform:"translateX(-50%) translateY(-100%)"},"&-placement-bottomLeft":{"--arrow-offset-horizontal":g,[`> ${d}-arrow`]:{left:{_skip_check_:!0,value:g}}},"&-placement-bottomRight":{"--arrow-offset-horizontal":`calc(100% - ${unit$1(g)})`,[`> ${d}-arrow`]:{right:{_skip_check_:!0,value:g}}}})),isInject(!!b.left,{[[`&-placement-left > ${d}-arrow`,`&-placement-leftTop > ${d}-arrow`,`&-placement-leftBottom > ${d}-arrow`].join(",")]:{right:{_skip_check_:!0,value:y},transform:"translateX(100%) rotate(90deg)"},[`&-placement-left > ${d}-arrow`]:{top:{_skip_check_:!0,value:"50%"},transform:"translateY(-50%) translateX(100%) rotate(90deg)"},[`&-placement-leftTop > ${d}-arrow`]:{top:m},[`&-placement-leftBottom > ${d}-arrow`]:{bottom:m}})),isInject(!!b.right,{[[`&-placement-right > ${d}-arrow`,`&-placement-rightTop > ${d}-arrow`,`&-placement-rightBottom > ${d}-arrow`].join(",")]:{left:{_skip_check_:!0,value:y},transform:"translateX(-100%) rotate(-90deg)"},[`&-placement-right > ${d}-arrow`]:{top:{_skip_check_:!0,value:"50%"},transform:"translateY(-50%) translateX(-100%) rotate(-90deg)"},[`&-placement-rightTop > ${d}-arrow`]:{top:m},[`&-placement-rightBottom > ${d}-arrow`]:{bottom:m}}))}}function getOverflowOptions(a,c,u,d){if(d===!1)return{adjustX:!1,adjustY:!1};const f=d&&typeof d=="object"?d:{},m={};switch(a){case"top":case"bottom":m.shiftX=c.arrowOffsetHorizontal*2+u,m.shiftY=!0,m.adjustY=!0;break;case"left":case"right":m.shiftY=c.arrowOffsetVertical*2+u,m.shiftX=!0,m.adjustX=!0;break}const g=Object.assign(Object.assign({},m),f);return g.shiftX||(g.adjustX=!0),g.shiftY||(g.adjustY=!0),g}const PlacementAlignMap={left:{points:["cr","cl"]},right:{points:["cl","cr"]},top:{points:["bc","tc"]},bottom:{points:["tc","bc"]},topLeft:{points:["bl","tl"]},leftTop:{points:["tr","tl"]},topRight:{points:["br","tr"]},rightTop:{points:["tl","tr"]},bottomRight:{points:["tr","br"]},rightBottom:{points:["bl","br"]},bottomLeft:{points:["tl","bl"]},leftBottom:{points:["br","bl"]}},ArrowCenterPlacementAlignMap={topLeft:{points:["bl","tc"]},leftTop:{points:["tr","cl"]},topRight:{points:["br","tc"]},rightTop:{points:["tl","cr"]},bottomRight:{points:["tr","bc"]},rightBottom:{points:["bl","cr"]},bottomLeft:{points:["tl","bc"]},leftBottom:{points:["br","cl"]}},DisableAutoArrowList=new Set(["topLeft","topRight","bottomLeft","bottomRight","leftTop","leftBottom","rightTop","rightBottom"]);function getPlacements(a){const{arrowWidth:c,autoAdjustOverflow:u,arrowPointAtCenter:d,offset:f,borderRadius:m,visibleFirst:g}=a,y=c/2,b={};return Object.keys(PlacementAlignMap).forEach(E=>{const C=d&&ArrowCenterPlacementAlignMap[E]||PlacementAlignMap[E],w=Object.assign(Object.assign({},C),{offset:[0,0],dynamicInset:!0});switch(b[E]=w,DisableAutoArrowList.has(E)&&(w.autoArrow=!1),E){case"top":case"topLeft":case"topRight":w.offset[1]=-y-f;break;case"bottom":case"bottomLeft":case"bottomRight":w.offset[1]=y+f;break;case"left":case"leftTop":case"leftBottom":w.offset[0]=-y-f;break;case"right":case"rightTop":case"rightBottom":w.offset[0]=y+f;break}const R=getArrowOffsetToken({contentRadius:m,limitVerticalRadius:!0});if(d)switch(E){case"topLeft":case"bottomLeft":w.offset[0]=-R.arrowOffsetHorizontal-y;break;case"topRight":case"bottomRight":w.offset[0]=R.arrowOffsetHorizontal+y;break;case"leftTop":case"rightTop":w.offset[1]=-R.arrowOffsetHorizontal*2+y;break;case"leftBottom":case"rightBottom":w.offset[1]=R.arrowOffsetHorizontal*2-y;break}w.overflow=getOverflowOptions(E,R,c,u),g&&(w.htmlRegion="visibleFirst")}),b}const genTooltipStyle=a=>{const{calc:c,componentCls:u,tooltipMaxWidth:d,tooltipColor:f,tooltipBg:m,tooltipBorderRadius:g,zIndexPopup:y,controlHeight:b,boxShadowSecondary:E,paddingSM:C,paddingXS:w,arrowOffsetHorizontal:R,sizePopupArrow:_}=a,M=c(g).add(_).add(R).equal(),I=c(g).mul(2).add(_).equal();return[{[u]:Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),{position:"absolute",zIndex:y,display:"block",width:"max-content",maxWidth:d,visibility:"visible","--valid-offset-x":"var(--arrow-offset-horizontal, var(--arrow-x))",transformOrigin:["var(--valid-offset-x, 50%)","var(--arrow-y, 50%)"].join(" "),"&-hidden":{display:"none"},"--antd-arrow-background-color":m,[`${u}-inner`]:{minWidth:I,minHeight:b,padding:`${unit$1(a.calc(C).div(2).equal())} ${unit$1(w)}`,color:f,textAlign:"start",textDecoration:"none",wordWrap:"break-word",backgroundColor:m,borderRadius:g,boxShadow:E,boxSizing:"border-box"},[["&-placement-topLeft","&-placement-topRight","&-placement-bottomLeft","&-placement-bottomRight"].join(",")]:{minWidth:M},[["&-placement-left","&-placement-leftTop","&-placement-leftBottom","&-placement-right","&-placement-rightTop","&-placement-rightBottom"].join(",")]:{[`${u}-inner`]:{borderRadius:a.min(g,MAX_VERTICAL_CONTENT_RADIUS)}},[`${u}-content`]:{position:"relative"}}),genPresetColor(a,(N,A)=>{let{darkColor:P}=A;return{[`&${u}-${N}`]:{[`${u}-inner`]:{backgroundColor:P},[`${u}-arrow`]:{"--antd-arrow-background-color":P}}}})),{"&-rtl":{direction:"rtl"}})},getArrowStyle(a,"var(--antd-arrow-background-color)"),{[`${u}-pure`]:{position:"relative",maxWidth:"none",margin:a.sizePopupArrow}}]},prepareComponentToken$i=a=>Object.assign(Object.assign({zIndexPopup:a.zIndexPopupBase+70},getArrowOffsetToken({contentRadius:a.borderRadius,limitVerticalRadius:!0})),getArrowToken(merge$2(a,{borderRadiusOuter:Math.min(a.borderRadiusOuter,4)}))),useStyle$n=function(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!0;return genStyleHooks("Tooltip",d=>{const{borderRadius:f,colorTextLightSolid:m,colorBgSpotlight:g}=d,y=merge$2(d,{tooltipMaxWidth:250,tooltipColor:m,tooltipBorderRadius:f,tooltipBg:g});return[genTooltipStyle(y),initZoomMotion(d,"zoom-big-fast")]},prepareComponentToken$i,{resetStyle:!1,injectStyle:c})(a)},inverseColors=PresetColors.map(a=>`${a}-inverse`),PresetStatusColorTypes=["success","processing","error","default","warning"];function isPresetColor(a){return(arguments.length>1&&arguments[1]!==void 0?arguments[1]:!0)?[].concat(_toConsumableArray(inverseColors),_toConsumableArray(PresetColors)).includes(a):PresetColors.includes(a)}function isPresetStatusColor(a){return PresetStatusColorTypes.includes(a)}function parseColor(a,c){const u=isPresetColor(c),d=classNames({[`${a}-${c}`]:c&&u}),f={},m={};return c&&!u&&(f.background=c,m["--antd-arrow-background-color"]=c),{className:d,overlayStyle:f,arrowStyle:m}}const PurePanel$3=a=>{const{prefixCls:c,className:u,placement:d="top",title:f,color:m,overlayInnerStyle:g}=a,{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("tooltip",c),[E,C,w]=useStyle$n(b),R=parseColor(b,m),_=R.arrowStyle,M=Object.assign(Object.assign({},g),R.overlayStyle),I=classNames(C,w,b,`${b}-pure`,`${b}-placement-${d}`,u,R.className);return E(reactExports.createElement("div",{className:I,style:_},reactExports.createElement("div",{className:`${b}-arrow`}),reactExports.createElement(Popup,Object.assign({},a,{className:C,prefixCls:b,overlayInnerStyle:M}),f)))};var __rest$N=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalTooltip=reactExports.forwardRef((a,c)=>{var u,d;const{prefixCls:f,openClassName:m,getTooltipContainer:g,color:y,overlayInnerStyle:b,children:E,afterOpenChange:C,afterVisibleChange:w,destroyTooltipOnHide:R,arrow:_=!0,title:M,overlay:I,builtinPlacements:N,arrowPointAtCenter:A=!1,autoAdjustOverflow:P=!0,motion:z,getPopupContainer:B,placement:j="top",mouseEnterDelay:L=.1,mouseLeaveDelay:U=.1,overlayStyle:q,rootClassName:F,overlayClassName:K,styles:X,classNames:Q}=a,Y=__rest$N(a,["prefixCls","openClassName","getTooltipContainer","color","overlayInnerStyle","children","afterOpenChange","afterVisibleChange","destroyTooltipOnHide","arrow","title","overlay","builtinPlacements","arrowPointAtCenter","autoAdjustOverflow","motion","getPopupContainer","placement","mouseEnterDelay","mouseLeaveDelay","overlayStyle","rootClassName","overlayClassName","styles","classNames"]),Z=!!_,[,J]=useToken$1(),{getPopupContainer:W,getPrefixCls:G,direction:te,className:ae,style:V,classNames:ne,styles:le}=useComponentConfig("tooltip"),ee=devUseWarning(),ie=reactExports.useRef(null),ce=()=>{var Be;(Be=ie.current)===null||Be===void 0||Be.forceAlign()};reactExports.useImperativeHandle(c,()=>{var Be,Ve;return{forceAlign:ce,forcePopupAlign:()=>{ee.deprecated(!1,"forcePopupAlign","forceAlign"),ce()},nativeElement:(Be=ie.current)===null||Be===void 0?void 0:Be.nativeElement,popupElement:(Ve=ie.current)===null||Ve===void 0?void 0:Ve.popupElement}});const[ue,me]=useMergedState(!1,{value:(u=a.open)!==null&&u!==void 0?u:a.visible,defaultValue:(d=a.defaultOpen)!==null&&d!==void 0?d:a.defaultVisible}),de=!M&&!I&&M!==0,ge=Be=>{var Ve,Pe;me(de?!1:Be),de||((Ve=a.onOpenChange)===null||Ve===void 0||Ve.call(a,Be),(Pe=a.onVisibleChange)===null||Pe===void 0||Pe.call(a,Be))},Ce=reactExports.useMemo(()=>{var Be,Ve;let Pe=A;return typeof _=="object"&&(Pe=(Ve=(Be=_.pointAtCenter)!==null&&Be!==void 0?Be:_.arrowPointAtCenter)!==null&&Ve!==void 0?Ve:A),N||getPlacements({arrowPointAtCenter:Pe,autoAdjustOverflow:P,arrowWidth:Z?J.sizePopupArrow:0,borderRadius:J.borderRadius,offset:J.marginXXS,visibleFirst:!0})},[A,_,N,J]),ve=reactExports.useMemo(()=>M===0?M:I||M||"",[I,M]),fe=reactExports.createElement(ContextIsolator,{space:!0},typeof ve=="function"?ve():ve),pe=G("tooltip",f),xe=G(),ye=a["data-popover-inject"];let he=ue;!("open"in a)&&!("visible"in a)&&de&&(he=!1);const we=reactExports.isValidElement(E)&&!isFragment(E)?E:reactExports.createElement("span",null,E),Re=we.props,De=!Re.className||typeof Re.className=="string"?classNames(Re.className,m||`${pe}-open`):Re.className,[Ae,Ee,Ne]=useStyle$n(pe,!ye),_e=parseColor(pe,y),ke=_e.arrowStyle,Ke=classNames(K,{[`${pe}-rtl`]:te==="rtl"},_e.className,F,Ee,Ne,ae,ne.root,Q==null?void 0:Q.root),be=classNames(ne.body,Q==null?void 0:Q.body),[Te,Le]=useZIndex("Tooltip",Y.zIndex),Oe=reactExports.createElement(Tooltip$2,Object.assign({},Y,{zIndex:Te,showArrow:Z,placement:j,mouseEnterDelay:L,mouseLeaveDelay:U,prefixCls:pe,classNames:{root:Ke,body:be},styles:{root:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},ke),le.root),V),q),X==null?void 0:X.root),body:Object.assign(Object.assign(Object.assign(Object.assign({},le.body),b),X==null?void 0:X.body),_e.overlayStyle)},getTooltipContainer:B||g||W,ref:ie,builtinPlacements:Ce,overlay:fe,visible:he,onVisibleChange:ge,afterVisibleChange:C??w,arrowContent:reactExports.createElement("span",{className:`${pe}-arrow-content`}),motion:{motionName:getTransitionName(xe,"zoom-big-fast",a.transitionName),motionDeadline:1e3},destroyTooltipOnHide:!!R}),he?cloneElement(we,{className:De}):we);return Ae(reactExports.createElement(zIndexContext.Provider,{value:Le},Oe))}),Tooltip=InternalTooltip;Tooltip._InternalPanelDoNotUseOrYouWillBeFired=PurePanel$3;const genBaseStyle$4=a=>{const{componentCls:c,popoverColor:u,titleMinWidth:d,fontWeightStrong:f,innerPadding:m,boxShadowSecondary:g,colorTextHeading:y,borderRadiusLG:b,zIndexPopup:E,titleMarginBottom:C,colorBgElevated:w,popoverBg:R,titleBorderBottom:_,innerContentPadding:M,titlePadding:I}=a;return[{[c]:Object.assign(Object.assign({},resetComponent(a)),{position:"absolute",top:0,left:{_skip_check_:!0,value:0},zIndex:E,fontWeight:"normal",whiteSpace:"normal",textAlign:"start",cursor:"auto",userSelect:"text","--valid-offset-x":"var(--arrow-offset-horizontal, var(--arrow-x))",transformOrigin:["var(--valid-offset-x, 50%)","var(--arrow-y, 50%)"].join(" "),"--antd-arrow-background-color":w,width:"max-content",maxWidth:"100vw","&-rtl":{direction:"rtl"},"&-hidden":{display:"none"},[`${c}-content`]:{position:"relative"},[`${c}-inner`]:{backgroundColor:R,backgroundClip:"padding-box",borderRadius:b,boxShadow:g,padding:m},[`${c}-title`]:{minWidth:d,marginBottom:C,color:y,fontWeight:f,borderBottom:_,padding:I},[`${c}-inner-content`]:{color:u,padding:M}})},getArrowStyle(a,"var(--antd-arrow-background-color)"),{[`${c}-pure`]:{position:"relative",maxWidth:"none",margin:a.sizePopupArrow,display:"inline-block",[`${c}-content`]:{display:"inline-block"}}}]},genColorStyle=a=>{const{componentCls:c}=a;return{[c]:PresetColors.map(u=>{const d=a[`${u}6`];return{[`&${c}-${u}`]:{"--antd-arrow-background-color":d,[`${c}-inner`]:{backgroundColor:d},[`${c}-arrow`]:{background:"transparent"}}}})}},prepareComponentToken$h=a=>{const{lineWidth:c,controlHeight:u,fontHeight:d,padding:f,wireframe:m,zIndexPopupBase:g,borderRadiusLG:y,marginXS:b,lineType:E,colorSplit:C,paddingSM:w}=a,R=u-d,_=R/2,M=R/2-c,I=f;return Object.assign(Object.assign(Object.assign({titleMinWidth:177,zIndexPopup:g+30},getArrowToken(a)),getArrowOffsetToken({contentRadius:y,limitVerticalRadius:!0})),{innerPadding:m?0:12,titleMarginBottom:m?0:b,titlePadding:m?`${_}px ${I}px ${M}px`:0,titleBorderBottom:m?`${c}px ${E} ${C}`:"none",innerContentPadding:m?`${w}px ${I}px`:0})},useStyle$m=genStyleHooks("Popover",a=>{const{colorBgElevated:c,colorText:u}=a,d=merge$2(a,{popoverBg:c,popoverColor:u});return[genBaseStyle$4(d),genColorStyle(d),initZoomMotion(d,"zoom-big")]},prepareComponentToken$h,{resetStyle:!1,deprecatedTokens:[["width","titleMinWidth"],["minWidth","titleMinWidth"]]});var __rest$M=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Overlay$2=a=>{let{title:c,content:u,prefixCls:d}=a;return!c&&!u?null:reactExports.createElement(reactExports.Fragment,null,c&&reactExports.createElement("div",{className:`${d}-title`},c),u&&reactExports.createElement("div",{className:`${d}-inner-content`},u))},RawPurePanel=a=>{const{hashId:c,prefixCls:u,className:d,style:f,placement:m="top",title:g,content:y,children:b}=a,E=getRenderPropValue(g),C=getRenderPropValue(y),w=classNames(c,u,`${u}-pure`,`${u}-placement-${m}`,d);return reactExports.createElement("div",{className:w,style:f},reactExports.createElement("div",{className:`${u}-arrow`}),reactExports.createElement(Popup,Object.assign({},a,{className:c,prefixCls:u}),b||reactExports.createElement(Overlay$2,{prefixCls:u,title:E,content:C})))},PurePanel$2=a=>{const{prefixCls:c,className:u}=a,d=__rest$M(a,["prefixCls","className"]),{getPrefixCls:f}=reactExports.useContext(ConfigContext),m=f("popover",c),[g,y,b]=useStyle$m(m);return g(reactExports.createElement(RawPurePanel,Object.assign({},d,{prefixCls:m,hashId:y,className:classNames(u,b)})))};var __rest$L=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalPopover=reactExports.forwardRef((a,c)=>{var u,d;const{prefixCls:f,title:m,content:g,overlayClassName:y,placement:b="top",trigger:E="hover",children:C,mouseEnterDelay:w=.1,mouseLeaveDelay:R=.1,onOpenChange:_,overlayStyle:M={},styles:I,classNames:N}=a,A=__rest$L(a,["prefixCls","title","content","overlayClassName","placement","trigger","children","mouseEnterDelay","mouseLeaveDelay","onOpenChange","overlayStyle","styles","classNames"]),{getPrefixCls:P,className:z,style:B,classNames:j,styles:L}=useComponentConfig("popover"),U=P("popover",f),[q,F,K]=useStyle$m(U),X=P(),Q=classNames(y,F,K,z,j.root,N==null?void 0:N.root),Y=classNames(j.body,N==null?void 0:N.body),[Z,J]=useMergedState(!1,{value:(u=a.open)!==null&&u!==void 0?u:a.visible,defaultValue:(d=a.defaultOpen)!==null&&d!==void 0?d:a.defaultVisible}),W=(ne,le)=>{J(ne,!0),_==null||_(ne,le)},G=ne=>{ne.keyCode===KeyCode.ESC&&W(!1,ne)},te=ne=>{W(ne)},ae=getRenderPropValue(m),V=getRenderPropValue(g);return q(reactExports.createElement(Tooltip,Object.assign({placement:b,trigger:E,mouseEnterDelay:w,mouseLeaveDelay:R},A,{prefixCls:U,classNames:{root:Q,body:Y},styles:{root:Object.assign(Object.assign(Object.assign(Object.assign({},L.root),B),M),I==null?void 0:I.root),body:Object.assign(Object.assign({},L.body),I==null?void 0:I.body)},ref:c,open:Z,onOpenChange:te,overlay:ae||V?reactExports.createElement(Overlay$2,{prefixCls:U,title:ae,content:V}):null,transitionName:getTransitionName(X,"zoom-big",A.transitionName),"data-popover-inject":!0}),cloneElement(C,{onKeyDown:ne=>{var le,ee;reactExports.isValidElement(C)&&((ee=C==null?void 0:(le=C.props).onKeyDown)===null||ee===void 0||ee.call(le,ne)),G(ne)}})))}),Popover=InternalPopover;Popover._InternalPanelDoNotUseOrYouWillBeFired=PurePanel$2;var ESC$1=KeyCode.ESC,TAB=KeyCode.TAB;function useAccessibility$1(a){var c=a.visible,u=a.triggerRef,d=a.onVisibleChange,f=a.autoFocus,m=a.overlayRef,g=reactExports.useRef(!1),y=function(){if(c){var w,R;(w=u.current)===null||w===void 0||(R=w.focus)===null||R===void 0||R.call(w),d==null||d(!1)}},b=function(){var w;return(w=m.current)!==null&&w!==void 0&&w.focus?(m.current.focus(),g.current=!0,!0):!1},E=function(w){switch(w.keyCode){case ESC$1:y();break;case TAB:{var R=!1;g.current||(R=b()),R?w.preventDefault():y();break}}};reactExports.useEffect(function(){return c?(window.addEventListener("keydown",E),f&&wrapperRaf(b,3),function(){window.removeEventListener("keydown",E),g.current=!1}):function(){g.current=!1}},[c])}var Overlay$1=reactExports.forwardRef(function(a,c){var u=a.overlay,d=a.arrow,f=a.prefixCls,m=reactExports.useMemo(function(){var y;return typeof u=="function"?y=u():y=u,y},[u]),g=composeRef(c,getNodeRef(m));return React.createElement(React.Fragment,null,d&&React.createElement("div",{className:"".concat(f,"-arrow")}),React.cloneElement(m,{ref:supportRef(m)?g:void 0}))}),autoAdjustOverflow$1={adjustX:1,adjustY:1},targetOffset=[0,0],placements$1={topLeft:{points:["bl","tl"],overflow:autoAdjustOverflow$1,offset:[0,-4],targetOffset},top:{points:["bc","tc"],overflow:autoAdjustOverflow$1,offset:[0,-4],targetOffset},topRight:{points:["br","tr"],overflow:autoAdjustOverflow$1,offset:[0,-4],targetOffset},bottomLeft:{points:["tl","bl"],overflow:autoAdjustOverflow$1,offset:[0,4],targetOffset},bottom:{points:["tc","bc"],overflow:autoAdjustOverflow$1,offset:[0,4],targetOffset},bottomRight:{points:["tr","br"],overflow:autoAdjustOverflow$1,offset:[0,4],targetOffset}},_excluded$u=["arrow","prefixCls","transitionName","animation","align","placement","placements","getPopupContainer","showAction","hideAction","overlayClassName","overlayStyle","visible","trigger","autoFocus","overlay","children","onVisibleChange"];function Dropdown$2(a,c){var u,d=a.arrow,f=d===void 0?!1:d,m=a.prefixCls,g=m===void 0?"rc-dropdown":m,y=a.transitionName,b=a.animation,E=a.align,C=a.placement,w=C===void 0?"bottomLeft":C,R=a.placements,_=R===void 0?placements$1:R,M=a.getPopupContainer,I=a.showAction,N=a.hideAction,A=a.overlayClassName,P=a.overlayStyle,z=a.visible,B=a.trigger,j=B===void 0?["hover"]:B,L=a.autoFocus,U=a.overlay,q=a.children,F=a.onVisibleChange,K=_objectWithoutProperties(a,_excluded$u),X=React.useState(),Q=_slicedToArray(X,2),Y=Q[0],Z=Q[1],J="visible"in a?z:Y,W=React.useRef(null),G=React.useRef(null),te=React.useRef(null);React.useImperativeHandle(c,function(){return W.current});var ae=function(de){Z(de),F==null||F(de)};useAccessibility$1({visible:J,triggerRef:te,onVisibleChange:ae,autoFocus:L,overlayRef:G});var V=function(de){var ge=a.onOverlayClick;Z(!1),ge&&ge(de)},ne=function(){return React.createElement(Overlay$1,{ref:G,overlay:U,prefixCls:g,arrow:f})},le=function(){return typeof U=="function"?ne:ne()},ee=function(){var de=a.minOverlayWidthMatchTrigger,ge=a.alignPoint;return"minOverlayWidthMatchTrigger"in a?de:!ge},ie=function(){var de=a.openClassName;return de!==void 0?de:"".concat(g,"-open")},ce=React.cloneElement(q,{className:classNames((u=q.props)===null||u===void 0?void 0:u.className,J&&ie()),ref:supportRef(q)?composeRef(te,getNodeRef(q)):void 0}),ue=N;return!ue&&j.indexOf("contextMenu")!==-1&&(ue=["click"]),React.createElement(Trigger,_extends({builtinPlacements:_},K,{prefixCls:g,ref:W,popupClassName:classNames(A,_defineProperty({},"".concat(g,"-show-arrow"),f)),popupStyle:P,action:j,showAction:I,hideAction:ue,popupPlacement:w,popupAlign:E,popupTransitionName:y,popupAnimation:b,popupVisible:J,stretch:ee()?"minWidth":"",popup:le(),onPopupVisibleChange:ae,onPopupClick:V,getPopupContainer:M}),ce)}const Dropdown$3=React.forwardRef(Dropdown$2),isPrimitive=a=>typeof a!="object"&&typeof a!="function"||a===null;var IdContext=reactExports.createContext(null);function getMenuId(a,c){return a===void 0?null:"".concat(a,"-").concat(c)}function useMenuId(a){var c=reactExports.useContext(IdContext);return getMenuId(c,a)}var _excluded$t=["children","locked"],MenuContext$1=reactExports.createContext(null);function mergeProps(a,c){var u=_objectSpread2({},a);return Object.keys(c).forEach(function(d){var f=c[d];f!==void 0&&(u[d]=f)}),u}function InheritableContextProvider(a){var c=a.children,u=a.locked,d=_objectWithoutProperties(a,_excluded$t),f=reactExports.useContext(MenuContext$1),m=useMemo(function(){return mergeProps(f,d)},[f,d],function(g,y){return!u&&(g[0]!==y[0]||!isEqual(g[1],y[1],!0))});return reactExports.createElement(MenuContext$1.Provider,{value:m},c)}var EmptyList=[],PathRegisterContext=reactExports.createContext(null);function useMeasure(){return reactExports.useContext(PathRegisterContext)}var PathTrackerContext=reactExports.createContext(EmptyList);function useFullPath(a){var c=reactExports.useContext(PathTrackerContext);return reactExports.useMemo(function(){return a!==void 0?[].concat(_toConsumableArray(c),[a]):c},[c,a])}var PathUserContext=reactExports.createContext(null),PrivateContext=reactExports.createContext({});function focusable(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;if(isVisible(a)){var u=a.nodeName.toLowerCase(),d=["input","select","textarea","button"].includes(u)||a.isContentEditable||u==="a"&&!!a.getAttribute("href"),f=a.getAttribute("tabindex"),m=Number(f),g=null;return f&&!Number.isNaN(m)?g=m:d&&g===null&&(g=0),d&&a.disabled&&(g=null),g!==null&&(g>=0||c&&g<0)}return!1}function getFocusNodeList(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,u=_toConsumableArray(a.querySelectorAll("*")).filter(function(d){return focusable(d,c)});return focusable(a,c)&&u.unshift(a),u}var LEFT=KeyCode.LEFT,RIGHT=KeyCode.RIGHT,UP=KeyCode.UP,DOWN=KeyCode.DOWN,ENTER=KeyCode.ENTER,ESC=KeyCode.ESC,HOME=KeyCode.HOME,END=KeyCode.END,ArrowKeys=[UP,DOWN,LEFT,RIGHT];function getOffset$2(a,c,u,d){var f,m="prev",g="next",y="children",b="parent";if(a==="inline"&&d===ENTER)return{inlineTrigger:!0};var E=_defineProperty(_defineProperty({},UP,m),DOWN,g),C=_defineProperty(_defineProperty(_defineProperty(_defineProperty({},LEFT,u?g:m),RIGHT,u?m:g),DOWN,y),ENTER,y),w=_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},UP,m),DOWN,g),ENTER,y),ESC,b),LEFT,u?y:b),RIGHT,u?b:y),R={inline:E,horizontal:C,vertical:w,inlineSub:E,horizontalSub:w,verticalSub:w},_=(f=R["".concat(a).concat(c?"":"Sub")])===null||f===void 0?void 0:f[d];switch(_){case m:return{offset:-1,sibling:!0};case g:return{offset:1,sibling:!0};case b:return{offset:-1,sibling:!1};case y:return{offset:1,sibling:!1};default:return null}}function findContainerUL(a){for(var c=a;c;){if(c.getAttribute("data-menu-list"))return c;c=c.parentElement}return null}function getFocusElement(a,c){for(var u=a||document.activeElement;u;){if(c.has(u))return u;u=u.parentElement}return null}function getFocusableElements(a,c){var u=getFocusNodeList(a,!0);return u.filter(function(d){return c.has(d)})}function getNextFocusElement(a,c,u){var d=arguments.length>3&&arguments[3]!==void 0?arguments[3]:1;if(!a)return null;var f=getFocusableElements(a,c),m=f.length,g=f.findIndex(function(y){return u===y});return d<0?g===-1?g=m-1:g-=1:d>0&&(g+=1),g=(g+m)%m,f[g]}var refreshElements=function(c,u){var d=new Set,f=new Map,m=new Map;return c.forEach(function(g){var y=document.querySelector("[data-menu-id='".concat(getMenuId(u,g),"']"));y&&(d.add(y),m.set(y,g),f.set(g,y))}),{elements:d,key2element:f,element2key:m}};function useAccessibility(a,c,u,d,f,m,g,y,b,E){var C=reactExports.useRef(),w=reactExports.useRef();w.current=c;var R=function(){wrapperRaf.cancel(C.current)};return reactExports.useEffect(function(){return function(){R()}},[]),function(_){var M=_.which;if([].concat(ArrowKeys,[ENTER,ESC,HOME,END]).includes(M)){var I=m(),N=refreshElements(I,d),A=N,P=A.elements,z=A.key2element,B=A.element2key,j=z.get(c),L=getFocusElement(j,P),U=B.get(L),q=getOffset$2(a,g(U,!0).length===1,u,M);if(!q&&M!==HOME&&M!==END)return;(ArrowKeys.includes(M)||[HOME,END].includes(M))&&_.preventDefault();var F=function(G){if(G){var te=G,ae=G.querySelector("a");ae!=null&&ae.getAttribute("href")&&(te=ae);var V=B.get(G);y(V),R(),C.current=wrapperRaf(function(){w.current===V&&te.focus()})}};if([HOME,END].includes(M)||q.sibling||!L){var K;!L||a==="inline"?K=f.current:K=findContainerUL(L);var X,Q=getFocusableElements(K,P);M===HOME?X=Q[0]:M===END?X=Q[Q.length-1]:X=getNextFocusElement(K,P,L,q.offset),F(X)}else if(q.inlineTrigger)b(U);else if(q.offset>0)b(U,!0),R(),C.current=wrapperRaf(function(){N=refreshElements(I,d);var W=L.getAttribute("aria-controls"),G=document.getElementById(W),te=getNextFocusElement(G,N.elements);F(te)},5);else if(q.offset<0){var Y=g(U,!0),Z=Y[Y.length-2],J=z.get(Z);b(Z,!1),F(J)}}E==null||E(_)}}function nextSlice(a){Promise.resolve().then(a)}var PATH_SPLIT="__RC_UTIL_PATH_SPLIT__",getPathStr=function(c){return c.join(PATH_SPLIT)},getPathKeys=function(c){return c.split(PATH_SPLIT)},OVERFLOW_KEY="rc-menu-more";function useKeyRecords(){var a=reactExports.useState({}),c=_slicedToArray(a,2),u=c[1],d=reactExports.useRef(new Map),f=reactExports.useRef(new Map),m=reactExports.useState([]),g=_slicedToArray(m,2),y=g[0],b=g[1],E=reactExports.useRef(0),C=reactExports.useRef(!1),w=function(){C.current||u({})},R=reactExports.useCallback(function(z,B){var j=getPathStr(B);f.current.set(j,z),d.current.set(z,j),E.current+=1;var L=E.current;nextSlice(function(){L===E.current&&w()})},[]),_=reactExports.useCallback(function(z,B){var j=getPathStr(B);f.current.delete(j),d.current.delete(z)},[]),M=reactExports.useCallback(function(z){b(z)},[]),I=reactExports.useCallback(function(z,B){var j=d.current.get(z)||"",L=getPathKeys(j);return B&&y.includes(L[0])&&L.unshift(OVERFLOW_KEY),L},[y]),N=reactExports.useCallback(function(z,B){return z.filter(function(j){return j!==void 0}).some(function(j){var L=I(j,!0);return L.includes(B)})},[I]),A=function(){var B=_toConsumableArray(d.current.keys());return y.length&&B.push(OVERFLOW_KEY),B},P=reactExports.useCallback(function(z){var B="".concat(d.current.get(z)).concat(PATH_SPLIT),j=new Set;return _toConsumableArray(f.current.keys()).forEach(function(L){L.startsWith(B)&&j.add(f.current.get(L))}),j},[]);return reactExports.useEffect(function(){return function(){C.current=!0}},[]),{registerPath:R,unregisterPath:_,refreshOverflowKeys:M,isSubPathKey:N,getKeyPath:I,getKeys:A,getSubPathKeys:P}}function useMemoCallback(a){var c=reactExports.useRef(a);c.current=a;var u=reactExports.useCallback(function(){for(var d,f=arguments.length,m=new Array(f),g=0;g<f;g++)m[g]=arguments[g];return(d=c.current)===null||d===void 0?void 0:d.call.apply(d,[c].concat(m))},[]);return a?u:void 0}var uniquePrefix=Math.random().toFixed(5).toString().slice(2),internalId=0;function useUUID(a){var c=useMergedState(a,{value:a}),u=_slicedToArray(c,2),d=u[0],f=u[1];return reactExports.useEffect(function(){internalId+=1;var m="".concat(uniquePrefix,"-").concat(internalId);f("rc-menu-uuid-".concat(m))},[]),d}function useActive(a,c,u,d){var f=reactExports.useContext(MenuContext$1),m=f.activeKey,g=f.onActive,y=f.onInactive,b={active:m===a};return c||(b.onMouseEnter=function(E){u==null||u({key:a,domEvent:E}),g(a)},b.onMouseLeave=function(E){d==null||d({key:a,domEvent:E}),y(a)}),b}function useDirectionStyle(a){var c=reactExports.useContext(MenuContext$1),u=c.mode,d=c.rtl,f=c.inlineIndent;if(u!=="inline")return null;var m=a;return d?{paddingRight:m*f}:{paddingLeft:m*f}}function Icon(a){var c=a.icon,u=a.props,d=a.children,f;return c===null||c===!1?null:(typeof c=="function"?f=reactExports.createElement(c,_objectSpread2({},u)):typeof c!="boolean"&&(f=c),f||d||null)}var _excluded$s=["item"];function warnItemProp(a){var c=a.item,u=_objectWithoutProperties(a,_excluded$s);return Object.defineProperty(u,"item",{get:function(){return warningOnce$1(!1,"`info.item` is deprecated since we will move to function component that not provides React Node instance in future."),c}}),u}var _excluded$r=["title","attribute","elementRef"],_excluded2$7=["style","className","eventKey","warnKey","disabled","itemIcon","children","role","onMouseEnter","onMouseLeave","onClick","onKeyDown","onFocus"],_excluded3=["active"],LegacyMenuItem=function(a){_inherits(u,a);var c=_createSuper(u);function u(){return _classCallCheck(this,u),c.apply(this,arguments)}return _createClass(u,[{key:"render",value:function(){var f=this.props,m=f.title,g=f.attribute,y=f.elementRef,b=_objectWithoutProperties(f,_excluded$r),E=omit(b,["eventKey","popupClassName","popupOffset","onTitleClick"]);return warningOnce$1(!g,"`attribute` of Menu.Item is deprecated. Please pass attribute directly."),reactExports.createElement(ForwardOverflow.Item,_extends({},g,{title:typeof m=="string"?m:void 0},E,{ref:y}))}}]),u}(reactExports.Component),InternalMenuItem=reactExports.forwardRef(function(a,c){var u=a.style,d=a.className,f=a.eventKey;a.warnKey;var m=a.disabled,g=a.itemIcon,y=a.children,b=a.role,E=a.onMouseEnter,C=a.onMouseLeave,w=a.onClick,R=a.onKeyDown,_=a.onFocus,M=_objectWithoutProperties(a,_excluded2$7),I=useMenuId(f),N=reactExports.useContext(MenuContext$1),A=N.prefixCls,P=N.onItemClick,z=N.disabled,B=N.overflowDisabled,j=N.itemIcon,L=N.selectedKeys,U=N.onActive,q=reactExports.useContext(PrivateContext),F=q._internalRenderMenuItem,K="".concat(A,"-item"),X=reactExports.useRef(),Q=reactExports.useRef(),Y=z||m,Z=useComposeRef(c,Q),J=useFullPath(f),W=function(ge){return{key:f,keyPath:_toConsumableArray(J).reverse(),item:X.current,domEvent:ge}},G=g||j,te=useActive(f,Y,E,C),ae=te.active,V=_objectWithoutProperties(te,_excluded3),ne=L.includes(f),le=useDirectionStyle(J.length),ee=function(ge){if(!Y){var Ce=W(ge);w==null||w(warnItemProp(Ce)),P(Ce)}},ie=function(ge){if(R==null||R(ge),ge.which===KeyCode.ENTER){var Ce=W(ge);w==null||w(warnItemProp(Ce)),P(Ce)}},ce=function(ge){U(f),_==null||_(ge)},ue={};a.role==="option"&&(ue["aria-selected"]=ne);var me=reactExports.createElement(LegacyMenuItem,_extends({ref:X,elementRef:Z,role:b===null?"none":b||"menuitem",tabIndex:m?null:-1,"data-menu-id":B&&I?null:I},omit(M,["extra"]),V,ue,{component:"li","aria-disabled":m,style:_objectSpread2(_objectSpread2({},le),u),className:classNames(K,_defineProperty(_defineProperty(_defineProperty({},"".concat(K,"-active"),ae),"".concat(K,"-selected"),ne),"".concat(K,"-disabled"),Y),d),onClick:ee,onKeyDown:ie,onFocus:ce}),y,reactExports.createElement(Icon,{props:_objectSpread2(_objectSpread2({},a),{},{isSelected:ne}),icon:G}));return F&&(me=F(me,a,{selected:ne})),me});function MenuItem$1(a,c){var u=a.eventKey,d=useMeasure(),f=useFullPath(u);return reactExports.useEffect(function(){if(d)return d.registerPath(u,f),function(){d.unregisterPath(u,f)}},[f]),d?null:reactExports.createElement(InternalMenuItem,_extends({},a,{ref:c}))}const MenuItem$2=reactExports.forwardRef(MenuItem$1);var _excluded$q=["className","children"],InternalSubMenuList=function(c,u){var d=c.className,f=c.children,m=_objectWithoutProperties(c,_excluded$q),g=reactExports.useContext(MenuContext$1),y=g.prefixCls,b=g.mode,E=g.rtl;return reactExports.createElement("ul",_extends({className:classNames(y,E&&"".concat(y,"-rtl"),"".concat(y,"-sub"),"".concat(y,"-").concat(b==="inline"?"inline":"vertical"),d),role:"menu"},m,{"data-menu-list":!0,ref:u}),f)},SubMenuList=reactExports.forwardRef(InternalSubMenuList);SubMenuList.displayName="SubMenuList";function parseChildren(a,c){return toArray$6(a).map(function(u,d){if(reactExports.isValidElement(u)){var f,m,g=u.key,y=(f=(m=u.props)===null||m===void 0?void 0:m.eventKey)!==null&&f!==void 0?f:g,b=y==null;b&&(y="tmp_key-".concat([].concat(_toConsumableArray(c),[d]).join("-")));var E={key:y,eventKey:y};return reactExports.cloneElement(u,E)}return u})}var autoAdjustOverflow={adjustX:1,adjustY:1},placements={topLeft:{points:["bl","tl"],overflow:autoAdjustOverflow},topRight:{points:["br","tr"],overflow:autoAdjustOverflow},bottomLeft:{points:["tl","bl"],overflow:autoAdjustOverflow},bottomRight:{points:["tr","br"],overflow:autoAdjustOverflow},leftTop:{points:["tr","tl"],overflow:autoAdjustOverflow},leftBottom:{points:["br","bl"],overflow:autoAdjustOverflow},rightTop:{points:["tl","tr"],overflow:autoAdjustOverflow},rightBottom:{points:["bl","br"],overflow:autoAdjustOverflow}},placementsRtl={topLeft:{points:["bl","tl"],overflow:autoAdjustOverflow},topRight:{points:["br","tr"],overflow:autoAdjustOverflow},bottomLeft:{points:["tl","bl"],overflow:autoAdjustOverflow},bottomRight:{points:["tr","br"],overflow:autoAdjustOverflow},rightTop:{points:["tr","tl"],overflow:autoAdjustOverflow},rightBottom:{points:["br","bl"],overflow:autoAdjustOverflow},leftTop:{points:["tl","tr"],overflow:autoAdjustOverflow},leftBottom:{points:["bl","br"],overflow:autoAdjustOverflow}};function getMotion(a,c,u){if(c)return c;if(u)return u[a]||u.other}var popupPlacementMap={horizontal:"bottomLeft",vertical:"rightTop","vertical-left":"rightTop","vertical-right":"leftTop"};function PopupTrigger(a){var c=a.prefixCls,u=a.visible,d=a.children,f=a.popup,m=a.popupStyle,g=a.popupClassName,y=a.popupOffset,b=a.disabled,E=a.mode,C=a.onVisibleChange,w=reactExports.useContext(MenuContext$1),R=w.getPopupContainer,_=w.rtl,M=w.subMenuOpenDelay,I=w.subMenuCloseDelay,N=w.builtinPlacements,A=w.triggerSubMenuAction,P=w.forceSubMenuRender,z=w.rootClassName,B=w.motion,j=w.defaultMotions,L=reactExports.useState(!1),U=_slicedToArray(L,2),q=U[0],F=U[1],K=_objectSpread2(_?_objectSpread2({},placementsRtl):_objectSpread2({},placements),N),X=popupPlacementMap[E],Q=getMotion(E,B,j),Y=reactExports.useRef(Q);E!=="inline"&&(Y.current=Q);var Z=_objectSpread2(_objectSpread2({},Y.current),{},{leavedClassName:"".concat(c,"-hidden"),removeOnLeave:!1,motionAppear:!0}),J=reactExports.useRef();return reactExports.useEffect(function(){return J.current=wrapperRaf(function(){F(u)}),function(){wrapperRaf.cancel(J.current)}},[u]),reactExports.createElement(Trigger,{prefixCls:c,popupClassName:classNames("".concat(c,"-popup"),_defineProperty({},"".concat(c,"-rtl"),_),g,z),stretch:E==="horizontal"?"minWidth":null,getPopupContainer:R,builtinPlacements:K,popupPlacement:X,popupVisible:q,popup:f,popupStyle:m,popupAlign:y&&{offset:y},action:b?[]:[A],mouseEnterDelay:M,mouseLeaveDelay:I,onPopupVisibleChange:C,forceRender:P,popupMotion:Z,fresh:!0},d)}function InlineSubMenuList(a){var c=a.id,u=a.open,d=a.keyPath,f=a.children,m="inline",g=reactExports.useContext(MenuContext$1),y=g.prefixCls,b=g.forceSubMenuRender,E=g.motion,C=g.defaultMotions,w=g.mode,R=reactExports.useRef(!1);R.current=w===m;var _=reactExports.useState(!R.current),M=_slicedToArray(_,2),I=M[0],N=M[1],A=R.current?u:!1;reactExports.useEffect(function(){R.current&&N(!1)},[w]);var P=_objectSpread2({},getMotion(m,E,C));d.length>1&&(P.motionAppear=!1);var z=P.onVisibleChanged;return P.onVisibleChanged=function(B){return!R.current&&!B&&N(!0),z==null?void 0:z(B)},I?null:reactExports.createElement(InheritableContextProvider,{mode:m,locked:!R.current},reactExports.createElement(CSSMotion,_extends({visible:A},P,{forceRender:b,removeOnLeave:!1,leavedClassName:"".concat(y,"-hidden")}),function(B){var j=B.className,L=B.style;return reactExports.createElement(SubMenuList,{id:c,className:j,style:L},f)}))}var _excluded$p=["style","className","title","eventKey","warnKey","disabled","internalPopupClose","children","itemIcon","expandIcon","popupClassName","popupOffset","popupStyle","onClick","onMouseEnter","onMouseLeave","onTitleClick","onTitleMouseEnter","onTitleMouseLeave"],_excluded2$6=["active"],InternalSubMenu=reactExports.forwardRef(function(a,c){var u=a.style,d=a.className,f=a.title,m=a.eventKey;a.warnKey;var g=a.disabled,y=a.internalPopupClose,b=a.children,E=a.itemIcon,C=a.expandIcon,w=a.popupClassName,R=a.popupOffset,_=a.popupStyle,M=a.onClick,I=a.onMouseEnter,N=a.onMouseLeave,A=a.onTitleClick,P=a.onTitleMouseEnter,z=a.onTitleMouseLeave,B=_objectWithoutProperties(a,_excluded$p),j=useMenuId(m),L=reactExports.useContext(MenuContext$1),U=L.prefixCls,q=L.mode,F=L.openKeys,K=L.disabled,X=L.overflowDisabled,Q=L.activeKey,Y=L.selectedKeys,Z=L.itemIcon,J=L.expandIcon,W=L.onItemClick,G=L.onOpenChange,te=L.onActive,ae=reactExports.useContext(PrivateContext),V=ae._internalRenderSubMenuItem,ne=reactExports.useContext(PathUserContext),le=ne.isSubPathKey,ee=useFullPath(),ie="".concat(U,"-submenu"),ce=K||g,ue=reactExports.useRef(),me=reactExports.useRef(),de=E??Z,ge=C??J,Ce=F.includes(m),ve=!X&&Ce,fe=le(Y,m),pe=useActive(m,ce,P,z),xe=pe.active,ye=_objectWithoutProperties(pe,_excluded2$6),he=reactExports.useState(!1),we=_slicedToArray(he,2),Re=we[0],De=we[1],Ae=function(je){ce||De(je)},Ee=function(je){Ae(!0),I==null||I({key:m,domEvent:je})},Ne=function(je){Ae(!1),N==null||N({key:m,domEvent:je})},_e=reactExports.useMemo(function(){return xe||(q!=="inline"?Re||le([Q],m):!1)},[q,xe,Q,Re,m,le]),ke=useDirectionStyle(ee.length),Ke=function(je){ce||(A==null||A({key:m,domEvent:je}),q==="inline"&&G(m,!Ce))},be=useMemoCallback(function(Ue){M==null||M(warnItemProp(Ue)),W(Ue)}),Te=function(je){q!=="inline"&&G(m,je)},Le=function(){te(m)},Oe=j&&"".concat(j,"-popup"),Be=reactExports.useMemo(function(){return reactExports.createElement(Icon,{icon:q!=="horizontal"?ge:void 0,props:_objectSpread2(_objectSpread2({},a),{},{isOpen:ve,isSubMenu:!0})},reactExports.createElement("i",{className:"".concat(ie,"-arrow")}))},[q,ge,a,ve,ie]),Ve=reactExports.createElement("div",_extends({role:"menuitem",style:ke,className:"".concat(ie,"-title"),tabIndex:ce?null:-1,ref:ue,title:typeof f=="string"?f:null,"data-menu-id":X&&j?null:j,"aria-expanded":ve,"aria-haspopup":!0,"aria-controls":Oe,"aria-disabled":ce,onClick:Ke,onFocus:Le},ye),f,Be),Pe=reactExports.useRef(q);if(q!=="inline"&&ee.length>1?Pe.current="vertical":Pe.current=q,!X){var Ge=Pe.current;Ve=reactExports.createElement(PopupTrigger,{mode:Ge,prefixCls:ie,visible:!y&&ve&&q!=="inline",popupClassName:w,popupOffset:R,popupStyle:_,popup:reactExports.createElement(InheritableContextProvider,{mode:Ge==="horizontal"?"vertical":Ge},reactExports.createElement(SubMenuList,{id:Oe,ref:me},b)),disabled:ce,onVisibleChange:Te},Ve)}var qe=reactExports.createElement(ForwardOverflow.Item,_extends({ref:c,role:"none"},B,{component:"li",style:u,className:classNames(ie,"".concat(ie,"-").concat(q),d,_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(ie,"-open"),ve),"".concat(ie,"-active"),_e),"".concat(ie,"-selected"),fe),"".concat(ie,"-disabled"),ce)),onMouseEnter:Ee,onMouseLeave:Ne}),Ve,!X&&reactExports.createElement(InlineSubMenuList,{id:Oe,open:ve,keyPath:ee},b));return V&&(qe=V(qe,a,{selected:fe,active:_e,open:ve,disabled:ce})),reactExports.createElement(InheritableContextProvider,{onItemClick:be,mode:q==="horizontal"?"vertical":q,itemIcon:de,expandIcon:ge},qe)}),SubMenu$1=reactExports.forwardRef(function(a,c){var u=a.eventKey,d=a.children,f=useFullPath(u),m=parseChildren(d,f),g=useMeasure();reactExports.useEffect(function(){if(g)return g.registerPath(u,f),function(){g.unregisterPath(u,f)}},[f]);var y;return g?y=m:y=reactExports.createElement(InternalSubMenu,_extends({ref:c},a),m),reactExports.createElement(PathTrackerContext.Provider,{value:f},y)});function Divider(a){var c=a.className,u=a.style,d=reactExports.useContext(MenuContext$1),f=d.prefixCls,m=useMeasure();return m?null:reactExports.createElement("li",{role:"separator",className:classNames("".concat(f,"-item-divider"),c),style:u})}var _excluded$o=["className","title","eventKey","children"],InternalMenuItemGroup=reactExports.forwardRef(function(a,c){var u=a.className,d=a.title;a.eventKey;var f=a.children,m=_objectWithoutProperties(a,_excluded$o),g=reactExports.useContext(MenuContext$1),y=g.prefixCls,b="".concat(y,"-item-group");return reactExports.createElement("li",_extends({ref:c,role:"presentation"},m,{onClick:function(C){return C.stopPropagation()},className:classNames(b,u)}),reactExports.createElement("div",{role:"presentation",className:"".concat(b,"-title"),title:typeof d=="string"?d:void 0},d),reactExports.createElement("ul",{role:"group",className:"".concat(b,"-list")},f))}),MenuItemGroup=reactExports.forwardRef(function(a,c){var u=a.eventKey,d=a.children,f=useFullPath(u),m=parseChildren(d,f),g=useMeasure();return g?m:reactExports.createElement(InternalMenuItemGroup,_extends({ref:c},omit(a,["warnKey"])),m)}),_excluded$n=["label","children","key","type","extra"];function convertItemsToNodes(a,c,u){var d=c.item,f=c.group,m=c.submenu,g=c.divider;return(a||[]).map(function(y,b){if(y&&_typeof(y)==="object"){var E=y,C=E.label,w=E.children,R=E.key,_=E.type,M=E.extra,I=_objectWithoutProperties(E,_excluded$n),N=R??"tmp-".concat(b);return w||_==="group"?_==="group"?reactExports.createElement(f,_extends({key:N},I,{title:C}),convertItemsToNodes(w,c,u)):reactExports.createElement(m,_extends({key:N},I,{title:C}),convertItemsToNodes(w,c,u)):_==="divider"?reactExports.createElement(g,_extends({key:N},I)):reactExports.createElement(d,_extends({key:N},I,{extra:M}),C,(!!M||M===0)&&reactExports.createElement("span",{className:"".concat(u,"-item-extra")},M))}return null}).filter(function(y){return y})}function parseItems(a,c,u,d,f){var m=a,g=_objectSpread2({divider:Divider,item:MenuItem$2,group:MenuItemGroup,submenu:SubMenu$1},d);return c&&(m=convertItemsToNodes(c,g,f)),parseChildren(m,u)}var _excluded$m=["prefixCls","rootClassName","style","className","tabIndex","items","children","direction","id","mode","inlineCollapsed","disabled","disabledOverflow","subMenuOpenDelay","subMenuCloseDelay","forceSubMenuRender","defaultOpenKeys","openKeys","activeKey","defaultActiveFirst","selectable","multiple","defaultSelectedKeys","selectedKeys","onSelect","onDeselect","inlineIndent","motion","defaultMotions","triggerSubMenuAction","builtinPlacements","itemIcon","expandIcon","overflowedIndicator","overflowedIndicatorPopupClassName","getPopupContainer","onClick","onOpenChange","onKeyDown","openAnimation","openTransitionName","_internalRenderMenuItem","_internalRenderSubMenuItem","_internalComponents"],EMPTY_LIST$3=[],Menu$1=reactExports.forwardRef(function(a,c){var u,d=a,f=d.prefixCls,m=f===void 0?"rc-menu":f,g=d.rootClassName,y=d.style,b=d.className,E=d.tabIndex,C=E===void 0?0:E,w=d.items,R=d.children,_=d.direction,M=d.id,I=d.mode,N=I===void 0?"vertical":I,A=d.inlineCollapsed,P=d.disabled,z=d.disabledOverflow,B=d.subMenuOpenDelay,j=B===void 0?.1:B,L=d.subMenuCloseDelay,U=L===void 0?.1:L,q=d.forceSubMenuRender,F=d.defaultOpenKeys,K=d.openKeys,X=d.activeKey,Q=d.defaultActiveFirst,Y=d.selectable,Z=Y===void 0?!0:Y,J=d.multiple,W=J===void 0?!1:J,G=d.defaultSelectedKeys,te=d.selectedKeys,ae=d.onSelect,V=d.onDeselect,ne=d.inlineIndent,le=ne===void 0?24:ne,ee=d.motion,ie=d.defaultMotions,ce=d.triggerSubMenuAction,ue=ce===void 0?"hover":ce,me=d.builtinPlacements,de=d.itemIcon,ge=d.expandIcon,Ce=d.overflowedIndicator,ve=Ce===void 0?"...":Ce,fe=d.overflowedIndicatorPopupClassName,pe=d.getPopupContainer,xe=d.onClick,ye=d.onOpenChange,he=d.onKeyDown;d.openAnimation,d.openTransitionName;var we=d._internalRenderMenuItem,Re=d._internalRenderSubMenuItem,De=d._internalComponents,Ae=_objectWithoutProperties(d,_excluded$m),Ee=reactExports.useMemo(function(){return[parseItems(R,w,EMPTY_LIST$3,De,m),parseItems(R,w,EMPTY_LIST$3,{},m)]},[R,w,De]),Ne=_slicedToArray(Ee,2),_e=Ne[0],ke=Ne[1],Ke=reactExports.useState(!1),be=_slicedToArray(Ke,2),Te=be[0],Le=be[1],Oe=reactExports.useRef(),Be=useUUID(M),Ve=_==="rtl",Pe=useMergedState(F,{value:K,postState:function(wt){return wt||EMPTY_LIST$3}}),Ge=_slicedToArray(Pe,2),qe=Ge[0],Ue=Ge[1],je=function(wt){var st=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1;function Xt(){Ue(wt),ye==null||ye(wt)}st?reactDomExports.flushSync(Xt):Xt()},We=reactExports.useState(qe),ut=_slicedToArray(We,2),gt=ut[0],kt=ut[1],Ut=reactExports.useRef(!1),at=reactExports.useMemo(function(){return(N==="inline"||N==="vertical")&&A?["vertical",A]:[N,!1]},[N,A]),ct=_slicedToArray(at,2),bt=ct[0],it=ct[1],vt=bt==="inline",ot=reactExports.useState(bt),rt=_slicedToArray(ot,2),et=rt[0],$t=rt[1],mt=reactExports.useState(it),Ze=_slicedToArray(mt,2),Je=Ze[0],yt=Ze[1];reactExports.useEffect(function(){$t(bt),yt(it),Ut.current&&(vt?Ue(gt):je(EMPTY_LIST$3))},[bt,it]);var Ct=reactExports.useState(0),pt=_slicedToArray(Ct,2),Rt=pt[0],ft=pt[1],dt=Rt>=_e.length-1||et!=="horizontal"||z;reactExports.useEffect(function(){vt&&kt(qe)},[qe]),reactExports.useEffect(function(){return Ut.current=!0,function(){Ut.current=!1}},[]);var xt=useKeyRecords(),Tt=xt.registerPath,Dt=xt.unregisterPath,Vt=xt.refreshOverflowKeys,Nt=xt.isSubPathKey,Kt=xt.getKeyPath,Zt=xt.getKeys,Gt=xt.getSubPathKeys,tt=reactExports.useMemo(function(){return{registerPath:Tt,unregisterPath:Dt}},[Tt,Dt]),ht=reactExports.useMemo(function(){return{isSubPathKey:Nt}},[Nt]);reactExports.useEffect(function(){Vt(dt?EMPTY_LIST$3:_e.slice(Rt+1).map(function(Wt){return Wt.key}))},[Rt,dt]);var lt=useMergedState(X||Q&&((u=_e[0])===null||u===void 0?void 0:u.key),{value:X}),nt=_slicedToArray(lt,2),Ot=nt[0],Bt=nt[1],qt=useMemoCallback(function(Wt){Bt(Wt)}),er=useMemoCallback(function(){Bt(void 0)});reactExports.useImperativeHandle(c,function(){return{list:Oe.current,focus:function(wt){var st,Xt=Zt(),Qt=refreshElements(Xt,Be),or=Qt.elements,ar=Qt.key2element,Ir=Qt.element2key,_r=getFocusableElements(Oe.current,or),Sr=Ot??(_r[0]?Ir.get(_r[0]):(st=_e.find(function(Pt){return!Pt.props.disabled}))===null||st===void 0?void 0:st.key),kr=ar.get(Sr);if(Sr&&kr){var jr;kr==null||(jr=kr.focus)===null||jr===void 0||jr.call(kr,wt)}}}});var St=useMergedState(G||[],{value:te,postState:function(wt){return Array.isArray(wt)?wt:wt==null?EMPTY_LIST$3:[wt]}}),_t=_slicedToArray(St,2),zt=_t[0],nr=_t[1],Rr=function(wt){if(Z){var st=wt.key,Xt=zt.includes(st),Qt;W?Xt?Qt=zt.filter(function(ar){return ar!==st}):Qt=[].concat(_toConsumableArray(zt),[st]):Qt=[st],nr(Qt);var or=_objectSpread2(_objectSpread2({},wt),{},{selectedKeys:Qt});Xt?V==null||V(or):ae==null||ae(or)}!W&&qe.length&&et!=="inline"&&je(EMPTY_LIST$3)},Jr=useMemoCallback(function(Wt){xe==null||xe(warnItemProp(Wt)),Rr(Wt)}),Tr=useMemoCallback(function(Wt,wt){var st=qe.filter(function(Qt){return Qt!==Wt});if(wt)st.push(Wt);else if(et!=="inline"){var Xt=Gt(Wt);st=st.filter(function(Qt){return!Xt.has(Qt)})}isEqual(qe,st,!0)||je(st,!0)}),lr=function(wt,st){var Xt=st??!qe.includes(wt);Tr(wt,Xt)},en=useAccessibility(et,Ot,Ve,Be,Oe,Zt,Kt,Bt,lr,he);reactExports.useEffect(function(){Le(!0)},[]);var tn=reactExports.useMemo(function(){return{_internalRenderMenuItem:we,_internalRenderSubMenuItem:Re}},[we,Re]),wr=et!=="horizontal"||z?_e:_e.map(function(Wt,wt){return reactExports.createElement(InheritableContextProvider,{key:Wt.key,overflowDisabled:wt>Rt},Wt)}),rn=reactExports.createElement(ForwardOverflow,_extends({id:M,ref:Oe,prefixCls:"".concat(m,"-overflow"),component:"ul",itemComponent:MenuItem$2,className:classNames(m,"".concat(m,"-root"),"".concat(m,"-").concat(et),b,_defineProperty(_defineProperty({},"".concat(m,"-inline-collapsed"),Je),"".concat(m,"-rtl"),Ve),g),dir:_,style:y,role:"menu",tabIndex:C,data:wr,renderRawItem:function(wt){return wt},renderRawRest:function(wt){var st=wt.length,Xt=st?_e.slice(-st):null;return reactExports.createElement(SubMenu$1,{eventKey:OVERFLOW_KEY,title:ve,disabled:dt,internalPopupClose:st===0,popupClassName:fe},Xt)},maxCount:et!=="horizontal"||z?ForwardOverflow.INVALIDATE:ForwardOverflow.RESPONSIVE,ssr:"full","data-menu-list":!0,onVisibleChange:function(wt){ft(wt)},onKeyDown:en},Ae));return reactExports.createElement(PrivateContext.Provider,{value:tn},reactExports.createElement(IdContext.Provider,{value:Be},reactExports.createElement(InheritableContextProvider,{prefixCls:m,rootClassName:g,mode:et,openKeys:qe,rtl:Ve,disabled:P,motion:Te?ee:null,defaultMotions:Te?ie:null,activeKey:Ot,onActive:qt,onInactive:er,selectedKeys:zt,inlineIndent:le,subMenuOpenDelay:j,subMenuCloseDelay:U,forceSubMenuRender:q,builtinPlacements:me,triggerSubMenuAction:ue,getPopupContainer:pe,itemIcon:de,expandIcon:ge,onItemClick:Jr,onOpenChange:Tr},reactExports.createElement(PathUserContext.Provider,{value:ht},rn),reactExports.createElement("div",{style:{display:"none"},"aria-hidden":!0},reactExports.createElement(PathRegisterContext.Provider,{value:tt},ke)))))}),ExportMenu=Menu$1;ExportMenu.Item=MenuItem$2;ExportMenu.SubMenu=SubMenu$1;ExportMenu.ItemGroup=MenuItemGroup;ExportMenu.Divider=Divider;const LayoutContext=reactExports.createContext({siderHook:{addSider:()=>null,removeSider:()=>null}}),genLayoutStyle=a=>{const{antCls:c,componentCls:u,colorText:d,footerBg:f,headerHeight:m,headerPadding:g,headerColor:y,footerPadding:b,fontSize:E,bodyBg:C,headerBg:w}=a;return{[u]:{display:"flex",flex:"auto",flexDirection:"column",minHeight:0,background:C,"&, *":{boxSizing:"border-box"},[`&${u}-has-sider`]:{flexDirection:"row",[`> ${u}, > ${u}-content`]:{width:0}},[`${u}-header, &${u}-footer`]:{flex:"0 0 auto"},"&-rtl":{direction:"rtl"}},[`${u}-header`]:{height:m,padding:g,color:y,lineHeight:unit$1(m),background:w,[`${c}-menu`]:{lineHeight:"inherit"}},[`${u}-footer`]:{padding:b,color:d,fontSize:E,background:f},[`${u}-content`]:{flex:"auto",color:d,minHeight:0}}},prepareComponentToken$g=a=>{const{colorBgLayout:c,controlHeight:u,controlHeightLG:d,colorText:f,controlHeightSM:m,marginXXS:g,colorTextLightSolid:y,colorBgContainer:b}=a,E=d*1.25;return{colorBgHeader:"#001529",colorBgBody:c,colorBgTrigger:"#002140",bodyBg:c,headerBg:"#001529",headerHeight:u*2,headerPadding:`0 ${E}px`,headerColor:f,footerPadding:`${m}px ${E}px`,footerBg:c,siderBg:"#001529",triggerHeight:d+g*2,triggerBg:"#002140",triggerColor:y,zeroTriggerWidth:d,zeroTriggerHeight:d,lightSiderBg:b,lightTriggerBg:b,lightTriggerColor:f}},DEPRECATED_TOKENS=[["colorBgBody","bodyBg"],["colorBgHeader","headerBg"],["colorBgTrigger","triggerBg"]],useStyle$l=genStyleHooks("Layout",a=>[genLayoutStyle(a)],prepareComponentToken$g,{deprecatedTokens:DEPRECATED_TOKENS}),genSiderStyle=a=>{const{componentCls:c,siderBg:u,motionDurationMid:d,motionDurationSlow:f,antCls:m,triggerHeight:g,triggerColor:y,triggerBg:b,headerHeight:E,zeroTriggerWidth:C,zeroTriggerHeight:w,borderRadiusLG:R,lightSiderBg:_,lightTriggerColor:M,lightTriggerBg:I,bodyBg:N}=a;return{[c]:{position:"relative",minWidth:0,background:u,transition:`all ${d}, background 0s`,"&-has-trigger":{paddingBottom:g},"&-right":{order:1},[`${c}-children`]:{height:"100%",marginTop:-.1,paddingTop:.1,[`${m}-menu${m}-menu-inline-collapsed`]:{width:"auto"}},[`&-zero-width ${c}-children`]:{overflow:"hidden"},[`${c}-trigger`]:{position:"fixed",bottom:0,zIndex:1,height:g,color:y,lineHeight:unit$1(g),textAlign:"center",background:b,cursor:"pointer",transition:`all ${d}`},[`${c}-zero-width-trigger`]:{position:"absolute",top:E,insetInlineEnd:a.calc(C).mul(-1).equal(),zIndex:1,width:C,height:w,color:y,fontSize:a.fontSizeXL,display:"flex",alignItems:"center",justifyContent:"center",background:u,borderRadius:`0 ${unit$1(R)} ${unit$1(R)} 0`,cursor:"pointer",transition:`background ${f} ease`,"&::after":{position:"absolute",inset:0,background:"transparent",transition:`all ${f}`,content:'""'},"&:hover::after":{background:"rgba(255, 255, 255, 0.2)"},"&-right":{insetInlineStart:a.calc(C).mul(-1).equal(),borderRadius:`${unit$1(R)} 0 0 ${unit$1(R)}`}},"&-light":{background:_,[`${c}-trigger`]:{color:M,background:I},[`${c}-zero-width-trigger`]:{color:M,background:I,border:`1px solid ${N}`,borderInlineStart:0}}}}},useStyle$k=genStyleHooks(["Layout","Sider"],a=>[genSiderStyle(a)],prepareComponentToken$g,{deprecatedTokens:DEPRECATED_TOKENS});var __rest$K=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const dimensionMaxMap={xs:"479.98px",sm:"575.98px",md:"767.98px",lg:"991.98px",xl:"1199.98px",xxl:"1599.98px"},isNumeric=a=>!Number.isNaN(Number.parseFloat(a))&&isFinite(a),SiderContext=reactExports.createContext({}),generateId=(()=>{let a=0;return function(){let c=arguments.length>0&&arguments[0]!==void 0?arguments[0]:"";return a+=1,`${c}${a}`}})(),Sider$1=reactExports.forwardRef((a,c)=>{const{prefixCls:u,className:d,trigger:f,children:m,defaultCollapsed:g=!1,theme:y="dark",style:b={},collapsible:E=!1,reverseArrow:C=!1,width:w=200,collapsedWidth:R=80,zeroWidthTriggerStyle:_,breakpoint:M,onCollapse:I,onBreakpoint:N}=a,A=__rest$K(a,["prefixCls","className","trigger","children","defaultCollapsed","theme","style","collapsible","reverseArrow","width","collapsedWidth","zeroWidthTriggerStyle","breakpoint","onCollapse","onBreakpoint"]),{siderHook:P}=reactExports.useContext(LayoutContext),[z,B]=reactExports.useState("collapsed"in a?a.collapsed:g),[j,L]=reactExports.useState(!1);reactExports.useEffect(()=>{"collapsed"in a&&B(a.collapsed)},[a.collapsed]);const U=(de,ge)=>{"collapsed"in a||B(de),I==null||I(de,ge)},{getPrefixCls:q,direction:F}=reactExports.useContext(ConfigContext),K=q("layout-sider",u),[X,Q,Y]=useStyle$k(K),Z=reactExports.useRef(null);Z.current=de=>{L(de.matches),N==null||N(de.matches),z!==de.matches&&U(de.matches,"responsive")},reactExports.useEffect(()=>{function de(Ce){return Z.current(Ce)}let ge;if(typeof window<"u"){const{matchMedia:Ce}=window;if(Ce&&M&&M in dimensionMaxMap){ge=Ce(`screen and (max-width: ${dimensionMaxMap[M]})`);try{ge.addEventListener("change",de)}catch{ge.addListener(de)}de(ge)}}return()=>{try{ge==null||ge.removeEventListener("change",de)}catch{ge==null||ge.removeListener(de)}}},[M]),reactExports.useEffect(()=>{const de=generateId("ant-sider-");return P.addSider(de),()=>P.removeSider(de)},[]);const J=()=>{U(!z,"clickTrigger")},W=omit(A,["collapsed"]),G=z?R:w,te=isNumeric(G)?`${G}px`:String(G),ae=parseFloat(String(R||0))===0?reactExports.createElement("span",{onClick:J,className:classNames(`${K}-zero-width-trigger`,`${K}-zero-width-trigger-${C?"right":"left"}`),style:_},f||reactExports.createElement(RefIcon$E,null)):null,V=F==="rtl"==!C,ee={expanded:V?reactExports.createElement(RefIcon$8,null):reactExports.createElement(RefIcon$f,null),collapsed:V?reactExports.createElement(RefIcon$f,null):reactExports.createElement(RefIcon$8,null)}[z?"collapsed":"expanded"],ie=f!==null?ae||reactExports.createElement("div",{className:`${K}-trigger`,onClick:J,style:{width:te}},f||ee):null,ce=Object.assign(Object.assign({},b),{flex:`0 0 ${te}`,maxWidth:te,minWidth:te,width:te}),ue=classNames(K,`${K}-${y}`,{[`${K}-collapsed`]:!!z,[`${K}-has-trigger`]:E&&f!==null&&!ae,[`${K}-below`]:!!j,[`${K}-zero-width`]:parseFloat(te)===0},d,Q,Y),me=reactExports.useMemo(()=>({siderCollapsed:z}),[z]);return X(reactExports.createElement(SiderContext.Provider,{value:me},reactExports.createElement("aside",Object.assign({className:ue},W,{style:ce,ref:c}),reactExports.createElement("div",{className:`${K}-children`},m),E||j&&ae?ie:null)))}),MenuContext=reactExports.createContext({prefixCls:"",firstLevel:!0,inlineCollapsed:!1});var __rest$J=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const MenuDivider=a=>{const{prefixCls:c,className:u,dashed:d}=a,f=__rest$J(a,["prefixCls","className","dashed"]),{getPrefixCls:m}=reactExports.useContext(ConfigContext),g=m("menu",c),y=classNames({[`${g}-item-divider-dashed`]:!!d},u);return reactExports.createElement(Divider,Object.assign({className:y},f))},MenuItem=a=>{var c;const{className:u,children:d,icon:f,title:m,danger:g,extra:y}=a,{prefixCls:b,firstLevel:E,direction:C,disableMenuItemTitleTooltip:w,inlineCollapsed:R}=reactExports.useContext(MenuContext),_=z=>{const B=d==null?void 0:d[0],j=reactExports.createElement("span",{className:classNames(`${b}-title-content`,{[`${b}-title-content-with-extra`]:!!y||y===0})},d);return(!f||reactExports.isValidElement(d)&&d.type==="span")&&d&&z&&E&&typeof B=="string"?reactExports.createElement("div",{className:`${b}-inline-collapsed-noicon`},B.charAt(0)):j},{siderCollapsed:M}=reactExports.useContext(SiderContext);let I=m;typeof m>"u"?I=E?d:"":m===!1&&(I="");const N={title:I};!M&&!R&&(N.title=null,N.open=!1);const A=toArray$6(d).length;let P=reactExports.createElement(MenuItem$2,Object.assign({},omit(a,["title","icon","danger"]),{className:classNames({[`${b}-item-danger`]:g,[`${b}-item-only-child`]:(f?A+1:A)===1},u),title:typeof m=="string"?m:void 0}),cloneElement(f,{className:classNames(reactExports.isValidElement(f)?(c=f.props)===null||c===void 0?void 0:c.className:"",`${b}-item-icon`)}),_(R));return w||(P=reactExports.createElement(Tooltip,Object.assign({},N,{placement:C==="rtl"?"left":"right",classNames:{root:`${b}-inline-collapsed-tooltip`}}),P)),P};var __rest$I=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const OverrideContext=reactExports.createContext(null),OverrideProvider=reactExports.forwardRef((a,c)=>{const{children:u}=a,d=__rest$I(a,["children"]),f=reactExports.useContext(OverrideContext),m=reactExports.useMemo(()=>Object.assign(Object.assign({},f),d),[f,d.prefixCls,d.mode,d.selectable,d.rootClassName]),g=supportNodeRef(u),y=useComposeRef(c,g?getNodeRef(u):null);return reactExports.createElement(OverrideContext.Provider,{value:m},reactExports.createElement(ContextIsolator,{space:!0},g?reactExports.cloneElement(u,{ref:y}):u))}),getHorizontalStyle=a=>{const{componentCls:c,motionDurationSlow:u,horizontalLineHeight:d,colorSplit:f,lineWidth:m,lineType:g,itemPaddingInline:y}=a;return{[`${c}-horizontal`]:{lineHeight:d,border:0,borderBottom:`${unit$1(m)} ${g} ${f}`,boxShadow:"none","&::after":{display:"block",clear:"both",height:0,content:'"\\20"'},[`${c}-item, ${c}-submenu`]:{position:"relative",display:"inline-block",verticalAlign:"bottom",paddingInline:y},[`> ${c}-item:hover,
        > ${c}-item-active,
        > ${c}-submenu ${c}-submenu-title:hover`]:{backgroundColor:"transparent"},[`${c}-item, ${c}-submenu-title`]:{transition:[`border-color ${u}`,`background ${u}`].join(",")},[`${c}-submenu-arrow`]:{display:"none"}}}},getRTLStyle=a=>{let{componentCls:c,menuArrowOffset:u,calc:d}=a;return{[`${c}-rtl`]:{direction:"rtl"},[`${c}-submenu-rtl`]:{transformOrigin:"100% 0"},[`${c}-rtl${c}-vertical,
    ${c}-submenu-rtl ${c}-vertical`]:{[`${c}-submenu-arrow`]:{"&::before":{transform:`rotate(-45deg) translateY(${unit$1(d(u).mul(-1).equal())})`},"&::after":{transform:`rotate(45deg) translateY(${unit$1(u)})`}}}}},accessibilityFocus=a=>Object.assign({},genFocusOutline(a)),getThemeStyle=(a,c)=>{const{componentCls:u,itemColor:d,itemSelectedColor:f,subMenuItemSelectedColor:m,groupTitleColor:g,itemBg:y,subMenuItemBg:b,itemSelectedBg:E,activeBarHeight:C,activeBarWidth:w,activeBarBorderWidth:R,motionDurationSlow:_,motionEaseInOut:M,motionEaseOut:I,itemPaddingInline:N,motionDurationMid:A,itemHoverColor:P,lineType:z,colorSplit:B,itemDisabledColor:j,dangerItemColor:L,dangerItemHoverColor:U,dangerItemSelectedColor:q,dangerItemActiveBg:F,dangerItemSelectedBg:K,popupBg:X,itemHoverBg:Q,itemActiveBg:Y,menuSubMenuBg:Z,horizontalItemSelectedColor:J,horizontalItemSelectedBg:W,horizontalItemBorderRadius:G,horizontalItemHoverBg:te}=a;return{[`${u}-${c}, ${u}-${c} > ${u}`]:{color:d,background:y,[`&${u}-root:focus-visible`]:Object.assign({},accessibilityFocus(a)),[`${u}-item`]:{"&-group-title, &-extra":{color:g}},[`${u}-submenu-selected > ${u}-submenu-title`]:{color:m},[`${u}-item, ${u}-submenu-title`]:{color:d,[`&:not(${u}-item-disabled):focus-visible`]:Object.assign({},accessibilityFocus(a))},[`${u}-item-disabled, ${u}-submenu-disabled`]:{color:`${j} !important`},[`${u}-item:not(${u}-item-selected):not(${u}-submenu-selected)`]:{[`&:hover, > ${u}-submenu-title:hover`]:{color:P}},[`&:not(${u}-horizontal)`]:{[`${u}-item:not(${u}-item-selected)`]:{"&:hover":{backgroundColor:Q},"&:active":{backgroundColor:Y}},[`${u}-submenu-title`]:{"&:hover":{backgroundColor:Q},"&:active":{backgroundColor:Y}}},[`${u}-item-danger`]:{color:L,[`&${u}-item:hover`]:{[`&:not(${u}-item-selected):not(${u}-submenu-selected)`]:{color:U}},[`&${u}-item:active`]:{background:F}},[`${u}-item a`]:{"&, &:hover":{color:"inherit"}},[`${u}-item-selected`]:{color:f,[`&${u}-item-danger`]:{color:q},"a, a:hover":{color:"inherit"}},[`& ${u}-item-selected`]:{backgroundColor:E,[`&${u}-item-danger`]:{backgroundColor:K}},[`&${u}-submenu > ${u}`]:{backgroundColor:Z},[`&${u}-popup > ${u}`]:{backgroundColor:X},[`&${u}-submenu-popup > ${u}`]:{backgroundColor:X},[`&${u}-horizontal`]:Object.assign(Object.assign({},c==="dark"?{borderBottom:0}:{}),{[`> ${u}-item, > ${u}-submenu`]:{top:R,marginTop:a.calc(R).mul(-1).equal(),marginBottom:0,borderRadius:G,"&::after":{position:"absolute",insetInline:N,bottom:0,borderBottom:`${unit$1(C)} solid transparent`,transition:`border-color ${_} ${M}`,content:'""'},"&:hover, &-active, &-open":{background:te,"&::after":{borderBottomWidth:C,borderBottomColor:J}},"&-selected":{color:J,backgroundColor:W,"&:hover":{backgroundColor:W},"&::after":{borderBottomWidth:C,borderBottomColor:J}}}}),[`&${u}-root`]:{[`&${u}-inline, &${u}-vertical`]:{borderInlineEnd:`${unit$1(R)} ${z} ${B}`}},[`&${u}-inline`]:{[`${u}-sub${u}-inline`]:{background:b},[`${u}-item`]:{position:"relative","&::after":{position:"absolute",insetBlock:0,insetInlineEnd:0,borderInlineEnd:`${unit$1(w)} solid ${f}`,transform:"scaleY(0.0001)",opacity:0,transition:[`transform ${A} ${I}`,`opacity ${A} ${I}`].join(","),content:'""'},[`&${u}-item-danger`]:{"&::after":{borderInlineEndColor:q}}},[`${u}-selected, ${u}-item-selected`]:{"&::after":{transform:"scaleY(1)",opacity:1,transition:[`transform ${A} ${M}`,`opacity ${A} ${M}`].join(",")}}}}}},getVerticalInlineStyle=a=>{const{componentCls:c,itemHeight:u,itemMarginInline:d,padding:f,menuArrowSize:m,marginXS:g,itemMarginBlock:y,itemWidth:b,itemPaddingInline:E}=a,C=a.calc(m).add(f).add(g).equal();return{[`${c}-item`]:{position:"relative",overflow:"hidden"},[`${c}-item, ${c}-submenu-title`]:{height:u,lineHeight:unit$1(u),paddingInline:E,overflow:"hidden",textOverflow:"ellipsis",marginInline:d,marginBlock:y,width:b},[`> ${c}-item,
            > ${c}-submenu > ${c}-submenu-title`]:{height:u,lineHeight:unit$1(u)},[`${c}-item-group-list ${c}-submenu-title,
            ${c}-submenu-title`]:{paddingInlineEnd:C}}},getVerticalStyle=a=>{const{componentCls:c,iconCls:u,itemHeight:d,colorTextLightSolid:f,dropdownWidth:m,controlHeightLG:g,motionEaseOut:y,paddingXL:b,itemMarginInline:E,fontSizeLG:C,motionDurationFast:w,motionDurationSlow:R,paddingXS:_,boxShadowSecondary:M,collapsedWidth:I,collapsedIconSize:N}=a,A={height:d,lineHeight:unit$1(d),listStylePosition:"inside",listStyleType:"disc"};return[{[c]:{"&-inline, &-vertical":Object.assign({[`&${c}-root`]:{boxShadow:"none"}},getVerticalInlineStyle(a))},[`${c}-submenu-popup`]:{[`${c}-vertical`]:Object.assign(Object.assign({},getVerticalInlineStyle(a)),{boxShadow:M})}},{[`${c}-submenu-popup ${c}-vertical${c}-sub`]:{minWidth:m,maxHeight:`calc(100vh - ${unit$1(a.calc(g).mul(2.5).equal())})`,padding:"0",overflow:"hidden",borderInlineEnd:0,"&:not([class*='-active'])":{overflowX:"hidden",overflowY:"auto"}}},{[`${c}-inline`]:{width:"100%",[`&${c}-root`]:{[`${c}-item, ${c}-submenu-title`]:{display:"flex",alignItems:"center",transition:[`border-color ${R}`,`background ${R}`,`padding ${w} ${y}`].join(","),[`> ${c}-title-content`]:{flex:"auto",minWidth:0,overflow:"hidden",textOverflow:"ellipsis"},"> *":{flex:"none"}}},[`${c}-sub${c}-inline`]:{padding:0,border:0,borderRadius:0,boxShadow:"none",[`& > ${c}-submenu > ${c}-submenu-title`]:A,[`& ${c}-item-group-title`]:{paddingInlineStart:b}},[`${c}-item`]:A}},{[`${c}-inline-collapsed`]:{width:I,[`&${c}-root`]:{[`${c}-item, ${c}-submenu ${c}-submenu-title`]:{[`> ${c}-inline-collapsed-noicon`]:{fontSize:C,textAlign:"center"}}},[`> ${c}-item,
          > ${c}-item-group > ${c}-item-group-list > ${c}-item,
          > ${c}-item-group > ${c}-item-group-list > ${c}-submenu > ${c}-submenu-title,
          > ${c}-submenu > ${c}-submenu-title`]:{insetInlineStart:0,paddingInline:`calc(50% - ${unit$1(a.calc(N).div(2).equal())} - ${unit$1(E)})`,textOverflow:"clip",[`
            ${c}-submenu-arrow,
            ${c}-submenu-expand-icon
          `]:{opacity:0},[`${c}-item-icon, ${u}`]:{margin:0,fontSize:N,lineHeight:unit$1(d),"+ span":{display:"inline-block",opacity:0}}},[`${c}-item-icon, ${u}`]:{display:"inline-block"},"&-tooltip":{pointerEvents:"none",[`${c}-item-icon, ${u}`]:{display:"none"},"a, a:hover":{color:f}},[`${c}-item-group-title`]:Object.assign(Object.assign({},textEllipsis),{paddingInline:_})}}]},genMenuItemStyle=a=>{const{componentCls:c,motionDurationSlow:u,motionDurationMid:d,motionEaseInOut:f,motionEaseOut:m,iconCls:g,iconSize:y,iconMarginInlineEnd:b}=a;return{[`${c}-item, ${c}-submenu-title`]:{position:"relative",display:"block",margin:0,whiteSpace:"nowrap",cursor:"pointer",transition:[`border-color ${u}`,`background ${u}`,`padding calc(${u} + 0.1s) ${f}`].join(","),[`${c}-item-icon, ${g}`]:{minWidth:y,fontSize:y,transition:[`font-size ${d} ${m}`,`margin ${u} ${f}`,`color ${u}`].join(","),"+ span":{marginInlineStart:b,opacity:1,transition:[`opacity ${u} ${f}`,`margin ${u}`,`color ${u}`].join(",")}},[`${c}-item-icon`]:Object.assign({},resetIcon()),[`&${c}-item-only-child`]:{[`> ${g}, > ${c}-item-icon`]:{marginInlineEnd:0}}},[`${c}-item-disabled, ${c}-submenu-disabled`]:{background:"none !important",cursor:"not-allowed","&::after":{borderColor:"transparent !important"},a:{color:"inherit !important",cursor:"not-allowed",pointerEvents:"none"},[`> ${c}-submenu-title`]:{color:"inherit !important",cursor:"not-allowed"}}}},genSubMenuArrowStyle=a=>{const{componentCls:c,motionDurationSlow:u,motionEaseInOut:d,borderRadius:f,menuArrowSize:m,menuArrowOffset:g}=a;return{[`${c}-submenu`]:{"&-expand-icon, &-arrow":{position:"absolute",top:"50%",insetInlineEnd:a.margin,width:m,color:"currentcolor",transform:"translateY(-50%)",transition:`transform ${u} ${d}, opacity ${u}`},"&-arrow":{"&::before, &::after":{position:"absolute",width:a.calc(m).mul(.6).equal(),height:a.calc(m).mul(.15).equal(),backgroundColor:"currentcolor",borderRadius:f,transition:[`background ${u} ${d}`,`transform ${u} ${d}`,`top ${u} ${d}`,`color ${u} ${d}`].join(","),content:'""'},"&::before":{transform:`rotate(45deg) translateY(${unit$1(a.calc(g).mul(-1).equal())})`},"&::after":{transform:`rotate(-45deg) translateY(${unit$1(g)})`}}}}},getBaseStyle=a=>{const{antCls:c,componentCls:u,fontSize:d,motionDurationSlow:f,motionDurationMid:m,motionEaseInOut:g,paddingXS:y,padding:b,colorSplit:E,lineWidth:C,zIndexPopup:w,borderRadiusLG:R,subMenuItemBorderRadius:_,menuArrowSize:M,menuArrowOffset:I,lineType:N,groupTitleLineHeight:A,groupTitleFontSize:P}=a;return[{"":{[u]:Object.assign(Object.assign({},clearFix()),{"&-hidden":{display:"none"}})},[`${u}-submenu-hidden`]:{display:"none"}},{[u]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),clearFix()),{marginBottom:0,paddingInlineStart:0,fontSize:d,lineHeight:0,listStyle:"none",outline:"none",transition:`width ${f} cubic-bezier(0.2, 0, 0, 1) 0s`,"ul, ol":{margin:0,padding:0,listStyle:"none"},"&-overflow":{display:"flex",[`${u}-item`]:{flex:"none"}},[`${u}-item, ${u}-submenu, ${u}-submenu-title`]:{borderRadius:a.itemBorderRadius},[`${u}-item-group-title`]:{padding:`${unit$1(y)} ${unit$1(b)}`,fontSize:P,lineHeight:A,transition:`all ${f}`},[`&-horizontal ${u}-submenu`]:{transition:[`border-color ${f} ${g}`,`background ${f} ${g}`].join(",")},[`${u}-submenu, ${u}-submenu-inline`]:{transition:[`border-color ${f} ${g}`,`background ${f} ${g}`,`padding ${m} ${g}`].join(",")},[`${u}-submenu ${u}-sub`]:{cursor:"initial",transition:[`background ${f} ${g}`,`padding ${f} ${g}`].join(",")},[`${u}-title-content`]:{transition:`color ${f}`,"&-with-extra":{display:"inline-flex",alignItems:"center",width:"100%"},[`> ${c}-typography-ellipsis-single-line`]:{display:"inline",verticalAlign:"unset"},[`${u}-item-extra`]:{marginInlineStart:"auto",paddingInlineStart:a.padding}},[`${u}-item a`]:{"&::before":{position:"absolute",inset:0,backgroundColor:"transparent",content:'""'}},[`${u}-item-divider`]:{overflow:"hidden",lineHeight:0,borderColor:E,borderStyle:N,borderWidth:0,borderTopWidth:C,marginBlock:C,padding:0,"&-dashed":{borderStyle:"dashed"}}}),genMenuItemStyle(a)),{[`${u}-item-group`]:{[`${u}-item-group-list`]:{margin:0,padding:0,[`${u}-item, ${u}-submenu-title`]:{paddingInline:`${unit$1(a.calc(d).mul(2).equal())} ${unit$1(b)}`}}},"&-submenu":{"&-popup":{position:"absolute",zIndex:w,borderRadius:R,boxShadow:"none",transformOrigin:"0 0",[`&${u}-submenu`]:{background:"transparent"},"&::before":{position:"absolute",inset:0,zIndex:-1,width:"100%",height:"100%",opacity:0,content:'""'},[`> ${u}`]:Object.assign(Object.assign(Object.assign({borderRadius:R},genMenuItemStyle(a)),genSubMenuArrowStyle(a)),{[`${u}-item, ${u}-submenu > ${u}-submenu-title`]:{borderRadius:_},[`${u}-submenu-title::after`]:{transition:`transform ${f} ${g}`}})},"\n          &-placement-leftTop,\n          &-placement-bottomRight,\n          ":{transformOrigin:"100% 0"},"\n          &-placement-leftBottom,\n          &-placement-topRight,\n          ":{transformOrigin:"100% 100%"},"\n          &-placement-rightBottom,\n          &-placement-topLeft,\n          ":{transformOrigin:"0 100%"},"\n          &-placement-bottomLeft,\n          &-placement-rightTop,\n          ":{transformOrigin:"0 0"},"\n          &-placement-leftTop,\n          &-placement-leftBottom\n          ":{paddingInlineEnd:a.paddingXS},"\n          &-placement-rightTop,\n          &-placement-rightBottom\n          ":{paddingInlineStart:a.paddingXS},"\n          &-placement-topRight,\n          &-placement-topLeft\n          ":{paddingBottom:a.paddingXS},"\n          &-placement-bottomRight,\n          &-placement-bottomLeft\n          ":{paddingTop:a.paddingXS}}}),genSubMenuArrowStyle(a)),{[`&-inline-collapsed ${u}-submenu-arrow,
        &-inline ${u}-submenu-arrow`]:{"&::before":{transform:`rotate(-45deg) translateX(${unit$1(I)})`},"&::after":{transform:`rotate(45deg) translateX(${unit$1(a.calc(I).mul(-1).equal())})`}},[`${u}-submenu-open${u}-submenu-inline > ${u}-submenu-title > ${u}-submenu-arrow`]:{transform:`translateY(${unit$1(a.calc(M).mul(.2).mul(-1).equal())})`,"&::after":{transform:`rotate(-45deg) translateX(${unit$1(a.calc(I).mul(-1).equal())})`},"&::before":{transform:`rotate(45deg) translateX(${unit$1(I)})`}}})},{[`${c}-layout-header`]:{[u]:{lineHeight:"inherit"}}}]},prepareComponentToken$f=a=>{var c,u,d;const{colorPrimary:f,colorError:m,colorTextDisabled:g,colorErrorBg:y,colorText:b,colorTextDescription:E,colorBgContainer:C,colorFillAlter:w,colorFillContent:R,lineWidth:_,lineWidthBold:M,controlItemBgActive:I,colorBgTextHover:N,controlHeightLG:A,lineHeight:P,colorBgElevated:z,marginXXS:B,padding:j,fontSize:L,controlHeightSM:U,fontSizeLG:q,colorTextLightSolid:F,colorErrorHover:K}=a,X=(c=a.activeBarWidth)!==null&&c!==void 0?c:0,Q=(u=a.activeBarBorderWidth)!==null&&u!==void 0?u:_,Y=(d=a.itemMarginInline)!==null&&d!==void 0?d:a.marginXXS,Z=new FastColor(F).setA(.65).toRgbString();return{dropdownWidth:160,zIndexPopup:a.zIndexPopupBase+50,radiusItem:a.borderRadiusLG,itemBorderRadius:a.borderRadiusLG,radiusSubMenuItem:a.borderRadiusSM,subMenuItemBorderRadius:a.borderRadiusSM,colorItemText:b,itemColor:b,colorItemTextHover:b,itemHoverColor:b,colorItemTextHoverHorizontal:f,horizontalItemHoverColor:f,colorGroupTitle:E,groupTitleColor:E,colorItemTextSelected:f,itemSelectedColor:f,subMenuItemSelectedColor:f,colorItemTextSelectedHorizontal:f,horizontalItemSelectedColor:f,colorItemBg:C,itemBg:C,colorItemBgHover:N,itemHoverBg:N,colorItemBgActive:R,itemActiveBg:I,colorSubItemBg:w,subMenuItemBg:w,colorItemBgSelected:I,itemSelectedBg:I,colorItemBgSelectedHorizontal:"transparent",horizontalItemSelectedBg:"transparent",colorActiveBarWidth:0,activeBarWidth:X,colorActiveBarHeight:M,activeBarHeight:M,colorActiveBarBorderSize:_,activeBarBorderWidth:Q,colorItemTextDisabled:g,itemDisabledColor:g,colorDangerItemText:m,dangerItemColor:m,colorDangerItemTextHover:m,dangerItemHoverColor:m,colorDangerItemTextSelected:m,dangerItemSelectedColor:m,colorDangerItemBgActive:y,dangerItemActiveBg:y,colorDangerItemBgSelected:y,dangerItemSelectedBg:y,itemMarginInline:Y,horizontalItemBorderRadius:0,horizontalItemHoverBg:"transparent",itemHeight:A,groupTitleLineHeight:P,collapsedWidth:A*2,popupBg:z,itemMarginBlock:B,itemPaddingInline:j,horizontalLineHeight:`${A*1.15}px`,iconSize:L,iconMarginInlineEnd:U-L,collapsedIconSize:q,groupTitleFontSize:L,darkItemDisabledColor:new FastColor(F).setA(.25).toRgbString(),darkItemColor:Z,darkDangerItemColor:m,darkItemBg:"#001529",darkPopupBg:"#001529",darkSubMenuItemBg:"#000c17",darkItemSelectedColor:F,darkItemSelectedBg:f,darkDangerItemSelectedBg:m,darkItemHoverBg:"transparent",darkGroupTitleColor:Z,darkItemHoverColor:F,darkDangerItemHoverColor:K,darkDangerItemSelectedColor:F,darkDangerItemActiveBg:m,itemWidth:X?`calc(100% + ${Q}px)`:`calc(100% - ${Y*2}px)`}},useStyle$j=function(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:a,u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!0;return genStyleHooks("Menu",f=>{const{colorBgElevated:m,controlHeightLG:g,fontSize:y,darkItemColor:b,darkDangerItemColor:E,darkItemBg:C,darkSubMenuItemBg:w,darkItemSelectedColor:R,darkItemSelectedBg:_,darkDangerItemSelectedBg:M,darkItemHoverBg:I,darkGroupTitleColor:N,darkItemHoverColor:A,darkItemDisabledColor:P,darkDangerItemHoverColor:z,darkDangerItemSelectedColor:B,darkDangerItemActiveBg:j,popupBg:L,darkPopupBg:U}=f,q=f.calc(y).div(7).mul(5).equal(),F=merge$2(f,{menuArrowSize:q,menuHorizontalHeight:f.calc(g).mul(1.15).equal(),menuArrowOffset:f.calc(q).mul(.25).equal(),menuSubMenuBg:m,calc:f.calc,popupBg:L}),K=merge$2(F,{itemColor:b,itemHoverColor:A,groupTitleColor:N,itemSelectedColor:R,subMenuItemSelectedColor:R,itemBg:C,popupBg:U,subMenuItemBg:w,itemActiveBg:"transparent",itemSelectedBg:_,activeBarHeight:0,activeBarBorderWidth:0,itemHoverBg:I,itemDisabledColor:P,dangerItemColor:E,dangerItemHoverColor:z,dangerItemSelectedColor:B,dangerItemActiveBg:j,dangerItemSelectedBg:M,menuSubMenuBg:w,horizontalItemSelectedColor:R,horizontalItemSelectedBg:_});return[getBaseStyle(F),getHorizontalStyle(F),getVerticalStyle(F),getThemeStyle(F,"light"),getThemeStyle(K,"dark"),getRTLStyle(F),genCollapseMotion(F),initSlideMotion(F,"slide-up"),initSlideMotion(F,"slide-down"),initZoomMotion(F,"zoom-big")]},prepareComponentToken$f,{deprecatedTokens:[["colorGroupTitle","groupTitleColor"],["radiusItem","itemBorderRadius"],["radiusSubMenuItem","subMenuItemBorderRadius"],["colorItemText","itemColor"],["colorItemTextHover","itemHoverColor"],["colorItemTextHoverHorizontal","horizontalItemHoverColor"],["colorItemTextSelected","itemSelectedColor"],["colorItemTextSelectedHorizontal","horizontalItemSelectedColor"],["colorItemTextDisabled","itemDisabledColor"],["colorDangerItemText","dangerItemColor"],["colorDangerItemTextHover","dangerItemHoverColor"],["colorDangerItemTextSelected","dangerItemSelectedColor"],["colorDangerItemBgActive","dangerItemActiveBg"],["colorDangerItemBgSelected","dangerItemSelectedBg"],["colorItemBg","itemBg"],["colorItemBgHover","itemHoverBg"],["colorSubItemBg","subMenuItemBg"],["colorItemBgActive","itemActiveBg"],["colorItemBgSelectedHorizontal","horizontalItemSelectedBg"],["colorActiveBarWidth","activeBarWidth"],["colorActiveBarHeight","activeBarHeight"],["colorActiveBarBorderSize","activeBarBorderWidth"],["colorItemBgSelected","itemSelectedBg"]],injectStyle:u,unitless:{groupTitleLineHeight:!0}})(a,c)},SubMenu=a=>{var c;const{popupClassName:u,icon:d,title:f,theme:m}=a,g=reactExports.useContext(MenuContext),{prefixCls:y,inlineCollapsed:b,theme:E}=g,C=useFullPath();let w;if(!d)w=b&&!C.length&&f&&typeof f=="string"?reactExports.createElement("div",{className:`${y}-inline-collapsed-noicon`},f.charAt(0)):reactExports.createElement("span",{className:`${y}-title-content`},f);else{const M=reactExports.isValidElement(f)&&f.type==="span";w=reactExports.createElement(reactExports.Fragment,null,cloneElement(d,{className:classNames(reactExports.isValidElement(d)?(c=d.props)===null||c===void 0?void 0:c.className:"",`${y}-item-icon`)}),M?f:reactExports.createElement("span",{className:`${y}-title-content`},f))}const R=reactExports.useMemo(()=>Object.assign(Object.assign({},g),{firstLevel:!1}),[g]),[_]=useZIndex("Menu");return reactExports.createElement(MenuContext.Provider,{value:R},reactExports.createElement(SubMenu$1,Object.assign({},omit(a,["icon"]),{title:w,popupClassName:classNames(y,u,`${y}-${m||E}`),popupStyle:Object.assign({zIndex:_},a.popupStyle)})))};var __rest$H=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function isEmptyIcon(a){return a===null||a===!1}const MENU_COMPONENTS={item:MenuItem,submenu:SubMenu,divider:MenuDivider},InternalMenu=reactExports.forwardRef((a,c)=>{var u;const d=reactExports.useContext(OverrideContext),f=d||{},{getPrefixCls:m,getPopupContainer:g,direction:y,menu:b}=reactExports.useContext(ConfigContext),E=m(),{prefixCls:C,className:w,style:R,theme:_="light",expandIcon:M,_internalDisableMenuItemTitleTooltip:I,inlineCollapsed:N,siderCollapsed:A,rootClassName:P,mode:z,selectable:B,onClick:j,overflowedIndicatorPopupClassName:L}=a,U=__rest$H(a,["prefixCls","className","style","theme","expandIcon","_internalDisableMenuItemTitleTooltip","inlineCollapsed","siderCollapsed","rootClassName","mode","selectable","onClick","overflowedIndicatorPopupClassName"]),q=omit(U,["collapsedWidth"]);(u=f.validator)===null||u===void 0||u.call(f,{mode:z});const F=useEvent(function(){var le;j==null||j.apply(void 0,arguments),(le=f.onClick)===null||le===void 0||le.call(f)}),K=f.mode||z,X=B??f.selectable,Q=N??A,Y={horizontal:{motionName:`${E}-slide-up`},inline:initCollapseMotion(E),other:{motionName:`${E}-zoom-big`}},Z=m("menu",C||f.prefixCls),J=useCSSVarCls(Z),[W,G,te]=useStyle$j(Z,J,!d),ae=classNames(`${Z}-${_}`,b==null?void 0:b.className,w),V=reactExports.useMemo(()=>{var le,ee;if(typeof M=="function"||isEmptyIcon(M))return M||null;if(typeof f.expandIcon=="function"||isEmptyIcon(f.expandIcon))return f.expandIcon||null;if(typeof(b==null?void 0:b.expandIcon)=="function"||isEmptyIcon(b==null?void 0:b.expandIcon))return(b==null?void 0:b.expandIcon)||null;const ie=(le=M??(f==null?void 0:f.expandIcon))!==null&&le!==void 0?le:b==null?void 0:b.expandIcon;return cloneElement(ie,{className:classNames(`${Z}-submenu-expand-icon`,reactExports.isValidElement(ie)?(ee=ie.props)===null||ee===void 0?void 0:ee.className:void 0)})},[M,f==null?void 0:f.expandIcon,b==null?void 0:b.expandIcon,Z]),ne=reactExports.useMemo(()=>({prefixCls:Z,inlineCollapsed:Q||!1,direction:y,firstLevel:!0,theme:_,mode:K,disableMenuItemTitleTooltip:I}),[Z,Q,y,I,_]);return W(reactExports.createElement(OverrideContext.Provider,{value:null},reactExports.createElement(MenuContext.Provider,{value:ne},reactExports.createElement(ExportMenu,Object.assign({getPopupContainer:g,overflowedIndicator:reactExports.createElement(RefIcon$r,null),overflowedIndicatorPopupClassName:classNames(Z,`${Z}-${_}`,L),mode:K,selectable:X,onClick:F},q,{inlineCollapsed:Q,style:Object.assign(Object.assign({},b==null?void 0:b.style),R),className:ae,prefixCls:Z,direction:y,defaultMotions:Y,expandIcon:V,ref:c,rootClassName:classNames(P,G,f.rootClassName,te,J),_internalComponents:MENU_COMPONENTS})))))}),Menu=reactExports.forwardRef((a,c)=>{const u=reactExports.useRef(null),d=reactExports.useContext(SiderContext);return reactExports.useImperativeHandle(c,()=>({menu:u.current,focus:f=>{var m;(m=u.current)===null||m===void 0||m.focus(f)}})),reactExports.createElement(InternalMenu,Object.assign({ref:u},a,d))});Menu.Item=MenuItem;Menu.SubMenu=SubMenu;Menu.Divider=MenuDivider;Menu.ItemGroup=MenuItemGroup;const genStatusStyle=a=>{const{componentCls:c,menuCls:u,colorError:d,colorTextLightSolid:f}=a,m=`${u}-item`;return{[`${c}, ${c}-menu-submenu`]:{[`${u} ${m}`]:{[`&${m}-danger:not(${m}-disabled)`]:{color:d,"&:hover":{color:f,backgroundColor:d}}}}}},genBaseStyle$3=a=>{const{componentCls:c,menuCls:u,zIndexPopup:d,dropdownArrowDistance:f,sizePopupArrow:m,antCls:g,iconCls:y,motionDurationMid:b,paddingBlock:E,fontSize:C,dropdownEdgeChildPadding:w,colorTextDisabled:R,fontSizeIcon:_,controlPaddingHorizontal:M,colorBgElevated:I}=a;return[{[c]:{position:"absolute",top:-9999,left:{_skip_check_:!0,value:-9999},zIndex:d,display:"block","&::before":{position:"absolute",insetBlock:a.calc(m).div(2).sub(f).equal(),zIndex:-9999,opacity:1e-4,content:'""'},"&-menu-vertical":{maxHeight:"100vh",overflowY:"auto"},[`&-trigger${g}-btn`]:{[`& > ${y}-down, & > ${g}-btn-icon > ${y}-down`]:{fontSize:_}},[`${c}-wrap`]:{position:"relative",[`${g}-btn > ${y}-down`]:{fontSize:_},[`${y}-down::before`]:{transition:`transform ${b}`}},[`${c}-wrap-open`]:{[`${y}-down::before`]:{transform:"rotate(180deg)"}},"\n        &-hidden,\n        &-menu-hidden,\n        &-menu-submenu-hidden\n      ":{display:"none"},[`&${g}-slide-down-enter${g}-slide-down-enter-active${c}-placement-bottomLeft,
          &${g}-slide-down-appear${g}-slide-down-appear-active${c}-placement-bottomLeft,
          &${g}-slide-down-enter${g}-slide-down-enter-active${c}-placement-bottom,
          &${g}-slide-down-appear${g}-slide-down-appear-active${c}-placement-bottom,
          &${g}-slide-down-enter${g}-slide-down-enter-active${c}-placement-bottomRight,
          &${g}-slide-down-appear${g}-slide-down-appear-active${c}-placement-bottomRight`]:{animationName:slideUpIn},[`&${g}-slide-up-enter${g}-slide-up-enter-active${c}-placement-topLeft,
          &${g}-slide-up-appear${g}-slide-up-appear-active${c}-placement-topLeft,
          &${g}-slide-up-enter${g}-slide-up-enter-active${c}-placement-top,
          &${g}-slide-up-appear${g}-slide-up-appear-active${c}-placement-top,
          &${g}-slide-up-enter${g}-slide-up-enter-active${c}-placement-topRight,
          &${g}-slide-up-appear${g}-slide-up-appear-active${c}-placement-topRight`]:{animationName:slideDownIn},[`&${g}-slide-down-leave${g}-slide-down-leave-active${c}-placement-bottomLeft,
          &${g}-slide-down-leave${g}-slide-down-leave-active${c}-placement-bottom,
          &${g}-slide-down-leave${g}-slide-down-leave-active${c}-placement-bottomRight`]:{animationName:slideUpOut},[`&${g}-slide-up-leave${g}-slide-up-leave-active${c}-placement-topLeft,
          &${g}-slide-up-leave${g}-slide-up-leave-active${c}-placement-top,
          &${g}-slide-up-leave${g}-slide-up-leave-active${c}-placement-topRight`]:{animationName:slideDownOut}}},getArrowStyle(a,I,{arrowPlacement:{top:!0,bottom:!0}}),{[`${c} ${u}`]:{position:"relative",margin:0},[`${u}-submenu-popup`]:{position:"absolute",zIndex:d,background:"transparent",boxShadow:"none",transformOrigin:"0 0","ul, li":{listStyle:"none",margin:0}},[`${c}, ${c}-menu-submenu`]:Object.assign(Object.assign({},resetComponent(a)),{[u]:Object.assign(Object.assign({padding:w,listStyleType:"none",backgroundColor:I,backgroundClip:"padding-box",borderRadius:a.borderRadiusLG,outline:"none",boxShadow:a.boxShadowSecondary},genFocusStyle(a)),{"&:empty":{padding:0,boxShadow:"none"},[`${u}-item-group-title`]:{padding:`${unit$1(E)} ${unit$1(M)}`,color:a.colorTextDescription,transition:`all ${b}`},[`${u}-item`]:{position:"relative",display:"flex",alignItems:"center"},[`${u}-item-icon`]:{minWidth:C,marginInlineEnd:a.marginXS,fontSize:a.fontSizeSM},[`${u}-title-content`]:{flex:"auto","&-with-extra":{display:"inline-flex",alignItems:"center",width:"100%"},"> a":{color:"inherit",transition:`all ${b}`,"&:hover":{color:"inherit"},"&::after":{position:"absolute",inset:0,content:'""'}},[`${u}-item-extra`]:{paddingInlineStart:a.padding,marginInlineStart:"auto",fontSize:a.fontSizeSM,color:a.colorTextDescription}},[`${u}-item, ${u}-submenu-title`]:Object.assign(Object.assign({display:"flex",margin:0,padding:`${unit$1(E)} ${unit$1(M)}`,color:a.colorText,fontWeight:"normal",fontSize:C,lineHeight:a.lineHeight,cursor:"pointer",transition:`all ${b}`,borderRadius:a.borderRadiusSM,"&:hover, &-active":{backgroundColor:a.controlItemBgHover}},genFocusStyle(a)),{"&-selected":{color:a.colorPrimary,backgroundColor:a.controlItemBgActive,"&:hover, &-active":{backgroundColor:a.controlItemBgActiveHover}},"&-disabled":{color:R,cursor:"not-allowed","&:hover":{color:R,backgroundColor:I,cursor:"not-allowed"},a:{pointerEvents:"none"}},"&-divider":{height:1,margin:`${unit$1(a.marginXXS)} 0`,overflow:"hidden",lineHeight:0,backgroundColor:a.colorSplit},[`${c}-menu-submenu-expand-icon`]:{position:"absolute",insetInlineEnd:a.paddingXS,[`${c}-menu-submenu-arrow-icon`]:{marginInlineEnd:"0 !important",color:a.colorIcon,fontSize:_,fontStyle:"normal"}}}),[`${u}-item-group-list`]:{margin:`0 ${unit$1(a.marginXS)}`,padding:0,listStyle:"none"},[`${u}-submenu-title`]:{paddingInlineEnd:a.calc(M).add(a.fontSizeSM).equal()},[`${u}-submenu-vertical`]:{position:"relative"},[`${u}-submenu${u}-submenu-disabled ${c}-menu-submenu-title`]:{[`&, ${c}-menu-submenu-arrow-icon`]:{color:R,backgroundColor:I,cursor:"not-allowed"}},[`${u}-submenu-selected ${c}-menu-submenu-title`]:{color:a.colorPrimary}})})},[initSlideMotion(a,"slide-up"),initSlideMotion(a,"slide-down"),initMoveMotion(a,"move-up"),initMoveMotion(a,"move-down"),initZoomMotion(a,"zoom-big")]]},prepareComponentToken$e=a=>Object.assign(Object.assign({zIndexPopup:a.zIndexPopupBase+50,paddingBlock:(a.controlHeight-a.fontSize*a.lineHeight)/2},getArrowOffsetToken({contentRadius:a.borderRadiusLG,limitVerticalRadius:!0})),getArrowToken(a)),useStyle$i=genStyleHooks("Dropdown",a=>{const{marginXXS:c,sizePopupArrow:u,paddingXXS:d,componentCls:f}=a,m=merge$2(a,{menuCls:`${f}-menu`,dropdownArrowDistance:a.calc(u).div(2).add(c).equal(),dropdownEdgeChildPadding:d});return[genBaseStyle$3(m),genStatusStyle(m)]},prepareComponentToken$e,{resetStyle:!1}),Dropdown$1=a=>{var c;const{menu:u,arrow:d,prefixCls:f,children:m,trigger:g,disabled:y,dropdownRender:b,getPopupContainer:E,overlayClassName:C,rootClassName:w,overlayStyle:R,open:_,onOpenChange:M,visible:I,onVisibleChange:N,mouseEnterDelay:A=.15,mouseLeaveDelay:P=.1,autoAdjustOverflow:z=!0,placement:B="",overlay:j,transitionName:L}=a,{getPopupContainer:U,getPrefixCls:q,direction:F,dropdown:K}=reactExports.useContext(ConfigContext);devUseWarning();const X=reactExports.useMemo(()=>{const pe=q();return L!==void 0?L:B.includes("top")?`${pe}-slide-down`:`${pe}-slide-up`},[q,B,L]),Q=reactExports.useMemo(()=>B?B.includes("Center")?B.slice(0,B.indexOf("Center")):B:F==="rtl"?"bottomRight":"bottomLeft",[B,F]),Y=q("dropdown",f),Z=useCSSVarCls(Y),[J,W,G]=useStyle$i(Y,Z),[,te]=useToken$1(),ae=reactExports.Children.only(isPrimitive(m)?reactExports.createElement("span",null,m):m),V=cloneElement(ae,{className:classNames(`${Y}-trigger`,{[`${Y}-rtl`]:F==="rtl"},ae.props.className),disabled:(c=ae.props.disabled)!==null&&c!==void 0?c:y}),ne=y?[]:g,le=!!(ne!=null&&ne.includes("contextMenu")),[ee,ie]=useMergedState(!1,{value:_??I}),ce=useEvent(pe=>{M==null||M(pe,{source:"trigger"}),N==null||N(pe),ie(pe)}),ue=classNames(C,w,W,G,Z,K==null?void 0:K.className,{[`${Y}-rtl`]:F==="rtl"}),me=getPlacements({arrowPointAtCenter:typeof d=="object"&&d.pointAtCenter,autoAdjustOverflow:z,offset:te.marginXXS,arrowWidth:d?te.sizePopupArrow:0,borderRadius:te.borderRadius}),de=reactExports.useCallback(()=>{u!=null&&u.selectable&&(u!=null&&u.multiple)||(M==null||M(!1,{source:"menu"}),ie(!1))},[u==null?void 0:u.selectable,u==null?void 0:u.multiple]),ge=()=>{let pe;return u!=null&&u.items?pe=reactExports.createElement(Menu,Object.assign({},u)):typeof j=="function"?pe=j():pe=j,b&&(pe=b(pe)),pe=reactExports.Children.only(typeof pe=="string"?reactExports.createElement("span",null,pe):pe),reactExports.createElement(OverrideProvider,{prefixCls:`${Y}-menu`,rootClassName:classNames(G,Z),expandIcon:reactExports.createElement("span",{className:`${Y}-menu-submenu-arrow`},F==="rtl"?reactExports.createElement(RefIcon$f,{className:`${Y}-menu-submenu-arrow-icon`}):reactExports.createElement(RefIcon$8,{className:`${Y}-menu-submenu-arrow-icon`})),mode:"vertical",selectable:!1,onClick:de,validator:xe=>{let{mode:ye}=xe}},pe)},[Ce,ve]=useZIndex("Dropdown",R==null?void 0:R.zIndex);let fe=reactExports.createElement(Dropdown$3,Object.assign({alignPoint:le},omit(a,["rootClassName"]),{mouseEnterDelay:A,mouseLeaveDelay:P,visible:ee,builtinPlacements:me,arrow:!!d,overlayClassName:ue,prefixCls:Y,getPopupContainer:E||U,transitionName:X,trigger:ne,overlay:ge,placement:Q,onVisibleChange:ce,overlayStyle:Object.assign(Object.assign(Object.assign({},K==null?void 0:K.style),R),{zIndex:Ce})}),V);return Ce&&(fe=reactExports.createElement(zIndexContext.Provider,{value:ve},fe)),J(fe)},PurePanel$1=genPurePanel(Dropdown$1,"align",void 0,"dropdown",a=>a),WrapPurePanel=a=>reactExports.createElement(PurePanel$1,Object.assign({},a),reactExports.createElement("span",null));Dropdown$1._InternalPanelDoNotUseOrYouWillBeFired=WrapPurePanel;const RadioGroupContext=reactExports.createContext(null),RadioGroupContextProvider=RadioGroupContext.Provider,RadioOptionTypeContext=reactExports.createContext(null),RadioOptionTypeContextProvider=RadioOptionTypeContext.Provider;var _excluded$l=["prefixCls","className","style","checked","disabled","defaultChecked","type","title","onChange"],Checkbox$2=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=u===void 0?"rc-checkbox":u,f=a.className,m=a.style,g=a.checked,y=a.disabled,b=a.defaultChecked,E=b===void 0?!1:b,C=a.type,w=C===void 0?"checkbox":C,R=a.title,_=a.onChange,M=_objectWithoutProperties(a,_excluded$l),I=reactExports.useRef(null),N=reactExports.useRef(null),A=useMergedState(E,{value:g}),P=_slicedToArray(A,2),z=P[0],B=P[1];reactExports.useImperativeHandle(c,function(){return{focus:function(q){var F;(F=I.current)===null||F===void 0||F.focus(q)},blur:function(){var q;(q=I.current)===null||q===void 0||q.blur()},input:I.current,nativeElement:N.current}});var j=classNames(d,f,_defineProperty(_defineProperty({},"".concat(d,"-checked"),z),"".concat(d,"-disabled"),y)),L=function(q){y||("checked"in a||B(q.target.checked),_==null||_({target:_objectSpread2(_objectSpread2({},a),{},{type:w,checked:q.target.checked}),stopPropagation:function(){q.stopPropagation()},preventDefault:function(){q.preventDefault()},nativeEvent:q.nativeEvent}))};return reactExports.createElement("span",{className:j,title:R,style:m,ref:N},reactExports.createElement("input",_extends({},M,{className:"".concat(d,"-input"),ref:I,onChange:L,disabled:y,checked:!!z,type:w})),reactExports.createElement("span",{className:"".concat(d,"-inner")}))});function useBubbleLock(a){const c=React.useRef(null),u=()=>{wrapperRaf.cancel(c.current),c.current=null};return[()=>{u(),c.current=wrapperRaf(()=>{c.current=null})},m=>{c.current&&(m.stopPropagation(),u()),a==null||a(m)}]}const getGroupRadioStyle=a=>{const{componentCls:c,antCls:u}=a,d=`${c}-group`;return{[d]:Object.assign(Object.assign({},resetComponent(a)),{display:"inline-block",fontSize:0,[`&${d}-rtl`]:{direction:"rtl"},[`&${d}-block`]:{display:"flex"},[`${u}-badge ${u}-badge-count`]:{zIndex:1},[`> ${u}-badge:not(:first-child) > ${u}-button-wrapper`]:{borderInlineStart:"none"}})}},getRadioBasicStyle=a=>{const{componentCls:c,wrapperMarginInlineEnd:u,colorPrimary:d,radioSize:f,motionDurationSlow:m,motionDurationMid:g,motionEaseInOutCirc:y,colorBgContainer:b,colorBorder:E,lineWidth:C,colorBgContainerDisabled:w,colorTextDisabled:R,paddingXS:_,dotColorDisabled:M,lineType:I,radioColor:N,radioBgColor:A,calc:P}=a,z=`${c}-inner`,j=P(f).sub(P(4).mul(2)),L=P(1).mul(f).equal({unit:!0});return{[`${c}-wrapper`]:Object.assign(Object.assign({},resetComponent(a)),{display:"inline-flex",alignItems:"baseline",marginInlineStart:0,marginInlineEnd:u,cursor:"pointer","&:last-child":{marginInlineEnd:0},[`&${c}-wrapper-rtl`]:{direction:"rtl"},"&-disabled":{cursor:"not-allowed",color:a.colorTextDisabled},"&::after":{display:"inline-block",width:0,overflow:"hidden",content:'"\\a0"'},"&-block":{flex:1,justifyContent:"center"},[`${c}-checked::after`]:{position:"absolute",insetBlockStart:0,insetInlineStart:0,width:"100%",height:"100%",border:`${unit$1(C)} ${I} ${d}`,borderRadius:"50%",visibility:"hidden",opacity:0,content:'""'},[c]:Object.assign(Object.assign({},resetComponent(a)),{position:"relative",display:"inline-block",outline:"none",cursor:"pointer",alignSelf:"center",borderRadius:"50%"}),[`${c}-wrapper:hover &,
        &:hover ${z}`]:{borderColor:d},[`${c}-input:focus-visible + ${z}`]:Object.assign({},genFocusOutline(a)),[`${c}:hover::after, ${c}-wrapper:hover &::after`]:{visibility:"visible"},[`${c}-inner`]:{"&::after":{boxSizing:"border-box",position:"absolute",insetBlockStart:"50%",insetInlineStart:"50%",display:"block",width:L,height:L,marginBlockStart:P(1).mul(f).div(-2).equal({unit:!0}),marginInlineStart:P(1).mul(f).div(-2).equal({unit:!0}),backgroundColor:N,borderBlockStart:0,borderInlineStart:0,borderRadius:L,transform:"scale(0)",opacity:0,transition:`all ${m} ${y}`,content:'""'},boxSizing:"border-box",position:"relative",insetBlockStart:0,insetInlineStart:0,display:"block",width:L,height:L,backgroundColor:b,borderColor:E,borderStyle:"solid",borderWidth:C,borderRadius:"50%",transition:`all ${g}`},[`${c}-input`]:{position:"absolute",inset:0,zIndex:1,cursor:"pointer",opacity:0},[`${c}-checked`]:{[z]:{borderColor:d,backgroundColor:A,"&::after":{transform:`scale(${a.calc(a.dotSize).div(f).equal()})`,opacity:1,transition:`all ${m} ${y}`}}},[`${c}-disabled`]:{cursor:"not-allowed",[z]:{backgroundColor:w,borderColor:E,cursor:"not-allowed","&::after":{backgroundColor:M}},[`${c}-input`]:{cursor:"not-allowed"},[`${c}-disabled + span`]:{color:R,cursor:"not-allowed"},[`&${c}-checked`]:{[z]:{"&::after":{transform:`scale(${P(j).div(f).equal()})`}}}},[`span${c} + *`]:{paddingInlineStart:_,paddingInlineEnd:_}})}},getRadioButtonStyle=a=>{const{buttonColor:c,controlHeight:u,componentCls:d,lineWidth:f,lineType:m,colorBorder:g,motionDurationSlow:y,motionDurationMid:b,buttonPaddingInline:E,fontSize:C,buttonBg:w,fontSizeLG:R,controlHeightLG:_,controlHeightSM:M,paddingXS:I,borderRadius:N,borderRadiusSM:A,borderRadiusLG:P,buttonCheckedBg:z,buttonSolidCheckedColor:B,colorTextDisabled:j,colorBgContainerDisabled:L,buttonCheckedBgDisabled:U,buttonCheckedColorDisabled:q,colorPrimary:F,colorPrimaryHover:K,colorPrimaryActive:X,buttonSolidCheckedBg:Q,buttonSolidCheckedHoverBg:Y,buttonSolidCheckedActiveBg:Z,calc:J}=a;return{[`${d}-button-wrapper`]:{position:"relative",display:"inline-block",height:u,margin:0,paddingInline:E,paddingBlock:0,color:c,fontSize:C,lineHeight:unit$1(J(u).sub(J(f).mul(2)).equal()),background:w,border:`${unit$1(f)} ${m} ${g}`,borderBlockStartWidth:J(f).add(.02).equal(),borderInlineStartWidth:0,borderInlineEndWidth:f,cursor:"pointer",transition:[`color ${b}`,`background ${b}`,`box-shadow ${b}`].join(","),a:{color:c},[`> ${d}-button`]:{position:"absolute",insetBlockStart:0,insetInlineStart:0,zIndex:-1,width:"100%",height:"100%"},"&:not(:first-child)":{"&::before":{position:"absolute",insetBlockStart:J(f).mul(-1).equal(),insetInlineStart:J(f).mul(-1).equal(),display:"block",boxSizing:"content-box",width:1,height:"100%",paddingBlock:f,paddingInline:0,backgroundColor:g,transition:`background-color ${y}`,content:'""'}},"&:first-child":{borderInlineStart:`${unit$1(f)} ${m} ${g}`,borderStartStartRadius:N,borderEndStartRadius:N},"&:last-child":{borderStartEndRadius:N,borderEndEndRadius:N},"&:first-child:last-child":{borderRadius:N},[`${d}-group-large &`]:{height:_,fontSize:R,lineHeight:unit$1(J(_).sub(J(f).mul(2)).equal()),"&:first-child":{borderStartStartRadius:P,borderEndStartRadius:P},"&:last-child":{borderStartEndRadius:P,borderEndEndRadius:P}},[`${d}-group-small &`]:{height:M,paddingInline:J(I).sub(f).equal(),paddingBlock:0,lineHeight:unit$1(J(M).sub(J(f).mul(2)).equal()),"&:first-child":{borderStartStartRadius:A,borderEndStartRadius:A},"&:last-child":{borderStartEndRadius:A,borderEndEndRadius:A}},"&:hover":{position:"relative",color:F},"&:has(:focus-visible)":Object.assign({},genFocusOutline(a)),[`${d}-inner, input[type='checkbox'], input[type='radio']`]:{width:0,height:0,opacity:0,pointerEvents:"none"},[`&-checked:not(${d}-button-wrapper-disabled)`]:{zIndex:1,color:F,background:z,borderColor:F,"&::before":{backgroundColor:F},"&:first-child":{borderColor:F},"&:hover":{color:K,borderColor:K,"&::before":{backgroundColor:K}},"&:active":{color:X,borderColor:X,"&::before":{backgroundColor:X}}},[`${d}-group-solid &-checked:not(${d}-button-wrapper-disabled)`]:{color:B,background:Q,borderColor:Q,"&:hover":{color:B,background:Y,borderColor:Y},"&:active":{color:B,background:Z,borderColor:Z}},"&-disabled":{color:j,backgroundColor:L,borderColor:g,cursor:"not-allowed","&:first-child, &:hover":{color:j,backgroundColor:L,borderColor:g}},[`&-disabled${d}-button-wrapper-checked`]:{color:q,backgroundColor:U,borderColor:g,boxShadow:"none"},"&-block":{flex:1,textAlign:"center"}}}},prepareComponentToken$d=a=>{const{wireframe:c,padding:u,marginXS:d,lineWidth:f,fontSizeLG:m,colorText:g,colorBgContainer:y,colorTextDisabled:b,controlItemBgActiveDisabled:E,colorTextLightSolid:C,colorPrimary:w,colorPrimaryHover:R,colorPrimaryActive:_,colorWhite:M}=a,I=4,N=m,A=c?N-I*2:N-(I+f)*2;return{radioSize:N,dotSize:A,dotColorDisabled:b,buttonSolidCheckedColor:C,buttonSolidCheckedBg:w,buttonSolidCheckedHoverBg:R,buttonSolidCheckedActiveBg:_,buttonBg:y,buttonCheckedBg:y,buttonColor:g,buttonCheckedBgDisabled:E,buttonCheckedColorDisabled:b,buttonPaddingInline:u-f,wrapperMarginInlineEnd:d,radioColor:c?w:M,radioBgColor:c?y:w}},useStyle$h=genStyleHooks("Radio",a=>{const{controlOutline:c,controlOutlineWidth:u}=a,d=`0 0 0 ${unit$1(u)} ${c}`,m=merge$2(a,{radioFocusShadow:d,radioButtonFocusShadow:d});return[getGroupRadioStyle(m),getRadioBasicStyle(m),getRadioButtonStyle(m)]},prepareComponentToken$d,{unitless:{radioSize:!0,dotSize:!0}});var __rest$G=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalRadio=(a,c)=>{var u,d;const f=reactExports.useContext(RadioGroupContext),m=reactExports.useContext(RadioOptionTypeContext),{getPrefixCls:g,direction:y,radio:b}=reactExports.useContext(ConfigContext),E=reactExports.useRef(null),C=composeRef(c,E),{isFormItemInput:w}=reactExports.useContext(FormItemInputContext),R=W=>{var G,te;(G=a.onChange)===null||G===void 0||G.call(a,W),(te=f==null?void 0:f.onChange)===null||te===void 0||te.call(f,W)},{prefixCls:_,className:M,rootClassName:I,children:N,style:A,title:P}=a,z=__rest$G(a,["prefixCls","className","rootClassName","children","style","title"]),B=g("radio",_),j=((f==null?void 0:f.optionType)||m)==="button",L=j?`${B}-button`:B,U=useCSSVarCls(B),[q,F,K]=useStyle$h(B,U),X=Object.assign({},z),Q=reactExports.useContext(DisabledContext);f&&(X.name=f.name,X.onChange=R,X.checked=a.value===f.value,X.disabled=(u=X.disabled)!==null&&u!==void 0?u:f.disabled),X.disabled=(d=X.disabled)!==null&&d!==void 0?d:Q;const Y=classNames(`${L}-wrapper`,{[`${L}-wrapper-checked`]:X.checked,[`${L}-wrapper-disabled`]:X.disabled,[`${L}-wrapper-rtl`]:y==="rtl",[`${L}-wrapper-in-form-item`]:w,[`${L}-wrapper-block`]:!!(f!=null&&f.block)},b==null?void 0:b.className,M,I,F,K,U),[Z,J]=useBubbleLock(X.onClick);return q(reactExports.createElement(Wave,{component:"Radio",disabled:X.disabled},reactExports.createElement("label",{className:Y,style:Object.assign(Object.assign({},b==null?void 0:b.style),A),onMouseEnter:a.onMouseEnter,onMouseLeave:a.onMouseLeave,title:P,onClick:Z},reactExports.createElement(Checkbox$2,Object.assign({},X,{className:classNames(X.className,{[TARGET_CLS]:!j}),type:"radio",prefixCls:L,ref:C,onClick:J})),N!==void 0?reactExports.createElement("span",{className:`${L}-label`},N):null)))},Radio$1=reactExports.forwardRef(InternalRadio),RadioGroup=reactExports.forwardRef((a,c)=>{const{getPrefixCls:u,direction:d}=reactExports.useContext(ConfigContext),f=useId$1(),{prefixCls:m,className:g,rootClassName:y,options:b,buttonStyle:E="outline",disabled:C,children:w,size:R,style:_,id:M,optionType:I,name:N=f,defaultValue:A,value:P,block:z=!1,onChange:B,onMouseEnter:j,onMouseLeave:L,onFocus:U,onBlur:q}=a,[F,K]=useMergedState(A,{value:P}),X=reactExports.useCallback(le=>{const ee=F,ie=le.target.value;"value"in a||K(ie),ie!==ee&&(B==null||B(le))},[F,K,B]),Q=u("radio",m),Y=`${Q}-group`,Z=useCSSVarCls(Q),[J,W,G]=useStyle$h(Q,Z);let te=w;b&&b.length>0&&(te=b.map(le=>typeof le=="string"||typeof le=="number"?reactExports.createElement(Radio$1,{key:le.toString(),prefixCls:Q,disabled:C,value:le,checked:F===le},le):reactExports.createElement(Radio$1,{key:`radio-group-value-options-${le.value}`,prefixCls:Q,disabled:le.disabled||C,value:le.value,checked:F===le.value,title:le.title,style:le.style,id:le.id,required:le.required},le.label)));const ae=useSize(R),V=classNames(Y,`${Y}-${E}`,{[`${Y}-${ae}`]:ae,[`${Y}-rtl`]:d==="rtl",[`${Y}-block`]:z},g,y,W,G,Z),ne=reactExports.useMemo(()=>({onChange:X,value:F,disabled:C,name:N,optionType:I,block:z}),[X,F,C,N,I,z]);return J(reactExports.createElement("div",Object.assign({},pickAttrs(a,{aria:!0,data:!0}),{className:V,style:_,onMouseEnter:j,onMouseLeave:L,onFocus:U,onBlur:q,id:M,ref:c}),reactExports.createElement(RadioGroupContextProvider,{value:ne},te)))}),Group$2=reactExports.memo(RadioGroup);var __rest$F=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const RadioButton=(a,c)=>{const{getPrefixCls:u}=reactExports.useContext(ConfigContext),{prefixCls:d}=a,f=__rest$F(a,["prefixCls"]),m=u("radio",d);return reactExports.createElement(RadioOptionTypeContextProvider,{value:"button"},reactExports.createElement(Radio$1,Object.assign({prefixCls:m},f,{type:"radio",ref:c})))},Button=reactExports.forwardRef(RadioButton),Radio=Radio$1;Radio.Button=Button;Radio.Group=Group$2;Radio.__ANT_RADIO=!0;function initInputToken(a){return merge$2(a,{inputAffixPadding:a.paddingXXS})}const initComponentToken$1=a=>{const{controlHeight:c,fontSize:u,lineHeight:d,lineWidth:f,controlHeightSM:m,controlHeightLG:g,fontSizeLG:y,lineHeightLG:b,paddingSM:E,controlPaddingHorizontalSM:C,controlPaddingHorizontal:w,colorFillAlter:R,colorPrimaryHover:_,colorPrimary:M,controlOutlineWidth:I,controlOutline:N,colorErrorOutline:A,colorWarningOutline:P,colorBgContainer:z,inputFontSize:B,inputFontSizeLG:j,inputFontSizeSM:L}=a,U=B||u,q=L||U,F=j||y,K=Math.round((c-U*d)/2*10)/10-f,X=Math.round((m-q*d)/2*10)/10-f,Q=Math.ceil((g-F*b)/2*10)/10-f;return{paddingBlock:Math.max(K,0),paddingBlockSM:Math.max(X,0),paddingBlockLG:Math.max(Q,0),paddingInline:E-f,paddingInlineSM:C-f,paddingInlineLG:w-f,addonBg:R,activeBorderColor:M,hoverBorderColor:_,activeShadow:`0 0 0 ${I}px ${N}`,errorActiveShadow:`0 0 0 ${I}px ${A}`,warningActiveShadow:`0 0 0 ${I}px ${P}`,hoverBg:z,activeBg:z,inputFontSize:U,inputFontSizeLG:F,inputFontSizeSM:q}},genHoverStyle=a=>({borderColor:a.hoverBorderColor,backgroundColor:a.hoverBg}),genDisabledStyle=a=>({color:a.colorTextDisabled,backgroundColor:a.colorBgContainerDisabled,borderColor:a.colorBorder,boxShadow:"none",cursor:"not-allowed",opacity:1,"input[disabled], textarea[disabled]":{cursor:"not-allowed"},"&:hover:not([disabled])":Object.assign({},genHoverStyle(merge$2(a,{hoverBorderColor:a.colorBorder,hoverBg:a.colorBgContainerDisabled})))}),genBaseOutlinedStyle=(a,c)=>({background:a.colorBgContainer,borderWidth:a.lineWidth,borderStyle:a.lineType,borderColor:c.borderColor,"&:hover":{borderColor:c.hoverBorderColor,backgroundColor:a.hoverBg},"&:focus, &:focus-within":{borderColor:c.activeBorderColor,boxShadow:c.activeShadow,outline:0,backgroundColor:a.activeBg}}),genOutlinedStatusStyle=(a,c)=>({[`&${a.componentCls}-status-${c.status}:not(${a.componentCls}-disabled)`]:Object.assign(Object.assign({},genBaseOutlinedStyle(a,c)),{[`${a.componentCls}-prefix, ${a.componentCls}-suffix`]:{color:c.affixColor}}),[`&${a.componentCls}-status-${c.status}${a.componentCls}-disabled`]:{borderColor:c.borderColor}}),genOutlinedStyle=(a,c)=>({"&-outlined":Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},genBaseOutlinedStyle(a,{borderColor:a.colorBorder,hoverBorderColor:a.hoverBorderColor,activeBorderColor:a.activeBorderColor,activeShadow:a.activeShadow})),{[`&${a.componentCls}-disabled, &[disabled]`]:Object.assign({},genDisabledStyle(a))}),genOutlinedStatusStyle(a,{status:"error",borderColor:a.colorError,hoverBorderColor:a.colorErrorBorderHover,activeBorderColor:a.colorError,activeShadow:a.errorActiveShadow,affixColor:a.colorError})),genOutlinedStatusStyle(a,{status:"warning",borderColor:a.colorWarning,hoverBorderColor:a.colorWarningBorderHover,activeBorderColor:a.colorWarning,activeShadow:a.warningActiveShadow,affixColor:a.colorWarning})),c)}),genOutlinedGroupStatusStyle=(a,c)=>({[`&${a.componentCls}-group-wrapper-status-${c.status}`]:{[`${a.componentCls}-group-addon`]:{borderColor:c.addonBorderColor,color:c.addonColor}}}),genOutlinedGroupStyle=a=>({"&-outlined":Object.assign(Object.assign(Object.assign({[`${a.componentCls}-group`]:{"&-addon":{background:a.addonBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`},"&-addon:first-child":{borderInlineEnd:0},"&-addon:last-child":{borderInlineStart:0}}},genOutlinedGroupStatusStyle(a,{status:"error",addonBorderColor:a.colorError,addonColor:a.colorErrorText})),genOutlinedGroupStatusStyle(a,{status:"warning",addonBorderColor:a.colorWarning,addonColor:a.colorWarningText})),{[`&${a.componentCls}-group-wrapper-disabled`]:{[`${a.componentCls}-group-addon`]:Object.assign({},genDisabledStyle(a))}})}),genBorderlessStyle=(a,c)=>{const{componentCls:u}=a;return{"&-borderless":Object.assign({background:"transparent",border:"none","&:focus, &:focus-within":{outline:"none"},[`&${u}-disabled, &[disabled]`]:{color:a.colorTextDisabled,cursor:"not-allowed"},[`&${u}-status-error`]:{"&, & input, & textarea":{color:a.colorError}},[`&${u}-status-warning`]:{"&, & input, & textarea":{color:a.colorWarning}}},c)}},genBaseFilledStyle=(a,c)=>{var u;return{background:c.bg,borderWidth:a.lineWidth,borderStyle:a.lineType,borderColor:"transparent","input&, & input, textarea&, & textarea":{color:(u=c==null?void 0:c.inputColor)!==null&&u!==void 0?u:"unset"},"&:hover":{background:c.hoverBg},"&:focus, &:focus-within":{outline:0,borderColor:c.activeBorderColor,backgroundColor:a.activeBg}}},genFilledStatusStyle=(a,c)=>({[`&${a.componentCls}-status-${c.status}:not(${a.componentCls}-disabled)`]:Object.assign(Object.assign({},genBaseFilledStyle(a,c)),{[`${a.componentCls}-prefix, ${a.componentCls}-suffix`]:{color:c.affixColor}})}),genFilledStyle=(a,c)=>({"&-filled":Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},genBaseFilledStyle(a,{bg:a.colorFillTertiary,hoverBg:a.colorFillSecondary,activeBorderColor:a.activeBorderColor})),{[`&${a.componentCls}-disabled, &[disabled]`]:Object.assign({},genDisabledStyle(a))}),genFilledStatusStyle(a,{status:"error",bg:a.colorErrorBg,hoverBg:a.colorErrorBgHover,activeBorderColor:a.colorError,inputColor:a.colorErrorText,affixColor:a.colorError})),genFilledStatusStyle(a,{status:"warning",bg:a.colorWarningBg,hoverBg:a.colorWarningBgHover,activeBorderColor:a.colorWarning,inputColor:a.colorWarningText,affixColor:a.colorWarning})),c)}),genFilledGroupStatusStyle=(a,c)=>({[`&${a.componentCls}-group-wrapper-status-${c.status}`]:{[`${a.componentCls}-group-addon`]:{background:c.addonBg,color:c.addonColor}}}),genFilledGroupStyle=a=>({"&-filled":Object.assign(Object.assign(Object.assign({[`${a.componentCls}-group`]:{"&-addon":{background:a.colorFillTertiary},[`${a.componentCls}-filled:not(:focus):not(:focus-within)`]:{"&:not(:first-child)":{borderInlineStart:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorSplit}`},"&:not(:last-child)":{borderInlineEnd:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorSplit}`}}}},genFilledGroupStatusStyle(a,{status:"error",addonBg:a.colorErrorBg,addonColor:a.colorErrorText})),genFilledGroupStatusStyle(a,{status:"warning",addonBg:a.colorWarningBg,addonColor:a.colorWarningText})),{[`&${a.componentCls}-group-wrapper-disabled`]:{[`${a.componentCls}-group`]:{"&-addon":{background:a.colorFillTertiary,color:a.colorTextDisabled},"&-addon:first-child":{borderInlineStart:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderTop:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderBottom:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`},"&-addon:last-child":{borderInlineEnd:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderTop:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderBottom:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`}}}})}),genBaseUnderlinedStyle=(a,c)=>({background:a.colorBgContainer,borderWidth:`${unit$1(a.lineWidth)} 0`,borderStyle:`${a.lineType} none`,borderColor:`transparent transparent ${c.borderColor} transparent`,borderRadius:0,"&:hover":{borderColor:`transparent transparent ${c.borderColor} transparent`,backgroundColor:a.hoverBg},"&:focus, &:focus-within":{borderColor:`transparent transparent ${c.borderColor} transparent`,outline:0,backgroundColor:a.activeBg}}),genUnderlinedStatusStyle=(a,c)=>({[`&${a.componentCls}-status-${c.status}:not(${a.componentCls}-disabled)`]:Object.assign(Object.assign({},genBaseUnderlinedStyle(a,c)),{[`${a.componentCls}-prefix, ${a.componentCls}-suffix`]:{color:c.affixColor}}),[`&${a.componentCls}-status-${c.status}${a.componentCls}-disabled`]:{borderColor:`transparent transparent ${c.borderColor} transparent`}}),genUnderlinedStyle=(a,c)=>({"&-underlined":Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},genBaseUnderlinedStyle(a,{borderColor:a.colorBorder,hoverBorderColor:a.hoverBorderColor,activeBorderColor:a.activeBorderColor,activeShadow:a.activeShadow})),{[`&${a.componentCls}-disabled, &[disabled]`]:{color:a.colorTextDisabled,boxShadow:"none",cursor:"not-allowed","&:hover":{borderColor:`transparent transparent ${a.colorBorder} transparent`}},"input[disabled], textarea[disabled]":{cursor:"not-allowed"}}),genUnderlinedStatusStyle(a,{status:"error",borderColor:a.colorError,hoverBorderColor:a.colorErrorBorderHover,activeBorderColor:a.colorError,activeShadow:a.errorActiveShadow,affixColor:a.colorError})),genUnderlinedStatusStyle(a,{status:"warning",borderColor:a.colorWarning,hoverBorderColor:a.colorWarningBorderHover,activeBorderColor:a.colorWarning,activeShadow:a.warningActiveShadow,affixColor:a.colorWarning})),c)}),genPlaceholderStyle=a=>({"&::-moz-placeholder":{opacity:1},"&::placeholder":{color:a,userSelect:"none"},"&:placeholder-shown":{textOverflow:"ellipsis"}}),genInputLargeStyle=a=>{const{paddingBlockLG:c,lineHeightLG:u,borderRadiusLG:d,paddingInlineLG:f}=a;return{padding:`${unit$1(c)} ${unit$1(f)}`,fontSize:a.inputFontSizeLG,lineHeight:u,borderRadius:d}},genInputSmallStyle=a=>({padding:`${unit$1(a.paddingBlockSM)} ${unit$1(a.paddingInlineSM)}`,fontSize:a.inputFontSizeSM,borderRadius:a.borderRadiusSM}),genBasicInputStyle=a=>Object.assign(Object.assign({position:"relative",display:"inline-block",width:"100%",minWidth:0,padding:`${unit$1(a.paddingBlock)} ${unit$1(a.paddingInline)}`,color:a.colorText,fontSize:a.inputFontSize,lineHeight:a.lineHeight,borderRadius:a.borderRadius,transition:`all ${a.motionDurationMid}`},genPlaceholderStyle(a.colorTextPlaceholder)),{"&-lg":Object.assign({},genInputLargeStyle(a)),"&-sm":Object.assign({},genInputSmallStyle(a)),"&-rtl, &-textarea-rtl":{direction:"rtl"}}),genInputGroupStyle=a=>{const{componentCls:c,antCls:u}=a;return{position:"relative",display:"table",width:"100%",borderCollapse:"separate",borderSpacing:0,"&[class*='col-']":{paddingInlineEnd:a.paddingXS,"&:last-child":{paddingInlineEnd:0}},[`&-lg ${c}, &-lg > ${c}-group-addon`]:Object.assign({},genInputLargeStyle(a)),[`&-sm ${c}, &-sm > ${c}-group-addon`]:Object.assign({},genInputSmallStyle(a)),[`&-lg ${u}-select-single ${u}-select-selector`]:{height:a.controlHeightLG},[`&-sm ${u}-select-single ${u}-select-selector`]:{height:a.controlHeightSM},[`> ${c}`]:{display:"table-cell","&:not(:first-child):not(:last-child)":{borderRadius:0}},[`${c}-group`]:{"&-addon, &-wrap":{display:"table-cell",width:1,whiteSpace:"nowrap",verticalAlign:"middle","&:not(:first-child):not(:last-child)":{borderRadius:0}},"&-wrap > *":{display:"block !important"},"&-addon":{position:"relative",padding:`0 ${unit$1(a.paddingInline)}`,color:a.colorText,fontWeight:"normal",fontSize:a.inputFontSize,textAlign:"center",borderRadius:a.borderRadius,transition:`all ${a.motionDurationSlow}`,lineHeight:1,[`${u}-select`]:{margin:`${unit$1(a.calc(a.paddingBlock).add(1).mul(-1).equal())} ${unit$1(a.calc(a.paddingInline).mul(-1).equal())}`,[`&${u}-select-single:not(${u}-select-customize-input):not(${u}-pagination-size-changer)`]:{[`${u}-select-selector`]:{backgroundColor:"inherit",border:`${unit$1(a.lineWidth)} ${a.lineType} transparent`,boxShadow:"none"}}},[`${u}-cascader-picker`]:{margin:`-9px ${unit$1(a.calc(a.paddingInline).mul(-1).equal())}`,backgroundColor:"transparent",[`${u}-cascader-input`]:{textAlign:"start",border:0,boxShadow:"none"}}}},[c]:{width:"100%",marginBottom:0,textAlign:"inherit","&:focus":{zIndex:1,borderInlineEndWidth:1},"&:hover":{zIndex:1,borderInlineEndWidth:1,[`${c}-search-with-button &`]:{zIndex:0}}},[`> ${c}:first-child, ${c}-group-addon:first-child`]:{borderStartEndRadius:0,borderEndEndRadius:0,[`${u}-select ${u}-select-selector`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`> ${c}-affix-wrapper`]:{[`&:not(:first-child) ${c}`]:{borderStartStartRadius:0,borderEndStartRadius:0},[`&:not(:last-child) ${c}`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`> ${c}:last-child, ${c}-group-addon:last-child`]:{borderStartStartRadius:0,borderEndStartRadius:0,[`${u}-select ${u}-select-selector`]:{borderStartStartRadius:0,borderEndStartRadius:0}},[`${c}-affix-wrapper`]:{"&:not(:last-child)":{borderStartEndRadius:0,borderEndEndRadius:0,[`${c}-search &`]:{borderStartStartRadius:a.borderRadius,borderEndStartRadius:a.borderRadius}},[`&:not(:first-child), ${c}-search &:not(:first-child)`]:{borderStartStartRadius:0,borderEndStartRadius:0}},[`&${c}-group-compact`]:Object.assign(Object.assign({display:"block"},clearFix()),{[`${c}-group-addon, ${c}-group-wrap, > ${c}`]:{"&:not(:first-child):not(:last-child)":{borderInlineEndWidth:a.lineWidth,"&:hover, &:focus":{zIndex:1}}},"& > *":{display:"inline-flex",float:"none",verticalAlign:"top",borderRadius:0},[`
        & > ${c}-affix-wrapper,
        & > ${c}-number-affix-wrapper,
        & > ${u}-picker-range
      `]:{display:"inline-flex"},"& > *:not(:last-child)":{marginInlineEnd:a.calc(a.lineWidth).mul(-1).equal(),borderInlineEndWidth:a.lineWidth},[c]:{float:"none"},[`& > ${u}-select > ${u}-select-selector,
      & > ${u}-select-auto-complete ${c},
      & > ${u}-cascader-picker ${c},
      & > ${c}-group-wrapper ${c}`]:{borderInlineEndWidth:a.lineWidth,borderRadius:0,"&:hover, &:focus":{zIndex:1}},[`& > ${u}-select-focused`]:{zIndex:1},[`& > ${u}-select > ${u}-select-arrow`]:{zIndex:1},[`& > *:first-child,
      & > ${u}-select:first-child > ${u}-select-selector,
      & > ${u}-select-auto-complete:first-child ${c},
      & > ${u}-cascader-picker:first-child ${c}`]:{borderStartStartRadius:a.borderRadius,borderEndStartRadius:a.borderRadius},[`& > *:last-child,
      & > ${u}-select:last-child > ${u}-select-selector,
      & > ${u}-cascader-picker:last-child ${c},
      & > ${u}-cascader-picker-focused:last-child ${c}`]:{borderInlineEndWidth:a.lineWidth,borderStartEndRadius:a.borderRadius,borderEndEndRadius:a.borderRadius},[`& > ${u}-select-auto-complete ${c}`]:{verticalAlign:"top"},[`${c}-group-wrapper + ${c}-group-wrapper`]:{marginInlineStart:a.calc(a.lineWidth).mul(-1).equal(),[`${c}-affix-wrapper`]:{borderRadius:0}},[`${c}-group-wrapper:not(:last-child)`]:{[`&${c}-search > ${c}-group`]:{[`& > ${c}-group-addon > ${c}-search-button`]:{borderRadius:0},[`& > ${c}`]:{borderStartStartRadius:a.borderRadius,borderStartEndRadius:0,borderEndEndRadius:0,borderEndStartRadius:a.borderRadius}}}})}},genInputStyle=a=>{const{componentCls:c,controlHeightSM:u,lineWidth:d,calc:f}=a,g=f(u).sub(f(d).mul(2)).sub(16).div(2).equal();return{[c]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),genBasicInputStyle(a)),genOutlinedStyle(a)),genFilledStyle(a)),genBorderlessStyle(a)),genUnderlinedStyle(a)),{'&[type="color"]':{height:a.controlHeight,[`&${c}-lg`]:{height:a.controlHeightLG},[`&${c}-sm`]:{height:u,paddingTop:g,paddingBottom:g}},'&[type="search"]::-webkit-search-cancel-button, &[type="search"]::-webkit-search-decoration':{appearance:"none"}})}},genAllowClearStyle=a=>{const{componentCls:c}=a;return{[`${c}-clear-icon`]:{margin:0,padding:0,lineHeight:0,color:a.colorTextQuaternary,fontSize:a.fontSizeIcon,verticalAlign:-1,cursor:"pointer",transition:`color ${a.motionDurationSlow}`,border:"none",outline:"none",backgroundColor:"transparent","&:hover":{color:a.colorIcon},"&:active":{color:a.colorText},"&-hidden":{visibility:"hidden"},"&-has-suffix":{margin:`0 ${unit$1(a.inputAffixPadding)}`}}}},genAffixStyle=a=>{const{componentCls:c,inputAffixPadding:u,colorTextDescription:d,motionDurationSlow:f,colorIcon:m,colorIconHover:g,iconCls:y}=a,b=`${c}-affix-wrapper`,E=`${c}-affix-wrapper-disabled`;return{[b]:Object.assign(Object.assign(Object.assign(Object.assign({},genBasicInputStyle(a)),{display:"inline-flex",[`&:not(${c}-disabled):hover`]:{zIndex:1,[`${c}-search-with-button &`]:{zIndex:0}},"&-focused, &:focus":{zIndex:1},[`> input${c}`]:{padding:0},[`> input${c}, > textarea${c}`]:{fontSize:"inherit",border:"none",borderRadius:0,outline:"none",background:"transparent",color:"inherit","&::-ms-reveal":{display:"none"},"&:focus":{boxShadow:"none !important"}},"&::before":{display:"inline-block",width:0,visibility:"hidden",content:'"\\a0"'},[c]:{"&-prefix, &-suffix":{display:"flex",flex:"none",alignItems:"center","> *:not(:last-child)":{marginInlineEnd:a.paddingXS}},"&-show-count-suffix":{color:d,direction:"ltr"},"&-show-count-has-suffix":{marginInlineEnd:a.paddingXXS},"&-prefix":{marginInlineEnd:u},"&-suffix":{marginInlineStart:u}}}),genAllowClearStyle(a)),{[`${y}${c}-password-icon`]:{color:m,cursor:"pointer",transition:`all ${f}`,"&:hover":{color:g}}}),[`${c}-underlined`]:{borderRadius:0},[E]:{[`${y}${c}-password-icon`]:{color:m,cursor:"not-allowed","&:hover":{color:m}}}}},genGroupStyle=a=>{const{componentCls:c,borderRadiusLG:u,borderRadiusSM:d}=a;return{[`${c}-group`]:Object.assign(Object.assign(Object.assign({},resetComponent(a)),genInputGroupStyle(a)),{"&-rtl":{direction:"rtl"},"&-wrapper":Object.assign(Object.assign(Object.assign({display:"inline-block",width:"100%",textAlign:"start",verticalAlign:"top","&-rtl":{direction:"rtl"},"&-lg":{[`${c}-group-addon`]:{borderRadius:u,fontSize:a.inputFontSizeLG}},"&-sm":{[`${c}-group-addon`]:{borderRadius:d}}},genOutlinedGroupStyle(a)),genFilledGroupStyle(a)),{[`&:not(${c}-compact-first-item):not(${c}-compact-last-item)${c}-compact-item`]:{[`${c}, ${c}-group-addon`]:{borderRadius:0}},[`&:not(${c}-compact-last-item)${c}-compact-first-item`]:{[`${c}, ${c}-group-addon`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&:not(${c}-compact-first-item)${c}-compact-last-item`]:{[`${c}, ${c}-group-addon`]:{borderStartStartRadius:0,borderEndStartRadius:0}},[`&:not(${c}-compact-last-item)${c}-compact-item`]:{[`${c}-affix-wrapper`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&:not(${c}-compact-first-item)${c}-compact-item`]:{[`${c}-affix-wrapper`]:{borderStartStartRadius:0,borderEndStartRadius:0}}})})}},genSearchInputStyle=a=>{const{componentCls:c,antCls:u}=a,d=`${c}-search`;return{[d]:{[c]:{"&:hover, &:focus":{[`+ ${c}-group-addon ${d}-button:not(${u}-btn-primary)`]:{borderInlineStartColor:a.colorPrimaryHover}}},[`${c}-affix-wrapper`]:{height:a.controlHeight,borderRadius:0},[`${c}-lg`]:{lineHeight:a.calc(a.lineHeightLG).sub(2e-4).equal()},[`> ${c}-group`]:{[`> ${c}-group-addon:last-child`]:{insetInlineStart:-1,padding:0,border:0,[`${d}-button`]:{marginInlineEnd:-1,borderStartStartRadius:0,borderEndStartRadius:0,boxShadow:"none"},[`${d}-button:not(${u}-btn-primary)`]:{color:a.colorTextDescription,"&:hover":{color:a.colorPrimaryHover},"&:active":{color:a.colorPrimaryActive},[`&${u}-btn-loading::before`]:{insetInlineStart:0,insetInlineEnd:0,insetBlockStart:0,insetBlockEnd:0}}}},[`${d}-button`]:{height:a.controlHeight,"&:hover, &:focus":{zIndex:1}},"&-large":{[`${c}-affix-wrapper, ${d}-button`]:{height:a.controlHeightLG}},"&-small":{[`${c}-affix-wrapper, ${d}-button`]:{height:a.controlHeightSM}},"&-rtl":{direction:"rtl"},[`&${c}-compact-item`]:{[`&:not(${c}-compact-last-item)`]:{[`${c}-group-addon`]:{[`${c}-search-button`]:{marginInlineEnd:a.calc(a.lineWidth).mul(-1).equal(),borderRadius:0}}},[`&:not(${c}-compact-first-item)`]:{[`${c},${c}-affix-wrapper`]:{borderRadius:0}},[`> ${c}-group-addon ${c}-search-button,
        > ${c},
        ${c}-affix-wrapper`]:{"&:hover, &:focus, &:active":{zIndex:2}},[`> ${c}-affix-wrapper-focused`]:{zIndex:2}}}}},genRangeStyle=a=>{const{componentCls:c}=a;return{[`${c}-out-of-range`]:{[`&, & input, & textarea, ${c}-show-count-suffix, ${c}-data-count`]:{color:a.colorError}}}},useSharedStyle=genStyleHooks(["Input","Shared"],a=>{const c=merge$2(a,initInputToken(a));return[genInputStyle(c),genAffixStyle(c)]},initComponentToken$1,{resetFont:!1}),useStyle$g=genStyleHooks(["Input","Component"],a=>{const c=merge$2(a,initInputToken(a));return[genGroupStyle(c),genSearchInputStyle(c),genRangeStyle(c),genCompactItemStyle(c)]},initComponentToken$1,{resetFont:!1}),TabContext=reactExports.createContext(null);var useIndicator=function(c){var u=c.activeTabOffset,d=c.horizontal,f=c.rtl,m=c.indicator,g=m===void 0?{}:m,y=g.size,b=g.align,E=b===void 0?"center":b,C=reactExports.useState(),w=_slicedToArray(C,2),R=w[0],_=w[1],M=reactExports.useRef(),I=React.useCallback(function(A){return typeof y=="function"?y(A):typeof y=="number"?y:A},[y]);function N(){wrapperRaf.cancel(M.current)}return reactExports.useEffect(function(){var A={};if(u)if(d){A.width=I(u.width);var P=f?"right":"left";E==="start"&&(A[P]=u[P]),E==="center"&&(A[P]=u[P]+u.width/2,A.transform=f?"translateX(50%)":"translateX(-50%)"),E==="end"&&(A[P]=u[P]+u.width,A.transform="translateX(-100%)")}else A.height=I(u.height),E==="start"&&(A.top=u.top),E==="center"&&(A.top=u.top+u.height/2,A.transform="translateY(-50%)"),E==="end"&&(A.top=u.top+u.height,A.transform="translateY(-100%)");return N(),M.current=wrapperRaf(function(){var z=R&&A&&Object.keys(A).every(function(B){var j=A[B],L=R[B];return typeof j=="number"&&typeof L=="number"?Math.round(j)===Math.round(L):j===L});z||_(A)}),N},[JSON.stringify(u),d,f,E,I]),{style:R}},DEFAULT_SIZE$1={width:0,height:0,left:0,top:0};function useOffsets(a,c,u){return reactExports.useMemo(function(){for(var d,f=new Map,m=c.get((d=a[0])===null||d===void 0?void 0:d.key)||DEFAULT_SIZE$1,g=m.left+m.width,y=0;y<a.length;y+=1){var b=a[y].key,E=c.get(b);if(!E){var C;E=c.get((C=a[y-1])===null||C===void 0?void 0:C.key)||DEFAULT_SIZE$1}var w=f.get(b)||_objectSpread2({},E);w.right=g-w.left-w.width,f.set(b,w)}return f},[a.map(function(d){return d.key}).join("_"),c,u])}function useSyncState$1(a,c){var u=reactExports.useRef(a),d=reactExports.useState({}),f=_slicedToArray(d,2),m=f[1];function g(y){var b=typeof y=="function"?y(u.current):y;b!==u.current&&c(b,u.current),u.current=b,m({})}return[u.current,g]}var MIN_SWIPE_DISTANCE=.1,STOP_SWIPE_DISTANCE=.01,REFRESH_INTERVAL=20,SPEED_OFF_MULTIPLE=Math.pow(.995,REFRESH_INTERVAL);function useTouchMove(a,c){var u=reactExports.useState(),d=_slicedToArray(u,2),f=d[0],m=d[1],g=reactExports.useState(0),y=_slicedToArray(g,2),b=y[0],E=y[1],C=reactExports.useState(0),w=_slicedToArray(C,2),R=w[0],_=w[1],M=reactExports.useState(),I=_slicedToArray(M,2),N=I[0],A=I[1],P=reactExports.useRef();function z(F){var K=F.touches[0],X=K.screenX,Q=K.screenY;m({x:X,y:Q}),window.clearInterval(P.current)}function B(F){if(f){var K=F.touches[0],X=K.screenX,Q=K.screenY;m({x:X,y:Q});var Y=X-f.x,Z=Q-f.y;c(Y,Z);var J=Date.now();E(J),_(J-b),A({x:Y,y:Z})}}function j(){if(f&&(m(null),A(null),N)){var F=N.x/R,K=N.y/R,X=Math.abs(F),Q=Math.abs(K);if(Math.max(X,Q)<MIN_SWIPE_DISTANCE)return;var Y=F,Z=K;P.current=window.setInterval(function(){if(Math.abs(Y)<STOP_SWIPE_DISTANCE&&Math.abs(Z)<STOP_SWIPE_DISTANCE){window.clearInterval(P.current);return}Y*=SPEED_OFF_MULTIPLE,Z*=SPEED_OFF_MULTIPLE,c(Y*REFRESH_INTERVAL,Z*REFRESH_INTERVAL)},REFRESH_INTERVAL)}}var L=reactExports.useRef();function U(F){var K=F.deltaX,X=F.deltaY,Q=0,Y=Math.abs(K),Z=Math.abs(X);Y===Z?Q=L.current==="x"?K:X:Y>Z?(Q=K,L.current="x"):(Q=X,L.current="y"),c(-Q,-Q)&&F.preventDefault()}var q=reactExports.useRef(null);q.current={onTouchStart:z,onTouchMove:B,onTouchEnd:j,onWheel:U},reactExports.useEffect(function(){function F(Y){q.current.onTouchStart(Y)}function K(Y){q.current.onTouchMove(Y)}function X(Y){q.current.onTouchEnd(Y)}function Q(Y){q.current.onWheel(Y)}return document.addEventListener("touchmove",K,{passive:!1}),document.addEventListener("touchend",X,{passive:!0}),a.current.addEventListener("touchstart",F,{passive:!0}),a.current.addEventListener("wheel",Q,{passive:!1}),function(){document.removeEventListener("touchmove",K),document.removeEventListener("touchend",X)}},[])}function useUpdate(a){var c=reactExports.useState(0),u=_slicedToArray(c,2),d=u[0],f=u[1],m=reactExports.useRef(0),g=reactExports.useRef();return g.current=a,useLayoutUpdateEffect(function(){var y;(y=g.current)===null||y===void 0||y.call(g)},[d]),function(){m.current===d&&(m.current+=1,f(m.current))}}function useUpdateState(a){var c=reactExports.useRef([]),u=reactExports.useState({}),d=_slicedToArray(u,2),f=d[1],m=reactExports.useRef(typeof a=="function"?a():a),g=useUpdate(function(){var b=m.current;c.current.forEach(function(E){b=E(b)}),c.current=[],m.current=b,f({})});function y(b){c.current.push(b),g()}return[m.current,y]}var DEFAULT_SIZE={width:0,height:0,left:0,top:0,right:0};function useVisibleRange(a,c,u,d,f,m,g){var y=g.tabs,b=g.tabPosition,E=g.rtl,C,w,R;return["top","bottom"].includes(b)?(C="width",w=E?"right":"left",R=Math.abs(u)):(C="height",w="top",R=-u),reactExports.useMemo(function(){if(!y.length)return[0,0];for(var _=y.length,M=_,I=0;I<_;I+=1){var N=a.get(y[I].key)||DEFAULT_SIZE;if(Math.floor(N[w]+N[C])>Math.floor(R+c)){M=I-1;break}}for(var A=0,P=_-1;P>=0;P-=1){var z=a.get(y[P].key)||DEFAULT_SIZE;if(z[w]<R){A=P+1;break}}return A>=M?[0,0]:[A,M]},[a,c,d,f,m,R,b,y.map(function(_){return _.key}).join("_"),E])}function stringify$2(a){var c;return a instanceof Map?(c={},a.forEach(function(u,d){c[d]=u})):c=a,JSON.stringify(c)}var RC_TABS_DOUBLE_QUOTE="TABS_DQ";function genDataNodeKey(a){return String(a).replace(/"/g,RC_TABS_DOUBLE_QUOTE)}function getRemovable(a,c,u,d){return!(!u||d||a===!1||a===void 0&&(c===!1||c===null))}var AddButton=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.editable,f=a.locale,m=a.style;return!d||d.showAdd===!1?null:reactExports.createElement("button",{ref:c,type:"button",className:"".concat(u,"-nav-add"),style:m,"aria-label":(f==null?void 0:f.addAriaLabel)||"Add tab",onClick:function(y){d.onEdit("add",{event:y})}},d.addIcon||"+")}),ExtraContent=reactExports.forwardRef(function(a,c){var u=a.position,d=a.prefixCls,f=a.extra;if(!f)return null;var m,g={};return _typeof(f)==="object"&&!reactExports.isValidElement(f)?g=f:g.right=f,u==="right"&&(m=g.right),u==="left"&&(m=g.left),m?reactExports.createElement("div",{className:"".concat(d,"-extra-content"),ref:c},m):null}),OperationNode=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.id,f=a.tabs,m=a.locale,g=a.mobile,y=a.more,b=y===void 0?{}:y,E=a.style,C=a.className,w=a.editable,R=a.tabBarGutter,_=a.rtl,M=a.removeAriaLabel,I=a.onTabClick,N=a.getPopupContainer,A=a.popupClassName,P=reactExports.useState(!1),z=_slicedToArray(P,2),B=z[0],j=z[1],L=reactExports.useState(null),U=_slicedToArray(L,2),q=U[0],F=U[1],K=b.icon,X=K===void 0?"More":K,Q="".concat(d,"-more-popup"),Y="".concat(u,"-dropdown"),Z=q!==null?"".concat(Q,"-").concat(q):null,J=m==null?void 0:m.dropdownAriaLabel;function W(ee,ie){ee.preventDefault(),ee.stopPropagation(),w.onEdit("remove",{key:ie,event:ee})}var G=reactExports.createElement(ExportMenu,{onClick:function(ie){var ce=ie.key,ue=ie.domEvent;I(ce,ue),j(!1)},prefixCls:"".concat(Y,"-menu"),id:Q,tabIndex:-1,role:"listbox","aria-activedescendant":Z,selectedKeys:[q],"aria-label":J!==void 0?J:"expanded dropdown"},f.map(function(ee){var ie=ee.closable,ce=ee.disabled,ue=ee.closeIcon,me=ee.key,de=ee.label,ge=getRemovable(ie,ue,w,ce);return reactExports.createElement(MenuItem$2,{key:me,id:"".concat(Q,"-").concat(me),role:"option","aria-controls":d&&"".concat(d,"-panel-").concat(me),disabled:ce},reactExports.createElement("span",null,de),ge&&reactExports.createElement("button",{type:"button","aria-label":M||"remove",tabIndex:0,className:"".concat(Y,"-menu-item-remove"),onClick:function(ve){ve.stopPropagation(),W(ve,me)}},ue||w.removeIcon||"×"))}));function te(ee){for(var ie=f.filter(function(ge){return!ge.disabled}),ce=ie.findIndex(function(ge){return ge.key===q})||0,ue=ie.length,me=0;me<ue;me+=1){ce=(ce+ee+ue)%ue;var de=ie[ce];if(!de.disabled){F(de.key);return}}}function ae(ee){var ie=ee.which;if(!B){[KeyCode.DOWN,KeyCode.SPACE,KeyCode.ENTER].includes(ie)&&(j(!0),ee.preventDefault());return}switch(ie){case KeyCode.UP:te(-1),ee.preventDefault();break;case KeyCode.DOWN:te(1),ee.preventDefault();break;case KeyCode.ESC:j(!1);break;case KeyCode.SPACE:case KeyCode.ENTER:q!==null&&I(q,ee);break}}reactExports.useEffect(function(){var ee=document.getElementById(Z);ee&&ee.scrollIntoView&&ee.scrollIntoView(!1)},[q]),reactExports.useEffect(function(){B||F(null)},[B]);var V=_defineProperty({},_?"marginRight":"marginLeft",R);f.length||(V.visibility="hidden",V.order=1);var ne=classNames(_defineProperty({},"".concat(Y,"-rtl"),_)),le=g?null:reactExports.createElement(Dropdown$3,_extends({prefixCls:Y,overlay:G,visible:f.length?B:!1,onVisibleChange:j,overlayClassName:classNames(ne,A),mouseEnterDelay:.1,mouseLeaveDelay:.1,getPopupContainer:N},b),reactExports.createElement("button",{type:"button",className:"".concat(u,"-nav-more"),style:V,"aria-haspopup":"listbox","aria-controls":Q,id:"".concat(d,"-more"),"aria-expanded":B,onKeyDown:ae},X));return reactExports.createElement("div",{className:classNames("".concat(u,"-nav-operations"),C),style:E,ref:c},le,reactExports.createElement(AddButton,{prefixCls:u,locale:m,editable:w}))});const OperationNode$1=reactExports.memo(OperationNode,function(a,c){return c.tabMoving});var TabNode=function(c){var u=c.prefixCls,d=c.id,f=c.active,m=c.focus,g=c.tab,y=g.key,b=g.label,E=g.disabled,C=g.closeIcon,w=g.icon,R=c.closable,_=c.renderWrapper,M=c.removeAriaLabel,I=c.editable,N=c.onClick,A=c.onFocus,P=c.onBlur,z=c.onKeyDown,B=c.onMouseDown,j=c.onMouseUp,L=c.style,U=c.tabCount,q=c.currentPosition,F="".concat(u,"-tab"),K=getRemovable(R,C,I,E);function X(W){E||N(W)}function Q(W){W.preventDefault(),W.stopPropagation(),I.onEdit("remove",{key:y,event:W})}var Y=reactExports.useMemo(function(){return w&&typeof b=="string"?reactExports.createElement("span",null,b):b},[b,w]),Z=reactExports.useRef(null);reactExports.useEffect(function(){m&&Z.current&&Z.current.focus()},[m]);var J=reactExports.createElement("div",{key:y,"data-node-key":genDataNodeKey(y),className:classNames(F,_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(F,"-with-remove"),K),"".concat(F,"-active"),f),"".concat(F,"-disabled"),E),"".concat(F,"-focus"),m)),style:L,onClick:X},reactExports.createElement("div",{ref:Z,role:"tab","aria-selected":f,id:d&&"".concat(d,"-tab-").concat(y),className:"".concat(F,"-btn"),"aria-controls":d&&"".concat(d,"-panel-").concat(y),"aria-disabled":E,tabIndex:E?null:f?0:-1,onClick:function(G){G.stopPropagation(),X(G)},onKeyDown:z,onMouseDown:B,onMouseUp:j,onFocus:A,onBlur:P},m&&reactExports.createElement("div",{"aria-live":"polite",style:{width:0,height:0,position:"absolute",overflow:"hidden",opacity:0}},"Tab ".concat(q," of ").concat(U)),w&&reactExports.createElement("span",{className:"".concat(F,"-icon")},w),b&&Y),K&&reactExports.createElement("button",{type:"button",role:"tab","aria-label":M||"remove",tabIndex:f?0:-1,className:"".concat(F,"-remove"),onClick:function(G){G.stopPropagation(),Q(G)}},C||I.removeIcon||"×"));return _?_(J):J},getTabSize=function(c,u){var d=c.offsetWidth,f=c.offsetHeight,m=c.offsetTop,g=c.offsetLeft,y=c.getBoundingClientRect(),b=y.width,E=y.height,C=y.left,w=y.top;return Math.abs(b-d)<1?[b,E,C-u.left,w-u.top]:[d,f,g,m]},getSize=function(c){var u=c.current||{},d=u.offsetWidth,f=d===void 0?0:d,m=u.offsetHeight,g=m===void 0?0:m;if(c.current){var y=c.current.getBoundingClientRect(),b=y.width,E=y.height;if(Math.abs(b-f)<1)return[b,E]}return[f,g]},getUnitValue=function(c,u){return c[u?0:1]},TabNavList=reactExports.forwardRef(function(a,c){var u=a.className,d=a.style,f=a.id,m=a.animated,g=a.activeKey,y=a.rtl,b=a.extra,E=a.editable,C=a.locale,w=a.tabPosition,R=a.tabBarGutter,_=a.children,M=a.onTabClick,I=a.onTabScroll,N=a.indicator,A=reactExports.useContext(TabContext),P=A.prefixCls,z=A.tabs,B=reactExports.useRef(null),j=reactExports.useRef(null),L=reactExports.useRef(null),U=reactExports.useRef(null),q=reactExports.useRef(null),F=reactExports.useRef(null),K=reactExports.useRef(null),X=w==="top"||w==="bottom",Q=useSyncState$1(0,function(lt,nt){X&&I&&I({direction:lt>nt?"left":"right"})}),Y=_slicedToArray(Q,2),Z=Y[0],J=Y[1],W=useSyncState$1(0,function(lt,nt){!X&&I&&I({direction:lt>nt?"top":"bottom"})}),G=_slicedToArray(W,2),te=G[0],ae=G[1],V=reactExports.useState([0,0]),ne=_slicedToArray(V,2),le=ne[0],ee=ne[1],ie=reactExports.useState([0,0]),ce=_slicedToArray(ie,2),ue=ce[0],me=ce[1],de=reactExports.useState([0,0]),ge=_slicedToArray(de,2),Ce=ge[0],ve=ge[1],fe=reactExports.useState([0,0]),pe=_slicedToArray(fe,2),xe=pe[0],ye=pe[1],he=useUpdateState(new Map),we=_slicedToArray(he,2),Re=we[0],De=we[1],Ae=useOffsets(z,Re,ue[0]),Ee=getUnitValue(le,X),Ne=getUnitValue(ue,X),_e=getUnitValue(Ce,X),ke=getUnitValue(xe,X),Ke=Math.floor(Ee)<Math.floor(Ne+_e),be=Ke?Ee-ke:Ee-_e,Te="".concat(P,"-nav-operations-hidden"),Le=0,Oe=0;X&&y?(Le=0,Oe=Math.max(0,Ne-be)):(Le=Math.min(0,be-Ne),Oe=0);function Be(lt){return lt<Le?Le:lt>Oe?Oe:lt}var Ve=reactExports.useRef(null),Pe=reactExports.useState(),Ge=_slicedToArray(Pe,2),qe=Ge[0],Ue=Ge[1];function je(){Ue(Date.now())}function We(){Ve.current&&clearTimeout(Ve.current)}useTouchMove(U,function(lt,nt){function Ot(Bt,qt){Bt(function(er){var St=Be(er+qt);return St})}return Ke?(X?Ot(J,lt):Ot(ae,nt),We(),je(),!0):!1}),reactExports.useEffect(function(){return We(),qe&&(Ve.current=setTimeout(function(){Ue(0)},100)),We},[qe]);var ut=useVisibleRange(Ae,be,X?Z:te,Ne,_e,ke,_objectSpread2(_objectSpread2({},a),{},{tabs:z})),gt=_slicedToArray(ut,2),kt=gt[0],Ut=gt[1],at=useEvent(function(){var lt=arguments.length>0&&arguments[0]!==void 0?arguments[0]:g,nt=Ae.get(lt)||{width:0,height:0,left:0,right:0,top:0};if(X){var Ot=Z;y?nt.right<Z?Ot=nt.right:nt.right+nt.width>Z+be&&(Ot=nt.right+nt.width-be):nt.left<-Z?Ot=-nt.left:nt.left+nt.width>-Z+be&&(Ot=-(nt.left+nt.width-be)),ae(0),J(Be(Ot))}else{var Bt=te;nt.top<-te?Bt=-nt.top:nt.top+nt.height>-te+be&&(Bt=-(nt.top+nt.height-be)),J(0),ae(Be(Bt))}}),ct=reactExports.useState(),bt=_slicedToArray(ct,2),it=bt[0],vt=bt[1],ot=reactExports.useState(!1),rt=_slicedToArray(ot,2),et=rt[0],$t=rt[1],mt=z.filter(function(lt){return!lt.disabled}).map(function(lt){return lt.key}),Ze=function(nt){var Ot=mt.indexOf(it||g),Bt=mt.length,qt=(Ot+nt+Bt)%Bt,er=mt[qt];vt(er)},Je=function(nt){var Ot=nt.code,Bt=y&&X,qt=mt[0],er=mt[mt.length-1];switch(Ot){case"ArrowLeft":{X&&Ze(Bt?1:-1);break}case"ArrowRight":{X&&Ze(Bt?-1:1);break}case"ArrowUp":{nt.preventDefault(),X||Ze(-1);break}case"ArrowDown":{nt.preventDefault(),X||Ze(1);break}case"Home":{nt.preventDefault(),vt(qt);break}case"End":{nt.preventDefault(),vt(er);break}case"Enter":case"Space":{nt.preventDefault(),M(g,nt);break}case"Backspace":case"Delete":{var St=mt.indexOf(it),_t=z.find(function(nr){return nr.key===it}),zt=getRemovable(_t==null?void 0:_t.closable,_t==null?void 0:_t.closeIcon,E,_t==null?void 0:_t.disabled);zt&&(nt.preventDefault(),nt.stopPropagation(),E.onEdit("remove",{key:it,event:nt}),St===mt.length-1?Ze(-1):Ze(1));break}}},yt={};X?yt[y?"marginRight":"marginLeft"]=R:yt.marginTop=R;var Ct=z.map(function(lt,nt){var Ot=lt.key;return reactExports.createElement(TabNode,{id:f,prefixCls:P,key:Ot,tab:lt,style:nt===0?void 0:yt,closable:lt.closable,editable:E,active:Ot===g,focus:Ot===it,renderWrapper:_,removeAriaLabel:C==null?void 0:C.removeAriaLabel,tabCount:mt.length,currentPosition:nt+1,onClick:function(qt){M(Ot,qt)},onKeyDown:Je,onFocus:function(){et||vt(Ot),at(Ot),je(),U.current&&(y||(U.current.scrollLeft=0),U.current.scrollTop=0)},onBlur:function(){vt(void 0)},onMouseDown:function(){$t(!0)},onMouseUp:function(){$t(!1)}})}),pt=function(){return De(function(){var nt,Ot=new Map,Bt=(nt=q.current)===null||nt===void 0?void 0:nt.getBoundingClientRect();return z.forEach(function(qt){var er,St=qt.key,_t=(er=q.current)===null||er===void 0?void 0:er.querySelector('[data-node-key="'.concat(genDataNodeKey(St),'"]'));if(_t){var zt=getTabSize(_t,Bt),nr=_slicedToArray(zt,4),Rr=nr[0],Jr=nr[1],Tr=nr[2],lr=nr[3];Ot.set(St,{width:Rr,height:Jr,left:Tr,top:lr})}}),Ot})};reactExports.useEffect(function(){pt()},[z.map(function(lt){return lt.key}).join("_")]);var Rt=useUpdate(function(){var lt=getSize(B),nt=getSize(j),Ot=getSize(L);ee([lt[0]-nt[0]-Ot[0],lt[1]-nt[1]-Ot[1]]);var Bt=getSize(K);ve(Bt);var qt=getSize(F);ye(qt);var er=getSize(q);me([er[0]-Bt[0],er[1]-Bt[1]]),pt()}),ft=z.slice(0,kt),dt=z.slice(Ut+1),xt=[].concat(_toConsumableArray(ft),_toConsumableArray(dt)),Tt=Ae.get(g),Dt=useIndicator({activeTabOffset:Tt,horizontal:X,indicator:N,rtl:y}),Vt=Dt.style;reactExports.useEffect(function(){at()},[g,Le,Oe,stringify$2(Tt),stringify$2(Ae),X]),reactExports.useEffect(function(){Rt()},[y]);var Nt=!!xt.length,Kt="".concat(P,"-nav-wrap"),Zt,Gt,tt,ht;return X?y?(Gt=Z>0,Zt=Z!==Oe):(Zt=Z<0,Gt=Z!==Le):(tt=te<0,ht=te!==Le),reactExports.createElement(RefResizeObserver,{onResize:Rt},reactExports.createElement("div",{ref:useComposeRef(c,B),role:"tablist","aria-orientation":X?"horizontal":"vertical",className:classNames("".concat(P,"-nav"),u),style:d,onKeyDown:function(){je()}},reactExports.createElement(ExtraContent,{ref:j,position:"left",extra:b,prefixCls:P}),reactExports.createElement(RefResizeObserver,{onResize:Rt},reactExports.createElement("div",{className:classNames(Kt,_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(Kt,"-ping-left"),Zt),"".concat(Kt,"-ping-right"),Gt),"".concat(Kt,"-ping-top"),tt),"".concat(Kt,"-ping-bottom"),ht)),ref:U},reactExports.createElement(RefResizeObserver,{onResize:Rt},reactExports.createElement("div",{ref:q,className:"".concat(P,"-nav-list"),style:{transform:"translate(".concat(Z,"px, ").concat(te,"px)"),transition:qe?"none":void 0}},Ct,reactExports.createElement(AddButton,{ref:K,prefixCls:P,locale:C,editable:E,style:_objectSpread2(_objectSpread2({},Ct.length===0?void 0:yt),{},{visibility:Nt?"hidden":null})}),reactExports.createElement("div",{className:classNames("".concat(P,"-ink-bar"),_defineProperty({},"".concat(P,"-ink-bar-animated"),m.inkBar)),style:Vt}))))),reactExports.createElement(OperationNode$1,_extends({},a,{removeAriaLabel:C==null?void 0:C.removeAriaLabel,ref:F,prefixCls:P,tabs:xt,className:!Nt&&Te,tabMoving:!!qe})),reactExports.createElement(ExtraContent,{ref:L,position:"right",extra:b,prefixCls:P})))}),TabPane$1=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.className,f=a.style,m=a.id,g=a.active,y=a.tabKey,b=a.children;return reactExports.createElement("div",{id:m&&"".concat(m,"-panel-").concat(y),role:"tabpanel",tabIndex:g?0:-1,"aria-labelledby":m&&"".concat(m,"-tab-").concat(y),"aria-hidden":!g,style:f,className:classNames(u,g&&"".concat(u,"-active"),d),ref:c},b)}),_excluded$k=["renderTabBar"],_excluded2$5=["label","key"],TabNavListWrapper=function(c){var u=c.renderTabBar,d=_objectWithoutProperties(c,_excluded$k),f=reactExports.useContext(TabContext),m=f.tabs;if(u){var g=_objectSpread2(_objectSpread2({},d),{},{panes:m.map(function(y){var b=y.label,E=y.key,C=_objectWithoutProperties(y,_excluded2$5);return reactExports.createElement(TabPane$1,_extends({tab:b,key:E,tabKey:E},C))})});return u(g,TabNavList)}return reactExports.createElement(TabNavList,d)},_excluded$j=["key","forceRender","style","className","destroyInactiveTabPane"],TabPanelList=function(c){var u=c.id,d=c.activeKey,f=c.animated,m=c.tabPosition,g=c.destroyInactiveTabPane,y=reactExports.useContext(TabContext),b=y.prefixCls,E=y.tabs,C=f.tabPane,w="".concat(b,"-tabpane");return reactExports.createElement("div",{className:classNames("".concat(b,"-content-holder"))},reactExports.createElement("div",{className:classNames("".concat(b,"-content"),"".concat(b,"-content-").concat(m),_defineProperty({},"".concat(b,"-content-animated"),C))},E.map(function(R){var _=R.key,M=R.forceRender,I=R.style,N=R.className,A=R.destroyInactiveTabPane,P=_objectWithoutProperties(R,_excluded$j),z=_===d;return reactExports.createElement(CSSMotion,_extends({key:_,visible:z,forceRender:M,removeOnLeave:!!(g||A),leavedClassName:"".concat(w,"-hidden")},f.tabPaneMotion),function(B,j){var L=B.style,U=B.className;return reactExports.createElement(TabPane$1,_extends({},P,{prefixCls:w,id:u,tabKey:_,animated:C,active:z,style:_objectSpread2(_objectSpread2({},I),L),className:classNames(N,U),ref:j}))})})))};function useAnimateConfig$1(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{inkBar:!0,tabPane:!1},c;return a===!1?c={inkBar:!1,tabPane:!1}:a===!0?c={inkBar:!0,tabPane:!1}:c=_objectSpread2({inkBar:!0},_typeof(a)==="object"?a:{}),c.tabPaneMotion&&c.tabPane===void 0&&(c.tabPane=!0),!c.tabPaneMotion&&c.tabPane&&(c.tabPane=!1),c}var _excluded$i=["id","prefixCls","className","items","direction","activeKey","defaultActiveKey","editable","animated","tabPosition","tabBarGutter","tabBarStyle","tabBarExtraContent","locale","more","destroyInactiveTabPane","renderTabBar","onChange","onTabClick","onTabScroll","getPopupContainer","popupClassName","indicator"],uuid=0,Tabs$1=reactExports.forwardRef(function(a,c){var u=a.id,d=a.prefixCls,f=d===void 0?"rc-tabs":d,m=a.className,g=a.items,y=a.direction,b=a.activeKey,E=a.defaultActiveKey,C=a.editable,w=a.animated,R=a.tabPosition,_=R===void 0?"top":R,M=a.tabBarGutter,I=a.tabBarStyle,N=a.tabBarExtraContent,A=a.locale,P=a.more,z=a.destroyInactiveTabPane,B=a.renderTabBar,j=a.onChange,L=a.onTabClick,U=a.onTabScroll,q=a.getPopupContainer,F=a.popupClassName,K=a.indicator,X=_objectWithoutProperties(a,_excluded$i),Q=reactExports.useMemo(function(){return(g||[]).filter(function(xe){return xe&&_typeof(xe)==="object"&&"key"in xe})},[g]),Y=y==="rtl",Z=useAnimateConfig$1(w),J=reactExports.useState(!1),W=_slicedToArray(J,2),G=W[0],te=W[1];reactExports.useEffect(function(){te(isMobile())},[]);var ae=useMergedState(function(){var xe;return(xe=Q[0])===null||xe===void 0?void 0:xe.key},{value:b,defaultValue:E}),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=reactExports.useState(function(){return Q.findIndex(function(xe){return xe.key===ne})}),ie=_slicedToArray(ee,2),ce=ie[0],ue=ie[1];reactExports.useEffect(function(){var xe=Q.findIndex(function(he){return he.key===ne});if(xe===-1){var ye;xe=Math.max(0,Math.min(ce,Q.length-1)),le((ye=Q[xe])===null||ye===void 0?void 0:ye.key)}ue(xe)},[Q.map(function(xe){return xe.key}).join("_"),ne,ce]);var me=useMergedState(null,{value:u}),de=_slicedToArray(me,2),ge=de[0],Ce=de[1];reactExports.useEffect(function(){u||(Ce("rc-tabs-".concat(uuid)),uuid+=1)},[]);function ve(xe,ye){L==null||L(xe,ye);var he=xe!==ne;le(xe),he&&(j==null||j(xe))}var fe={id:ge,activeKey:ne,animated:Z,tabPosition:_,rtl:Y,mobile:G},pe=_objectSpread2(_objectSpread2({},fe),{},{editable:C,locale:A,more:P,tabBarGutter:M,onTabClick:ve,onTabScroll:U,extra:N,style:I,panes:null,getPopupContainer:q,popupClassName:F,indicator:K});return reactExports.createElement(TabContext.Provider,{value:{tabs:Q,prefixCls:f}},reactExports.createElement("div",_extends({ref:c,id:u,className:classNames(f,"".concat(f,"-").concat(_),_defineProperty(_defineProperty(_defineProperty({},"".concat(f,"-mobile"),G),"".concat(f,"-editable"),C),"".concat(f,"-rtl"),Y),m)},X),reactExports.createElement(TabNavListWrapper,_extends({},pe,{renderTabBar:B})),reactExports.createElement(TabPanelList,_extends({destroyInactiveTabPane:z},fe,{animated:Z}))))});const motion={motionAppear:!1,motionEnter:!0,motionLeave:!0};function useAnimateConfig(a){let c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{inkBar:!0,tabPane:!1},u;return c===!1?u={inkBar:!1,tabPane:!1}:c===!0?u={inkBar:!0,tabPane:!0}:u=Object.assign({inkBar:!0},typeof c=="object"?c:{}),u.tabPane&&(u.tabPaneMotion=Object.assign(Object.assign({},motion),{motionName:getTransitionName(a,"switch")})),u}var __rest$E=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function filter(a){return a.filter(c=>c)}function useLegacyItems(a,c){if(a)return a;const u=toArray$6(c).map(d=>{if(reactExports.isValidElement(d)){const{key:f,props:m}=d,g=m||{},{tab:y}=g,b=__rest$E(g,["tab"]);return Object.assign(Object.assign({key:String(f)},b),{label:y})}return null});return filter(u)}const genMotionStyle=a=>{const{componentCls:c,motionDurationSlow:u}=a;return[{[c]:{[`${c}-switch`]:{"&-appear, &-enter":{transition:"none","&-start":{opacity:0},"&-active":{opacity:1,transition:`opacity ${u}`}},"&-leave":{position:"absolute",transition:"none",inset:0,"&-start":{opacity:1},"&-active":{opacity:0,transition:`opacity ${u}`}}}}},[initSlideMotion(a,"slide-up"),initSlideMotion(a,"slide-down")]]},genCardStyle$1=a=>{const{componentCls:c,tabsCardPadding:u,cardBg:d,cardGutter:f,colorBorderSecondary:m,itemSelectedColor:g}=a;return{[`${c}-card`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab`]:{margin:0,padding:u,background:d,border:`${unit$1(a.lineWidth)} ${a.lineType} ${m}`,transition:`all ${a.motionDurationSlow} ${a.motionEaseInOut}`},[`${c}-tab-active`]:{color:g,background:a.colorBgContainer},[`${c}-tab-focus`]:Object.assign({},genFocusOutline(a,-3)),[`${c}-ink-bar`]:{visibility:"hidden"},[`& ${c}-tab${c}-tab-focus ${c}-tab-btn`]:{outline:"none"}},[`&${c}-top, &${c}-bottom`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab + ${c}-tab`]:{marginLeft:{_skip_check_:!0,value:unit$1(f)}}}},[`&${c}-top`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab`]:{borderRadius:`${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0 0`},[`${c}-tab-active`]:{borderBottomColor:a.colorBgContainer}}},[`&${c}-bottom`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab`]:{borderRadius:`0 0 ${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)}`},[`${c}-tab-active`]:{borderTopColor:a.colorBgContainer}}},[`&${c}-left, &${c}-right`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab + ${c}-tab`]:{marginTop:unit$1(f)}}},[`&${c}-left`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab`]:{borderRadius:{_skip_check_:!0,value:`${unit$1(a.borderRadiusLG)} 0 0 ${unit$1(a.borderRadiusLG)}`}},[`${c}-tab-active`]:{borderRightColor:{_skip_check_:!0,value:a.colorBgContainer}}}},[`&${c}-right`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab`]:{borderRadius:{_skip_check_:!0,value:`0 ${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0`}},[`${c}-tab-active`]:{borderLeftColor:{_skip_check_:!0,value:a.colorBgContainer}}}}}}},genDropdownStyle=a=>{const{componentCls:c,itemHoverColor:u,dropdownEdgeChildVerticalPadding:d}=a;return{[`${c}-dropdown`]:Object.assign(Object.assign({},resetComponent(a)),{position:"absolute",top:-9999,left:{_skip_check_:!0,value:-9999},zIndex:a.zIndexPopup,display:"block","&-hidden":{display:"none"},[`${c}-dropdown-menu`]:{maxHeight:a.tabsDropdownHeight,margin:0,padding:`${unit$1(d)} 0`,overflowX:"hidden",overflowY:"auto",textAlign:{_skip_check_:!0,value:"left"},listStyleType:"none",backgroundColor:a.colorBgContainer,backgroundClip:"padding-box",borderRadius:a.borderRadiusLG,outline:"none",boxShadow:a.boxShadowSecondary,"&-item":Object.assign(Object.assign({},textEllipsis),{display:"flex",alignItems:"center",minWidth:a.tabsDropdownWidth,margin:0,padding:`${unit$1(a.paddingXXS)} ${unit$1(a.paddingSM)}`,color:a.colorText,fontWeight:"normal",fontSize:a.fontSize,lineHeight:a.lineHeight,cursor:"pointer",transition:`all ${a.motionDurationSlow}`,"> span":{flex:1,whiteSpace:"nowrap"},"&-remove":{flex:"none",marginLeft:{_skip_check_:!0,value:a.marginSM},color:a.colorIcon,fontSize:a.fontSizeSM,background:"transparent",border:0,cursor:"pointer","&:hover":{color:u}},"&:hover":{background:a.controlItemBgHover},"&-disabled":{"&, &:hover":{color:a.colorTextDisabled,background:"transparent",cursor:"not-allowed"}}})}})}},genPositionStyle=a=>{const{componentCls:c,margin:u,colorBorderSecondary:d,horizontalMargin:f,verticalItemPadding:m,verticalItemMargin:g,calc:y}=a;return{[`${c}-top, ${c}-bottom`]:{flexDirection:"column",[`> ${c}-nav, > div > ${c}-nav`]:{margin:f,"&::before":{position:"absolute",right:{_skip_check_:!0,value:0},left:{_skip_check_:!0,value:0},borderBottom:`${unit$1(a.lineWidth)} ${a.lineType} ${d}`,content:"''"},[`${c}-ink-bar`]:{height:a.lineWidthBold,"&-animated":{transition:`width ${a.motionDurationSlow}, left ${a.motionDurationSlow},
            right ${a.motionDurationSlow}`}},[`${c}-nav-wrap`]:{"&::before, &::after":{top:0,bottom:0,width:a.controlHeight},"&::before":{left:{_skip_check_:!0,value:0},boxShadow:a.boxShadowTabsOverflowLeft},"&::after":{right:{_skip_check_:!0,value:0},boxShadow:a.boxShadowTabsOverflowRight},[`&${c}-nav-wrap-ping-left::before`]:{opacity:1},[`&${c}-nav-wrap-ping-right::after`]:{opacity:1}}}},[`${c}-top`]:{[`> ${c}-nav,
        > div > ${c}-nav`]:{"&::before":{bottom:0},[`${c}-ink-bar`]:{bottom:0}}},[`${c}-bottom`]:{[`> ${c}-nav, > div > ${c}-nav`]:{order:1,marginTop:u,marginBottom:0,"&::before":{top:0},[`${c}-ink-bar`]:{top:0}},[`> ${c}-content-holder, > div > ${c}-content-holder`]:{order:0}},[`${c}-left, ${c}-right`]:{[`> ${c}-nav, > div > ${c}-nav`]:{flexDirection:"column",minWidth:y(a.controlHeight).mul(1.25).equal(),[`${c}-tab`]:{padding:m,textAlign:"center"},[`${c}-tab + ${c}-tab`]:{margin:g},[`${c}-nav-wrap`]:{flexDirection:"column","&::before, &::after":{right:{_skip_check_:!0,value:0},left:{_skip_check_:!0,value:0},height:a.controlHeight},"&::before":{top:0,boxShadow:a.boxShadowTabsOverflowTop},"&::after":{bottom:0,boxShadow:a.boxShadowTabsOverflowBottom},[`&${c}-nav-wrap-ping-top::before`]:{opacity:1},[`&${c}-nav-wrap-ping-bottom::after`]:{opacity:1}},[`${c}-ink-bar`]:{width:a.lineWidthBold,"&-animated":{transition:`height ${a.motionDurationSlow}, top ${a.motionDurationSlow}`}},[`${c}-nav-list, ${c}-nav-operations`]:{flex:"1 0 auto",flexDirection:"column"}}},[`${c}-left`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-ink-bar`]:{right:{_skip_check_:!0,value:0}}},[`> ${c}-content-holder, > div > ${c}-content-holder`]:{marginLeft:{_skip_check_:!0,value:unit$1(y(a.lineWidth).mul(-1).equal())},borderLeft:{_skip_check_:!0,value:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`},[`> ${c}-content > ${c}-tabpane`]:{paddingLeft:{_skip_check_:!0,value:a.paddingLG}}}},[`${c}-right`]:{[`> ${c}-nav, > div > ${c}-nav`]:{order:1,[`${c}-ink-bar`]:{left:{_skip_check_:!0,value:0}}},[`> ${c}-content-holder, > div > ${c}-content-holder`]:{order:0,marginRight:{_skip_check_:!0,value:y(a.lineWidth).mul(-1).equal()},borderRight:{_skip_check_:!0,value:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`},[`> ${c}-content > ${c}-tabpane`]:{paddingRight:{_skip_check_:!0,value:a.paddingLG}}}}}},genSizeStyle$1=a=>{const{componentCls:c,cardPaddingSM:u,cardPaddingLG:d,horizontalItemPaddingSM:f,horizontalItemPaddingLG:m}=a;return{[c]:{"&-small":{[`> ${c}-nav`]:{[`${c}-tab`]:{padding:f,fontSize:a.titleFontSizeSM}}},"&-large":{[`> ${c}-nav`]:{[`${c}-tab`]:{padding:m,fontSize:a.titleFontSizeLG}}}},[`${c}-card`]:{[`&${c}-small`]:{[`> ${c}-nav`]:{[`${c}-tab`]:{padding:u}},[`&${c}-bottom`]:{[`> ${c}-nav ${c}-tab`]:{borderRadius:`0 0 ${unit$1(a.borderRadius)} ${unit$1(a.borderRadius)}`}},[`&${c}-top`]:{[`> ${c}-nav ${c}-tab`]:{borderRadius:`${unit$1(a.borderRadius)} ${unit$1(a.borderRadius)} 0 0`}},[`&${c}-right`]:{[`> ${c}-nav ${c}-tab`]:{borderRadius:{_skip_check_:!0,value:`0 ${unit$1(a.borderRadius)} ${unit$1(a.borderRadius)} 0`}}},[`&${c}-left`]:{[`> ${c}-nav ${c}-tab`]:{borderRadius:{_skip_check_:!0,value:`${unit$1(a.borderRadius)} 0 0 ${unit$1(a.borderRadius)}`}}}},[`&${c}-large`]:{[`> ${c}-nav`]:{[`${c}-tab`]:{padding:d}}}}}},genTabStyle=a=>{const{componentCls:c,itemActiveColor:u,itemHoverColor:d,iconCls:f,tabsHorizontalItemMargin:m,horizontalItemPadding:g,itemSelectedColor:y,itemColor:b}=a,E=`${c}-tab`;return{[E]:{position:"relative",WebkitTouchCallout:"none",WebkitTapHighlightColor:"transparent",display:"inline-flex",alignItems:"center",padding:g,fontSize:a.titleFontSize,background:"transparent",border:0,outline:"none",cursor:"pointer",color:b,"&-btn, &-remove":{"&:focus:not(:focus-visible), &:active":{color:u}},"&-btn":{outline:"none",transition:`all ${a.motionDurationSlow}`,[`${E}-icon:not(:last-child)`]:{marginInlineEnd:a.marginSM}},"&-remove":Object.assign({flex:"none",marginRight:{_skip_check_:!0,value:a.calc(a.marginXXS).mul(-1).equal()},marginLeft:{_skip_check_:!0,value:a.marginXS},color:a.colorIcon,fontSize:a.fontSizeSM,background:"transparent",border:"none",outline:"none",cursor:"pointer",transition:`all ${a.motionDurationSlow}`,"&:hover":{color:a.colorTextHeading}},genFocusStyle(a)),"&:hover":{color:d},[`&${E}-active ${E}-btn`]:{color:y,textShadow:a.tabsActiveTextShadow},[`&${E}-focus ${E}-btn`]:Object.assign({},genFocusOutline(a)),[`&${E}-disabled`]:{color:a.colorTextDisabled,cursor:"not-allowed"},[`&${E}-disabled ${E}-btn, &${E}-disabled ${c}-remove`]:{"&:focus, &:active":{color:a.colorTextDisabled}},[`& ${E}-remove ${f}`]:{margin:0},[`${f}:not(:last-child)`]:{marginRight:{_skip_check_:!0,value:a.marginSM}}},[`${E} + ${E}`]:{margin:{_skip_check_:!0,value:m}}}},genRtlStyle=a=>{const{componentCls:c,tabsHorizontalItemMarginRTL:u,iconCls:d,cardGutter:f,calc:m}=a;return{[`${c}-rtl`]:{direction:"rtl",[`${c}-nav`]:{[`${c}-tab`]:{margin:{_skip_check_:!0,value:u},[`${c}-tab:last-of-type`]:{marginLeft:{_skip_check_:!0,value:0}},[d]:{marginRight:{_skip_check_:!0,value:0},marginLeft:{_skip_check_:!0,value:unit$1(a.marginSM)}},[`${c}-tab-remove`]:{marginRight:{_skip_check_:!0,value:unit$1(a.marginXS)},marginLeft:{_skip_check_:!0,value:unit$1(m(a.marginXXS).mul(-1).equal())},[d]:{margin:0}}}},[`&${c}-left`]:{[`> ${c}-nav`]:{order:1},[`> ${c}-content-holder`]:{order:0}},[`&${c}-right`]:{[`> ${c}-nav`]:{order:0},[`> ${c}-content-holder`]:{order:1}},[`&${c}-card${c}-top, &${c}-card${c}-bottom`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-tab + ${c}-tab`]:{marginRight:{_skip_check_:!0,value:f},marginLeft:{_skip_check_:!0,value:0}}}}},[`${c}-dropdown-rtl`]:{direction:"rtl"},[`${c}-menu-item`]:{[`${c}-dropdown-rtl`]:{textAlign:{_skip_check_:!0,value:"right"}}}}},genTabsStyle=a=>{const{componentCls:c,tabsCardPadding:u,cardHeight:d,cardGutter:f,itemHoverColor:m,itemActiveColor:g,colorBorderSecondary:y}=a;return{[c]:Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),{display:"flex",[`> ${c}-nav, > div > ${c}-nav`]:{position:"relative",display:"flex",flex:"none",alignItems:"center",[`${c}-nav-wrap`]:{position:"relative",display:"flex",flex:"auto",alignSelf:"stretch",overflow:"hidden",whiteSpace:"nowrap",transform:"translate(0)","&::before, &::after":{position:"absolute",zIndex:1,opacity:0,transition:`opacity ${a.motionDurationSlow}`,content:"''",pointerEvents:"none"}},[`${c}-nav-list`]:{position:"relative",display:"flex",transition:`opacity ${a.motionDurationSlow}`},[`${c}-nav-operations`]:{display:"flex",alignSelf:"stretch"},[`${c}-nav-operations-hidden`]:{position:"absolute",visibility:"hidden",pointerEvents:"none"},[`${c}-nav-more`]:{position:"relative",padding:u,background:"transparent",border:0,color:a.colorText,"&::after":{position:"absolute",right:{_skip_check_:!0,value:0},bottom:0,left:{_skip_check_:!0,value:0},height:a.calc(a.controlHeightLG).div(8).equal(),transform:"translateY(100%)",content:"''"}},[`${c}-nav-add`]:Object.assign({minWidth:d,marginLeft:{_skip_check_:!0,value:f},padding:unit$1(a.paddingXS),background:"transparent",border:`${unit$1(a.lineWidth)} ${a.lineType} ${y}`,borderRadius:`${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0 0`,outline:"none",cursor:"pointer",color:a.colorText,transition:`all ${a.motionDurationSlow} ${a.motionEaseInOut}`,"&:hover":{color:m},"&:active, &:focus:not(:focus-visible)":{color:g}},genFocusStyle(a,-3))},[`${c}-extra-content`]:{flex:"none"},[`${c}-ink-bar`]:{position:"absolute",background:a.inkBarColor,pointerEvents:"none"}}),genTabStyle(a)),{[`${c}-content`]:{position:"relative",width:"100%"},[`${c}-content-holder`]:{flex:"auto",minWidth:0,minHeight:0},[`${c}-tabpane`]:Object.assign(Object.assign({},genFocusStyle(a)),{"&-hidden":{display:"none"}})}),[`${c}-centered`]:{[`> ${c}-nav, > div > ${c}-nav`]:{[`${c}-nav-wrap`]:{[`&:not([class*='${c}-nav-wrap-ping']) > ${c}-nav-list`]:{margin:"auto"}}}}}},prepareComponentToken$c=a=>{const c=a.controlHeightLG;return{zIndexPopup:a.zIndexPopupBase+50,cardBg:a.colorFillAlter,cardHeight:c,cardPadding:`${(c-Math.round(a.fontSize*a.lineHeight))/2-a.lineWidth}px ${a.padding}px`,cardPaddingSM:`${a.paddingXXS*1.5}px ${a.padding}px`,cardPaddingLG:`${a.paddingXS}px ${a.padding}px ${a.paddingXXS*1.5}px`,titleFontSize:a.fontSize,titleFontSizeLG:a.fontSizeLG,titleFontSizeSM:a.fontSize,inkBarColor:a.colorPrimary,horizontalMargin:`0 0 ${a.margin}px 0`,horizontalItemGutter:32,horizontalItemMargin:"",horizontalItemMarginRTL:"",horizontalItemPadding:`${a.paddingSM}px 0`,horizontalItemPaddingSM:`${a.paddingXS}px 0`,horizontalItemPaddingLG:`${a.padding}px 0`,verticalItemPadding:`${a.paddingXS}px ${a.paddingLG}px`,verticalItemMargin:`${a.margin}px 0 0 0`,itemColor:a.colorText,itemSelectedColor:a.colorPrimary,itemHoverColor:a.colorPrimaryHover,itemActiveColor:a.colorPrimaryActive,cardGutter:a.marginXXS/2}},useStyle$f=genStyleHooks("Tabs",a=>{const c=merge$2(a,{tabsCardPadding:a.cardPadding,dropdownEdgeChildVerticalPadding:a.paddingXXS,tabsActiveTextShadow:"0 0 0.25px currentcolor",tabsDropdownHeight:200,tabsDropdownWidth:120,tabsHorizontalItemMargin:`0 0 0 ${unit$1(a.horizontalItemGutter)}`,tabsHorizontalItemMarginRTL:`0 0 0 ${unit$1(a.horizontalItemGutter)}`});return[genSizeStyle$1(c),genRtlStyle(c),genPositionStyle(c),genDropdownStyle(c),genCardStyle$1(c),genTabsStyle(c),genMotionStyle(c)]},prepareComponentToken$c),TabPane=()=>null;var __rest$D=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Tabs=a=>{var c,u,d,f,m,g,y,b,E,C,w;const{type:R,className:_,rootClassName:M,size:I,onEdit:N,hideAdd:A,centered:P,addIcon:z,removeIcon:B,moreIcon:j,more:L,popupClassName:U,children:q,items:F,animated:K,style:X,indicatorSize:Q,indicator:Y}=a,Z=__rest$D(a,["type","className","rootClassName","size","onEdit","hideAdd","centered","addIcon","removeIcon","moreIcon","more","popupClassName","children","items","animated","style","indicatorSize","indicator"]),{prefixCls:J}=Z,{direction:W,tabs:G,getPrefixCls:te,getPopupContainer:ae}=reactExports.useContext(ConfigContext),V=te("tabs",J),ne=useCSSVarCls(V),[le,ee,ie]=useStyle$f(V,ne);let ce;R==="editable-card"&&(ce={onEdit:(fe,pe)=>{let{key:xe,event:ye}=pe;N==null||N(fe==="add"?ye:xe,fe)},removeIcon:(c=B??(G==null?void 0:G.removeIcon))!==null&&c!==void 0?c:reactExports.createElement(RefIcon$x,null),addIcon:(z??(G==null?void 0:G.addIcon))||reactExports.createElement(RefIcon$b,null),showAdd:A!==!0});const ue=te(),me=useSize(I),de=useLegacyItems(F,q),ge=useAnimateConfig(V,K),Ce=Object.assign(Object.assign({},G==null?void 0:G.style),X),ve={align:(u=Y==null?void 0:Y.align)!==null&&u!==void 0?u:(d=G==null?void 0:G.indicator)===null||d===void 0?void 0:d.align,size:(y=(m=(f=Y==null?void 0:Y.size)!==null&&f!==void 0?f:Q)!==null&&m!==void 0?m:(g=G==null?void 0:G.indicator)===null||g===void 0?void 0:g.size)!==null&&y!==void 0?y:G==null?void 0:G.indicatorSize};return le(reactExports.createElement(Tabs$1,Object.assign({direction:W,getPopupContainer:ae},Z,{items:de,className:classNames({[`${V}-${me}`]:me,[`${V}-card`]:["card","editable-card"].includes(R),[`${V}-editable-card`]:R==="editable-card",[`${V}-centered`]:P},G==null?void 0:G.className,_,M,ee,ie,ne),popupClassName:classNames(U,ee,ie,ne),style:Ce,editable:ce,more:Object.assign({icon:(w=(C=(E=(b=G==null?void 0:G.more)===null||b===void 0?void 0:b.icon)!==null&&E!==void 0?E:G==null?void 0:G.moreIcon)!==null&&C!==void 0?C:j)!==null&&w!==void 0?w:reactExports.createElement(RefIcon$r,null),transitionName:`${ue}-slide-up`},L),prefixCls:V,animated:ge,indicator:ve})))};Tabs.TabPane=TabPane;var __rest$C=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Grid$1=a=>{var{prefixCls:c,className:u,hoverable:d=!0}=a,f=__rest$C(a,["prefixCls","className","hoverable"]);const{getPrefixCls:m}=reactExports.useContext(ConfigContext),g=m("card",c),y=classNames(`${g}-grid`,u,{[`${g}-grid-hoverable`]:d});return reactExports.createElement("div",Object.assign({},f,{className:y}))},genCardHeadStyle=a=>{const{antCls:c,componentCls:u,headerHeight:d,headerPadding:f,tabsMarginBottom:m}=a;return Object.assign(Object.assign({display:"flex",justifyContent:"center",flexDirection:"column",minHeight:d,marginBottom:-1,padding:`0 ${unit$1(f)}`,color:a.colorTextHeading,fontWeight:a.fontWeightStrong,fontSize:a.headerFontSize,background:a.headerBg,borderBottom:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorderSecondary}`,borderRadius:`${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0 0`},clearFix()),{"&-wrapper":{width:"100%",display:"flex",alignItems:"center"},"&-title":Object.assign(Object.assign({display:"inline-block",flex:1},textEllipsis),{[`
          > ${u}-typography,
          > ${u}-typography-edit-content
        `]:{insetInlineStart:0,marginTop:0,marginBottom:0}}),[`${c}-tabs-top`]:{clear:"both",marginBottom:m,color:a.colorText,fontWeight:"normal",fontSize:a.fontSize,"&-bar":{borderBottom:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorderSecondary}`}}})},genCardGridStyle=a=>{const{cardPaddingBase:c,colorBorderSecondary:u,cardShadow:d,lineWidth:f}=a;return{width:"33.33%",padding:c,border:0,borderRadius:0,boxShadow:`
      ${unit$1(f)} 0 0 0 ${u},
      0 ${unit$1(f)} 0 0 ${u},
      ${unit$1(f)} ${unit$1(f)} 0 0 ${u},
      ${unit$1(f)} 0 0 0 ${u} inset,
      0 ${unit$1(f)} 0 0 ${u} inset;
    `,transition:`all ${a.motionDurationMid}`,"&-hoverable:hover":{position:"relative",zIndex:1,boxShadow:d}}},genCardActionsStyle=a=>{const{componentCls:c,iconCls:u,actionsLiMargin:d,cardActionsIconSize:f,colorBorderSecondary:m,actionsBg:g}=a;return Object.assign(Object.assign({margin:0,padding:0,listStyle:"none",background:g,borderTop:`${unit$1(a.lineWidth)} ${a.lineType} ${m}`,display:"flex",borderRadius:`0 0 ${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)}`},clearFix()),{"& > li":{margin:d,color:a.colorTextDescription,textAlign:"center","> span":{position:"relative",display:"block",minWidth:a.calc(a.cardActionsIconSize).mul(2).equal(),fontSize:a.fontSize,lineHeight:a.lineHeight,cursor:"pointer","&:hover":{color:a.colorPrimary,transition:`color ${a.motionDurationMid}`},[`a:not(${c}-btn), > ${u}`]:{display:"inline-block",width:"100%",color:a.colorIcon,lineHeight:unit$1(a.fontHeight),transition:`color ${a.motionDurationMid}`,"&:hover":{color:a.colorPrimary}},[`> ${u}`]:{fontSize:f,lineHeight:unit$1(a.calc(f).mul(a.lineHeight).equal())}},"&:not(:last-child)":{borderInlineEnd:`${unit$1(a.lineWidth)} ${a.lineType} ${m}`}}})},genCardMetaStyle=a=>Object.assign(Object.assign({margin:`${unit$1(a.calc(a.marginXXS).mul(-1).equal())} 0`,display:"flex"},clearFix()),{"&-avatar":{paddingInlineEnd:a.padding},"&-detail":{overflow:"hidden",flex:1,"> div:not(:last-child)":{marginBottom:a.marginXS}},"&-title":Object.assign({color:a.colorTextHeading,fontWeight:a.fontWeightStrong,fontSize:a.fontSizeLG},textEllipsis),"&-description":{color:a.colorTextDescription}}),genCardTypeInnerStyle=a=>{const{componentCls:c,colorFillAlter:u,headerPadding:d,bodyPadding:f}=a;return{[`${c}-head`]:{padding:`0 ${unit$1(d)}`,background:u,"&-title":{fontSize:a.fontSize}},[`${c}-body`]:{padding:`${unit$1(a.padding)} ${unit$1(f)}`}}},genCardLoadingStyle=a=>{const{componentCls:c}=a;return{overflow:"hidden",[`${c}-body`]:{userSelect:"none"}}},genCardStyle=a=>{const{componentCls:c,cardShadow:u,cardHeadPadding:d,colorBorderSecondary:f,boxShadowTertiary:m,bodyPadding:g,extraColor:y}=a;return{[c]:Object.assign(Object.assign({},resetComponent(a)),{position:"relative",background:a.colorBgContainer,borderRadius:a.borderRadiusLG,[`&:not(${c}-bordered)`]:{boxShadow:m},[`${c}-head`]:genCardHeadStyle(a),[`${c}-extra`]:{marginInlineStart:"auto",color:y,fontWeight:"normal",fontSize:a.fontSize},[`${c}-body`]:Object.assign({padding:g,borderRadius:`0 0 ${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)}`},clearFix()),[`${c}-grid`]:genCardGridStyle(a),[`${c}-cover`]:{"> *":{display:"block",width:"100%",borderRadius:`${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0 0`}},[`${c}-actions`]:genCardActionsStyle(a),[`${c}-meta`]:genCardMetaStyle(a)}),[`${c}-bordered`]:{border:`${unit$1(a.lineWidth)} ${a.lineType} ${f}`,[`${c}-cover`]:{marginTop:-1,marginInlineStart:-1,marginInlineEnd:-1}},[`${c}-hoverable`]:{cursor:"pointer",transition:`box-shadow ${a.motionDurationMid}, border-color ${a.motionDurationMid}`,"&:hover":{borderColor:"transparent",boxShadow:u}},[`${c}-contain-grid`]:{borderRadius:`${unit$1(a.borderRadiusLG)} ${unit$1(a.borderRadiusLG)} 0 0 `,[`${c}-body`]:{display:"flex",flexWrap:"wrap"},[`&:not(${c}-loading) ${c}-body`]:{marginBlockStart:a.calc(a.lineWidth).mul(-1).equal(),marginInlineStart:a.calc(a.lineWidth).mul(-1).equal(),padding:0}},[`${c}-contain-tabs`]:{[`> div${c}-head`]:{minHeight:0,[`${c}-head-title, ${c}-extra`]:{paddingTop:d}}},[`${c}-type-inner`]:genCardTypeInnerStyle(a),[`${c}-loading`]:genCardLoadingStyle(a),[`${c}-rtl`]:{direction:"rtl"}}},genCardSizeStyle=a=>{const{componentCls:c,bodyPaddingSM:u,headerPaddingSM:d,headerHeightSM:f,headerFontSizeSM:m}=a;return{[`${c}-small`]:{[`> ${c}-head`]:{minHeight:f,padding:`0 ${unit$1(d)}`,fontSize:m,[`> ${c}-head-wrapper`]:{[`> ${c}-extra`]:{fontSize:a.fontSize}}},[`> ${c}-body`]:{padding:u}},[`${c}-small${c}-contain-tabs`]:{[`> ${c}-head`]:{[`${c}-head-title, ${c}-extra`]:{paddingTop:0,display:"flex",alignItems:"center"}}}}},prepareComponentToken$b=a=>{var c,u;return{headerBg:"transparent",headerFontSize:a.fontSizeLG,headerFontSizeSM:a.fontSize,headerHeight:a.fontSizeLG*a.lineHeightLG+a.padding*2,headerHeightSM:a.fontSize*a.lineHeight+a.paddingXS*2,actionsBg:a.colorBgContainer,actionsLiMargin:`${a.paddingSM}px 0`,tabsMarginBottom:-a.padding-a.lineWidth,extraColor:a.colorText,bodyPaddingSM:12,headerPaddingSM:12,bodyPadding:(c=a.bodyPadding)!==null&&c!==void 0?c:a.paddingLG,headerPadding:(u=a.headerPadding)!==null&&u!==void 0?u:a.paddingLG}},useStyle$e=genStyleHooks("Card",a=>{const c=merge$2(a,{cardShadow:a.boxShadowCard,cardHeadPadding:a.padding,cardPaddingBase:a.paddingLG,cardActionsIconSize:a.fontSize});return[genCardStyle(c),genCardSizeStyle(c)]},prepareComponentToken$b);var __rest$B=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const ActionNode=a=>{const{actionClasses:c,actions:u=[],actionStyle:d}=a;return reactExports.createElement("ul",{className:c,style:d},u.map((f,m)=>{const g=`action-${m}`;return reactExports.createElement("li",{style:{width:`${100/u.length}%`},key:g},reactExports.createElement("span",null,f))}))},Card$1=reactExports.forwardRef((a,c)=>{const{prefixCls:u,className:d,rootClassName:f,style:m,extra:g,headStyle:y={},bodyStyle:b={},title:E,loading:C,bordered:w,variant:R,size:_,type:M,cover:I,actions:N,tabList:A,children:P,activeTabKey:z,defaultActiveTabKey:B,tabBarExtraContent:j,hoverable:L,tabProps:U={},classNames:q,styles:F}=a,K=__rest$B(a,["prefixCls","className","rootClassName","style","extra","headStyle","bodyStyle","title","loading","bordered","variant","size","type","cover","actions","tabList","children","activeTabKey","defaultActiveTabKey","tabBarExtraContent","hoverable","tabProps","classNames","styles"]),{getPrefixCls:X,direction:Q,card:Y}=reactExports.useContext(ConfigContext),[Z]=useVariant("card",R,w),J=Ae=>{var Ee;(Ee=a.onTabChange)===null||Ee===void 0||Ee.call(a,Ae)},W=Ae=>{var Ee;return classNames((Ee=Y==null?void 0:Y.classNames)===null||Ee===void 0?void 0:Ee[Ae],q==null?void 0:q[Ae])},G=Ae=>{var Ee;return Object.assign(Object.assign({},(Ee=Y==null?void 0:Y.styles)===null||Ee===void 0?void 0:Ee[Ae]),F==null?void 0:F[Ae])},te=reactExports.useMemo(()=>{let Ae=!1;return reactExports.Children.forEach(P,Ee=>{(Ee==null?void 0:Ee.type)===Grid$1&&(Ae=!0)}),Ae},[P]),ae=X("card",u),[V,ne,le]=useStyle$e(ae),ee=reactExports.createElement(Skeleton,{loading:!0,active:!0,paragraph:{rows:4},title:!1},P),ie=z!==void 0,ce=Object.assign(Object.assign({},U),{[ie?"activeKey":"defaultActiveKey"]:ie?z:B,tabBarExtraContent:j});let ue;const me=useSize(_),de=!me||me==="default"?"large":me,ge=A?reactExports.createElement(Tabs,Object.assign({size:de},ce,{className:`${ae}-head-tabs`,onChange:J,items:A.map(Ae=>{var{tab:Ee}=Ae,Ne=__rest$B(Ae,["tab"]);return Object.assign({label:Ee},Ne)})})):null;if(E||g||ge){const Ae=classNames(`${ae}-head`,W("header")),Ee=classNames(`${ae}-head-title`,W("title")),Ne=classNames(`${ae}-extra`,W("extra")),_e=Object.assign(Object.assign({},y),G("header"));ue=reactExports.createElement("div",{className:Ae,style:_e},reactExports.createElement("div",{className:`${ae}-head-wrapper`},E&&reactExports.createElement("div",{className:Ee,style:G("title")},E),g&&reactExports.createElement("div",{className:Ne,style:G("extra")},g)),ge)}const Ce=classNames(`${ae}-cover`,W("cover")),ve=I?reactExports.createElement("div",{className:Ce,style:G("cover")},I):null,fe=classNames(`${ae}-body`,W("body")),pe=Object.assign(Object.assign({},b),G("body")),xe=reactExports.createElement("div",{className:fe,style:pe},C?ee:P),ye=classNames(`${ae}-actions`,W("actions")),he=N!=null&&N.length?reactExports.createElement(ActionNode,{actionClasses:ye,actionStyle:G("actions"),actions:N}):null,we=omit(K,["onTabChange"]),Re=classNames(ae,Y==null?void 0:Y.className,{[`${ae}-loading`]:C,[`${ae}-bordered`]:Z!=="borderless",[`${ae}-hoverable`]:L,[`${ae}-contain-grid`]:te,[`${ae}-contain-tabs`]:A==null?void 0:A.length,[`${ae}-${me}`]:me,[`${ae}-type-${M}`]:!!M,[`${ae}-rtl`]:Q==="rtl"},d,f,ne,le),De=Object.assign(Object.assign({},Y==null?void 0:Y.style),m);return V(reactExports.createElement("div",Object.assign({ref:c},we,{className:Re,style:De}),ue,ve,xe,he))});var __rest$A=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Meta=a=>{const{prefixCls:c,className:u,avatar:d,title:f,description:m}=a,g=__rest$A(a,["prefixCls","className","avatar","title","description"]),{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("card",c),E=classNames(`${b}-meta`,u),C=d?reactExports.createElement("div",{className:`${b}-meta-avatar`},d):null,w=f?reactExports.createElement("div",{className:`${b}-meta-title`},f):null,R=m?reactExports.createElement("div",{className:`${b}-meta-description`},m):null,_=w||R?reactExports.createElement("div",{className:`${b}-meta-detail`},w,R):null;return reactExports.createElement("div",Object.assign({},g,{className:E}),C,_)},Card=Card$1;Card.Grid=Grid$1;Card.Meta=Meta;function throttle$1(a,c,u){var d=u||{},f=d.noTrailing,m=f===void 0?!1:f,g=d.noLeading,y=g===void 0?!1:g,b=d.debounceMode,E=b===void 0?void 0:b,C,w=!1,R=0;function _(){C&&clearTimeout(C)}function M(N){var A=N||{},P=A.upcomingOnly,z=P===void 0?!1:P;_(),w=!z}function I(){for(var N=arguments.length,A=new Array(N),P=0;P<N;P++)A[P]=arguments[P];var z=this,B=Date.now()-R;if(w)return;function j(){R=Date.now(),c.apply(z,A)}function L(){C=void 0}!y&&E&&!C&&j(),_(),E===void 0&&B>a?y?(R=Date.now(),m||(C=setTimeout(E?L:j,a))):j():m!==!0&&(C=setTimeout(E?L:j,E===void 0?a-B:a))}return I.cancel=M,I}function debounce(a,c,u){var d={},f=d.atBegin,m=f===void 0?!1:f;return throttle$1(a,c,{debounceMode:m!==!1})}function getEntity(a,c){return a[c]}var _excluded$h=["children"];function getPosition(a,c){return"".concat(a,"-").concat(c)}function isTreeNode(a){return a&&a.type&&a.type.isTreeNode}function getKey(a,c){return a??c}function fillFieldNames(a){var c=a||{},u=c.title,d=c._title,f=c.key,m=c.children,g=u||"title";return{title:g,_title:d||[g],key:f||"key",children:m||"children"}}function convertTreeToData(a){function c(u){var d=toArray$6(u);return d.map(function(f){if(!isTreeNode(f))return warningOnce$1(!f,"Tree/TreeNode can only accept TreeNode as children."),null;var m=f.key,g=f.props,y=g.children,b=_objectWithoutProperties(g,_excluded$h),E=_objectSpread2({key:m},b),C=c(y);return C.length&&(E.children=C),E}).filter(function(f){return f})}return c(a)}function flattenTreeData(a,c,u){var d=fillFieldNames(u),f=d._title,m=d.key,g=d.children,y=new Set(c===!0?[]:c),b=[];function E(C){var w=arguments.length>1&&arguments[1]!==void 0?arguments[1]:null;return C.map(function(R,_){for(var M=getPosition(w?w.pos:"0",_),I=getKey(R[m],M),N,A=0;A<f.length;A+=1){var P=f[A];if(R[P]!==void 0){N=R[P];break}}var z=Object.assign(omit(R,[].concat(_toConsumableArray(f),[m,g])),{title:N,key:I,parent:w,pos:M,children:null,data:R,isStart:[].concat(_toConsumableArray(w?w.isStart:[]),[_===0]),isEnd:[].concat(_toConsumableArray(w?w.isEnd:[]),[_===C.length-1])});return b.push(z),c===!0||y.has(I)?z.children=E(R[g]||[],z):z.children=[],z})}return E(a),b}function traverseDataNodes(a,c,u){var d={};_typeof(u)==="object"?d=u:d={externalGetKey:u},d=d||{};var f=d,m=f.childrenPropName,g=f.externalGetKey,y=f.fieldNames,b=fillFieldNames(y),E=b.key,C=b.children,w=m||C,R;g?typeof g=="string"?R=function(I){return I[g]}:typeof g=="function"&&(R=function(I){return g(I)}):R=function(I,N){return getKey(I[E],N)};function _(M,I,N,A){var P=M?M[w]:a,z=M?getPosition(N.pos,I):"0",B=M?[].concat(_toConsumableArray(A),[M]):[];if(M){var j=R(M,z),L={node:M,index:I,pos:z,key:j,parentPos:N.node?N.pos:null,level:N.level+1,nodes:B};c(L)}P&&P.forEach(function(U,q){_(U,q,{node:M,pos:z,level:N?N.level+1:-1},B)})}_(null)}function convertDataToEntities(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{},u=c.initWrapper,d=c.processEntity,f=c.onProcessFinished,m=c.externalGetKey,g=c.childrenPropName,y=c.fieldNames,b=arguments.length>2?arguments[2]:void 0,E=m||b,C={},w={},R={posEntities:C,keyEntities:w};return u&&(R=u(R)||R),traverseDataNodes(a,function(_){var M=_.node,I=_.index,N=_.pos,A=_.key,P=_.parentPos,z=_.level,B=_.nodes,j={node:M,nodes:B,index:I,key:A,pos:N,level:z},L=getKey(A,N);C[N]=j,w[L]=j,j.parent=C[P],j.parent&&(j.parent.children=j.parent.children||[],j.parent.children.push(j)),d&&d(j,R)},{externalGetKey:E,childrenPropName:g,fieldNames:y}),f&&f(R),R}function getTreeNodeProps(a,c){var u=c.expandedKeys,d=c.selectedKeys,f=c.loadedKeys,m=c.loadingKeys,g=c.checkedKeys,y=c.halfCheckedKeys,b=c.dragOverNodeKey,E=c.dropPosition,C=c.keyEntities,w=getEntity(C,a),R={eventKey:a,expanded:u.indexOf(a)!==-1,selected:d.indexOf(a)!==-1,loaded:f.indexOf(a)!==-1,loading:m.indexOf(a)!==-1,checked:g.indexOf(a)!==-1,halfChecked:y.indexOf(a)!==-1,pos:String(w?w.pos:""),dragOver:b===a&&E===0,dragOverGapTop:b===a&&E===-1,dragOverGapBottom:b===a&&E===1};return R}function convertNodePropsToEventData(a){var c=a.data,u=a.expanded,d=a.selected,f=a.checked,m=a.loaded,g=a.loading,y=a.halfChecked,b=a.dragOver,E=a.dragOverGapTop,C=a.dragOverGapBottom,w=a.pos,R=a.active,_=a.eventKey,M=_objectSpread2(_objectSpread2({},c),{},{expanded:u,selected:d,checked:f,loaded:m,loading:g,halfChecked:y,dragOver:b,dragOverGapTop:E,dragOverGapBottom:C,pos:w,active:R,key:_});return"props"in M||Object.defineProperty(M,"props",{get:function(){return warningOnce$1(!1,"Second param return from event is node data instead of TreeNode instance. Please read value directly instead of reading from `props`."),a}}),M}function removeFromCheckedKeys(a,c){var u=new Set;return a.forEach(function(d){c.has(d)||u.add(d)}),u}function isCheckDisabled(a){var c=a||{},u=c.disabled,d=c.disableCheckbox,f=c.checkable;return!!(u||d)||f===!1}function fillConductCheck(a,c,u,d){for(var f=new Set(a),m=new Set,g=0;g<=u;g+=1){var y=c.get(g)||new Set;y.forEach(function(w){var R=w.key,_=w.node,M=w.children,I=M===void 0?[]:M;f.has(R)&&!d(_)&&I.filter(function(N){return!d(N.node)}).forEach(function(N){f.add(N.key)})})}for(var b=new Set,E=u;E>=0;E-=1){var C=c.get(E)||new Set;C.forEach(function(w){var R=w.parent,_=w.node;if(!(d(_)||!w.parent||b.has(w.parent.key))){if(d(w.parent.node)){b.add(R.key);return}var M=!0,I=!1;(R.children||[]).filter(function(N){return!d(N.node)}).forEach(function(N){var A=N.key,P=f.has(A);M&&!P&&(M=!1),!I&&(P||m.has(A))&&(I=!0)}),M&&f.add(R.key),I&&m.add(R.key),b.add(R.key)}})}return{checkedKeys:Array.from(f),halfCheckedKeys:Array.from(removeFromCheckedKeys(m,f))}}function cleanConductCheck(a,c,u,d,f){for(var m=new Set(a),g=new Set(c),y=0;y<=d;y+=1){var b=u.get(y)||new Set;b.forEach(function(R){var _=R.key,M=R.node,I=R.children,N=I===void 0?[]:I;!m.has(_)&&!g.has(_)&&!f(M)&&N.filter(function(A){return!f(A.node)}).forEach(function(A){m.delete(A.key)})})}g=new Set;for(var E=new Set,C=d;C>=0;C-=1){var w=u.get(C)||new Set;w.forEach(function(R){var _=R.parent,M=R.node;if(!(f(M)||!R.parent||E.has(R.parent.key))){if(f(R.parent.node)){E.add(_.key);return}var I=!0,N=!1;(_.children||[]).filter(function(A){return!f(A.node)}).forEach(function(A){var P=A.key,z=m.has(P);I&&!z&&(I=!1),!N&&(z||g.has(P))&&(N=!0)}),I||m.delete(_.key),N&&g.add(_.key),E.add(_.key)}})}return{checkedKeys:Array.from(m),halfCheckedKeys:Array.from(removeFromCheckedKeys(g,m))}}function conductCheck(a,c,u,d){var f=[],m;d?m=d:m=isCheckDisabled;var g=new Set(a.filter(function(C){var w=!!getEntity(u,C);return w||f.push(C),w})),y=new Map,b=0;Object.keys(u).forEach(function(C){var w=u[C],R=w.level,_=y.get(R);_||(_=new Set,y.set(R,_)),_.add(w),b=Math.max(b,R)}),warningOnce$1(!f.length,"Tree missing follow keys: ".concat(f.slice(0,100).map(function(C){return"'".concat(C,"'")}).join(", ")));var E;return c===!0?E=fillConductCheck(g,y,b,m):E=cleanConductCheck(g,c.halfCheckedKeys,y,b,m),E}const genCheckboxStyle=a=>{const{checkboxCls:c}=a,u=`${c}-wrapper`;return[{[`${c}-group`]:Object.assign(Object.assign({},resetComponent(a)),{display:"inline-flex",flexWrap:"wrap",columnGap:a.marginXS,[`> ${a.antCls}-row`]:{flex:1}}),[u]:Object.assign(Object.assign({},resetComponent(a)),{display:"inline-flex",alignItems:"baseline",cursor:"pointer","&:after":{display:"inline-block",width:0,overflow:"hidden",content:"'\\a0'"},[`& + ${u}`]:{marginInlineStart:0},[`&${u}-in-form-item`]:{'input[type="checkbox"]':{width:14,height:14}}}),[c]:Object.assign(Object.assign({},resetComponent(a)),{position:"relative",whiteSpace:"nowrap",lineHeight:1,cursor:"pointer",borderRadius:a.borderRadiusSM,alignSelf:"center",[`${c}-input`]:{position:"absolute",inset:0,zIndex:1,cursor:"pointer",opacity:0,margin:0,[`&:focus-visible + ${c}-inner`]:Object.assign({},genFocusOutline(a))},[`${c}-inner`]:{boxSizing:"border-box",display:"block",width:a.checkboxSize,height:a.checkboxSize,direction:"ltr",backgroundColor:a.colorBgContainer,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderRadius:a.borderRadiusSM,borderCollapse:"separate",transition:`all ${a.motionDurationSlow}`,"&:after":{boxSizing:"border-box",position:"absolute",top:"50%",insetInlineStart:"25%",display:"table",width:a.calc(a.checkboxSize).div(14).mul(5).equal(),height:a.calc(a.checkboxSize).div(14).mul(8).equal(),border:`${unit$1(a.lineWidthBold)} solid ${a.colorWhite}`,borderTop:0,borderInlineStart:0,transform:"rotate(45deg) scale(0) translate(-50%,-50%)",opacity:0,content:'""',transition:`all ${a.motionDurationFast} ${a.motionEaseInBack}, opacity ${a.motionDurationFast}`}},"& + span":{paddingInlineStart:a.paddingXS,paddingInlineEnd:a.paddingXS}})},{[`
        ${u}:not(${u}-disabled),
        ${c}:not(${c}-disabled)
      `]:{[`&:hover ${c}-inner`]:{borderColor:a.colorPrimary}},[`${u}:not(${u}-disabled)`]:{[`&:hover ${c}-checked:not(${c}-disabled) ${c}-inner`]:{backgroundColor:a.colorPrimaryHover,borderColor:"transparent"},[`&:hover ${c}-checked:not(${c}-disabled):after`]:{borderColor:a.colorPrimaryHover}}},{[`${c}-checked`]:{[`${c}-inner`]:{backgroundColor:a.colorPrimary,borderColor:a.colorPrimary,"&:after":{opacity:1,transform:"rotate(45deg) scale(1) translate(-50%,-50%)",transition:`all ${a.motionDurationMid} ${a.motionEaseOutBack} ${a.motionDurationFast}`}}},[`
        ${u}-checked:not(${u}-disabled),
        ${c}-checked:not(${c}-disabled)
      `]:{[`&:hover ${c}-inner`]:{backgroundColor:a.colorPrimaryHover,borderColor:"transparent"}}},{[c]:{"&-indeterminate":{[`${c}-inner`]:{backgroundColor:`${a.colorBgContainer} !important`,borderColor:`${a.colorBorder} !important`,"&:after":{top:"50%",insetInlineStart:"50%",width:a.calc(a.fontSizeLG).div(2).equal(),height:a.calc(a.fontSizeLG).div(2).equal(),backgroundColor:a.colorPrimary,border:0,transform:"translate(-50%, -50%) scale(1)",opacity:1,content:'""'}},[`&:hover ${c}-inner`]:{backgroundColor:`${a.colorBgContainer} !important`,borderColor:`${a.colorPrimary} !important`}}}},{[`${u}-disabled`]:{cursor:"not-allowed"},[`${c}-disabled`]:{[`&, ${c}-input`]:{cursor:"not-allowed",pointerEvents:"none"},[`${c}-inner`]:{background:a.colorBgContainerDisabled,borderColor:a.colorBorder,"&:after":{borderColor:a.colorTextDisabled}},"&:after":{display:"none"},"& + span":{color:a.colorTextDisabled},[`&${c}-indeterminate ${c}-inner::after`]:{background:a.colorTextDisabled}}}]};function getStyle(a,c){const u=merge$2(c,{checkboxCls:`.${a}`,checkboxSize:c.controlInteractiveSize});return[genCheckboxStyle(u)]}const useStyle$d=genStyleHooks("Checkbox",(a,c)=>{let{prefixCls:u}=c;return[getStyle(u,a)]}),GroupContext=React.createContext(null);var __rest$z=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalCheckbox=(a,c)=>{var u;const{prefixCls:d,className:f,rootClassName:m,children:g,indeterminate:y=!1,style:b,onMouseEnter:E,onMouseLeave:C,skipGroup:w=!1,disabled:R}=a,_=__rest$z(a,["prefixCls","className","rootClassName","children","indeterminate","style","onMouseEnter","onMouseLeave","skipGroup","disabled"]),{getPrefixCls:M,direction:I,checkbox:N}=reactExports.useContext(ConfigContext),A=reactExports.useContext(GroupContext),{isFormItemInput:P}=reactExports.useContext(FormItemInputContext),z=reactExports.useContext(DisabledContext),B=(u=(A==null?void 0:A.disabled)||R)!==null&&u!==void 0?u:z,j=reactExports.useRef(_.value),L=reactExports.useRef(null),U=composeRef(c,L);reactExports.useEffect(()=>{A==null||A.registerValue(_.value)},[]),reactExports.useEffect(()=>{if(!w)return _.value!==j.current&&(A==null||A.cancelValue(j.current),A==null||A.registerValue(_.value),j.current=_.value),()=>A==null?void 0:A.cancelValue(_.value)},[_.value]),reactExports.useEffect(()=>{var te;!((te=L.current)===null||te===void 0)&&te.input&&(L.current.input.indeterminate=y)},[y]);const q=M("checkbox",d),F=useCSSVarCls(q),[K,X,Q]=useStyle$d(q,F),Y=Object.assign({},_);A&&!w&&(Y.onChange=function(){_.onChange&&_.onChange.apply(_,arguments),A.toggleOption&&A.toggleOption({label:g,value:_.value})},Y.name=A.name,Y.checked=A.value.includes(_.value));const Z=classNames(`${q}-wrapper`,{[`${q}-rtl`]:I==="rtl",[`${q}-wrapper-checked`]:Y.checked,[`${q}-wrapper-disabled`]:B,[`${q}-wrapper-in-form-item`]:P},N==null?void 0:N.className,f,m,Q,F,X),J=classNames({[`${q}-indeterminate`]:y},TARGET_CLS,X),[W,G]=useBubbleLock(Y.onClick);return K(reactExports.createElement(Wave,{component:"Checkbox",disabled:B},reactExports.createElement("label",{className:Z,style:Object.assign(Object.assign({},N==null?void 0:N.style),b),onMouseEnter:E,onMouseLeave:C,onClick:W},reactExports.createElement(Checkbox$2,Object.assign({},Y,{onClick:G,prefixCls:q,className:J,disabled:B,ref:U})),g!==void 0&&reactExports.createElement("span",{className:`${q}-label`},g))))},Checkbox$1=reactExports.forwardRef(InternalCheckbox);var __rest$y=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const CheckboxGroup=reactExports.forwardRef((a,c)=>{const{defaultValue:u,children:d,options:f=[],prefixCls:m,className:g,rootClassName:y,style:b,onChange:E}=a,C=__rest$y(a,["defaultValue","children","options","prefixCls","className","rootClassName","style","onChange"]),{getPrefixCls:w,direction:R}=reactExports.useContext(ConfigContext),[_,M]=reactExports.useState(C.value||u||[]),[I,N]=reactExports.useState([]);reactExports.useEffect(()=>{"value"in C&&M(C.value||[])},[C.value]);const A=reactExports.useMemo(()=>f.map(J=>typeof J=="string"||typeof J=="number"?{label:J,value:J}:J),[f]),P=J=>{N(W=>W.filter(G=>G!==J))},z=J=>{N(W=>[].concat(_toConsumableArray(W),[J]))},B=J=>{const W=_.indexOf(J.value),G=_toConsumableArray(_);W===-1?G.push(J.value):G.splice(W,1),"value"in C||M(G),E==null||E(G.filter(te=>I.includes(te)).sort((te,ae)=>{const V=A.findIndex(le=>le.value===te),ne=A.findIndex(le=>le.value===ae);return V-ne}))},j=w("checkbox",m),L=`${j}-group`,U=useCSSVarCls(j),[q,F,K]=useStyle$d(j,U),X=omit(C,["value","disabled"]),Q=f.length?A.map(J=>reactExports.createElement(Checkbox$1,{prefixCls:j,key:J.value.toString(),disabled:"disabled"in J?J.disabled:C.disabled,value:J.value,checked:_.includes(J.value),onChange:J.onChange,className:`${L}-item`,style:J.style,title:J.title,id:J.id,required:J.required},J.label)):d,Y={toggleOption:B,value:_,disabled:C.disabled,name:C.name,registerValue:z,cancelValue:P},Z=classNames(L,{[`${L}-rtl`]:R==="rtl"},g,y,K,U,F);return q(reactExports.createElement("div",Object.assign({className:Z,style:b},X,{ref:c}),reactExports.createElement(GroupContext.Provider,{value:Y},Q)))}),Checkbox=Checkbox$1;Checkbox.Group=CheckboxGroup;Checkbox.__ANT_CHECKBOX=!0;const RowContext=reactExports.createContext({});var __rest$x=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function parseFlex(a){return typeof a=="number"?`${a} ${a} auto`:/^\d+(\.\d+)?(px|em|rem|%)$/.test(a)?`0 0 ${a}`:a}const sizes=["xs","sm","md","lg","xl","xxl"],Col=reactExports.forwardRef((a,c)=>{const{getPrefixCls:u,direction:d}=reactExports.useContext(ConfigContext),{gutter:f,wrap:m}=reactExports.useContext(RowContext),{prefixCls:g,span:y,order:b,offset:E,push:C,pull:w,className:R,children:_,flex:M,style:I}=a,N=__rest$x(a,["prefixCls","span","order","offset","push","pull","className","children","flex","style"]),A=u("col",g),[P,z,B]=useColStyle(A),j={};let L={};sizes.forEach(F=>{let K={};const X=a[F];typeof X=="number"?K.span=X:typeof X=="object"&&(K=X||{}),delete N[F],L=Object.assign(Object.assign({},L),{[`${A}-${F}-${K.span}`]:K.span!==void 0,[`${A}-${F}-order-${K.order}`]:K.order||K.order===0,[`${A}-${F}-offset-${K.offset}`]:K.offset||K.offset===0,[`${A}-${F}-push-${K.push}`]:K.push||K.push===0,[`${A}-${F}-pull-${K.pull}`]:K.pull||K.pull===0,[`${A}-rtl`]:d==="rtl"}),K.flex&&(L[`${A}-${F}-flex`]=!0,j[`--${A}-${F}-flex`]=parseFlex(K.flex))});const U=classNames(A,{[`${A}-${y}`]:y!==void 0,[`${A}-order-${b}`]:b,[`${A}-offset-${E}`]:E,[`${A}-push-${C}`]:C,[`${A}-pull-${w}`]:w},R,L,z,B),q={};if(f&&f[0]>0){const F=f[0]/2;q.paddingLeft=F,q.paddingRight=F}return M&&(q.flex=parseFlex(M),m===!1&&!q.minWidth&&(q.minWidth=0)),P(reactExports.createElement("div",Object.assign({},N,{style:Object.assign(Object.assign(Object.assign({},q),I),j),className:U,ref:c}),_))});function useGutter(a,c){const u=[void 0,void 0],d=Array.isArray(a)?a:[a,void 0],f=c||{xs:!0,sm:!0,md:!0,lg:!0,xl:!0,xxl:!0};return d.forEach((m,g)=>{if(typeof m=="object"&&m!==null)for(let y=0;y<responsiveArray.length;y++){const b=responsiveArray[y];if(f[b]&&m[b]!==void 0){u[g]=m[b];break}}else u[g]=m}),u}var __rest$w=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function useMergedPropByScreen(a,c){const[u,d]=reactExports.useState(typeof a=="string"?a:""),f=()=>{if(typeof a=="string"&&d(a),typeof a=="object")for(let m=0;m<responsiveArray.length;m++){const g=responsiveArray[m];if(!c||!c[g])continue;const y=a[g];if(y!==void 0){d(y);return}}};return reactExports.useEffect(()=>{f()},[JSON.stringify(a),c]),u}const Row=reactExports.forwardRef((a,c)=>{const{prefixCls:u,justify:d,align:f,className:m,style:g,children:y,gutter:b=0,wrap:E}=a,C=__rest$w(a,["prefixCls","justify","align","className","style","children","gutter","wrap"]),{getPrefixCls:w,direction:R}=reactExports.useContext(ConfigContext),_=useBreakpoint(!0,null),M=useMergedPropByScreen(f,_),I=useMergedPropByScreen(d,_),N=w("row",u),[A,P,z]=useRowStyle(N),B=useGutter(b,_),j=classNames(N,{[`${N}-no-wrap`]:E===!1,[`${N}-${I}`]:I,[`${N}-${M}`]:M,[`${N}-rtl`]:R==="rtl"},m,P,z),L={},U=B[0]!=null&&B[0]>0?B[0]/-2:void 0;U&&(L.marginLeft=U,L.marginRight=U);const[q,F]=B;L.rowGap=F;const K=reactExports.useMemo(()=>({gutter:[q,F],wrap:E}),[q,F,E]);return A(reactExports.createElement(RowContext.Provider,{value:K},reactExports.createElement("div",Object.assign({},C,{className:j,style:Object.assign(Object.assign({},L),g),ref:c}),y)))});function supportBigInt(){return typeof BigInt=="function"}function isEmpty(a){return!a&&a!==0&&!Number.isNaN(a)||!String(a).trim()}function trimNumber(a){var c=a.trim(),u=c.startsWith("-");u&&(c=c.slice(1)),c=c.replace(/(\.\d*[^0])0*$/,"$1").replace(/\.0*$/,"").replace(/^0+/,""),c.startsWith(".")&&(c="0".concat(c));var d=c||"0",f=d.split("."),m=f[0]||"0",g=f[1]||"0";m==="0"&&g==="0"&&(u=!1);var y=u?"-":"";return{negative:u,negativeStr:y,trimStr:d,integerStr:m,decimalStr:g,fullStr:"".concat(y).concat(d)}}function isE(a){var c=String(a);return!Number.isNaN(Number(c))&&c.includes("e")}function getNumberPrecision(a){var c=String(a);if(isE(a)){var u=Number(c.slice(c.indexOf("e-")+2)),d=c.match(/\.(\d+)/);return d!=null&&d[1]&&(u+=d[1].length),u}return c.includes(".")&&validateNumber(c)?c.length-c.indexOf(".")-1:0}function num2str(a){var c=String(a);if(isE(a)){if(a>Number.MAX_SAFE_INTEGER)return String(supportBigInt()?BigInt(a).toString():Number.MAX_SAFE_INTEGER);if(a<Number.MIN_SAFE_INTEGER)return String(supportBigInt()?BigInt(a).toString():Number.MIN_SAFE_INTEGER);c=a.toFixed(getNumberPrecision(c))}return trimNumber(c).fullStr}function validateNumber(a){return typeof a=="number"?!Number.isNaN(a):a?/^\s*-?\d+(\.\d+)?\s*$/.test(a)||/^\s*-?\d+\.\s*$/.test(a)||/^\s*-?\.\d+\s*$/.test(a):!1}var BigIntDecimal=function(){function a(c){if(_classCallCheck(this,a),_defineProperty(this,"origin",""),_defineProperty(this,"negative",void 0),_defineProperty(this,"integer",void 0),_defineProperty(this,"decimal",void 0),_defineProperty(this,"decimalLen",void 0),_defineProperty(this,"empty",void 0),_defineProperty(this,"nan",void 0),isEmpty(c)){this.empty=!0;return}if(this.origin=String(c),c==="-"||Number.isNaN(c)){this.nan=!0;return}var u=c;if(isE(u)&&(u=Number(u)),u=typeof u=="string"?u:num2str(u),validateNumber(u)){var d=trimNumber(u);this.negative=d.negative;var f=d.trimStr.split(".");this.integer=BigInt(f[0]);var m=f[1]||"0";this.decimal=BigInt(m),this.decimalLen=m.length}else this.nan=!0}return _createClass(a,[{key:"getMark",value:function(){return this.negative?"-":""}},{key:"getIntegerStr",value:function(){return this.integer.toString()}},{key:"getDecimalStr",value:function(){return this.decimal.toString().padStart(this.decimalLen,"0")}},{key:"alignDecimal",value:function(u){var d="".concat(this.getMark()).concat(this.getIntegerStr()).concat(this.getDecimalStr().padEnd(u,"0"));return BigInt(d)}},{key:"negate",value:function(){var u=new a(this.toString());return u.negative=!u.negative,u}},{key:"cal",value:function(u,d,f){var m=Math.max(this.getDecimalStr().length,u.getDecimalStr().length),g=this.alignDecimal(m),y=u.alignDecimal(m),b=d(g,y).toString(),E=f(m),C=trimNumber(b),w=C.negativeStr,R=C.trimStr,_="".concat(w).concat(R.padStart(E+1,"0"));return new a("".concat(_.slice(0,-E),".").concat(_.slice(-E)))}},{key:"add",value:function(u){if(this.isInvalidate())return new a(u);var d=new a(u);return d.isInvalidate()?this:this.cal(d,function(f,m){return f+m},function(f){return f})}},{key:"multi",value:function(u){var d=new a(u);return this.isInvalidate()||d.isInvalidate()?new a(NaN):this.cal(d,function(f,m){return f*m},function(f){return f*2})}},{key:"isEmpty",value:function(){return this.empty}},{key:"isNaN",value:function(){return this.nan}},{key:"isInvalidate",value:function(){return this.isEmpty()||this.isNaN()}},{key:"equals",value:function(u){return this.toString()===(u==null?void 0:u.toString())}},{key:"lessEquals",value:function(u){return this.add(u.negate().toString()).toNumber()<=0}},{key:"toNumber",value:function(){return this.isNaN()?NaN:Number(this.toString())}},{key:"toString",value:function(){var u=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!0;return u?this.isInvalidate()?"":trimNumber("".concat(this.getMark()).concat(this.getIntegerStr(),".").concat(this.getDecimalStr())).fullStr:this.origin}}]),a}(),NumberDecimal=function(){function a(c){if(_classCallCheck(this,a),_defineProperty(this,"origin",""),_defineProperty(this,"number",void 0),_defineProperty(this,"empty",void 0),isEmpty(c)){this.empty=!0;return}this.origin=String(c),this.number=Number(c)}return _createClass(a,[{key:"negate",value:function(){return new a(-this.toNumber())}},{key:"add",value:function(u){if(this.isInvalidate())return new a(u);var d=Number(u);if(Number.isNaN(d))return this;var f=this.number+d;if(f>Number.MAX_SAFE_INTEGER)return new a(Number.MAX_SAFE_INTEGER);if(f<Number.MIN_SAFE_INTEGER)return new a(Number.MIN_SAFE_INTEGER);var m=Math.max(getNumberPrecision(this.number),getNumberPrecision(d));return new a(f.toFixed(m))}},{key:"multi",value:function(u){var d=Number(u);if(this.isInvalidate()||Number.isNaN(d))return new a(NaN);var f=this.number*d;if(f>Number.MAX_SAFE_INTEGER)return new a(Number.MAX_SAFE_INTEGER);if(f<Number.MIN_SAFE_INTEGER)return new a(Number.MIN_SAFE_INTEGER);var m=Math.max(getNumberPrecision(this.number),getNumberPrecision(d));return new a(f.toFixed(m))}},{key:"isEmpty",value:function(){return this.empty}},{key:"isNaN",value:function(){return Number.isNaN(this.number)}},{key:"isInvalidate",value:function(){return this.isEmpty()||this.isNaN()}},{key:"equals",value:function(u){return this.toNumber()===(u==null?void 0:u.toNumber())}},{key:"lessEquals",value:function(u){return this.add(u.negate().toString()).toNumber()<=0}},{key:"toNumber",value:function(){return this.number}},{key:"toString",value:function(){var u=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!0;return u?this.isInvalidate()?"":num2str(this.number):this.origin}}]),a}();function getMiniDecimal(a){return supportBigInt()?new BigIntDecimal(a):new NumberDecimal(a)}function toFixed(a,c,u){var d=arguments.length>3&&arguments[3]!==void 0?arguments[3]:!1;if(a==="")return"";var f=trimNumber(a),m=f.negativeStr,g=f.integerStr,y=f.decimalStr,b="".concat(c).concat(y),E="".concat(m).concat(g);if(u>=0){var C=Number(y[u]);if(C>=5&&!d){var w=getMiniDecimal(a).add("".concat(m,"0.").concat("0".repeat(u)).concat(10-C));return toFixed(w.toString(),c,u,d)}return u===0?E:"".concat(E).concat(c).concat(y.padEnd(u,"0").slice(0,u))}return b===".0"?E:"".concat(E).concat(b)}function hasAddon(a){return!!(a.addonBefore||a.addonAfter)}function hasPrefixSuffix$1(a){return!!(a.prefix||a.suffix||a.allowClear)}function cloneEvent(a,c,u){var d=c.cloneNode(!0),f=Object.create(a,{target:{value:d},currentTarget:{value:d}});return d.value=u,typeof c.selectionStart=="number"&&typeof c.selectionEnd=="number"&&(d.selectionStart=c.selectionStart,d.selectionEnd=c.selectionEnd),d.setSelectionRange=function(){c.setSelectionRange.apply(c,arguments)},f}function resolveOnChange(a,c,u,d){if(u){var f=c;if(c.type==="click"){f=cloneEvent(c,a,""),u(f);return}if(a.type!=="file"&&d!==void 0){f=cloneEvent(c,a,d),u(f);return}u(f)}}function triggerFocus(a,c){if(a){a.focus(c);var u=c||{},d=u.cursor;if(d){var f=a.value.length;switch(d){case"start":a.setSelectionRange(0,0);break;case"end":a.setSelectionRange(f,f);break;default:a.setSelectionRange(0,f)}}}}var BaseInput$1=React.forwardRef(function(a,c){var u,d,f,m=a.inputElement,g=a.children,y=a.prefixCls,b=a.prefix,E=a.suffix,C=a.addonBefore,w=a.addonAfter,R=a.className,_=a.style,M=a.disabled,I=a.readOnly,N=a.focused,A=a.triggerFocus,P=a.allowClear,z=a.value,B=a.handleReset,j=a.hidden,L=a.classes,U=a.classNames,q=a.dataAttrs,F=a.styles,K=a.components,X=a.onClear,Q=g??m,Y=(K==null?void 0:K.affixWrapper)||"span",Z=(K==null?void 0:K.groupWrapper)||"span",J=(K==null?void 0:K.wrapper)||"span",W=(K==null?void 0:K.groupAddon)||"span",G=reactExports.useRef(null),te=function(ye){var he;(he=G.current)!==null&&he!==void 0&&he.contains(ye.target)&&(A==null||A())},ae=hasPrefixSuffix$1(a),V=reactExports.cloneElement(Q,{value:z,className:classNames((u=Q.props)===null||u===void 0?void 0:u.className,!ae&&(U==null?void 0:U.variant))||null}),ne=reactExports.useRef(null);if(React.useImperativeHandle(c,function(){return{nativeElement:ne.current||G.current}}),ae){var le=null;if(P){var ee=!M&&!I&&z,ie="".concat(y,"-clear-icon"),ce=_typeof(P)==="object"&&P!==null&&P!==void 0&&P.clearIcon?P.clearIcon:"✖";le=React.createElement("button",{type:"button",tabIndex:-1,onClick:function(ye){B==null||B(ye),X==null||X()},onMouseDown:function(ye){return ye.preventDefault()},className:classNames(ie,_defineProperty(_defineProperty({},"".concat(ie,"-hidden"),!ee),"".concat(ie,"-has-suffix"),!!E))},ce)}var ue="".concat(y,"-affix-wrapper"),me=classNames(ue,_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(y,"-disabled"),M),"".concat(ue,"-disabled"),M),"".concat(ue,"-focused"),N),"".concat(ue,"-readonly"),I),"".concat(ue,"-input-with-clear-btn"),E&&P&&z),L==null?void 0:L.affixWrapper,U==null?void 0:U.affixWrapper,U==null?void 0:U.variant),de=(E||P)&&React.createElement("span",{className:classNames("".concat(y,"-suffix"),U==null?void 0:U.suffix),style:F==null?void 0:F.suffix},le,E);V=React.createElement(Y,_extends({className:me,style:F==null?void 0:F.affixWrapper,onClick:te},q==null?void 0:q.affixWrapper,{ref:G}),b&&React.createElement("span",{className:classNames("".concat(y,"-prefix"),U==null?void 0:U.prefix),style:F==null?void 0:F.prefix},b),V,de)}if(hasAddon(a)){var ge="".concat(y,"-group"),Ce="".concat(ge,"-addon"),ve="".concat(ge,"-wrapper"),fe=classNames("".concat(y,"-wrapper"),ge,L==null?void 0:L.wrapper,U==null?void 0:U.wrapper),pe=classNames(ve,_defineProperty({},"".concat(ve,"-disabled"),M),L==null?void 0:L.group,U==null?void 0:U.groupWrapper);V=React.createElement(Z,{className:pe,ref:ne},React.createElement(J,{className:fe},C&&React.createElement(W,{className:Ce},C),V,w&&React.createElement(W,{className:Ce},w)))}return React.cloneElement(V,{className:classNames((d=V.props)===null||d===void 0?void 0:d.className,R)||null,style:_objectSpread2(_objectSpread2({},(f=V.props)===null||f===void 0?void 0:f.style),_),hidden:j})}),_excluded$g=["show"];function useCount(a,c){return reactExports.useMemo(function(){var u={};c&&(u.show=_typeof(c)==="object"&&c.formatter?c.formatter:!!c),u=_objectSpread2(_objectSpread2({},u),a);var d=u,f=d.show,m=_objectWithoutProperties(d,_excluded$g);return _objectSpread2(_objectSpread2({},m),{},{show:!!f,showFormatter:typeof f=="function"?f:void 0,strategy:m.strategy||function(g){return g.length}})},[a,c])}var _excluded$f=["autoComplete","onChange","onFocus","onBlur","onPressEnter","onKeyDown","onKeyUp","prefixCls","disabled","htmlSize","className","maxLength","suffix","showCount","count","type","classes","classNames","styles","onCompositionStart","onCompositionEnd"],Input$2=reactExports.forwardRef(function(a,c){var u=a.autoComplete,d=a.onChange,f=a.onFocus,m=a.onBlur,g=a.onPressEnter,y=a.onKeyDown,b=a.onKeyUp,E=a.prefixCls,C=E===void 0?"rc-input":E,w=a.disabled,R=a.htmlSize,_=a.className,M=a.maxLength,I=a.suffix,N=a.showCount,A=a.count,P=a.type,z=P===void 0?"text":P,B=a.classes,j=a.classNames,L=a.styles,U=a.onCompositionStart,q=a.onCompositionEnd,F=_objectWithoutProperties(a,_excluded$f),K=reactExports.useState(!1),X=_slicedToArray(K,2),Q=X[0],Y=X[1],Z=reactExports.useRef(!1),J=reactExports.useRef(!1),W=reactExports.useRef(null),G=reactExports.useRef(null),te=function(ke){W.current&&triggerFocus(W.current,ke)},ae=useMergedState(a.defaultValue,{value:a.value}),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=ne==null?"":String(ne),ie=reactExports.useState(null),ce=_slicedToArray(ie,2),ue=ce[0],me=ce[1],de=useCount(A,N),ge=de.max||M,Ce=de.strategy(ee),ve=!!ge&&Ce>ge;reactExports.useImperativeHandle(c,function(){var _e;return{focus:te,blur:function(){var Ke;(Ke=W.current)===null||Ke===void 0||Ke.blur()},setSelectionRange:function(Ke,be,Te){var Le;(Le=W.current)===null||Le===void 0||Le.setSelectionRange(Ke,be,Te)},select:function(){var Ke;(Ke=W.current)===null||Ke===void 0||Ke.select()},input:W.current,nativeElement:((_e=G.current)===null||_e===void 0?void 0:_e.nativeElement)||W.current}}),reactExports.useEffect(function(){J.current&&(J.current=!1),Y(function(_e){return _e&&w?!1:_e})},[w]);var fe=function(ke,Ke,be){var Te=Ke;if(!Z.current&&de.exceedFormatter&&de.max&&de.strategy(Ke)>de.max){if(Te=de.exceedFormatter(Ke,{max:de.max}),Ke!==Te){var Le,Oe;me([((Le=W.current)===null||Le===void 0?void 0:Le.selectionStart)||0,((Oe=W.current)===null||Oe===void 0?void 0:Oe.selectionEnd)||0])}}else if(be.source==="compositionEnd")return;le(Te),W.current&&resolveOnChange(W.current,ke,d,Te)};reactExports.useEffect(function(){if(ue){var _e;(_e=W.current)===null||_e===void 0||_e.setSelectionRange.apply(_e,_toConsumableArray(ue))}},[ue]);var pe=function(ke){fe(ke,ke.target.value,{source:"change"})},xe=function(ke){Z.current=!1,fe(ke,ke.currentTarget.value,{source:"compositionEnd"}),q==null||q(ke)},ye=function(ke){g&&ke.key==="Enter"&&!J.current&&(J.current=!0,g(ke)),y==null||y(ke)},he=function(ke){ke.key==="Enter"&&(J.current=!1),b==null||b(ke)},we=function(ke){Y(!0),f==null||f(ke)},Re=function(ke){J.current&&(J.current=!1),Y(!1),m==null||m(ke)},De=function(ke){le(""),te(),W.current&&resolveOnChange(W.current,ke,d)},Ae=ve&&"".concat(C,"-out-of-range"),Ee=function(){var ke=omit(a,["prefixCls","onPressEnter","addonBefore","addonAfter","prefix","suffix","allowClear","defaultValue","showCount","count","classes","htmlSize","styles","classNames","onClear"]);return React.createElement("input",_extends({autoComplete:u},ke,{onChange:pe,onFocus:we,onBlur:Re,onKeyDown:ye,onKeyUp:he,className:classNames(C,_defineProperty({},"".concat(C,"-disabled"),w),j==null?void 0:j.input),style:L==null?void 0:L.input,ref:W,size:R,type:z,onCompositionStart:function(be){Z.current=!0,U==null||U(be)},onCompositionEnd:xe}))},Ne=function(){var ke=Number(ge)>0;if(I||de.show){var Ke=de.showFormatter?de.showFormatter({value:ee,count:Ce,maxLength:ge}):"".concat(Ce).concat(ke?" / ".concat(ge):"");return React.createElement(React.Fragment,null,de.show&&React.createElement("span",{className:classNames("".concat(C,"-show-count-suffix"),_defineProperty({},"".concat(C,"-show-count-has-suffix"),!!I),j==null?void 0:j.count),style:_objectSpread2({},L==null?void 0:L.count)},Ke),I)}return null};return React.createElement(BaseInput$1,_extends({},F,{prefixCls:C,className:classNames(_,Ae),handleReset:De,value:ee,focused:Q,triggerFocus:te,suffix:Ne(),disabled:w,classes:B,classNames:j,styles:L,ref:G}),Ee())});function proxyObject(a,c){return typeof Proxy<"u"&&a?new Proxy(a,{get:function(d,f){if(c[f])return c[f];var m=d[f];return typeof m=="function"?m.bind(d):m}}):a}function useCursor(a,c){var u=reactExports.useRef(null);function d(){try{var m=a.selectionStart,g=a.selectionEnd,y=a.value,b=y.substring(0,m),E=y.substring(g);u.current={start:m,end:g,value:y,beforeTxt:b,afterTxt:E}}catch{}}function f(){if(a&&u.current&&c)try{var m=a.value,g=u.current,y=g.beforeTxt,b=g.afterTxt,E=g.start,C=m.length;if(m.startsWith(y))C=y.length;else if(m.endsWith(b))C=m.length-u.current.afterTxt.length;else{var w=y[E-1],R=m.indexOf(w,E-1);R!==-1&&(C=R+1)}a.setSelectionRange(C,C)}catch(_){warningOnce$1(!1,"Something warning of cursor restore. Please fire issue about this: ".concat(_.message))}}return[d,f]}var useMobile=function(){var c=reactExports.useState(!1),u=_slicedToArray(c,2),d=u[0],f=u[1];return useLayoutEffect$1(function(){f(isMobile())},[]),d},STEP_INTERVAL=200,STEP_DELAY=600;function StepHandler(a){var c=a.prefixCls,u=a.upNode,d=a.downNode,f=a.upDisabled,m=a.downDisabled,g=a.onStep,y=reactExports.useRef(),b=reactExports.useRef([]),E=reactExports.useRef();E.current=g;var C=function(){clearTimeout(y.current)},w=function(z,B){z.preventDefault(),C(),E.current(B);function j(){E.current(B),y.current=setTimeout(j,STEP_INTERVAL)}y.current=setTimeout(j,STEP_DELAY)};reactExports.useEffect(function(){return function(){C(),b.current.forEach(function(P){return wrapperRaf.cancel(P)})}},[]);var R=useMobile();if(R)return null;var _="".concat(c,"-handler"),M=classNames(_,"".concat(_,"-up"),_defineProperty({},"".concat(_,"-up-disabled"),f)),I=classNames(_,"".concat(_,"-down"),_defineProperty({},"".concat(_,"-down-disabled"),m)),N=function(){return b.current.push(wrapperRaf(C))},A={unselectable:"on",role:"button",onMouseUp:N,onMouseLeave:N};return reactExports.createElement("div",{className:"".concat(_,"-wrap")},reactExports.createElement("span",_extends({},A,{onMouseDown:function(z){w(z,!0)},"aria-label":"Increase Value","aria-disabled":f,className:M}),u||reactExports.createElement("span",{unselectable:"on",className:"".concat(c,"-handler-up-inner")})),reactExports.createElement("span",_extends({},A,{onMouseDown:function(z){w(z,!1)},"aria-label":"Decrease Value","aria-disabled":m,className:I}),d||reactExports.createElement("span",{unselectable:"on",className:"".concat(c,"-handler-down-inner")})))}function getDecupleSteps(a){var c=typeof a=="number"?num2str(a):trimNumber(a).fullStr,u=c.includes(".");return u?trimNumber(c.replace(/(\d)\.(\d)/g,"$1$2.")).fullStr:a+"0"}const useFrame=function(){var a=reactExports.useRef(0),c=function(){wrapperRaf.cancel(a.current)};return reactExports.useEffect(function(){return c},[]),function(u){c(),a.current=wrapperRaf(function(){u()})}};var _excluded$e=["prefixCls","className","style","min","max","step","defaultValue","value","disabled","readOnly","upHandler","downHandler","keyboard","changeOnWheel","controls","classNames","stringMode","parser","formatter","precision","decimalSeparator","onChange","onInput","onPressEnter","onStep","changeOnBlur","domRef"],_excluded2$4=["disabled","style","prefixCls","value","prefix","suffix","addonBefore","addonAfter","className","classNames"],getDecimalValue=function(c,u){return c||u.isEmpty()?u.toString():u.toNumber()},getDecimalIfValidate=function(c){var u=getMiniDecimal(c);return u.isInvalidate()?null:u},InternalInputNumber=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.className,f=a.style,m=a.min,g=a.max,y=a.step,b=y===void 0?1:y,E=a.defaultValue,C=a.value,w=a.disabled,R=a.readOnly,_=a.upHandler,M=a.downHandler,I=a.keyboard,N=a.changeOnWheel,A=N===void 0?!1:N,P=a.controls,z=P===void 0?!0:P;a.classNames;var B=a.stringMode,j=a.parser,L=a.formatter,U=a.precision,q=a.decimalSeparator,F=a.onChange,K=a.onInput,X=a.onPressEnter,Q=a.onStep,Y=a.changeOnBlur,Z=Y===void 0?!0:Y,J=a.domRef,W=_objectWithoutProperties(a,_excluded$e),G="".concat(u,"-input"),te=reactExports.useRef(null),ae=reactExports.useState(!1),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=reactExports.useRef(!1),ie=reactExports.useRef(!1),ce=reactExports.useRef(!1),ue=reactExports.useState(function(){return getMiniDecimal(C??E)}),me=_slicedToArray(ue,2),de=me[0],ge=me[1];function Ce(at){C===void 0&&ge(at)}var ve=reactExports.useCallback(function(at,ct){if(!ct)return U>=0?U:Math.max(getNumberPrecision(at),getNumberPrecision(b))},[U,b]),fe=reactExports.useCallback(function(at){var ct=String(at);if(j)return j(ct);var bt=ct;return q&&(bt=bt.replace(q,".")),bt.replace(/[^\w.-]+/g,"")},[j,q]),pe=reactExports.useRef(""),xe=reactExports.useCallback(function(at,ct){if(L)return L(at,{userTyping:ct,input:String(pe.current)});var bt=typeof at=="number"?num2str(at):at;if(!ct){var it=ve(bt,ct);if(validateNumber(bt)&&(q||it>=0)){var vt=q||".";bt=toFixed(bt,vt,it)}}return bt},[L,ve,q]),ye=reactExports.useState(function(){var at=E??C;return de.isInvalidate()&&["string","number"].includes(_typeof(at))?Number.isNaN(at)?"":at:xe(de.toString(),!1)}),he=_slicedToArray(ye,2),we=he[0],Re=he[1];pe.current=we;function De(at,ct){Re(xe(at.isInvalidate()?at.toString(!1):at.toString(!ct),ct))}var Ae=reactExports.useMemo(function(){return getDecimalIfValidate(g)},[g,U]),Ee=reactExports.useMemo(function(){return getDecimalIfValidate(m)},[m,U]),Ne=reactExports.useMemo(function(){return!Ae||!de||de.isInvalidate()?!1:Ae.lessEquals(de)},[Ae,de]),_e=reactExports.useMemo(function(){return!Ee||!de||de.isInvalidate()?!1:de.lessEquals(Ee)},[Ee,de]),ke=useCursor(te.current,ne),Ke=_slicedToArray(ke,2),be=Ke[0],Te=Ke[1],Le=function(ct){return Ae&&!ct.lessEquals(Ae)?Ae:Ee&&!Ee.lessEquals(ct)?Ee:null},Oe=function(ct){return!Le(ct)},Be=function(ct,bt){var it=ct,vt=Oe(it)||it.isEmpty();if(!it.isEmpty()&&!bt&&(it=Le(it)||it,vt=!0),!R&&!w&&vt){var ot=it.toString(),rt=ve(ot,bt);return rt>=0&&(it=getMiniDecimal(toFixed(ot,".",rt)),Oe(it)||(it=getMiniDecimal(toFixed(ot,".",rt,!0)))),it.equals(de)||(Ce(it),F==null||F(it.isEmpty()?null:getDecimalValue(B,it)),C===void 0&&De(it,bt)),it}return de},Ve=useFrame(),Pe=function at(ct){if(be(),pe.current=ct,Re(ct),!ie.current){var bt=fe(ct),it=getMiniDecimal(bt);it.isNaN()||Be(it,!0)}K==null||K(ct),Ve(function(){var vt=ct;j||(vt=ct.replace(/。/g,".")),vt!==ct&&at(vt)})},Ge=function(){ie.current=!0},qe=function(){ie.current=!1,Pe(te.current.value)},Ue=function(ct){Pe(ct.target.value)},je=function(ct){var bt;if(!(ct&&Ne||!ct&&_e)){ee.current=!1;var it=getMiniDecimal(ce.current?getDecupleSteps(b):b);ct||(it=it.negate());var vt=(de||getMiniDecimal(0)).add(it.toString()),ot=Be(vt,!1);Q==null||Q(getDecimalValue(B,ot),{offset:ce.current?getDecupleSteps(b):b,type:ct?"up":"down"}),(bt=te.current)===null||bt===void 0||bt.focus()}},We=function(ct){var bt=getMiniDecimal(fe(we)),it;bt.isNaN()?it=Be(de,ct):it=Be(bt,ct),C!==void 0?De(de,!1):it.isNaN()||De(it,!1)},ut=function(){ee.current=!0},gt=function(ct){var bt=ct.key,it=ct.shiftKey;ee.current=!0,ce.current=it,bt==="Enter"&&(ie.current||(ee.current=!1),We(!1),X==null||X(ct)),I!==!1&&!ie.current&&["Up","ArrowUp","Down","ArrowDown"].includes(bt)&&(je(bt==="Up"||bt==="ArrowUp"),ct.preventDefault())},kt=function(){ee.current=!1,ce.current=!1};reactExports.useEffect(function(){if(A&&ne){var at=function(it){je(it.deltaY<0),it.preventDefault()},ct=te.current;if(ct)return ct.addEventListener("wheel",at,{passive:!1}),function(){return ct.removeEventListener("wheel",at)}}});var Ut=function(){Z&&We(!1),le(!1),ee.current=!1};return useLayoutUpdateEffect(function(){de.isInvalidate()||De(de,!1)},[U,L]),useLayoutUpdateEffect(function(){var at=getMiniDecimal(C);ge(at);var ct=getMiniDecimal(fe(we));(!at.equals(ct)||!ee.current||L)&&De(at,ee.current)},[C]),useLayoutUpdateEffect(function(){L&&Te()},[we]),reactExports.createElement("div",{ref:J,className:classNames(u,d,_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(u,"-focused"),ne),"".concat(u,"-disabled"),w),"".concat(u,"-readonly"),R),"".concat(u,"-not-a-number"),de.isNaN()),"".concat(u,"-out-of-range"),!de.isInvalidate()&&!Oe(de))),style:f,onFocus:function(){le(!0)},onBlur:Ut,onKeyDown:gt,onKeyUp:kt,onCompositionStart:Ge,onCompositionEnd:qe,onBeforeInput:ut},z&&reactExports.createElement(StepHandler,{prefixCls:u,upNode:_,downNode:M,upDisabled:Ne,downDisabled:_e,onStep:je}),reactExports.createElement("div",{className:"".concat(G,"-wrap")},reactExports.createElement("input",_extends({autoComplete:"off",role:"spinbutton","aria-valuemin":m,"aria-valuemax":g,"aria-valuenow":de.isInvalidate()?null:de.toString(),step:b},W,{ref:composeRef(te,c),className:G,value:we,onChange:Ue,disabled:w,readOnly:R}))))}),InputNumber$1=reactExports.forwardRef(function(a,c){var u=a.disabled,d=a.style,f=a.prefixCls,m=f===void 0?"rc-input-number":f,g=a.value,y=a.prefix,b=a.suffix,E=a.addonBefore,C=a.addonAfter,w=a.className,R=a.classNames,_=_objectWithoutProperties(a,_excluded2$4),M=reactExports.useRef(null),I=reactExports.useRef(null),N=reactExports.useRef(null),A=function(z){N.current&&triggerFocus(N.current,z)};return reactExports.useImperativeHandle(c,function(){return proxyObject(N.current,{focus:A,nativeElement:M.current.nativeElement||I.current})}),reactExports.createElement(BaseInput$1,{className:w,triggerFocus:A,prefixCls:m,value:g,disabled:u,style:d,prefix:y,suffix:b,addonAfter:C,addonBefore:E,classNames:R,components:{affixWrapper:"div",groupWrapper:"div",wrapper:"div",groupAddon:"div"},ref:M},reactExports.createElement(InternalInputNumber,_extends({prefixCls:m,disabled:u,ref:N,domRef:I,className:R==null?void 0:R.input},_)))});const prepareComponentToken$a=a=>{var c;const u=(c=a.handleVisible)!==null&&c!==void 0?c:"auto",d=a.controlHeightSM-a.lineWidth*2;return Object.assign(Object.assign({},initComponentToken$1(a)),{controlWidth:90,handleWidth:d,handleFontSize:a.fontSize/2,handleVisible:u,handleActiveBg:a.colorFillAlter,handleBg:a.colorBgContainer,filledHandleBg:new FastColor(a.colorFillSecondary).onBackground(a.colorBgContainer).toHexString(),handleHoverColor:a.colorPrimary,handleBorderColor:a.colorBorder,handleOpacity:u===!0?1:0,handleVisibleWidth:u===!0?d:0})},genRadiusStyle$1=(a,c)=>{let{componentCls:u,borderRadiusSM:d,borderRadiusLG:f}=a;const m=c==="lg"?f:d;return{[`&-${c}`]:{[`${u}-handler-wrap`]:{borderStartEndRadius:m,borderEndEndRadius:m},[`${u}-handler-up`]:{borderStartEndRadius:m},[`${u}-handler-down`]:{borderEndEndRadius:m}}}},genInputNumberStyles=a=>{const{componentCls:c,lineWidth:u,lineType:d,borderRadius:f,inputFontSizeSM:m,inputFontSizeLG:g,controlHeightLG:y,controlHeightSM:b,colorError:E,paddingInlineSM:C,paddingBlockSM:w,paddingBlockLG:R,paddingInlineLG:_,colorIcon:M,motionDurationMid:I,handleHoverColor:N,handleOpacity:A,paddingInline:P,paddingBlock:z,handleBg:B,handleActiveBg:j,colorTextDisabled:L,borderRadiusSM:U,borderRadiusLG:q,controlWidth:F,handleBorderColor:K,filledHandleBg:X,lineHeightLG:Q,calc:Y}=a;return[{[c]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),genBasicInputStyle(a)),{display:"inline-block",width:F,margin:0,padding:0,borderRadius:f}),genOutlinedStyle(a,{[`${c}-handler-wrap`]:{background:B,[`${c}-handler-down`]:{borderBlockStart:`${unit$1(u)} ${d} ${K}`}}})),genFilledStyle(a,{[`${c}-handler-wrap`]:{background:X,[`${c}-handler-down`]:{borderBlockStart:`${unit$1(u)} ${d} ${K}`}},"&:focus-within":{[`${c}-handler-wrap`]:{background:B}}})),genUnderlinedStyle(a,{[`${c}-handler-wrap`]:{background:B,[`${c}-handler-down`]:{borderBlockStart:`${unit$1(u)} ${d} ${K}`}}})),genBorderlessStyle(a)),{"&-rtl":{direction:"rtl",[`${c}-input`]:{direction:"rtl"}},"&-lg":{padding:0,fontSize:g,lineHeight:Q,borderRadius:q,[`input${c}-input`]:{height:Y(y).sub(Y(u).mul(2)).equal(),padding:`${unit$1(R)} ${unit$1(_)}`}},"&-sm":{padding:0,fontSize:m,borderRadius:U,[`input${c}-input`]:{height:Y(b).sub(Y(u).mul(2)).equal(),padding:`${unit$1(w)} ${unit$1(C)}`}},"&-out-of-range":{[`${c}-input-wrap`]:{input:{color:E}}},"&-group":Object.assign(Object.assign(Object.assign({},resetComponent(a)),genInputGroupStyle(a)),{"&-wrapper":Object.assign(Object.assign(Object.assign({display:"inline-block",textAlign:"start",verticalAlign:"top",[`${c}-affix-wrapper`]:{width:"100%"},"&-lg":{[`${c}-group-addon`]:{borderRadius:q,fontSize:a.fontSizeLG}},"&-sm":{[`${c}-group-addon`]:{borderRadius:U}}},genOutlinedGroupStyle(a)),genFilledGroupStyle(a)),{[`&:not(${c}-compact-first-item):not(${c}-compact-last-item)${c}-compact-item`]:{[`${c}, ${c}-group-addon`]:{borderRadius:0}},[`&:not(${c}-compact-last-item)${c}-compact-first-item`]:{[`${c}, ${c}-group-addon`]:{borderStartEndRadius:0,borderEndEndRadius:0}},[`&:not(${c}-compact-first-item)${c}-compact-last-item`]:{[`${c}, ${c}-group-addon`]:{borderStartStartRadius:0,borderEndStartRadius:0}}})}),[`&-disabled ${c}-input`]:{cursor:"not-allowed"},[c]:{"&-input":Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),{width:"100%",padding:`${unit$1(z)} ${unit$1(P)}`,textAlign:"start",backgroundColor:"transparent",border:0,borderRadius:f,outline:0,transition:`all ${I} linear`,appearance:"textfield",fontSize:"inherit"}),genPlaceholderStyle(a.colorTextPlaceholder)),{'&[type="number"]::-webkit-inner-spin-button, &[type="number"]::-webkit-outer-spin-button':{margin:0,appearance:"none"}})},[`&:hover ${c}-handler-wrap, &-focused ${c}-handler-wrap`]:{width:a.handleWidth,opacity:1}})},{[c]:Object.assign(Object.assign(Object.assign({[`${c}-handler-wrap`]:{position:"absolute",insetBlockStart:0,insetInlineEnd:0,width:a.handleVisibleWidth,opacity:A,height:"100%",borderStartStartRadius:0,borderStartEndRadius:f,borderEndEndRadius:f,borderEndStartRadius:0,display:"flex",flexDirection:"column",alignItems:"stretch",transition:`all ${I}`,overflow:"hidden",[`${c}-handler`]:{display:"flex",alignItems:"center",justifyContent:"center",flex:"auto",height:"40%",[`
              ${c}-handler-up-inner,
              ${c}-handler-down-inner
            `]:{marginInlineEnd:0,fontSize:a.handleFontSize}}},[`${c}-handler`]:{height:"50%",overflow:"hidden",color:M,fontWeight:"bold",lineHeight:0,textAlign:"center",cursor:"pointer",borderInlineStart:`${unit$1(u)} ${d} ${K}`,transition:`all ${I} linear`,"&:active":{background:j},"&:hover":{height:"60%",[`
              ${c}-handler-up-inner,
              ${c}-handler-down-inner
            `]:{color:N}},"&-up-inner, &-down-inner":Object.assign(Object.assign({},resetIcon()),{color:M,transition:`all ${I} linear`,userSelect:"none"})},[`${c}-handler-up`]:{borderStartEndRadius:f},[`${c}-handler-down`]:{borderEndEndRadius:f}},genRadiusStyle$1(a,"lg")),genRadiusStyle$1(a,"sm")),{"&-disabled, &-readonly":{[`${c}-handler-wrap`]:{display:"none"},[`${c}-input`]:{color:"inherit"}},[`
          ${c}-handler-up-disabled,
          ${c}-handler-down-disabled
        `]:{cursor:"not-allowed"},[`
          ${c}-handler-up-disabled:hover &-handler-up-inner,
          ${c}-handler-down-disabled:hover &-handler-down-inner
        `]:{color:L}})}]},genAffixWrapperStyles=a=>{const{componentCls:c,paddingBlock:u,paddingInline:d,inputAffixPadding:f,controlWidth:m,borderRadiusLG:g,borderRadiusSM:y,paddingInlineLG:b,paddingInlineSM:E,paddingBlockLG:C,paddingBlockSM:w,motionDurationMid:R}=a;return{[`${c}-affix-wrapper`]:Object.assign(Object.assign({[`input${c}-input`]:{padding:`${unit$1(u)} 0`}},genBasicInputStyle(a)),{position:"relative",display:"inline-flex",alignItems:"center",width:m,padding:0,paddingInlineStart:d,"&-lg":{borderRadius:g,paddingInlineStart:b,[`input${c}-input`]:{padding:`${unit$1(C)} 0`}},"&-sm":{borderRadius:y,paddingInlineStart:E,[`input${c}-input`]:{padding:`${unit$1(w)} 0`}},[`&:not(${c}-disabled):hover`]:{zIndex:1},"&-focused, &:focus":{zIndex:1},[`&-disabled > ${c}-disabled`]:{background:"transparent"},[`> div${c}`]:{width:"100%",border:"none",outline:"none",[`&${c}-focused`]:{boxShadow:"none !important"}},"&::before":{display:"inline-block",width:0,visibility:"hidden",content:'"\\a0"'},[`${c}-handler-wrap`]:{zIndex:2},[c]:{position:"static",color:"inherit","&-prefix, &-suffix":{display:"flex",flex:"none",alignItems:"center",pointerEvents:"none"},"&-prefix":{marginInlineEnd:f},"&-suffix":{insetBlockStart:0,insetInlineEnd:0,height:"100%",marginInlineEnd:d,marginInlineStart:f,transition:`margin ${R}`}},[`&:hover ${c}-handler-wrap, &-focused ${c}-handler-wrap`]:{width:a.handleWidth,opacity:1},[`&:not(${c}-affix-wrapper-without-controls):hover ${c}-suffix`]:{marginInlineEnd:a.calc(a.handleWidth).add(d).equal()}})}},useStyle$c=genStyleHooks("InputNumber",a=>{const c=merge$2(a,initInputToken(a));return[genInputNumberStyles(c),genAffixWrapperStyles(c),genCompactItemStyle(c)]},prepareComponentToken$a,{unitless:{handleOpacity:!0}});var __rest$v=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InputNumber=reactExports.forwardRef((a,c)=>{const{getPrefixCls:u,direction:d}=reactExports.useContext(ConfigContext),f=reactExports.useRef(null);reactExports.useImperativeHandle(c,()=>f.current);const{className:m,rootClassName:g,size:y,disabled:b,prefixCls:E,addonBefore:C,addonAfter:w,prefix:R,suffix:_,bordered:M,readOnly:I,status:N,controls:A,variant:P}=a,z=__rest$v(a,["className","rootClassName","size","disabled","prefixCls","addonBefore","addonAfter","prefix","suffix","bordered","readOnly","status","controls","variant"]),B=u("input-number",E),j=useCSSVarCls(B),[L,U,q]=useStyle$c(B,j),{compactSize:F,compactItemClassnames:K}=useCompactItemContext(B,d);let X=reactExports.createElement(RefIcon$3,{className:`${B}-handler-up-inner`}),Q=reactExports.createElement(RefIcon$t,{className:`${B}-handler-down-inner`});const Y=typeof A=="boolean"?A:void 0;typeof A=="object"&&(X=typeof A.upIcon>"u"?X:reactExports.createElement("span",{className:`${B}-handler-up-inner`},A.upIcon),Q=typeof A.downIcon>"u"?Q:reactExports.createElement("span",{className:`${B}-handler-down-inner`},A.downIcon));const{hasFeedback:Z,status:J,isFormItemInput:W,feedbackIcon:G}=reactExports.useContext(FormItemInputContext),te=getMergedStatus(J,N),ae=useSize(de=>{var ge;return(ge=y??F)!==null&&ge!==void 0?ge:de}),V=reactExports.useContext(DisabledContext),ne=b??V,[le,ee]=useVariant("inputNumber",P,M),ie=Z&&reactExports.createElement(reactExports.Fragment,null,G),ce=classNames({[`${B}-lg`]:ae==="large",[`${B}-sm`]:ae==="small",[`${B}-rtl`]:d==="rtl",[`${B}-in-form-item`]:W},U),ue=`${B}-group`,me=reactExports.createElement(InputNumber$1,Object.assign({ref:f,disabled:ne,className:classNames(q,j,m,g,K),upHandler:X,downHandler:Q,prefixCls:B,readOnly:I,controls:Y,prefix:R,suffix:ie||_,addonBefore:C&&reactExports.createElement(ContextIsolator,{form:!0,space:!0},C),addonAfter:w&&reactExports.createElement(ContextIsolator,{form:!0,space:!0},w),classNames:{input:ce,variant:classNames({[`${B}-${le}`]:ee},getStatusClassNames(B,te,Z)),affixWrapper:classNames({[`${B}-affix-wrapper-sm`]:ae==="small",[`${B}-affix-wrapper-lg`]:ae==="large",[`${B}-affix-wrapper-rtl`]:d==="rtl",[`${B}-affix-wrapper-without-controls`]:A===!1||ne},U),wrapper:classNames({[`${ue}-rtl`]:d==="rtl"},U),groupWrapper:classNames({[`${B}-group-wrapper-sm`]:ae==="small",[`${B}-group-wrapper-lg`]:ae==="large",[`${B}-group-wrapper-rtl`]:d==="rtl",[`${B}-group-wrapper-${le}`]:ee},getStatusClassNames(`${B}-group-wrapper`,te,Z),U)}},z));return L(me)}),TypedInputNumber=InputNumber,PureInputNumber=a=>reactExports.createElement(ConfigProvider,{theme:{components:{InputNumber:{handleVisible:!0}}}},reactExports.createElement(InputNumber,Object.assign({},a)));TypedInputNumber._InternalPanelDoNotUseOrYouWillBeFired=PureInputNumber;const getAllowClear=a=>{let c;return typeof a=="object"&&(a!=null&&a.clearIcon)?c=a:a&&(c={clearIcon:React.createElement(RefIcon$y,null)}),c};function useRemovePasswordTimeout(a,c){const u=reactExports.useRef([]),d=()=>{u.current.push(setTimeout(()=>{var f,m,g,y;!((f=a.current)===null||f===void 0)&&f.input&&((m=a.current)===null||m===void 0?void 0:m.input.getAttribute("type"))==="password"&&(!((g=a.current)===null||g===void 0)&&g.input.hasAttribute("value"))&&((y=a.current)===null||y===void 0||y.input.removeAttribute("value"))}))};return reactExports.useEffect(()=>(c&&d(),()=>u.current.forEach(f=>{f&&clearTimeout(f)})),[]),d}function hasPrefixSuffix(a){return!!(a.prefix||a.suffix||a.allowClear||a.showCount)}var __rest$u=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Input$1=reactExports.forwardRef((a,c)=>{const{prefixCls:u,bordered:d=!0,status:f,size:m,disabled:g,onBlur:y,onFocus:b,suffix:E,allowClear:C,addonAfter:w,addonBefore:R,className:_,style:M,styles:I,rootClassName:N,onChange:A,classNames:P,variant:z}=a,B=__rest$u(a,["prefixCls","bordered","status","size","disabled","onBlur","onFocus","suffix","allowClear","addonAfter","addonBefore","className","style","styles","rootClassName","onChange","classNames","variant"]),{getPrefixCls:j,direction:L,allowClear:U,autoComplete:q,className:F,style:K,classNames:X,styles:Q}=useComponentConfig("input"),Y=j("input",u),Z=reactExports.useRef(null),J=useCSSVarCls(Y),[W,G,te]=useSharedStyle(Y,N),[ae]=useStyle$g(Y,J),{compactSize:V,compactItemClassnames:ne}=useCompactItemContext(Y,L),le=useSize(Re=>{var De;return(De=m??V)!==null&&De!==void 0?De:Re}),ee=React.useContext(DisabledContext),ie=g??ee,{status:ce,hasFeedback:ue,feedbackIcon:me}=reactExports.useContext(FormItemInputContext),de=getMergedStatus(ce,f),ge=hasPrefixSuffix(a)||!!ue;reactExports.useRef(ge);const Ce=useRemovePasswordTimeout(Z,!0),ve=Re=>{Ce(),y==null||y(Re)},fe=Re=>{Ce(),b==null||b(Re)},pe=Re=>{Ce(),A==null||A(Re)},xe=(ue||E)&&React.createElement(React.Fragment,null,E,ue&&me),ye=getAllowClear(C??U),[he,we]=useVariant("input",z,d);return W(ae(React.createElement(Input$2,Object.assign({ref:composeRef(c,Z),prefixCls:Y,autoComplete:q},B,{disabled:ie,onBlur:ve,onFocus:fe,style:Object.assign(Object.assign({},K),M),styles:Object.assign(Object.assign({},Q),I),suffix:xe,allowClear:ye,className:classNames(_,N,te,J,ne,F),onChange:pe,addonBefore:R&&React.createElement(ContextIsolator,{form:!0,space:!0},R),addonAfter:w&&React.createElement(ContextIsolator,{form:!0,space:!0},w),classNames:Object.assign(Object.assign(Object.assign({},P),X),{input:classNames({[`${Y}-sm`]:le==="small",[`${Y}-lg`]:le==="large",[`${Y}-rtl`]:L==="rtl"},P==null?void 0:P.input,X.input,G),variant:classNames({[`${Y}-${he}`]:we},getStatusClassNames(Y,de)),affixWrapper:classNames({[`${Y}-affix-wrapper-sm`]:le==="small",[`${Y}-affix-wrapper-lg`]:le==="large",[`${Y}-affix-wrapper-rtl`]:L==="rtl"},G),wrapper:classNames({[`${Y}-group-rtl`]:L==="rtl"},G),groupWrapper:classNames({[`${Y}-group-wrapper-sm`]:le==="small",[`${Y}-group-wrapper-lg`]:le==="large",[`${Y}-group-wrapper-rtl`]:L==="rtl",[`${Y}-group-wrapper-${he}`]:we},getStatusClassNames(`${Y}-group-wrapper`,de,ue),G)})}))))});function isPresetSize(a){return["small","middle","large"].includes(a)}function isValidGapNumber(a){return a?typeof a=="number"&&!Number.isNaN(a):!1}const SpaceContext=React.createContext({latestIndex:0}),SpaceContextProvider=SpaceContext.Provider,Item=a=>{let{className:c,index:u,children:d,split:f,style:m}=a;const{latestIndex:g}=reactExports.useContext(SpaceContext);return d==null?null:reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("div",{className:c,style:m},d),u<g&&f&&reactExports.createElement("span",{className:`${c}-split`},f))};var __rest$t=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalSpace=reactExports.forwardRef((a,c)=>{var u;const{getPrefixCls:d,direction:f,size:m,className:g,style:y,classNames:b,styles:E}=useComponentConfig("space"),{size:C=m??"small",align:w,className:R,rootClassName:_,children:M,direction:I="horizontal",prefixCls:N,split:A,style:P,wrap:z=!1,classNames:B,styles:j}=a,L=__rest$t(a,["size","align","className","rootClassName","children","direction","prefixCls","split","style","wrap","classNames","styles"]),[U,q]=Array.isArray(C)?C:[C,C],F=isPresetSize(q),K=isPresetSize(U),X=isValidGapNumber(q),Q=isValidGapNumber(U),Y=toArray$6(M,{keepEmpty:!0}),Z=w===void 0&&I==="horizontal"?"center":w,J=d("space",N),[W,G,te]=useStyle$t(J),ae=classNames(J,g,G,`${J}-${I}`,{[`${J}-rtl`]:f==="rtl",[`${J}-align-${Z}`]:Z,[`${J}-gap-row-${q}`]:F,[`${J}-gap-col-${U}`]:K},R,_,te),V=classNames(`${J}-item`,(u=B==null?void 0:B.item)!==null&&u!==void 0?u:b.item);let ne=0;const le=Y.map((ce,ue)=>{var me;ce!=null&&(ne=ue);const de=(ce==null?void 0:ce.key)||`${V}-${ue}`;return reactExports.createElement(Item,{className:V,key:de,index:ue,split:A,style:(me=j==null?void 0:j.item)!==null&&me!==void 0?me:E.item},ce)}),ee=reactExports.useMemo(()=>({latestIndex:ne}),[ne]);if(Y.length===0)return null;const ie={};return z&&(ie.flexWrap="wrap"),!K&&Q&&(ie.columnGap=U),!F&&X&&(ie.rowGap=q),W(reactExports.createElement("div",Object.assign({ref:c,className:ae,style:Object.assign(Object.assign(Object.assign({},ie),y),P)},L),reactExports.createElement(SpaceContextProvider,{value:ee},le)))}),Space=InternalSpace;Space.Compact=Compact$1;var __rest$s=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const DropdownButton=a=>{const{getPopupContainer:c,getPrefixCls:u,direction:d}=reactExports.useContext(ConfigContext),{prefixCls:f,type:m="default",danger:g,disabled:y,loading:b,onClick:E,htmlType:C,children:w,className:R,menu:_,arrow:M,autoFocus:I,overlay:N,trigger:A,align:P,open:z,onOpenChange:B,placement:j,getPopupContainer:L,href:U,icon:q=reactExports.createElement(RefIcon$r,null),title:F,buttonsRender:K=de=>de,mouseEnterDelay:X,mouseLeaveDelay:Q,overlayClassName:Y,overlayStyle:Z,destroyPopupOnHide:J,dropdownRender:W}=a,G=__rest$s(a,["prefixCls","type","danger","disabled","loading","onClick","htmlType","children","className","menu","arrow","autoFocus","overlay","trigger","align","open","onOpenChange","placement","getPopupContainer","href","icon","title","buttonsRender","mouseEnterDelay","mouseLeaveDelay","overlayClassName","overlayStyle","destroyPopupOnHide","dropdownRender"]),te=u("dropdown",f),ae=`${te}-button`,V={menu:_,arrow:M,autoFocus:I,align:P,disabled:y,trigger:y?[]:A,onOpenChange:B,getPopupContainer:L||c,mouseEnterDelay:X,mouseLeaveDelay:Q,overlayClassName:Y,overlayStyle:Z,destroyPopupOnHide:J,dropdownRender:W},{compactSize:ne,compactItemClassnames:le}=useCompactItemContext(te,d),ee=classNames(ae,le,R);"overlay"in a&&(V.overlay=N),"open"in a&&(V.open=z),"placement"in a?V.placement=j:V.placement=d==="rtl"?"bottomLeft":"bottomRight";const ie=reactExports.createElement(Button$1,{type:m,danger:g,disabled:y,loading:b,onClick:E,htmlType:C,href:U,title:F},w),ce=reactExports.createElement(Button$1,{type:m,danger:g,icon:q}),[ue,me]=K([ie,ce]);return reactExports.createElement(Space.Compact,Object.assign({className:ee,size:ne,block:!0},G),ue,reactExports.createElement(Dropdown$1,Object.assign({},V),me))};DropdownButton.__ANT_BUTTON=!0;const Dropdown=Dropdown$1;Dropdown.Button=DropdownButton;const flexWrapValues=["wrap","nowrap","wrap-reverse"],justifyContentValues=["flex-start","flex-end","start","end","center","space-between","space-around","space-evenly","stretch","normal","left","right"],alignItemsValues=["center","start","end","flex-start","flex-end","self-start","self-end","baseline","normal","stretch"],genClsWrap=(a,c)=>{const u=c.wrap===!0?"wrap":c.wrap;return{[`${a}-wrap-${u}`]:u&&flexWrapValues.includes(u)}},genClsAlign=(a,c)=>{const u={};return alignItemsValues.forEach(d=>{u[`${a}-align-${d}`]=c.align===d}),u[`${a}-align-stretch`]=!c.align&&!!c.vertical,u},genClsJustify=(a,c)=>{const u={};return justifyContentValues.forEach(d=>{u[`${a}-justify-${d}`]=c.justify===d}),u};function createFlexClassNames(a,c){return classNames(Object.assign(Object.assign(Object.assign({},genClsWrap(a,c)),genClsAlign(a,c)),genClsJustify(a,c)))}const genFlexStyle=a=>{const{componentCls:c}=a;return{[c]:{display:"flex",margin:0,padding:0,"&-vertical":{flexDirection:"column"},"&-rtl":{direction:"rtl"},"&:empty":{display:"none"}}}},genFlexGapStyle=a=>{const{componentCls:c}=a;return{[c]:{"&-gap-small":{gap:a.flexGapSM},"&-gap-middle":{gap:a.flexGap},"&-gap-large":{gap:a.flexGapLG}}}},genFlexWrapStyle=a=>{const{componentCls:c}=a,u={};return flexWrapValues.forEach(d=>{u[`${c}-wrap-${d}`]={flexWrap:d}}),u},genAlignItemsStyle=a=>{const{componentCls:c}=a,u={};return alignItemsValues.forEach(d=>{u[`${c}-align-${d}`]={alignItems:d}}),u},genJustifyContentStyle=a=>{const{componentCls:c}=a,u={};return justifyContentValues.forEach(d=>{u[`${c}-justify-${d}`]={justifyContent:d}}),u},prepareComponentToken$9=()=>({}),useStyle$b=genStyleHooks("Flex",a=>{const{paddingXS:c,padding:u,paddingLG:d}=a,f=merge$2(a,{flexGapSM:c,flexGap:u,flexGapLG:d});return[genFlexStyle(f),genFlexGapStyle(f),genFlexWrapStyle(f),genAlignItemsStyle(f),genJustifyContentStyle(f)]},prepareComponentToken$9,{resetStyle:!1});var __rest$r=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Flex=React.forwardRef((a,c)=>{const{prefixCls:u,rootClassName:d,className:f,style:m,flex:g,gap:y,children:b,vertical:E=!1,component:C="div"}=a,w=__rest$r(a,["prefixCls","rootClassName","className","style","flex","gap","children","vertical","component"]),{flex:R,direction:_,getPrefixCls:M}=React.useContext(ConfigContext),I=M("flex",u),[N,A,P]=useStyle$b(I),z=E??(R==null?void 0:R.vertical),B=classNames(f,d,R==null?void 0:R.className,I,A,P,createFlexClassNames(I,a),{[`${I}-rtl`]:_==="rtl",[`${I}-gap-${y}`]:isPresetSize(y),[`${I}-vertical`]:z}),j=Object.assign(Object.assign({},R==null?void 0:R.style),m);return g&&(j.flex=g),y&&!isPresetSize(y)&&(j.gap=y),N(React.createElement(C,Object.assign({ref:c,className:B,style:j},omit(w,["justify","wrap","align"])),b))});function useDebounce(a){const[c,u]=reactExports.useState(a);return reactExports.useEffect(()=>{const d=setTimeout(()=>{u(a)},a.length?0:10);return()=>{clearTimeout(d)}},[a]),c}const genFormValidateMotionStyle=a=>{const{componentCls:c}=a,u=`${c}-show-help`,d=`${c}-show-help-item`;return{[u]:{transition:`opacity ${a.motionDurationFast} ${a.motionEaseInOut}`,"&-appear, &-enter":{opacity:0,"&-active":{opacity:1}},"&-leave":{opacity:1,"&-active":{opacity:0}},[d]:{overflow:"hidden",transition:`height ${a.motionDurationFast} ${a.motionEaseInOut},
                     opacity ${a.motionDurationFast} ${a.motionEaseInOut},
                     transform ${a.motionDurationFast} ${a.motionEaseInOut} !important`,[`&${d}-appear, &${d}-enter`]:{transform:"translateY(-5px)",opacity:0,"&-active":{transform:"translateY(0)",opacity:1}},[`&${d}-leave-active`]:{transform:"translateY(-5px)"}}}}},resetForm=a=>({legend:{display:"block",width:"100%",marginBottom:a.marginLG,padding:0,color:a.colorTextDescription,fontSize:a.fontSizeLG,lineHeight:"inherit",border:0,borderBottom:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`},'input[type="search"]':{boxSizing:"border-box"},'input[type="radio"], input[type="checkbox"]':{lineHeight:"normal"},'input[type="file"]':{display:"block"},'input[type="range"]':{display:"block",width:"100%"},"select[multiple], select[size]":{height:"auto"},"input[type='file']:focus,\n  input[type='radio']:focus,\n  input[type='checkbox']:focus":{outline:0,boxShadow:`0 0 0 ${unit$1(a.controlOutlineWidth)} ${a.controlOutline}`},output:{display:"block",paddingTop:15,color:a.colorText,fontSize:a.fontSize,lineHeight:a.lineHeight}}),genFormSize=(a,c)=>{const{formItemCls:u}=a;return{[u]:{[`${u}-label > label`]:{height:c},[`${u}-control-input`]:{minHeight:c}}}},genFormStyle=a=>{const{componentCls:c}=a;return{[a.componentCls]:Object.assign(Object.assign(Object.assign({},resetComponent(a)),resetForm(a)),{[`${c}-text`]:{display:"inline-block",paddingInlineEnd:a.paddingSM},"&-small":Object.assign({},genFormSize(a,a.controlHeightSM)),"&-large":Object.assign({},genFormSize(a,a.controlHeightLG))})}},genFormItemStyle=a=>{const{formItemCls:c,iconCls:u,rootPrefixCls:d,antCls:f,labelRequiredMarkColor:m,labelColor:g,labelFontSize:y,labelHeight:b,labelColonMarginInlineStart:E,labelColonMarginInlineEnd:C,itemMarginBottom:w}=a;return{[c]:Object.assign(Object.assign({},resetComponent(a)),{marginBottom:w,verticalAlign:"top","&-with-help":{transition:"none"},[`&-hidden,
        &-hidden${f}-row`]:{display:"none"},"&-has-warning":{[`${c}-split`]:{color:a.colorError}},"&-has-error":{[`${c}-split`]:{color:a.colorWarning}},[`${c}-label`]:{flexGrow:0,overflow:"hidden",whiteSpace:"nowrap",textAlign:"end",verticalAlign:"middle","&-left":{textAlign:"start"},"&-wrap":{overflow:"unset",lineHeight:a.lineHeight,whiteSpace:"unset"},"> label":{position:"relative",display:"inline-flex",alignItems:"center",maxWidth:"100%",height:b,color:g,fontSize:y,[`> ${u}`]:{fontSize:a.fontSize,verticalAlign:"top"},[`&${c}-required`]:{"&::before":{display:"inline-block",marginInlineEnd:a.marginXXS,color:m,fontSize:a.fontSize,fontFamily:"SimSun, sans-serif",lineHeight:1,content:'"*"'},[`&${c}-required-mark-hidden, &${c}-required-mark-optional`]:{"&::before":{display:"none"}}},[`${c}-optional`]:{display:"inline-block",marginInlineStart:a.marginXXS,color:a.colorTextDescription,[`&${c}-required-mark-hidden`]:{display:"none"}},[`${c}-tooltip`]:{color:a.colorTextDescription,cursor:"help",writingMode:"horizontal-tb",marginInlineStart:a.marginXXS},"&::after":{content:'":"',position:"relative",marginBlock:0,marginInlineStart:E,marginInlineEnd:C},[`&${c}-no-colon::after`]:{content:'"\\a0"'}}},[`${c}-control`]:{"--ant-display":"flex",flexDirection:"column",flexGrow:1,[`&:first-child:not([class^="'${d}-col-'"]):not([class*="' ${d}-col-'"])`]:{width:"100%"},"&-input":{position:"relative",display:"flex",alignItems:"center",minHeight:a.controlHeight,"&-content":{flex:"auto",maxWidth:"100%"}}},[c]:{"&-additional":{display:"flex",flexDirection:"column"},"&-explain, &-extra":{clear:"both",color:a.colorTextDescription,fontSize:a.fontSize,lineHeight:a.lineHeight},"&-explain-connected":{width:"100%"},"&-extra":{minHeight:a.controlHeightSM,transition:`color ${a.motionDurationMid} ${a.motionEaseOut}`},"&-explain":{"&-error":{color:a.colorError},"&-warning":{color:a.colorWarning}}},[`&-with-help ${c}-explain`]:{height:"auto",opacity:1},[`${c}-feedback-icon`]:{fontSize:a.fontSize,textAlign:"center",visibility:"visible",animationName:zoomIn,animationDuration:a.motionDurationMid,animationTimingFunction:a.motionEaseOutBack,pointerEvents:"none","&-success":{color:a.colorSuccess},"&-error":{color:a.colorError},"&-warning":{color:a.colorWarning},"&-validating":{color:a.colorPrimary}}})}},genHorizontalStyle=(a,c)=>{const{formItemCls:u}=a;return{[`${c}-horizontal`]:{[`${u}-label`]:{flexGrow:0},[`${u}-control`]:{flex:"1 1 0",minWidth:0},[`${u}-label[class$='-24'], ${u}-label[class*='-24 ']`]:{[`& + ${u}-control`]:{minWidth:"unset"}}}}},genInlineStyle=a=>{const{componentCls:c,formItemCls:u,inlineItemMarginBottom:d}=a;return{[`${c}-inline`]:{display:"flex",flexWrap:"wrap",[u]:{flex:"none",marginInlineEnd:a.margin,marginBottom:d,"&-row":{flexWrap:"nowrap"},[`> ${u}-label,
        > ${u}-control`]:{display:"inline-block",verticalAlign:"top"},[`> ${u}-label`]:{flex:"none"},[`${c}-text`]:{display:"inline-block"},[`${u}-has-feedback`]:{display:"inline-block"}}}}},makeVerticalLayoutLabel=a=>({padding:a.verticalLabelPadding,margin:a.verticalLabelMargin,whiteSpace:"initial",textAlign:"start","> label":{margin:0,"&::after":{visibility:"hidden"}}}),makeVerticalLayout=a=>{const{componentCls:c,formItemCls:u,rootPrefixCls:d}=a;return{[`${u} ${u}-label`]:makeVerticalLayoutLabel(a),[`${c}:not(${c}-inline)`]:{[u]:{flexWrap:"wrap",[`${u}-label, ${u}-control`]:{[`&:not([class*=" ${d}-col-xs"])`]:{flex:"0 0 100%",maxWidth:"100%"}}}}}},genVerticalStyle=a=>{const{componentCls:c,formItemCls:u,antCls:d}=a;return{[`${c}-vertical`]:{[`${u}:not(${u}-horizontal)`]:{[`${u}-row`]:{flexDirection:"column"},[`${u}-label > label`]:{height:"auto"},[`${u}-control`]:{width:"100%"},[`${u}-label,
        ${d}-col-24${u}-label,
        ${d}-col-xl-24${u}-label`]:makeVerticalLayoutLabel(a)}},[`@media (max-width: ${unit$1(a.screenXSMax)})`]:[makeVerticalLayout(a),{[c]:{[`${u}:not(${u}-horizontal)`]:{[`${d}-col-xs-24${u}-label`]:makeVerticalLayoutLabel(a)}}}],[`@media (max-width: ${unit$1(a.screenSMMax)})`]:{[c]:{[`${u}:not(${u}-horizontal)`]:{[`${d}-col-sm-24${u}-label`]:makeVerticalLayoutLabel(a)}}},[`@media (max-width: ${unit$1(a.screenMDMax)})`]:{[c]:{[`${u}:not(${u}-horizontal)`]:{[`${d}-col-md-24${u}-label`]:makeVerticalLayoutLabel(a)}}},[`@media (max-width: ${unit$1(a.screenLGMax)})`]:{[c]:{[`${u}:not(${u}-horizontal)`]:{[`${d}-col-lg-24${u}-label`]:makeVerticalLayoutLabel(a)}}}}},genItemVerticalStyle=a=>{const{formItemCls:c,antCls:u}=a;return{[`${c}-vertical`]:{[`${c}-row`]:{flexDirection:"column"},[`${c}-label > label`]:{height:"auto"},[`${c}-control`]:{width:"100%"}},[`${c}-vertical ${c}-label,
      ${u}-col-24${c}-label,
      ${u}-col-xl-24${c}-label`]:makeVerticalLayoutLabel(a),[`@media (max-width: ${unit$1(a.screenXSMax)})`]:[makeVerticalLayout(a),{[c]:{[`${u}-col-xs-24${c}-label`]:makeVerticalLayoutLabel(a)}}],[`@media (max-width: ${unit$1(a.screenSMMax)})`]:{[c]:{[`${u}-col-sm-24${c}-label`]:makeVerticalLayoutLabel(a)}},[`@media (max-width: ${unit$1(a.screenMDMax)})`]:{[c]:{[`${u}-col-md-24${c}-label`]:makeVerticalLayoutLabel(a)}},[`@media (max-width: ${unit$1(a.screenLGMax)})`]:{[c]:{[`${u}-col-lg-24${c}-label`]:makeVerticalLayoutLabel(a)}}}},prepareComponentToken$8=a=>({labelRequiredMarkColor:a.colorError,labelColor:a.colorTextHeading,labelFontSize:a.fontSize,labelHeight:a.controlHeight,labelColonMarginInlineStart:a.marginXXS/2,labelColonMarginInlineEnd:a.marginXS,itemMarginBottom:a.marginLG,verticalLabelPadding:`0 0 ${a.paddingXS}px`,verticalLabelMargin:0,inlineItemMarginBottom:0}),prepareToken$2=(a,c)=>merge$2(a,{formItemCls:`${a.componentCls}-item`,rootPrefixCls:c}),useStyle$a=genStyleHooks("Form",(a,c)=>{let{rootPrefixCls:u}=c;const d=prepareToken$2(a,u);return[genFormStyle(d),genFormItemStyle(d),genFormValidateMotionStyle(d),genHorizontalStyle(d,d.componentCls),genHorizontalStyle(d,d.formItemCls),genInlineStyle(d),genVerticalStyle(d),genItemVerticalStyle(d),genCollapseMotion(d),zoomIn]},prepareComponentToken$8,{order:-1e3}),EMPTY_LIST$2=[];function toErrorEntity(a,c,u){let d=arguments.length>3&&arguments[3]!==void 0?arguments[3]:0;return{key:typeof a=="string"?a:`${c}-${d}`,error:a,errorStatus:u}}const ErrorList=a=>{let{help:c,helpStatus:u,errors:d=EMPTY_LIST$2,warnings:f=EMPTY_LIST$2,className:m,fieldId:g,onVisibleChanged:y}=a;const{prefixCls:b}=reactExports.useContext(FormItemPrefixContext),E=`${b}-item-explain`,C=useCSSVarCls(b),[w,R,_]=useStyle$a(b,C),M=reactExports.useMemo(()=>initCollapseMotion(b),[b]),I=useDebounce(d),N=useDebounce(f),A=reactExports.useMemo(()=>c!=null?[toErrorEntity(c,"help",u)]:[].concat(_toConsumableArray(I.map((B,j)=>toErrorEntity(B,"error","error",j))),_toConsumableArray(N.map((B,j)=>toErrorEntity(B,"warning","warning",j)))),[c,u,I,N]),P=reactExports.useMemo(()=>{const B={};return A.forEach(j=>{let{key:L}=j;B[L]=(B[L]||0)+1}),A.map((j,L)=>Object.assign(Object.assign({},j),{key:B[j.key]>1?`${j.key}-fallback-${L}`:j.key}))},[A]),z={};return g&&(z.id=`${g}_help`),w(reactExports.createElement(CSSMotion,{motionDeadline:M.motionDeadline,motionName:`${b}-show-help`,visible:!!P.length,onVisibleChanged:y},B=>{const{className:j,style:L}=B;return reactExports.createElement("div",Object.assign({},z,{className:classNames(E,j,_,C,m,R),style:L}),reactExports.createElement(CSSMotionList,Object.assign({keys:P},initCollapseMotion(b),{motionName:`${b}-show-help-item`,component:!1}),U=>{const{key:q,error:F,errorStatus:K,className:X,style:Q}=U;return reactExports.createElement("div",{key:q,className:classNames(X,{[`${E}-${K}`]:K}),style:Q},F)}))}))},formItemNameBlackList=["parentNode"],defaultItemNamePrefixCls="form_item";function toArray$2(a){return a===void 0||a===!1?[]:Array.isArray(a)?a:[a]}function getFieldId(a,c){if(!a.length)return;const u=a.join("_");return c?`${c}_${u}`:formItemNameBlackList.includes(u)?`${defaultItemNamePrefixCls}_${u}`:u}function getStatus(a,c,u,d,f,m){let g=d;return m!==void 0?g=m:u.validating?g="validating":a.length?g="error":c.length?g="warning":(u.touched||f&&u.validated)&&(g="success"),g}var __rest$q=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function toNamePathStr(a){return toArray$2(a).join("_")}function getFieldDOMNode(a,c){const u=c.getFieldInstance(a),d=getDOM(u);if(d)return d;const f=getFieldId(toArray$2(a),c.__INTERNAL__.name);if(f)return document.getElementById(f)}function useForm(a){const[c]=useForm$1(),u=reactExports.useRef({}),d=reactExports.useMemo(()=>a??Object.assign(Object.assign({},c),{__INTERNAL__:{itemRef:f=>m=>{const g=toNamePathStr(f);m?u.current[g]=m:delete u.current[g]}},scrollToField:function(f){let m=arguments.length>1&&arguments[1]!==void 0?arguments[1]:{};const{focus:g}=m,y=__rest$q(m,["focus"]),b=getFieldDOMNode(f,d);b&&(e(b,Object.assign({scrollMode:"if-needed",block:"nearest"},y)),g&&d.focusField(f))},focusField:f=>{var m,g;const y=d.getFieldInstance(f);typeof(y==null?void 0:y.focus)=="function"?y.focus():(g=(m=getFieldDOMNode(f,d))===null||m===void 0?void 0:m.focus)===null||g===void 0||g.call(m)},getFieldInstance:f=>{const m=toNamePathStr(f);return u.current[m]}}),[a,c]);return[d]}var __rest$p=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalForm=(a,c)=>{const u=reactExports.useContext(DisabledContext),{getPrefixCls:d,direction:f,requiredMark:m,colon:g,scrollToFirstError:y,className:b,style:E}=useComponentConfig("form"),{prefixCls:C,className:w,rootClassName:R,size:_,disabled:M=u,form:I,colon:N,labelAlign:A,labelWrap:P,labelCol:z,wrapperCol:B,hideRequiredMark:j,layout:L="horizontal",scrollToFirstError:U,requiredMark:q,onFinishFailed:F,name:K,style:X,feedbackIcons:Q,variant:Y}=a,Z=__rest$p(a,["prefixCls","className","rootClassName","size","disabled","form","colon","labelAlign","labelWrap","labelCol","wrapperCol","hideRequiredMark","layout","scrollToFirstError","requiredMark","onFinishFailed","name","style","feedbackIcons","variant"]),J=useSize(_),W=reactExports.useContext(ValidateMessagesContext),G=reactExports.useMemo(()=>q!==void 0?q:j?!1:m!==void 0?m:!0,[j,q,m]),te=N??g,ae=d("form",C),V=useCSSVarCls(ae),[ne,le,ee]=useStyle$a(ae,V),ie=classNames(ae,`${ae}-${L}`,{[`${ae}-hide-required-mark`]:G===!1,[`${ae}-rtl`]:f==="rtl",[`${ae}-${J}`]:J},ee,V,le,b,w,R),[ce]=useForm(I),{__INTERNAL__:ue}=ce;ue.name=K;const me=reactExports.useMemo(()=>({name:K,labelAlign:A,labelCol:z,labelWrap:P,wrapperCol:B,vertical:L==="vertical",colon:te,requiredMark:G,itemRef:ue.itemRef,form:ce,feedbackIcons:Q}),[K,A,z,B,L,te,G,ce,Q]),de=reactExports.useRef(null);reactExports.useImperativeHandle(c,()=>{var ve;return Object.assign(Object.assign({},ce),{nativeElement:(ve=de.current)===null||ve===void 0?void 0:ve.nativeElement})});const ge=(ve,fe)=>{if(ve){let pe={block:"nearest"};typeof ve=="object"&&(pe=Object.assign(Object.assign({},pe),ve)),ce.scrollToField(fe,pe)}},Ce=ve=>{if(F==null||F(ve),ve.errorFields.length){const fe=ve.errorFields[0].name;if(U!==void 0){ge(U,fe);return}y!==void 0&&ge(y,fe)}};return ne(reactExports.createElement(VariantContext.Provider,{value:Y},reactExports.createElement(DisabledContextProvider,{disabled:M},reactExports.createElement(SizeContext.Provider,{value:J},reactExports.createElement(FormProvider,{validateMessages:W},reactExports.createElement(FormContext.Provider,{value:me},reactExports.createElement(RefForm,Object.assign({id:K},Z,{name:K,onFinishFailed:Ce,form:ce,ref:de,style:Object.assign(Object.assign({},E),X),className:ie}))))))))},Form$2=reactExports.forwardRef(InternalForm);function useChildren(a){if(typeof a=="function")return a;const c=toArray$6(a);return c.length<=1?c[0]:c}const useFormItemStatus=()=>{const{status:a,errors:c=[],warnings:u=[]}=reactExports.useContext(FormItemInputContext);return{status:a,errors:c,warnings:u}};useFormItemStatus.Context=FormItemInputContext;function useFrameState(a){const[c,u]=reactExports.useState(a),d=reactExports.useRef(null),f=reactExports.useRef([]),m=reactExports.useRef(!1);reactExports.useEffect(()=>(m.current=!1,()=>{m.current=!0,wrapperRaf.cancel(d.current),d.current=null}),[]);function g(y){m.current||(d.current===null&&(f.current=[],d.current=wrapperRaf(()=>{d.current=null,u(b=>{let E=b;return f.current.forEach(C=>{E=C(E)}),E})})),f.current.push(y))}return[c,g]}function useItemRef(){const{itemRef:a}=reactExports.useContext(FormContext),c=reactExports.useRef({});function u(d,f){const m=f&&typeof f=="object"&&getNodeRef(f),g=d.join("_");return(c.current.name!==g||c.current.originRef!==m)&&(c.current.name=g,c.current.originRef=m,c.current.ref=composeRef(a(d),m)),c.current.ref}return u}const genFallbackStyle=a=>{const{formItemCls:c}=a;return{"@media screen and (-ms-high-contrast: active), (-ms-high-contrast: none)":{[`${c}-control`]:{display:"flex"}}}},FallbackCmp=genSubStyleComponent(["Form","item-item"],(a,c)=>{let{rootPrefixCls:u}=c;const d=prepareToken$2(a,u);return[genFallbackStyle(d)]});var __rest$o=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const GRID_MAX=24,FormItemInput=a=>{const{prefixCls:c,status:u,labelCol:d,wrapperCol:f,children:m,errors:g,warnings:y,_internalItemRender:b,extra:E,help:C,fieldId:w,marginBottom:R,onErrorVisibleChanged:_,label:M}=a,I=`${c}-item`,N=reactExports.useContext(FormContext),A=reactExports.useMemo(()=>{let Z=Object.assign({},f||N.wrapperCol||{});return M===null&&!d&&!f&&N.labelCol&&[void 0,"xs","sm","md","lg","xl","xxl"].forEach(W=>{const G=W?[W]:[],te=get(N.labelCol,G),ae=typeof te=="object"?te:{},V=get(Z,G),ne=typeof V=="object"?V:{};"span"in ae&&!("offset"in ne)&&ae.span<GRID_MAX&&(Z=set$1(Z,[].concat(G,["offset"]),ae.span))}),Z},[f,N]),P=classNames(`${I}-control`,A.className),z=reactExports.useMemo(()=>{const{labelCol:Z,wrapperCol:J}=N;return __rest$o(N,["labelCol","wrapperCol"])},[N]),B=reactExports.useRef(null),[j,L]=reactExports.useState(0);useLayoutEffect$1(()=>{E&&B.current?L(B.current.clientHeight):L(0)},[E]);const U=reactExports.createElement("div",{className:`${I}-control-input`},reactExports.createElement("div",{className:`${I}-control-input-content`},m)),q=reactExports.useMemo(()=>({prefixCls:c,status:u}),[c,u]),F=R!==null||g.length||y.length?reactExports.createElement(FormItemPrefixContext.Provider,{value:q},reactExports.createElement(ErrorList,{fieldId:w,errors:g,warnings:y,help:C,helpStatus:u,className:`${I}-explain-connected`,onVisibleChanged:_})):null,K={};w&&(K.id=`${w}_extra`);const X=E?reactExports.createElement("div",Object.assign({},K,{className:`${I}-extra`,ref:B}),E):null,Q=F||X?reactExports.createElement("div",{className:`${I}-additional`,style:R?{minHeight:R+j}:{}},F,X):null,Y=b&&b.mark==="pro_table_render"&&b.render?b.render(a,{input:U,errorList:F,extra:X}):reactExports.createElement(reactExports.Fragment,null,U,Q);return reactExports.createElement(FormContext.Provider,{value:z},reactExports.createElement(Col,Object.assign({},A,{className:P}),Y),reactExports.createElement(FallbackCmp,{prefixCls:c}))};var __rest$n=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function toTooltipProps(a){return a?typeof a=="object"&&!reactExports.isValidElement(a)?a:{title:a}:null}const FormItemLabel=a=>{let{prefixCls:c,label:u,htmlFor:d,labelCol:f,labelAlign:m,colon:g,required:y,requiredMark:b,tooltip:E,vertical:C}=a;var w;const[R]=useLocale("Form"),{labelAlign:_,labelCol:M,labelWrap:I,colon:N}=reactExports.useContext(FormContext);if(!u)return null;const A=f||M||{},P=m||_,z=`${c}-item-label`,B=classNames(z,P==="left"&&`${z}-left`,A.className,{[`${z}-wrap`]:!!I});let j=u;const L=g===!0||N!==!1&&g!==!1;L&&!C&&typeof u=="string"&&u.trim()&&(j=u.replace(/[:|：]\s*$/,""));const q=toTooltipProps(E);if(q){const{icon:Z=reactExports.createElement(RefIcon$9,null)}=q,J=__rest$n(q,["icon"]),W=reactExports.createElement(Tooltip,Object.assign({},J),reactExports.cloneElement(Z,{className:`${c}-item-tooltip`,title:"",onClick:G=>{G.preventDefault()},tabIndex:null}));j=reactExports.createElement(reactExports.Fragment,null,j,W)}const F=b==="optional",K=typeof b=="function",X=b===!1;K?j=b(j,{required:!!y}):F&&!y&&(j=reactExports.createElement(reactExports.Fragment,null,j,reactExports.createElement("span",{className:`${c}-item-optional`,title:""},(R==null?void 0:R.optional)||((w=localeValues.Form)===null||w===void 0?void 0:w.optional))));let Q;X?Q="hidden":(F||K)&&(Q="optional");const Y=classNames({[`${c}-item-required`]:y,[`${c}-item-required-mark-${Q}`]:Q,[`${c}-item-no-colon`]:!L});return reactExports.createElement(Col,Object.assign({},A,{className:B}),reactExports.createElement("label",{htmlFor:d,className:Y,title:typeof u=="string"?u:""},j))},iconMap={success:RefIcon$A,warning:RefIcon$p,error:RefIcon$y,validating:RefIcon$e};function StatusProvider(a){let{children:c,errors:u,warnings:d,hasFeedback:f,validateStatus:m,prefixCls:g,meta:y,noStyle:b}=a;const E=`${g}-item`,{feedbackIcons:C}=reactExports.useContext(FormContext),w=getStatus(u,d,y,null,!!f,m),{isFormItemInput:R,status:_,hasFeedback:M,feedbackIcon:I}=reactExports.useContext(FormItemInputContext),N=reactExports.useMemo(()=>{var A;let P;if(f){const B=f!==!0&&f.icons||C,j=w&&((A=B==null?void 0:B({status:w,errors:u,warnings:d}))===null||A===void 0?void 0:A[w]),L=w&&iconMap[w];P=j!==!1&&L?reactExports.createElement("span",{className:classNames(`${E}-feedback-icon`,`${E}-feedback-icon-${w}`)},j||reactExports.createElement(L,null)):null}const z={status:w||"",errors:u,warnings:d,hasFeedback:!!f,feedbackIcon:P,isFormItemInput:!0};return b&&(z.status=(w??_)||"",z.isFormItemInput=R,z.hasFeedback=!!(f??M),z.feedbackIcon=f!==void 0?z.feedbackIcon:I),z},[w,f,b,R,_]);return reactExports.createElement(FormItemInputContext.Provider,{value:N},c)}var __rest$m=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function ItemHolder(a){const{prefixCls:c,className:u,rootClassName:d,style:f,help:m,errors:g,warnings:y,validateStatus:b,meta:E,hasFeedback:C,hidden:w,children:R,fieldId:_,required:M,isRequired:I,onSubItemMetaChange:N,layout:A}=a,P=__rest$m(a,["prefixCls","className","rootClassName","style","help","errors","warnings","validateStatus","meta","hasFeedback","hidden","children","fieldId","required","isRequired","onSubItemMetaChange","layout"]),z=`${c}-item`,{requiredMark:B,vertical:j}=reactExports.useContext(FormContext),L=j||A==="vertical",U=reactExports.useRef(null),q=useDebounce(g),F=useDebounce(y),K=m!=null,X=!!(K||g.length||y.length),Q=!!U.current&&isVisible(U.current),[Y,Z]=reactExports.useState(null);useLayoutEffect$1(()=>{if(X&&U.current){const ae=getComputedStyle(U.current);Z(parseInt(ae.marginBottom,10))}},[X,Q]);const J=ae=>{ae||Z(null)},G=function(){let ae=arguments.length>0&&arguments[0]!==void 0?arguments[0]:!1;const V=ae?q:E.errors,ne=ae?F:E.warnings;return getStatus(V,ne,E,"",!!C,b)}(),te=classNames(z,u,d,{[`${z}-with-help`]:K||q.length||F.length,[`${z}-has-feedback`]:G&&C,[`${z}-has-success`]:G==="success",[`${z}-has-warning`]:G==="warning",[`${z}-has-error`]:G==="error",[`${z}-is-validating`]:G==="validating",[`${z}-hidden`]:w,[`${z}-${A}`]:A});return reactExports.createElement("div",{className:te,style:f,ref:U},reactExports.createElement(Row,Object.assign({className:`${z}-row`},omit(P,["_internalItemRender","colon","dependencies","extra","fieldKey","getValueFromEvent","getValueProps","htmlFor","id","initialValue","isListField","label","labelAlign","labelCol","labelWrap","messageVariables","name","normalize","noStyle","preserve","requiredMark","rules","shouldUpdate","trigger","tooltip","validateFirst","validateTrigger","valuePropName","wrapperCol","validateDebounce"])),reactExports.createElement(FormItemLabel,Object.assign({htmlFor:_},a,{requiredMark:B,required:M??I,prefixCls:c,vertical:L})),reactExports.createElement(FormItemInput,Object.assign({},a,E,{errors:q,warnings:F,prefixCls:c,status:G,help:m,marginBottom:Y,onErrorVisibleChanged:J}),reactExports.createElement(NoStyleItemContext.Provider,{value:N},reactExports.createElement(StatusProvider,{prefixCls:c,meta:E,errors:E.errors,warnings:E.warnings,hasFeedback:C,validateStatus:G},R)))),!!Y&&reactExports.createElement("div",{className:`${z}-margin-offset`,style:{marginBottom:-Y}}))}const NAME_SPLIT="__SPLIT__";function isSimilarControl(a,c){const u=Object.keys(a),d=Object.keys(c);return u.length===d.length&&u.every(f=>{const m=a[f],g=c[f];return m===g||typeof m=="function"||typeof g=="function"})}const MemoInput=reactExports.memo(a=>{let{children:c}=a;return c},(a,c)=>isSimilarControl(a.control,c.control)&&a.update===c.update&&a.childProps.length===c.childProps.length&&a.childProps.every((u,d)=>u===c.childProps[d]));function genEmptyMeta(){return{errors:[],warnings:[],touched:!1,validating:!1,name:[],validated:!1}}function InternalFormItem(a){const{name:c,noStyle:u,className:d,dependencies:f,prefixCls:m,shouldUpdate:g,rules:y,children:b,required:E,label:C,messageVariables:w,trigger:R="onChange",validateTrigger:_,hidden:M,help:I,layout:N}=a,{getPrefixCls:A}=reactExports.useContext(ConfigContext),{name:P}=reactExports.useContext(FormContext),z=useChildren(b),B=typeof z=="function",j=reactExports.useContext(NoStyleItemContext),{validateTrigger:L}=reactExports.useContext(Context),U=_!==void 0?_:L,q=c!=null,F=A("form",m),K=useCSSVarCls(F),[X,Q,Y]=useStyle$a(F,K);devUseWarning();const Z=reactExports.useContext(ListContext),J=reactExports.useRef(null),[W,G]=useFrameState({}),[te,ae]=useSafeState(()=>genEmptyMeta()),V=me=>{const de=Z==null?void 0:Z.getKey(me.name);if(ae(me.destroy?genEmptyMeta():me,!0),u&&I!==!1&&j){let ge=me.name;if(me.destroy)ge=J.current||ge;else if(de!==void 0){const[Ce,ve]=de;ge=[Ce].concat(_toConsumableArray(ve)),J.current=ge}j(me,ge)}},ne=(me,de)=>{G(ge=>{const Ce=Object.assign({},ge),fe=[].concat(_toConsumableArray(me.name.slice(0,-1)),_toConsumableArray(de)).join(NAME_SPLIT);return me.destroy?delete Ce[fe]:Ce[fe]=me,Ce})},[le,ee]=reactExports.useMemo(()=>{const me=_toConsumableArray(te.errors),de=_toConsumableArray(te.warnings);return Object.values(W).forEach(ge=>{me.push.apply(me,_toConsumableArray(ge.errors||[])),de.push.apply(de,_toConsumableArray(ge.warnings||[]))}),[me,de]},[W,te.errors,te.warnings]),ie=useItemRef();function ce(me,de,ge){return u&&!M?reactExports.createElement(StatusProvider,{prefixCls:F,hasFeedback:a.hasFeedback,validateStatus:a.validateStatus,meta:te,errors:le,warnings:ee,noStyle:!0},me):reactExports.createElement(ItemHolder,Object.assign({key:"row"},a,{className:classNames(d,Y,K,Q),prefixCls:F,fieldId:de,isRequired:ge,errors:le,warnings:ee,meta:te,onSubItemMetaChange:ne,layout:N}),me)}if(!q&&!B&&!f)return X(ce(z));let ue={};return typeof C=="string"?ue.label=C:c&&(ue.label=String(c)),w&&(ue=Object.assign(Object.assign({},ue),w)),X(reactExports.createElement(WrapperField,Object.assign({},a,{messageVariables:ue,trigger:R,validateTrigger:U,onMetaChange:V}),(me,de,ge)=>{const Ce=toArray$2(c).length&&de?de.name:[],ve=getFieldId(Ce,P),fe=E!==void 0?E:!!(y!=null&&y.some(ye=>{if(ye&&typeof ye=="object"&&ye.required&&!ye.warningOnly)return!0;if(typeof ye=="function"){const he=ye(ge);return(he==null?void 0:he.required)&&!(he!=null&&he.warningOnly)}return!1})),pe=Object.assign({},me);let xe=null;if(Array.isArray(z)&&q)xe=z;else if(!(B&&(!(g||f)||q))){if(!(f&&!B&&!q))if(reactExports.isValidElement(z)){const ye=Object.assign(Object.assign({},z.props),pe);if(ye.id||(ye.id=ve),I||le.length>0||ee.length>0||a.extra){const Re=[];(I||le.length>0)&&Re.push(`${ve}_help`),a.extra&&Re.push(`${ve}_extra`),ye["aria-describedby"]=Re.join(" ")}le.length>0&&(ye["aria-invalid"]="true"),fe&&(ye["aria-required"]="true"),supportRef(z)&&(ye.ref=ie(Ce,z)),new Set([].concat(_toConsumableArray(toArray$2(R)),_toConsumableArray(toArray$2(U)))).forEach(Re=>{ye[Re]=function(){for(var De,Ae,Ee,Ne,_e,ke=arguments.length,Ke=new Array(ke),be=0;be<ke;be++)Ke[be]=arguments[be];(Ee=pe[Re])===null||Ee===void 0||(De=Ee).call.apply(De,[pe].concat(Ke)),(_e=(Ne=z.props)[Re])===null||_e===void 0||(Ae=_e).call.apply(Ae,[Ne].concat(Ke))}});const we=[ye["aria-required"],ye["aria-invalid"],ye["aria-describedby"]];xe=reactExports.createElement(MemoInput,{control:pe,update:z,childProps:we},cloneElement(z,ye))}else B&&(g||f)&&!q?xe=z(ge):xe=z}return ce(xe,ve,fe)}))}const FormItem=InternalFormItem;FormItem.useStatus=useFormItemStatus;var __rest$l=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const FormList=a=>{var{prefixCls:c,children:u}=a,d=__rest$l(a,["prefixCls","children"]);const{getPrefixCls:f}=reactExports.useContext(ConfigContext),m=f("form",c),g=reactExports.useMemo(()=>({prefixCls:m,status:"error"}),[m]);return reactExports.createElement(List$1,Object.assign({},d),(y,b,E)=>reactExports.createElement(FormItemPrefixContext.Provider,{value:g},u(y.map(C=>Object.assign(Object.assign({},C),{fieldKey:C.key})),b,{errors:E.errors,warnings:E.warnings})))};function useFormInstance(){const{form:a}=reactExports.useContext(FormContext);return a}const Form$1=Form$2;Form$1.Item=FormItem;Form$1.List=FormList;Form$1.ErrorList=ErrorList;Form$1.useForm=useForm;Form$1.useFormInstance=useFormInstance;Form$1.useWatch=useWatch$1;Form$1.Provider=FormProvider;Form$1.create=()=>{};function getClientSize(){var a=document.documentElement.clientWidth,c=window.innerHeight||document.documentElement.clientHeight;return{width:a,height:c}}function getOffset$1(a){var c=a.getBoundingClientRect(),u=document.documentElement;return{left:c.left+(window.pageXOffset||u.scrollLeft)-(u.clientLeft||document.body.clientLeft||0),top:c.top+(window.pageYOffset||u.scrollTop)-(u.clientTop||document.body.clientTop||0)}}function addEventListenerWrap(a,c,u,d){var f=ReactDOM.unstable_batchedUpdates?function(g){ReactDOM.unstable_batchedUpdates(u,g)}:u;return a!=null&&a.addEventListener&&a.addEventListener(c,f,d),{remove:function(){a!=null&&a.removeEventListener&&a.removeEventListener(c,f,d)}}}var PreviewGroupContext=reactExports.createContext(null),Operations=function(c){var u=c.visible,d=c.maskTransitionName,f=c.getContainer,m=c.prefixCls,g=c.rootClassName,y=c.icons,b=c.countRender,E=c.showSwitch,C=c.showProgress,w=c.current,R=c.transform,_=c.count,M=c.scale,I=c.minScale,N=c.maxScale,A=c.closeIcon,P=c.onActive,z=c.onClose,B=c.onZoomIn,j=c.onZoomOut,L=c.onRotateRight,U=c.onRotateLeft,q=c.onFlipX,F=c.onFlipY,K=c.onReset,X=c.toolbarRender,Q=c.zIndex,Y=c.image,Z=reactExports.useContext(PreviewGroupContext),J=y.rotateLeft,W=y.rotateRight,G=y.zoomIn,te=y.zoomOut,ae=y.close,V=y.left,ne=y.right,le=y.flipX,ee=y.flipY,ie="".concat(m,"-operations-operation");reactExports.useEffect(function(){var he=function(Re){Re.keyCode===KeyCode.ESC&&z()};return u&&window.addEventListener("keydown",he),function(){window.removeEventListener("keydown",he)}},[u]);var ce=function(we,Re){we.preventDefault(),we.stopPropagation(),P(Re)},ue=reactExports.useCallback(function(he){var we=he.type,Re=he.disabled,De=he.onClick,Ae=he.icon;return reactExports.createElement("div",{key:we,className:classNames(ie,"".concat(m,"-operations-operation-").concat(we),_defineProperty({},"".concat(m,"-operations-operation-disabled"),!!Re)),onClick:De},Ae)},[ie,m]),me=E?ue({icon:V,onClick:function(we){return ce(we,-1)},type:"prev",disabled:w===0}):void 0,de=E?ue({icon:ne,onClick:function(we){return ce(we,1)},type:"next",disabled:w===_-1}):void 0,ge=ue({icon:ee,onClick:F,type:"flipY"}),Ce=ue({icon:le,onClick:q,type:"flipX"}),ve=ue({icon:J,onClick:U,type:"rotateLeft"}),fe=ue({icon:W,onClick:L,type:"rotateRight"}),pe=ue({icon:te,onClick:j,type:"zoomOut",disabled:M<=I}),xe=ue({icon:G,onClick:B,type:"zoomIn",disabled:M===N}),ye=reactExports.createElement("div",{className:"".concat(m,"-operations")},ge,Ce,ve,fe,pe,xe);return reactExports.createElement(CSSMotion,{visible:u,motionName:d},function(he){var we=he.className,Re=he.style;return reactExports.createElement(Portal,{open:!0,getContainer:f??document.body},reactExports.createElement("div",{className:classNames("".concat(m,"-operations-wrapper"),we,g),style:_objectSpread2(_objectSpread2({},Re),{},{zIndex:Q})},A===null?null:reactExports.createElement("button",{className:"".concat(m,"-close"),onClick:z},A||ae),E&&reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("div",{className:classNames("".concat(m,"-switch-left"),_defineProperty({},"".concat(m,"-switch-left-disabled"),w===0)),onClick:function(Ae){return ce(Ae,-1)}},V),reactExports.createElement("div",{className:classNames("".concat(m,"-switch-right"),_defineProperty({},"".concat(m,"-switch-right-disabled"),w===_-1)),onClick:function(Ae){return ce(Ae,1)}},ne)),reactExports.createElement("div",{className:"".concat(m,"-footer")},C&&reactExports.createElement("div",{className:"".concat(m,"-progress")},b?b(w+1,_):"".concat(w+1," / ").concat(_)),X?X(ye,_objectSpread2(_objectSpread2({icons:{prevIcon:me,nextIcon:de,flipYIcon:ge,flipXIcon:Ce,rotateLeftIcon:ve,rotateRightIcon:fe,zoomOutIcon:pe,zoomInIcon:xe},actions:{onActive:P,onFlipY:F,onFlipX:q,onRotateLeft:U,onRotateRight:L,onZoomOut:j,onZoomIn:B,onReset:K,onClose:z},transform:R},Z?{current:w,total:_}:{}),{},{image:Y})):ye)))})},initialTransform={x:0,y:0,rotate:0,scale:1,flipX:!1,flipY:!1};function useImageTransform(a,c,u,d){var f=reactExports.useRef(null),m=reactExports.useRef([]),g=reactExports.useState(initialTransform),y=_slicedToArray(g,2),b=y[0],E=y[1],C=function(M){E(initialTransform),isEqual(initialTransform,b)||d==null||d({transform:initialTransform,action:M})},w=function(M,I){f.current===null&&(m.current=[],f.current=wrapperRaf(function(){E(function(N){var A=N;return m.current.forEach(function(P){A=_objectSpread2(_objectSpread2({},A),P)}),f.current=null,d==null||d({transform:A,action:I}),A})})),m.current.push(_objectSpread2(_objectSpread2({},b),M))},R=function(M,I,N,A,P){var z=a.current,B=z.width,j=z.height,L=z.offsetWidth,U=z.offsetHeight,q=z.offsetLeft,F=z.offsetTop,K=M,X=b.scale*M;X>u?(X=u,K=u/b.scale):X<c&&(X=P?X:c,K=X/b.scale);var Q=N??innerWidth/2,Y=A??innerHeight/2,Z=K-1,J=Z*B*.5,W=Z*j*.5,G=Z*(Q-b.x-q),te=Z*(Y-b.y-F),ae=b.x-(G-J),V=b.y-(te-W);if(M<1&&X===1){var ne=L*X,le=U*X,ee=getClientSize(),ie=ee.width,ce=ee.height;ne<=ie&&le<=ce&&(ae=0,V=0)}w({x:ae,y:V,scale:X},I)};return{transform:b,resetTransform:C,updateTransform:w,dispatchZoomChange:R}}function fixPoint(a,c,u,d){var f=c+u,m=(u-d)/2;if(u>d){if(c>0)return _defineProperty({},a,m);if(c<0&&f<d)return _defineProperty({},a,-m)}else if(c<0||f>d)return _defineProperty({},a,c<0?m:-m);return{}}function getFixScaleEleTransPosition(a,c,u,d){var f=getClientSize(),m=f.width,g=f.height,y=null;return a<=m&&c<=g?y={x:0,y:0}:(a>m||c>g)&&(y=_objectSpread2(_objectSpread2({},fixPoint("x",u,a,m)),fixPoint("y",d,c,g))),y}var BASE_SCALE_RATIO=1,WHEEL_MAX_SCALE_RATIO=1;function useMouseEvent(a,c,u,d,f,m,g){var y=f.rotate,b=f.scale,E=f.x,C=f.y,w=reactExports.useState(!1),R=_slicedToArray(w,2),_=R[0],M=R[1],I=reactExports.useRef({diffX:0,diffY:0,transformX:0,transformY:0}),N=function(j){!c||j.button!==0||(j.preventDefault(),j.stopPropagation(),I.current={diffX:j.pageX-E,diffY:j.pageY-C,transformX:E,transformY:C},M(!0))},A=function(j){u&&_&&m({x:j.pageX-I.current.diffX,y:j.pageY-I.current.diffY},"move")},P=function(){if(u&&_){M(!1);var j=I.current,L=j.transformX,U=j.transformY,q=E!==L&&C!==U;if(!q)return;var F=a.current.offsetWidth*b,K=a.current.offsetHeight*b,X=a.current.getBoundingClientRect(),Q=X.left,Y=X.top,Z=y%180!==0,J=getFixScaleEleTransPosition(Z?K:F,Z?F:K,Q,Y);J&&m(_objectSpread2({},J),"dragRebound")}},z=function(j){if(!(!u||j.deltaY==0)){var L=Math.abs(j.deltaY/100),U=Math.min(L,WHEEL_MAX_SCALE_RATIO),q=BASE_SCALE_RATIO+U*d;j.deltaY>0&&(q=BASE_SCALE_RATIO/q),g(q,"wheel",j.clientX,j.clientY)}};return reactExports.useEffect(function(){var B,j,L,U;if(c){L=addEventListenerWrap(window,"mouseup",P,!1),U=addEventListenerWrap(window,"mousemove",A,!1);try{window.top!==window.self&&(B=addEventListenerWrap(window.top,"mouseup",P,!1),j=addEventListenerWrap(window.top,"mousemove",A,!1))}catch{}}return function(){var q,F,K,X;(q=L)===null||q===void 0||q.remove(),(F=U)===null||F===void 0||F.remove(),(K=B)===null||K===void 0||K.remove(),(X=j)===null||X===void 0||X.remove()}},[u,_,E,C,y,c]),{isMoving:_,onMouseDown:N,onMouseMove:A,onMouseUp:P,onWheel:z}}function isImageValid(a){return new Promise(function(c){if(!a){c(!1);return}var u=document.createElement("img");u.onerror=function(){return c(!1)},u.onload=function(){return c(!0)},u.src=a})}function useStatus(a){var c=a.src,u=a.isCustomPlaceholder,d=a.fallback,f=reactExports.useState(u?"loading":"normal"),m=_slicedToArray(f,2),g=m[0],y=m[1],b=reactExports.useRef(!1),E=g==="error";reactExports.useEffect(function(){var _=!0;return isImageValid(c).then(function(M){!M&&_&&y("error")}),function(){_=!1}},[c]),reactExports.useEffect(function(){u&&!b.current?y("loading"):E&&y("normal")},[c]);var C=function(){y("normal")},w=function(M){b.current=!1,g==="loading"&&M!==null&&M!==void 0&&M.complete&&(M.naturalWidth||M.naturalHeight)&&(b.current=!0,C())},R=E&&d?{src:d}:{onLoad:C,src:c};return[w,R,g]}function getDistance(a,c){var u=a.x-c.x,d=a.y-c.y;return Math.hypot(u,d)}function getCenter(a,c,u,d){var f=getDistance(a,u),m=getDistance(c,d);if(f===0&&m===0)return[a.x,a.y];var g=f/(f+m),y=a.x+g*(c.x-a.x),b=a.y+g*(c.y-a.y);return[y,b]}function useTouchEvent(a,c,u,d,f,m,g){var y=f.rotate,b=f.scale,E=f.x,C=f.y,w=reactExports.useState(!1),R=_slicedToArray(w,2),_=R[0],M=R[1],I=reactExports.useRef({point1:{x:0,y:0},point2:{x:0,y:0},eventType:"none"}),N=function(j){I.current=_objectSpread2(_objectSpread2({},I.current),j)},A=function(j){if(c){j.stopPropagation(),M(!0);var L=j.touches,U=L===void 0?[]:L;U.length>1?N({point1:{x:U[0].clientX,y:U[0].clientY},point2:{x:U[1].clientX,y:U[1].clientY},eventType:"touchZoom"}):N({point1:{x:U[0].clientX-E,y:U[0].clientY-C},eventType:"move"})}},P=function(j){var L=j.touches,U=L===void 0?[]:L,q=I.current,F=q.point1,K=q.point2,X=q.eventType;if(U.length>1&&X==="touchZoom"){var Q={x:U[0].clientX,y:U[0].clientY},Y={x:U[1].clientX,y:U[1].clientY},Z=getCenter(F,K,Q,Y),J=_slicedToArray(Z,2),W=J[0],G=J[1],te=getDistance(Q,Y)/getDistance(F,K);g(te,"touchZoom",W,G,!0),N({point1:Q,point2:Y,eventType:"touchZoom"})}else X==="move"&&(m({x:U[0].clientX-F.x,y:U[0].clientY-F.y},"move"),N({eventType:"move"}))},z=function(){if(u){if(_&&M(!1),N({eventType:"none"}),d>b)return m({x:0,y:0,scale:d},"touchZoom");var j=a.current.offsetWidth*b,L=a.current.offsetHeight*b,U=a.current.getBoundingClientRect(),q=U.left,F=U.top,K=y%180!==0,X=getFixScaleEleTransPosition(K?L:j,K?j:L,q,F);X&&m(_objectSpread2({},X),"dragRebound")}};return reactExports.useEffect(function(){var B;return u&&c&&(B=addEventListenerWrap(window,"touchmove",function(j){return j.preventDefault()},{passive:!1})),function(){var j;(j=B)===null||j===void 0||j.remove()}},[u,c]),{isTouching:_,onTouchStart:A,onTouchMove:P,onTouchEnd:z}}var _excluded$d=["fallback","src","imgRef"],_excluded2$3=["prefixCls","src","alt","imageInfo","fallback","movable","onClose","visible","icons","rootClassName","closeIcon","getContainer","current","count","countRender","scaleStep","minScale","maxScale","transitionName","maskTransitionName","imageRender","imgCommonProps","toolbarRender","onTransform","onChange"],PreviewImage=function(c){var u=c.fallback,d=c.src,f=c.imgRef,m=_objectWithoutProperties(c,_excluded$d),g=useStatus({src:d,fallback:u}),y=_slicedToArray(g,2),b=y[0],E=y[1];return React.createElement("img",_extends({ref:function(w){f.current=w,b(w)}},m,E))},Preview=function(c){var u=c.prefixCls,d=c.src,f=c.alt,m=c.imageInfo,g=c.fallback,y=c.movable,b=y===void 0?!0:y,E=c.onClose,C=c.visible,w=c.icons,R=w===void 0?{}:w,_=c.rootClassName,M=c.closeIcon,I=c.getContainer,N=c.current,A=N===void 0?0:N,P=c.count,z=P===void 0?1:P,B=c.countRender,j=c.scaleStep,L=j===void 0?.5:j,U=c.minScale,q=U===void 0?1:U,F=c.maxScale,K=F===void 0?50:F,X=c.transitionName,Q=X===void 0?"zoom":X,Y=c.maskTransitionName,Z=Y===void 0?"fade":Y,J=c.imageRender,W=c.imgCommonProps,G=c.toolbarRender,te=c.onTransform,ae=c.onChange,V=_objectWithoutProperties(c,_excluded2$3),ne=reactExports.useRef(),le=reactExports.useContext(PreviewGroupContext),ee=le&&z>1,ie=le&&z>=1,ce=reactExports.useState(!0),ue=_slicedToArray(ce,2),me=ue[0],de=ue[1],ge=useImageTransform(ne,q,K,te),Ce=ge.transform,ve=ge.resetTransform,fe=ge.updateTransform,pe=ge.dispatchZoomChange,xe=useMouseEvent(ne,b,C,L,Ce,fe,pe),ye=xe.isMoving,he=xe.onMouseDown,we=xe.onWheel,Re=useTouchEvent(ne,b,C,q,Ce,fe,pe),De=Re.isTouching,Ae=Re.onTouchStart,Ee=Re.onTouchMove,Ne=Re.onTouchEnd,_e=Ce.rotate,ke=Ce.scale,Ke=classNames(_defineProperty({},"".concat(u,"-moving"),ye));reactExports.useEffect(function(){me||de(!0)},[me]);var be=function(){ve("close")},Te=function(){pe(BASE_SCALE_RATIO+L,"zoomIn")},Le=function(){pe(BASE_SCALE_RATIO/(BASE_SCALE_RATIO+L),"zoomOut")},Oe=function(){fe({rotate:_e+90},"rotateRight")},Be=function(){fe({rotate:_e-90},"rotateLeft")},Ve=function(){fe({flipX:!Ce.flipX},"flipX")},Pe=function(){fe({flipY:!Ce.flipY},"flipY")},Ge=function(){ve("reset")},qe=function(kt){var Ut=A+kt;!Number.isInteger(Ut)||Ut<0||Ut>z-1||(de(!1),ve(kt<0?"prev":"next"),ae==null||ae(Ut,A))},Ue=function(kt){!C||!ee||(kt.keyCode===KeyCode.LEFT?qe(-1):kt.keyCode===KeyCode.RIGHT&&qe(1))},je=function(kt){C&&(ke!==1?fe({x:0,y:0,scale:1},"doubleClick"):pe(BASE_SCALE_RATIO+L,"doubleClick",kt.clientX,kt.clientY))};reactExports.useEffect(function(){var gt=addEventListenerWrap(window,"keydown",Ue,!1);return function(){gt.remove()}},[C,ee,A]);var We=React.createElement(PreviewImage,_extends({},W,{width:c.width,height:c.height,imgRef:ne,className:"".concat(u,"-img"),alt:f,style:{transform:"translate3d(".concat(Ce.x,"px, ").concat(Ce.y,"px, 0) scale3d(").concat(Ce.flipX?"-":"").concat(ke,", ").concat(Ce.flipY?"-":"").concat(ke,", 1) rotate(").concat(_e,"deg)"),transitionDuration:(!me||De)&&"0s"},fallback:g,src:d,onWheel:we,onMouseDown:he,onDoubleClick:je,onTouchStart:Ae,onTouchMove:Ee,onTouchEnd:Ne,onTouchCancel:Ne})),ut=_objectSpread2({url:d,alt:f},m);return React.createElement(React.Fragment,null,React.createElement(DialogWrap,_extends({transitionName:Q,maskTransitionName:Z,closable:!1,keyboard:!0,prefixCls:u,onClose:E,visible:C,classNames:{wrapper:Ke},rootClassName:_,getContainer:I},V,{afterClose:be}),React.createElement("div",{className:"".concat(u,"-img-wrapper")},J?J(We,_objectSpread2({transform:Ce,image:ut},le?{current:A}:{})):We)),React.createElement(Operations,{visible:C,transform:Ce,maskTransitionName:Z,closeIcon:M,getContainer:I,prefixCls:u,rootClassName:_,icons:R,countRender:B,showSwitch:ee,showProgress:ie,current:A,count:z,scale:ke,minScale:q,maxScale:K,toolbarRender:G,onActive:qe,onZoomIn:Te,onZoomOut:Le,onRotateRight:Oe,onRotateLeft:Be,onFlipX:Ve,onFlipY:Pe,onClose:E,onReset:Ge,zIndex:V.zIndex!==void 0?V.zIndex+1:void 0,image:ut}))},COMMON_PROPS=["crossOrigin","decoding","draggable","loading","referrerPolicy","sizes","srcSet","useMap","alt"];function usePreviewItems(a){var c=reactExports.useState({}),u=_slicedToArray(c,2),d=u[0],f=u[1],m=reactExports.useCallback(function(y,b){return f(function(E){return _objectSpread2(_objectSpread2({},E),{},_defineProperty({},y,b))}),function(){f(function(E){var C=_objectSpread2({},E);return delete C[y],C})}},[]),g=reactExports.useMemo(function(){return a?a.map(function(y){if(typeof y=="string")return{data:{src:y}};var b={};return Object.keys(y).forEach(function(E){["src"].concat(_toConsumableArray(COMMON_PROPS)).includes(E)&&(b[E]=y[E])}),{data:b}}):Object.keys(d).reduce(function(y,b){var E=d[b],C=E.canPreview,w=E.data;return C&&y.push({data:w,id:b}),y},[])},[a,d]);return[g,m,!!a]}var _excluded$c=["visible","onVisibleChange","getContainer","current","movable","minScale","maxScale","countRender","closeIcon","onChange","onTransform","toolbarRender","imageRender"],_excluded2$2=["src"],Group$1=function(c){var u,d=c.previewPrefixCls,f=d===void 0?"rc-image-preview":d,m=c.children,g=c.icons,y=g===void 0?{}:g,b=c.items,E=c.preview,C=c.fallback,w=_typeof(E)==="object"?E:{},R=w.visible,_=w.onVisibleChange,M=w.getContainer,I=w.current,N=w.movable,A=w.minScale,P=w.maxScale,z=w.countRender,B=w.closeIcon,j=w.onChange,L=w.onTransform,U=w.toolbarRender,q=w.imageRender,F=_objectWithoutProperties(w,_excluded$c),K=usePreviewItems(b),X=_slicedToArray(K,3),Q=X[0],Y=X[1],Z=X[2],J=useMergedState(0,{value:I}),W=_slicedToArray(J,2),G=W[0],te=W[1],ae=reactExports.useState(!1),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=((u=Q[G])===null||u===void 0?void 0:u.data)||{},ie=ee.src,ce=_objectWithoutProperties(ee,_excluded2$2),ue=useMergedState(!!R,{value:R,onChange:function(De,Ae){_==null||_(De,Ae,G)}}),me=_slicedToArray(ue,2),de=me[0],ge=me[1],Ce=reactExports.useState(null),ve=_slicedToArray(Ce,2),fe=ve[0],pe=ve[1],xe=reactExports.useCallback(function(Re,De,Ae,Ee){var Ne=Z?Q.findIndex(function(_e){return _e.data.src===De}):Q.findIndex(function(_e){return _e.id===Re});te(Ne<0?0:Ne),ge(!0),pe({x:Ae,y:Ee}),le(!0)},[Q,Z]);reactExports.useEffect(function(){de?ne||te(0):le(!1)},[de]);var ye=function(De,Ae){te(De),j==null||j(De,Ae)},he=function(){ge(!1),pe(null)},we=reactExports.useMemo(function(){return{register:Y,onPreview:xe}},[Y,xe]);return reactExports.createElement(PreviewGroupContext.Provider,{value:we},m,reactExports.createElement(Preview,_extends({"aria-hidden":!de,movable:N,visible:de,prefixCls:f,closeIcon:B,onClose:he,mousePosition:fe,imgCommonProps:ce,src:ie,fallback:C,icons:y,minScale:A,maxScale:P,getContainer:M,current:G,count:Q.length,countRender:z,onTransform:L,toolbarRender:U,imageRender:q,onChange:ye},F)))},uid=0;function useRegisterImage(a,c){var u=reactExports.useState(function(){return uid+=1,String(uid)}),d=_slicedToArray(u,1),f=d[0],m=reactExports.useContext(PreviewGroupContext),g={data:c,canPreview:a};return reactExports.useEffect(function(){if(m)return m.register(f,g)},[]),reactExports.useEffect(function(){m&&m.register(f,g)},[a,c]),f}var _excluded$b=["src","alt","onPreviewClose","prefixCls","previewPrefixCls","placeholder","fallback","width","height","style","preview","className","onClick","onError","wrapperClassName","wrapperStyle","rootClassName"],_excluded2$1=["src","visible","onVisibleChange","getContainer","mask","maskClassName","movable","icons","scaleStep","minScale","maxScale","imageRender","toolbarRender"],ImageInternal=function(c){var u=c.src,d=c.alt,f=c.onPreviewClose,m=c.prefixCls,g=m===void 0?"rc-image":m,y=c.previewPrefixCls,b=y===void 0?"".concat(g,"-preview"):y,E=c.placeholder,C=c.fallback,w=c.width,R=c.height,_=c.style,M=c.preview,I=M===void 0?!0:M,N=c.className,A=c.onClick,P=c.onError,z=c.wrapperClassName,B=c.wrapperStyle,j=c.rootClassName,L=_objectWithoutProperties(c,_excluded$b),U=E&&E!==!0,q=_typeof(I)==="object"?I:{},F=q.src,K=q.visible,X=K===void 0?void 0:K,Q=q.onVisibleChange,Y=Q===void 0?f:Q,Z=q.getContainer,J=Z===void 0?void 0:Z,W=q.mask,G=q.maskClassName,te=q.movable,ae=q.icons,V=q.scaleStep,ne=q.minScale,le=q.maxScale,ee=q.imageRender,ie=q.toolbarRender,ce=_objectWithoutProperties(q,_excluded2$1),ue=F??u,me=useMergedState(!!X,{value:X,onChange:Y}),de=_slicedToArray(me,2),ge=de[0],Ce=de[1],ve=useStatus({src:u,isCustomPlaceholder:U,fallback:C}),fe=_slicedToArray(ve,3),pe=fe[0],xe=fe[1],ye=fe[2],he=reactExports.useState(null),we=_slicedToArray(he,2),Re=we[0],De=we[1],Ae=reactExports.useContext(PreviewGroupContext),Ee=!!I,Ne=function(){Ce(!1),De(null)},_e=classNames(g,z,j,_defineProperty({},"".concat(g,"-error"),ye==="error")),ke=reactExports.useMemo(function(){var Le={};return COMMON_PROPS.forEach(function(Oe){c[Oe]!==void 0&&(Le[Oe]=c[Oe])}),Le},COMMON_PROPS.map(function(Le){return c[Le]})),Ke=reactExports.useMemo(function(){return _objectSpread2(_objectSpread2({},ke),{},{src:ue})},[ue,ke]),be=useRegisterImage(Ee,Ke),Te=function(Oe){var Be=getOffset$1(Oe.target),Ve=Be.left,Pe=Be.top;Ae?Ae.onPreview(be,ue,Ve,Pe):(De({x:Ve,y:Pe}),Ce(!0)),A==null||A(Oe)};return reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("div",_extends({},L,{className:_e,onClick:Ee?Te:A,style:_objectSpread2({width:w,height:R},B)}),reactExports.createElement("img",_extends({},ke,{className:classNames("".concat(g,"-img"),_defineProperty({},"".concat(g,"-img-placeholder"),E===!0),N),style:_objectSpread2({height:R},_),ref:pe},xe,{width:w,height:R,onError:P})),ye==="loading"&&reactExports.createElement("div",{"aria-hidden":"true",className:"".concat(g,"-placeholder")},E),W&&Ee&&reactExports.createElement("div",{className:classNames("".concat(g,"-mask"),G),style:{display:(_==null?void 0:_.display)==="none"?"none":void 0}},W)),!Ae&&Ee&&reactExports.createElement(Preview,_extends({"aria-hidden":!ge,visible:ge,prefixCls:b,onClose:Ne,mousePosition:Re,src:ue,alt:d,imageInfo:{width:w,height:R},fallback:C,getContainer:J,icons:ae,movable:te,scaleStep:V,minScale:ne,maxScale:le,rootClassName:j,imageRender:ee,imgCommonProps:ke,toolbarRender:ie},ce)))};ImageInternal.PreviewGroup=Group$1;const genBoxStyle=a=>({position:a||"absolute",inset:0}),genImageMaskStyle=a=>{const{iconCls:c,motionDurationSlow:u,paddingXXS:d,marginXXS:f,prefixCls:m,colorTextLightSolid:g}=a;return{position:"absolute",inset:0,display:"flex",alignItems:"center",justifyContent:"center",color:g,background:new FastColor("#000").setA(.5).toRgbString(),cursor:"pointer",opacity:0,transition:`opacity ${u}`,[`.${m}-mask-info`]:Object.assign(Object.assign({},textEllipsis),{padding:`0 ${unit$1(d)}`,[c]:{marginInlineEnd:f,svg:{verticalAlign:"baseline"}}})}},genPreviewOperationsStyle=a=>{const{previewCls:c,modalMaskBg:u,paddingSM:d,marginXL:f,margin:m,paddingLG:g,previewOperationColorDisabled:y,previewOperationHoverColor:b,motionDurationSlow:E,iconCls:C,colorTextLightSolid:w}=a,R=new FastColor(u).setA(.1),_=R.clone().setA(.2);return{[`${c}-footer`]:{position:"fixed",bottom:f,left:{_skip_check_:!0,value:"50%"},display:"flex",flexDirection:"column",alignItems:"center",color:a.previewOperationColor,transform:"translateX(-50%)"},[`${c}-progress`]:{marginBottom:m},[`${c}-close`]:{position:"fixed",top:f,right:{_skip_check_:!0,value:f},display:"flex",color:w,backgroundColor:R.toRgbString(),borderRadius:"50%",padding:d,outline:0,border:0,cursor:"pointer",transition:`all ${E}`,"&:hover":{backgroundColor:_.toRgbString()},[`& > ${C}`]:{fontSize:a.previewOperationSize}},[`${c}-operations`]:{display:"flex",alignItems:"center",padding:`0 ${unit$1(g)}`,backgroundColor:R.toRgbString(),borderRadius:100,"&-operation":{marginInlineStart:d,padding:d,cursor:"pointer",transition:`all ${E}`,userSelect:"none",[`&:not(${c}-operations-operation-disabled):hover > ${C}`]:{color:b},"&-disabled":{color:y,cursor:"not-allowed"},"&:first-of-type":{marginInlineStart:0},[`& > ${C}`]:{fontSize:a.previewOperationSize}}}}},genPreviewSwitchStyle=a=>{const{modalMaskBg:c,iconCls:u,previewOperationColorDisabled:d,previewCls:f,zIndexPopup:m,motionDurationSlow:g}=a,y=new FastColor(c).setA(.1),b=y.clone().setA(.2);return{[`${f}-switch-left, ${f}-switch-right`]:{position:"fixed",insetBlockStart:"50%",zIndex:a.calc(m).add(1).equal(),display:"flex",alignItems:"center",justifyContent:"center",width:a.imagePreviewSwitchSize,height:a.imagePreviewSwitchSize,marginTop:a.calc(a.imagePreviewSwitchSize).mul(-1).div(2).equal(),color:a.previewOperationColor,background:y.toRgbString(),borderRadius:"50%",transform:"translateY(-50%)",cursor:"pointer",transition:`all ${g}`,userSelect:"none","&:hover":{background:b.toRgbString()},"&-disabled":{"&, &:hover":{color:d,background:"transparent",cursor:"not-allowed",[`> ${u}`]:{cursor:"not-allowed"}}},[`> ${u}`]:{fontSize:a.previewOperationSize}},[`${f}-switch-left`]:{insetInlineStart:a.marginSM},[`${f}-switch-right`]:{insetInlineEnd:a.marginSM}}},genImagePreviewStyle=a=>{const{motionEaseOut:c,previewCls:u,motionDurationSlow:d,componentCls:f}=a;return[{[`${f}-preview-root`]:{[u]:{height:"100%",textAlign:"center",pointerEvents:"none"},[`${u}-body`]:Object.assign(Object.assign({},genBoxStyle()),{overflow:"hidden"}),[`${u}-img`]:{maxWidth:"100%",maxHeight:"70%",verticalAlign:"middle",transform:"scale3d(1, 1, 1)",cursor:"grab",transition:`transform ${d} ${c} 0s`,userSelect:"none","&-wrapper":Object.assign(Object.assign({},genBoxStyle()),{transition:`transform ${d} ${c} 0s`,display:"flex",justifyContent:"center",alignItems:"center","& > *":{pointerEvents:"auto"},"&::before":{display:"inline-block",width:1,height:"50%",marginInlineEnd:-1,content:'""'}})},[`${u}-moving`]:{[`${u}-preview-img`]:{cursor:"grabbing","&-wrapper":{transitionDuration:"0s"}}}}},{[`${f}-preview-root`]:{[`${u}-wrap`]:{zIndex:a.zIndexPopup}}},{[`${f}-preview-operations-wrapper`]:{position:"fixed",zIndex:a.calc(a.zIndexPopup).add(1).equal()},"&":[genPreviewOperationsStyle(a),genPreviewSwitchStyle(a)]}]},genImageStyle=a=>{const{componentCls:c}=a;return{[c]:{position:"relative",display:"inline-block",[`${c}-img`]:{width:"100%",height:"auto",verticalAlign:"middle"},[`${c}-img-placeholder`]:{backgroundColor:a.colorBgContainerDisabled,backgroundImage:"url('data:image/svg+xml;base64,PHN2ZyB3aWR0aD0iMTYiIGhlaWdodD0iMTYiIHZpZXdCb3g9IjAgMCAxNiAxNiIgeG1sbnM9Imh0dHA6Ly93d3cudzMub3JnLzIwMDAvc3ZnIj48cGF0aCBkPSJNMTQuNSAyLjVoLTEzQS41LjUgMCAwIDAgMSAzdjEwYS41LjUgMCAwIDAgLjUuNWgxM2EuNS41IDAgMCAwIC41LS41VjNhLjUuNSAwIDAgMC0uNS0uNXpNNS4yODEgNC43NWExIDEgMCAwIDEgMCAyIDEgMSAwIDAgMSAwLTJ6bTguMDMgNi44M2EuMTI3LjEyNyAwIDAgMS0uMDgxLjAzSDIuNzY5YS4xMjUuMTI1IDAgMCAxLS4wOTYtLjIwN2wyLjY2MS0zLjE1NmEuMTI2LjEyNiAwIDAgMSAuMTc3LS4wMTZsLjAxNi4wMTZMNy4wOCAxMC4wOWwyLjQ3LTIuOTNhLjEyNi4xMjYgMCAwIDEgLjE3Ny0uMDE2bC4wMTUuMDE2IDMuNTg4IDQuMjQ0YS4xMjcuMTI3IDAgMCAxLS4wMi4xNzV6IiBmaWxsPSIjOEM4QzhDIiBmaWxsLXJ1bGU9Im5vbnplcm8iLz48L3N2Zz4=')",backgroundRepeat:"no-repeat",backgroundPosition:"center center",backgroundSize:"30%"},[`${c}-mask`]:Object.assign({},genImageMaskStyle(a)),[`${c}-mask:hover`]:{opacity:1},[`${c}-placeholder`]:Object.assign({},genBoxStyle())}}},genPreviewMotion=a=>{const{previewCls:c}=a;return{[`${c}-root`]:initZoomMotion(a,"zoom"),"&":initFadeMotion(a,!0)}},prepareComponentToken$7=a=>({zIndexPopup:a.zIndexPopupBase+80,previewOperationColor:new FastColor(a.colorTextLightSolid).setA(.65).toRgbString(),previewOperationHoverColor:new FastColor(a.colorTextLightSolid).setA(.85).toRgbString(),previewOperationColorDisabled:new FastColor(a.colorTextLightSolid).setA(.25).toRgbString(),previewOperationSize:a.fontSizeIcon*1.5}),useStyle$9=genStyleHooks("Image",a=>{const c=`${a.componentCls}-preview`,u=merge$2(a,{previewCls:c,modalMaskBg:new FastColor("#000").setA(.45).toRgbString(),imagePreviewSwitchSize:a.controlHeightLG});return[genImageStyle(u),genImagePreviewStyle(u),genModalMaskStyle(merge$2(u,{componentCls:c})),genPreviewMotion(u)]},prepareComponentToken$7);var __rest$k=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const icons={rotateLeft:reactExports.createElement(RefIcon$7,null),rotateRight:reactExports.createElement(RefIcon$6,null),zoomIn:reactExports.createElement(RefIcon$1,null),zoomOut:reactExports.createElement(RefIcon,null),close:reactExports.createElement(RefIcon$x,null),left:reactExports.createElement(RefIcon$f,null),right:reactExports.createElement(RefIcon$8,null),flipX:reactExports.createElement(RefIcon$4,null),flipY:reactExports.createElement(RefIcon$4,{rotate:90})},InternalPreviewGroup=a=>{var{previewPrefixCls:c,preview:u}=a,d=__rest$k(a,["previewPrefixCls","preview"]);const{getPrefixCls:f,direction:m}=reactExports.useContext(ConfigContext),g=f("image",c),y=`${g}-preview`,b=f(),E=useCSSVarCls(g),[C,w,R]=useStyle$9(g,E),[_]=useZIndex("ImagePreview",typeof u=="object"?u.zIndex:void 0),M=reactExports.useMemo(()=>Object.assign(Object.assign({},icons),{left:m==="rtl"?reactExports.createElement(RefIcon$8,null):reactExports.createElement(RefIcon$f,null),right:m==="rtl"?reactExports.createElement(RefIcon$f,null):reactExports.createElement(RefIcon$8,null)}),[m]),I=reactExports.useMemo(()=>{var N;if(u===!1)return u;const A=typeof u=="object"?u:{},P=classNames(w,R,E,(N=A.rootClassName)!==null&&N!==void 0?N:"");return Object.assign(Object.assign({},A),{transitionName:getTransitionName(b,"zoom",A.transitionName),maskTransitionName:getTransitionName(b,"fade",A.maskTransitionName),rootClassName:P,zIndex:_})},[u]);return C(reactExports.createElement(ImageInternal.PreviewGroup,Object.assign({preview:I,previewPrefixCls:y,icons:M},d)))};var __rest$j=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Image=a=>{const{prefixCls:c,preview:u,className:d,rootClassName:f,style:m}=a,g=__rest$j(a,["prefixCls","preview","className","rootClassName","style"]),{getPrefixCls:y,getPopupContainer:b,className:E,style:C,preview:w}=useComponentConfig("image"),[R]=useLocale("Image"),_=y("image",c),M=y(),I=useCSSVarCls(_),[N,A,P]=useStyle$9(_,I),z=classNames(f,A,P,I),B=classNames(d,A,E),[j]=useZIndex("ImagePreview",typeof u=="object"?u.zIndex:void 0),L=reactExports.useMemo(()=>{if(u===!1)return u;const q=typeof u=="object"?u:{},{getContainer:F,closeIcon:K,rootClassName:X}=q,Q=__rest$j(q,["getContainer","closeIcon","rootClassName"]);return Object.assign(Object.assign({mask:reactExports.createElement("div",{className:`${_}-mask-info`},reactExports.createElement(RefIcon$n,null),R==null?void 0:R.preview),icons},Q),{rootClassName:classNames(z,X),getContainer:F??b,transitionName:getTransitionName(M,"zoom",q.transitionName),maskTransitionName:getTransitionName(M,"fade",q.maskTransitionName),zIndex:j,closeIcon:K??(w==null?void 0:w.closeIcon)})},[u,R,w==null?void 0:w.closeIcon]),U=Object.assign(Object.assign({},C),m);return N(reactExports.createElement(ImageInternal,Object.assign({prefixCls:_,preview:L,rootClassName:z,className:B,style:U},g)))};Image.PreviewGroup=InternalPreviewGroup;const Group=a=>{const{getPrefixCls:c,direction:u}=reactExports.useContext(ConfigContext),{prefixCls:d,className:f}=a,m=c("input-group",d),g=c("input"),[y,b,E]=useStyle$g(g),C=classNames(m,E,{[`${m}-lg`]:a.size==="large",[`${m}-sm`]:a.size==="small",[`${m}-compact`]:a.compact,[`${m}-rtl`]:u==="rtl"},b,f),w=reactExports.useContext(FormItemInputContext),R=reactExports.useMemo(()=>Object.assign(Object.assign({},w),{isFormItemInput:!1}),[w]);return y(reactExports.createElement("span",{className:C,style:a.style,onMouseEnter:a.onMouseEnter,onMouseLeave:a.onMouseLeave,onFocus:a.onFocus,onBlur:a.onBlur},reactExports.createElement(FormItemInputContext.Provider,{value:R},a.children)))},genOTPStyle=a=>{const{componentCls:c,paddingXS:u}=a;return{[c]:{display:"inline-flex",alignItems:"center",flexWrap:"nowrap",columnGap:u,[`${c}-input-wrapper`]:{position:"relative",[`${c}-mask-icon`]:{position:"absolute",zIndex:"1",top:"50%",right:"50%",transform:"translate(50%, -50%)",pointerEvents:"none"},[`${c}-mask-input`]:{color:"transparent",caretColor:"var(--ant-color-text)"},[`${c}-mask-input[type=number]::-webkit-inner-spin-button`]:{"-webkit-appearance":"none",margin:0},[`${c}-mask-input[type=number]`]:{"-moz-appearance":"textfield"}},"&-rtl":{direction:"rtl"},[`${c}-input`]:{textAlign:"center",paddingInline:a.paddingXXS},[`&${c}-sm ${c}-input`]:{paddingInline:a.calc(a.paddingXXS).div(2).equal()},[`&${c}-lg ${c}-input`]:{paddingInline:a.paddingXS}}}},useStyle$8=genStyleHooks(["Input","OTP"],a=>{const c=merge$2(a,initInputToken(a));return[genOTPStyle(c)]},initComponentToken$1);var __rest$i=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const OTPInput=reactExports.forwardRef((a,c)=>{const{className:u,value:d,onChange:f,onActiveChange:m,index:g,mask:y}=a,b=__rest$i(a,["className","value","onChange","onActiveChange","index","mask"]),{getPrefixCls:E}=reactExports.useContext(ConfigContext),C=E("otp"),w=typeof y=="string"?y:d,R=reactExports.useRef(null);reactExports.useImperativeHandle(c,()=>R.current);const _=A=>{f(g,A.target.value)},M=()=>{wrapperRaf(()=>{var A;const P=(A=R.current)===null||A===void 0?void 0:A.input;document.activeElement===P&&P&&P.select()})},I=A=>{const{key:P,ctrlKey:z,metaKey:B}=A;P==="ArrowLeft"?m(g-1):P==="ArrowRight"?m(g+1):P==="z"&&(z||B)&&A.preventDefault(),M()},N=A=>{A.key==="Backspace"&&!d&&m(g-1),M()};return reactExports.createElement("span",{className:`${C}-input-wrapper`,role:"presentation"},y&&d!==""&&d!==void 0&&reactExports.createElement("span",{className:`${C}-mask-icon`,"aria-hidden":"true"},w),reactExports.createElement(Input$1,Object.assign({"aria-label":`OTP Input ${g+1}`,type:y===!0?"password":"text"},b,{ref:R,value:d,onInput:_,onFocus:M,onKeyDown:I,onKeyUp:N,onMouseDown:M,onMouseUp:M,className:classNames(u,{[`${C}-mask-input`]:y})})))});var __rest$h=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function strToArr(a){return(a||"").split("")}const Separator=a=>{const{index:c,prefixCls:u,separator:d}=a,f=typeof d=="function"?d(c):d;return f?reactExports.createElement("span",{className:`${u}-separator`},f):null},OTP=reactExports.forwardRef((a,c)=>{const{prefixCls:u,length:d=6,size:f,defaultValue:m,value:g,onChange:y,formatter:b,separator:E,variant:C,disabled:w,status:R,autoFocus:_,mask:M,type:I,onInput:N,inputMode:A}=a,P=__rest$h(a,["prefixCls","length","size","defaultValue","value","onChange","formatter","separator","variant","disabled","status","autoFocus","mask","type","onInput","inputMode"]),{getPrefixCls:z,direction:B}=reactExports.useContext(ConfigContext),j=z("otp",u),L=pickAttrs(P,{aria:!0,data:!0,attr:!0}),[U,q,F]=useStyle$8(j),K=useSize(ie=>f??ie),X=reactExports.useContext(FormItemInputContext),Q=getMergedStatus(X.status,R),Y=reactExports.useMemo(()=>Object.assign(Object.assign({},X),{status:Q,hasFeedback:!1,feedbackIcon:null}),[X,Q]),Z=reactExports.useRef(null),J=reactExports.useRef({});reactExports.useImperativeHandle(c,()=>({focus:()=>{var ie;(ie=J.current[0])===null||ie===void 0||ie.focus()},blur:()=>{var ie;for(let ce=0;ce<d;ce+=1)(ie=J.current[ce])===null||ie===void 0||ie.blur()},nativeElement:Z.current}));const W=ie=>b?b(ie):ie,[G,te]=reactExports.useState(()=>strToArr(W(m||"")));reactExports.useEffect(()=>{g!==void 0&&te(strToArr(g))},[g]);const ae=useEvent(ie=>{te(ie),N&&N(ie),y&&ie.length===d&&ie.every(ce=>ce)&&ie.some((ce,ue)=>G[ue]!==ce)&&y(ie.join(""))}),V=useEvent((ie,ce)=>{let ue=_toConsumableArray(G);for(let de=0;de<ie;de+=1)ue[de]||(ue[de]="");ce.length<=1?ue[ie]=ce:ue=ue.slice(0,ie).concat(strToArr(ce)),ue=ue.slice(0,d);for(let de=ue.length-1;de>=0&&!ue[de];de-=1)ue.pop();const me=W(ue.map(de=>de||" ").join(""));return ue=strToArr(me).map((de,ge)=>de===" "&&!ue[ge]?ue[ge]:de),ue}),ne=(ie,ce)=>{var ue;const me=V(ie,ce),de=Math.min(ie+ce.length,d-1);de!==ie&&me[ie]!==void 0&&((ue=J.current[de])===null||ue===void 0||ue.focus()),ae(me)},le=ie=>{var ce;(ce=J.current[ie])===null||ce===void 0||ce.focus()},ee={variant:C,disabled:w,status:Q,mask:M,type:I,inputMode:A};return U(reactExports.createElement("div",Object.assign({},L,{ref:Z,className:classNames(j,{[`${j}-sm`]:K==="small",[`${j}-lg`]:K==="large",[`${j}-rtl`]:B==="rtl"},F,q),role:"group"}),reactExports.createElement(FormItemInputContext.Provider,{value:Y},Array.from({length:d}).map((ie,ce)=>{const ue=`otp-${ce}`,me=G[ce]||"";return reactExports.createElement(reactExports.Fragment,{key:ue},reactExports.createElement(OTPInput,Object.assign({ref:de=>{J.current[ce]=de},index:ce,size:K,htmlSize:1,className:`${j}-input`,onChange:ne,value:me,onActiveChange:le,autoFocus:ce===0&&_},ee)),ce<d-1&&reactExports.createElement(Separator,{separator:E,index:ce,prefixCls:j}))}))))});var __rest$g=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const defaultIconRender=a=>a?reactExports.createElement(RefIcon$n,null):reactExports.createElement(RefIcon$o,null),actionMap={click:"onClick",hover:"onMouseOver"},Password=reactExports.forwardRef((a,c)=>{const{disabled:u,action:d="click",visibilityToggle:f=!0,iconRender:m=defaultIconRender}=a,g=reactExports.useContext(DisabledContext),y=u??g,b=typeof f=="object"&&f.visible!==void 0,[E,C]=reactExports.useState(()=>b?f.visible:!1),w=reactExports.useRef(null);reactExports.useEffect(()=>{b&&C(f.visible)},[b,f]);const R=useRemovePasswordTimeout(w),_=()=>{var K;if(y)return;E&&R();const X=!E;C(X),typeof f=="object"&&((K=f.onVisibleChange)===null||K===void 0||K.call(f,X))},M=K=>{const X=actionMap[d]||"",Q=m(E),Y={[X]:_,className:`${K}-icon`,key:"passwordIcon",onMouseDown:Z=>{Z.preventDefault()},onMouseUp:Z=>{Z.preventDefault()}};return reactExports.cloneElement(reactExports.isValidElement(Q)?Q:reactExports.createElement("span",null,Q),Y)},{className:I,prefixCls:N,inputPrefixCls:A,size:P}=a,z=__rest$g(a,["className","prefixCls","inputPrefixCls","size"]),{getPrefixCls:B}=reactExports.useContext(ConfigContext),j=B("input",A),L=B("input-password",N),U=f&&M(L),q=classNames(L,I,{[`${L}-${P}`]:!!P}),F=Object.assign(Object.assign({},omit(z,["suffix","iconRender","visibilityToggle"])),{type:E?"text":"password",className:q,prefixCls:j,suffix:U});return P&&(F.size=P),reactExports.createElement(Input$1,Object.assign({ref:composeRef(c,w)},F))});var __rest$f=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Search=reactExports.forwardRef((a,c)=>{const{prefixCls:u,inputPrefixCls:d,className:f,size:m,suffix:g,enterButton:y=!1,addonAfter:b,loading:E,disabled:C,onSearch:w,onChange:R,onCompositionStart:_,onCompositionEnd:M}=a,I=__rest$f(a,["prefixCls","inputPrefixCls","className","size","suffix","enterButton","addonAfter","loading","disabled","onSearch","onChange","onCompositionStart","onCompositionEnd"]),{getPrefixCls:N,direction:A}=reactExports.useContext(ConfigContext),P=reactExports.useRef(!1),z=N("input-search",u),B=N("input",d),{compactSize:j}=useCompactItemContext(z,A),L=useSize(ne=>{var le;return(le=m??j)!==null&&le!==void 0?le:ne}),U=reactExports.useRef(null),q=ne=>{ne!=null&&ne.target&&ne.type==="click"&&w&&w(ne.target.value,ne,{source:"clear"}),R==null||R(ne)},F=ne=>{var le;document.activeElement===((le=U.current)===null||le===void 0?void 0:le.input)&&ne.preventDefault()},K=ne=>{var le,ee;w&&w((ee=(le=U.current)===null||le===void 0?void 0:le.input)===null||ee===void 0?void 0:ee.value,ne,{source:"input"})},X=ne=>{P.current||E||K(ne)},Q=typeof y=="boolean"?reactExports.createElement(RefIcon$5,null):null,Y=`${z}-button`;let Z;const J=y||{},W=J.type&&J.type.__ANT_BUTTON===!0;W||J.type==="button"?Z=cloneElement(J,Object.assign({onMouseDown:F,onClick:ne=>{var le,ee;(ee=(le=J==null?void 0:J.props)===null||le===void 0?void 0:le.onClick)===null||ee===void 0||ee.call(le,ne),K(ne)},key:"enterButton"},W?{className:Y,size:L}:{})):Z=reactExports.createElement(Button$1,{className:Y,type:y?"primary":void 0,size:L,disabled:C,key:"enterButton",onMouseDown:F,onClick:K,loading:E,icon:Q},y),b&&(Z=[Z,cloneElement(b,{key:"addonAfter"})]);const G=classNames(z,{[`${z}-rtl`]:A==="rtl",[`${z}-${L}`]:!!L,[`${z}-with-button`]:!!y},f),te=Object.assign(Object.assign({},I),{className:G,prefixCls:B,type:"search"}),ae=ne=>{P.current=!0,_==null||_(ne)},V=ne=>{P.current=!1,M==null||M(ne)};return reactExports.createElement(Input$1,Object.assign({ref:composeRef(U,c),onPressEnter:X},te,{size:L,onCompositionStart:ae,onCompositionEnd:V,addonAfter:Z,suffix:g,onChange:q,disabled:C}))});var HIDDEN_TEXTAREA_STYLE=`
  min-height:0 !important;
  max-height:none !important;
  height:0 !important;
  visibility:hidden !important;
  overflow:hidden !important;
  position:absolute !important;
  z-index:-1000 !important;
  top:0 !important;
  right:0 !important;
  pointer-events: none !important;
`,SIZING_STYLE=["letter-spacing","line-height","padding-top","padding-bottom","font-family","font-weight","font-size","font-variant","text-rendering","text-transform","width","text-indent","padding-left","padding-right","border-width","box-sizing","word-break","white-space"],computedStyleCache={},hiddenTextarea;function calculateNodeStyling(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,u=a.getAttribute("id")||a.getAttribute("data-reactid")||a.getAttribute("name");if(c&&computedStyleCache[u])return computedStyleCache[u];var d=window.getComputedStyle(a),f=d.getPropertyValue("box-sizing")||d.getPropertyValue("-moz-box-sizing")||d.getPropertyValue("-webkit-box-sizing"),m=parseFloat(d.getPropertyValue("padding-bottom"))+parseFloat(d.getPropertyValue("padding-top")),g=parseFloat(d.getPropertyValue("border-bottom-width"))+parseFloat(d.getPropertyValue("border-top-width")),y=SIZING_STYLE.map(function(E){return"".concat(E,":").concat(d.getPropertyValue(E))}).join(";"),b={sizingStyle:y,paddingSize:m,borderSize:g,boxSizing:f};return c&&u&&(computedStyleCache[u]=b),b}function calculateAutoSizeStyle(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:null,d=arguments.length>3&&arguments[3]!==void 0?arguments[3]:null;hiddenTextarea||(hiddenTextarea=document.createElement("textarea"),hiddenTextarea.setAttribute("tab-index","-1"),hiddenTextarea.setAttribute("aria-hidden","true"),hiddenTextarea.setAttribute("name","hiddenTextarea"),document.body.appendChild(hiddenTextarea)),a.getAttribute("wrap")?hiddenTextarea.setAttribute("wrap",a.getAttribute("wrap")):hiddenTextarea.removeAttribute("wrap");var f=calculateNodeStyling(a,c),m=f.paddingSize,g=f.borderSize,y=f.boxSizing,b=f.sizingStyle;hiddenTextarea.setAttribute("style","".concat(b,";").concat(HIDDEN_TEXTAREA_STYLE)),hiddenTextarea.value=a.value||a.placeholder||"";var E=void 0,C=void 0,w,R=hiddenTextarea.scrollHeight;if(y==="border-box"?R+=g:y==="content-box"&&(R-=m),u!==null||d!==null){hiddenTextarea.value=" ";var _=hiddenTextarea.scrollHeight-m;u!==null&&(E=_*u,y==="border-box"&&(E=E+m+g),R=Math.max(E,R)),d!==null&&(C=_*d,y==="border-box"&&(C=C+m+g),w=R>C?"":"hidden",R=Math.min(C,R))}var M={height:R,overflowY:w,resize:"none"};return E&&(M.minHeight=E),C&&(M.maxHeight=C),M}var _excluded$a=["prefixCls","defaultValue","value","autoSize","onResize","className","style","disabled","onChange","onInternalAutoSize"],RESIZE_START=0,RESIZE_MEASURING=1,RESIZE_STABLE=2,ResizableTextArea=reactExports.forwardRef(function(a,c){var u=a,d=u.prefixCls,f=u.defaultValue,m=u.value,g=u.autoSize,y=u.onResize,b=u.className,E=u.style,C=u.disabled,w=u.onChange;u.onInternalAutoSize;var R=_objectWithoutProperties(u,_excluded$a),_=useMergedState(f,{value:m,postState:function(ie){return ie??""}}),M=_slicedToArray(_,2),I=M[0],N=M[1],A=function(ie){N(ie.target.value),w==null||w(ie)},P=reactExports.useRef();reactExports.useImperativeHandle(c,function(){return{textArea:P.current}});var z=reactExports.useMemo(function(){return g&&_typeof(g)==="object"?[g.minRows,g.maxRows]:[]},[g]),B=_slicedToArray(z,2),j=B[0],L=B[1],U=!!g,q=function(){try{if(document.activeElement===P.current){var ie=P.current,ce=ie.selectionStart,ue=ie.selectionEnd,me=ie.scrollTop;P.current.setSelectionRange(ce,ue),P.current.scrollTop=me}}catch{}},F=reactExports.useState(RESIZE_STABLE),K=_slicedToArray(F,2),X=K[0],Q=K[1],Y=reactExports.useState(),Z=_slicedToArray(Y,2),J=Z[0],W=Z[1],G=function(){Q(RESIZE_START)};useLayoutEffect$1(function(){U&&G()},[m,j,L,U]),useLayoutEffect$1(function(){if(X===RESIZE_START)Q(RESIZE_MEASURING);else if(X===RESIZE_MEASURING){var ee=calculateAutoSizeStyle(P.current,!1,j,L);Q(RESIZE_STABLE),W(ee)}else q()},[X]);var te=reactExports.useRef(),ae=function(){wrapperRaf.cancel(te.current)},V=function(ie){X===RESIZE_STABLE&&(y==null||y(ie),g&&(ae(),te.current=wrapperRaf(function(){G()})))};reactExports.useEffect(function(){return ae},[]);var ne=U?J:null,le=_objectSpread2(_objectSpread2({},E),ne);return(X===RESIZE_START||X===RESIZE_MEASURING)&&(le.overflowY="hidden",le.overflowX="hidden"),reactExports.createElement(RefResizeObserver,{onResize:V,disabled:!(g||y)},reactExports.createElement("textarea",_extends({},R,{ref:P,style:le,className:classNames(d,b,_defineProperty({},"".concat(d,"-disabled"),C)),disabled:C,value:I,onChange:A})))}),_excluded$9=["defaultValue","value","onFocus","onBlur","onChange","allowClear","maxLength","onCompositionStart","onCompositionEnd","suffix","prefixCls","showCount","count","className","style","disabled","hidden","classNames","styles","onResize","onClear","onPressEnter","readOnly","autoSize","onKeyDown"],TextArea$1=React.forwardRef(function(a,c){var u,d=a.defaultValue,f=a.value,m=a.onFocus,g=a.onBlur,y=a.onChange,b=a.allowClear,E=a.maxLength,C=a.onCompositionStart,w=a.onCompositionEnd,R=a.suffix,_=a.prefixCls,M=_===void 0?"rc-textarea":_,I=a.showCount,N=a.count,A=a.className,P=a.style,z=a.disabled,B=a.hidden,j=a.classNames,L=a.styles,U=a.onResize,q=a.onClear,F=a.onPressEnter,K=a.readOnly,X=a.autoSize,Q=a.onKeyDown,Y=_objectWithoutProperties(a,_excluded$9),Z=useMergedState(d,{value:f,defaultValue:d}),J=_slicedToArray(Z,2),W=J[0],G=J[1],te=W==null?"":String(W),ae=React.useState(!1),V=_slicedToArray(ae,2),ne=V[0],le=V[1],ee=React.useRef(!1),ie=React.useState(null),ce=_slicedToArray(ie,2),ue=ce[0],me=ce[1],de=reactExports.useRef(null),ge=reactExports.useRef(null),Ce=function(){var qe;return(qe=ge.current)===null||qe===void 0?void 0:qe.textArea},ve=function(){Ce().focus()};reactExports.useImperativeHandle(c,function(){var Ge;return{resizableTextArea:ge.current,focus:ve,blur:function(){Ce().blur()},nativeElement:((Ge=de.current)===null||Ge===void 0?void 0:Ge.nativeElement)||Ce()}}),reactExports.useEffect(function(){le(function(Ge){return!z&&Ge})},[z]);var fe=React.useState(null),pe=_slicedToArray(fe,2),xe=pe[0],ye=pe[1];React.useEffect(function(){if(xe){var Ge;(Ge=Ce()).setSelectionRange.apply(Ge,_toConsumableArray(xe))}},[xe]);var he=useCount(N,I),we=(u=he.max)!==null&&u!==void 0?u:E,Re=Number(we)>0,De=he.strategy(te),Ae=!!we&&De>we,Ee=function(qe,Ue){var je=Ue;!ee.current&&he.exceedFormatter&&he.max&&he.strategy(Ue)>he.max&&(je=he.exceedFormatter(Ue,{max:he.max}),Ue!==je&&ye([Ce().selectionStart||0,Ce().selectionEnd||0])),G(je),resolveOnChange(qe.currentTarget,qe,y,je)},Ne=function(qe){ee.current=!0,C==null||C(qe)},_e=function(qe){ee.current=!1,Ee(qe,qe.currentTarget.value),w==null||w(qe)},ke=function(qe){Ee(qe,qe.target.value)},Ke=function(qe){qe.key==="Enter"&&F&&F(qe),Q==null||Q(qe)},be=function(qe){le(!0),m==null||m(qe)},Te=function(qe){le(!1),g==null||g(qe)},Le=function(qe){G(""),ve(),resolveOnChange(Ce(),qe,y)},Oe=R,Be;he.show&&(he.showFormatter?Be=he.showFormatter({value:te,count:De,maxLength:we}):Be="".concat(De).concat(Re?" / ".concat(we):""),Oe=React.createElement(React.Fragment,null,Oe,React.createElement("span",{className:classNames("".concat(M,"-data-count"),j==null?void 0:j.count),style:L==null?void 0:L.count},Be)));var Ve=function(qe){var Ue;U==null||U(qe),(Ue=Ce())!==null&&Ue!==void 0&&Ue.style.height&&me(!0)},Pe=!X&&!I&&!b;return React.createElement(BaseInput$1,{ref:de,value:te,allowClear:b,handleReset:Le,suffix:Oe,prefixCls:M,classNames:_objectSpread2(_objectSpread2({},j),{},{affixWrapper:classNames(j==null?void 0:j.affixWrapper,_defineProperty(_defineProperty({},"".concat(M,"-show-count"),I),"".concat(M,"-textarea-allow-clear"),b))}),disabled:z,focused:ne,className:classNames(A,Ae&&"".concat(M,"-out-of-range")),style:_objectSpread2(_objectSpread2({},P),ue&&!Pe?{height:"auto"}:{}),dataAttrs:{affixWrapper:{"data-count":typeof Be=="string"?Be:void 0}},hidden:B,readOnly:K,onClear:q},React.createElement(ResizableTextArea,_extends({},Y,{autoSize:X,maxLength:E,onKeyDown:Ke,onChange:ke,onFocus:be,onBlur:Te,onCompositionStart:Ne,onCompositionEnd:_e,className:classNames(j==null?void 0:j.textarea),style:_objectSpread2(_objectSpread2({},L==null?void 0:L.textarea),{},{resize:P==null?void 0:P.resize}),disabled:z,prefixCls:M,onResize:Ve,ref:ge,readOnly:K})))});const genTextAreaStyle=a=>{const{componentCls:c,paddingLG:u}=a,d=`${c}-textarea`;return{[`textarea${c}`]:{maxWidth:"100%",height:"auto",minHeight:a.controlHeight,lineHeight:a.lineHeight,verticalAlign:"bottom",transition:`all ${a.motionDurationSlow}`,resize:"vertical",[`&${c}-mouse-active`]:{transition:`all ${a.motionDurationSlow}, height 0s, width 0s`}},[`${c}-textarea-affix-wrapper-resize-dirty`]:{width:"auto"},[d]:{position:"relative","&-show-count":{[`${c}-data-count`]:{position:"absolute",bottom:a.calc(a.fontSize).mul(a.lineHeight).mul(-1).equal(),insetInlineEnd:0,color:a.colorTextDescription,whiteSpace:"nowrap",pointerEvents:"none"}},[`
        &-allow-clear > ${c},
        &-affix-wrapper${d}-has-feedback ${c}
      `]:{paddingInlineEnd:u},[`&-affix-wrapper${c}-affix-wrapper`]:{padding:0,[`> textarea${c}`]:{fontSize:"inherit",border:"none",outline:"none",background:"transparent",minHeight:a.calc(a.controlHeight).sub(a.calc(a.lineWidth).mul(2)).equal(),"&:focus":{boxShadow:"none !important"}},[`${c}-suffix`]:{margin:0,"> *:not(:last-child)":{marginInline:0},[`${c}-clear-icon`]:{position:"absolute",insetInlineEnd:a.paddingInline,insetBlockStart:a.paddingXS},[`${d}-suffix`]:{position:"absolute",top:0,insetInlineEnd:a.paddingInline,bottom:0,zIndex:1,display:"inline-flex",alignItems:"center",margin:"auto",pointerEvents:"none"}}},[`&-affix-wrapper${c}-affix-wrapper-rtl`]:{[`${c}-suffix`]:{[`${c}-data-count`]:{direction:"ltr",insetInlineStart:0}}},[`&-affix-wrapper${c}-affix-wrapper-sm`]:{[`${c}-suffix`]:{[`${c}-clear-icon`]:{insetInlineEnd:a.paddingInlineSM}}}}}},useStyle$7=genStyleHooks(["Input","TextArea"],a=>{const c=merge$2(a,initInputToken(a));return[genTextAreaStyle(c)]},initComponentToken$1,{resetFont:!1});var __rest$e=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const TextArea=reactExports.forwardRef((a,c)=>{var u;const{prefixCls:d,bordered:f=!0,size:m,disabled:g,status:y,allowClear:b,classNames:E,rootClassName:C,className:w,style:R,styles:_,variant:M,showCount:I,onMouseDown:N,onResize:A}=a,P=__rest$e(a,["prefixCls","bordered","size","disabled","status","allowClear","classNames","rootClassName","className","style","styles","variant","showCount","onMouseDown","onResize"]),{getPrefixCls:z,direction:B,allowClear:j,autoComplete:L,className:U,style:q,classNames:F,styles:K}=useComponentConfig("textArea"),X=reactExports.useContext(DisabledContext),Q=g??X,{status:Y,hasFeedback:Z,feedbackIcon:J}=reactExports.useContext(FormItemInputContext),W=getMergedStatus(Y,y),G=reactExports.useRef(null);reactExports.useImperativeHandle(c,()=>{var he;return{resizableTextArea:(he=G.current)===null||he===void 0?void 0:he.resizableTextArea,focus:we=>{var Re,De;triggerFocus((De=(Re=G.current)===null||Re===void 0?void 0:Re.resizableTextArea)===null||De===void 0?void 0:De.textArea,we)},blur:()=>{var we;return(we=G.current)===null||we===void 0?void 0:we.blur()}}});const te=z("input",d),ae=useCSSVarCls(te),[V,ne,le]=useSharedStyle(te,C),[ee]=useStyle$7(te,ae),{compactSize:ie,compactItemClassnames:ce}=useCompactItemContext(te,B),ue=useSize(he=>{var we;return(we=m??ie)!==null&&we!==void 0?we:he}),[me,de]=useVariant("textArea",M,f),ge=getAllowClear(b??j),[Ce,ve]=reactExports.useState(!1),[fe,pe]=reactExports.useState(!1),xe=he=>{ve(!0),N==null||N(he);const we=()=>{ve(!1),document.removeEventListener("mouseup",we)};document.addEventListener("mouseup",we)},ye=he=>{var we,Re;if(A==null||A(he),Ce&&typeof getComputedStyle=="function"){const De=(Re=(we=G.current)===null||we===void 0?void 0:we.nativeElement)===null||Re===void 0?void 0:Re.querySelector("textarea");De&&getComputedStyle(De).resize==="both"&&pe(!0)}};return V(ee(reactExports.createElement(TextArea$1,Object.assign({autoComplete:L},P,{style:Object.assign(Object.assign({},q),R),styles:Object.assign(Object.assign({},K),_),disabled:Q,allowClear:ge,className:classNames(le,ae,w,C,ce,U,fe&&`${te}-textarea-affix-wrapper-resize-dirty`),classNames:Object.assign(Object.assign(Object.assign({},E),F),{textarea:classNames({[`${te}-sm`]:ue==="small",[`${te}-lg`]:ue==="large"},ne,E==null?void 0:E.textarea,F.textarea,Ce&&`${te}-mouse-active`),variant:classNames({[`${te}-${me}`]:de},getStatusClassNames(te,W)),affixWrapper:classNames(`${te}-textarea-affix-wrapper`,{[`${te}-affix-wrapper-rtl`]:B==="rtl",[`${te}-affix-wrapper-sm`]:ue==="small",[`${te}-affix-wrapper-lg`]:ue==="large",[`${te}-textarea-show-count`]:I||((u=a.count)===null||u===void 0?void 0:u.show)},ne)}),prefixCls:te,suffix:Z&&reactExports.createElement("span",{className:`${te}-textarea-suffix`},J),showCount:I,ref:G,onResize:ye,onMouseDown:xe}))))}),Input=Input$1;Input.Group=Group;Input.Search=Search;Input.TextArea=TextArea;Input.Password=Password;Input.OTP=OTP;function useHasSider(a,c,u){return typeof u=="boolean"?u:a.length?!0:toArray$6(c).some(f=>f.type===Sider$1)}var __rest$d=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function generator(a){let{suffixCls:c,tagName:u,displayName:d}=a;return f=>reactExports.forwardRef((g,y)=>reactExports.createElement(f,Object.assign({ref:y,suffixCls:c,tagName:u},g)))}const Basic=reactExports.forwardRef((a,c)=>{const{prefixCls:u,suffixCls:d,className:f,tagName:m}=a,g=__rest$d(a,["prefixCls","suffixCls","className","tagName"]),{getPrefixCls:y}=reactExports.useContext(ConfigContext),b=y("layout",u),[E,C,w]=useStyle$l(b),R=d?`${b}-${d}`:b;return E(reactExports.createElement(m,Object.assign({className:classNames(u||R,f,C,w),ref:c},g)))}),BasicLayout=reactExports.forwardRef((a,c)=>{const{direction:u}=reactExports.useContext(ConfigContext),[d,f]=reactExports.useState([]),{prefixCls:m,className:g,rootClassName:y,children:b,hasSider:E,tagName:C,style:w}=a,R=__rest$d(a,["prefixCls","className","rootClassName","children","hasSider","tagName","style"]),_=omit(R,["suffixCls"]),{getPrefixCls:M,className:I,style:N}=useComponentConfig("layout"),A=M("layout",m),P=useHasSider(d,b,E),[z,B,j]=useStyle$l(A),L=classNames(A,{[`${A}-has-sider`]:P,[`${A}-rtl`]:u==="rtl"},I,g,y,B,j),U=reactExports.useMemo(()=>({siderHook:{addSider:q=>{f(F=>[].concat(_toConsumableArray(F),[q]))},removeSider:q=>{f(F=>F.filter(K=>K!==q))}}}),[]);return z(reactExports.createElement(LayoutContext.Provider,{value:U},reactExports.createElement(C,Object.assign({ref:c,className:L,style:Object.assign(Object.assign({},N),w)},_),b)))}),Layout$1=generator({tagName:"div",displayName:"Layout"})(BasicLayout),Header$2=generator({suffixCls:"header",tagName:"header",displayName:"Header"})(Basic),Footer$2=generator({suffixCls:"footer",tagName:"footer",displayName:"Footer"})(Basic),Content$1=generator({suffixCls:"content",tagName:"main",displayName:"Content"})(Basic),Layout=Layout$1;Layout.Header=Header$2;Layout.Footer=Footer$2;Layout.Content=Content$1;Layout.Sider=Sider$1;Layout._InternalSiderContext=SiderContext;const extendsObject=function(){const a=Object.assign({},arguments.length<=0?void 0:arguments[0]);for(let c=1;c<arguments.length;c++){const u=c<0||arguments.length<=c?void 0:arguments[c];u&&Object.keys(u).forEach(d=>{const f=u[d];f!==void 0&&(a[d]=f)})}return a};var locale={items_per_page:"条/页",jump_to:"跳至",jump_to_confirm:"确定",page:"页",prev_page:"上一页",next_page:"下一页",prev_5:"向前 5 页",next_5:"向后 5 页",prev_3:"向前 3 页",next_3:"向后 3 页",page_size:"页码"},defaultPageSizeOptions=[10,20,50,100],Options$1=function(c){var u=c.pageSizeOptions,d=u===void 0?defaultPageSizeOptions:u,f=c.locale,m=c.changeSize,g=c.pageSize,y=c.goButton,b=c.quickGo,E=c.rootPrefixCls,C=c.disabled,w=c.buildOptionText,R=c.showSizeChanger,_=c.sizeChangerRender,M=React.useState(""),I=_slicedToArray(M,2),N=I[0],A=I[1],P=function(){return!N||Number.isNaN(N)?void 0:Number(N)},z=typeof w=="function"?w:function(Q){return"".concat(Q," ").concat(f.items_per_page)},B=function(Y){A(Y.target.value)},j=function(Y){y||N===""||(A(""),!(Y.relatedTarget&&(Y.relatedTarget.className.indexOf("".concat(E,"-item-link"))>=0||Y.relatedTarget.className.indexOf("".concat(E,"-item"))>=0))&&(b==null||b(P())))},L=function(Y){N!==""&&(Y.keyCode===KeyCode.ENTER||Y.type==="click")&&(A(""),b==null||b(P()))},U=function(){return d.some(function(Y){return Y.toString()===g.toString()})?d:d.concat([g]).sort(function(Y,Z){var J=Number.isNaN(Number(Y))?0:Number(Y),W=Number.isNaN(Number(Z))?0:Number(Z);return J-W})},q="".concat(E,"-options");if(!R&&!b)return null;var F=null,K=null,X=null;return R&&_&&(F=_({disabled:C,size:g,onSizeChange:function(Y){m==null||m(Number(Y))},"aria-label":f.page_size,className:"".concat(q,"-size-changer"),options:U().map(function(Q){return{label:z(Q),value:Q}})})),b&&(y&&(X=typeof y=="boolean"?React.createElement("button",{type:"button",onClick:L,onKeyUp:L,disabled:C,className:"".concat(q,"-quick-jumper-button")},f.jump_to_confirm):React.createElement("span",{onClick:L,onKeyUp:L},y)),K=React.createElement("div",{className:"".concat(q,"-quick-jumper")},f.jump_to,React.createElement("input",{disabled:C,type:"text",value:N,onChange:B,onKeyUp:L,onBlur:j,"aria-label":f.page}),f.page,X)),React.createElement("li",{className:q},F,K)},Pager=function(c){var u=c.rootPrefixCls,d=c.page,f=c.active,m=c.className,g=c.showTitle,y=c.onClick,b=c.onKeyPress,E=c.itemRender,C="".concat(u,"-item"),w=classNames(C,"".concat(C,"-").concat(d),_defineProperty(_defineProperty({},"".concat(C,"-active"),f),"".concat(C,"-disabled"),!d),m),R=function(){y(d)},_=function(N){b(N,y,d)},M=E(d,"page",React.createElement("a",{rel:"nofollow"},d));return M?React.createElement("li",{title:g?String(d):null,className:w,onClick:R,onKeyDown:_,tabIndex:0},M):null},defaultItemRender=function(c,u,d){return d};function noop$3(){}function isInteger(a){var c=Number(a);return typeof c=="number"&&!Number.isNaN(c)&&isFinite(c)&&Math.floor(c)===c}function calculatePage(a,c,u){var d=typeof a>"u"?c:a;return Math.floor((u-1)/d)+1}var Pagination$1=function(c){var u=c.prefixCls,d=u===void 0?"rc-pagination":u,f=c.selectPrefixCls,m=f===void 0?"rc-select":f,g=c.className,y=c.current,b=c.defaultCurrent,E=b===void 0?1:b,C=c.total,w=C===void 0?0:C,R=c.pageSize,_=c.defaultPageSize,M=_===void 0?10:_,I=c.onChange,N=I===void 0?noop$3:I,A=c.hideOnSinglePage,P=c.align,z=c.showPrevNextJumpers,B=z===void 0?!0:z,j=c.showQuickJumper,L=c.showLessItems,U=c.showTitle,q=U===void 0?!0:U,F=c.onShowSizeChange,K=F===void 0?noop$3:F,X=c.locale,Q=X===void 0?locale:X,Y=c.style,Z=c.totalBoundaryShowSizeChanger,J=Z===void 0?50:Z,W=c.disabled,G=c.simple,te=c.showTotal,ae=c.showSizeChanger,V=ae===void 0?w>J:ae,ne=c.sizeChangerRender,le=c.pageSizeOptions,ee=c.itemRender,ie=ee===void 0?defaultItemRender:ee,ce=c.jumpPrevIcon,ue=c.jumpNextIcon,me=c.prevIcon,de=c.nextIcon,ge=React.useRef(null),Ce=useMergedState(10,{value:R,defaultValue:M}),ve=_slicedToArray(Ce,2),fe=ve[0],pe=ve[1],xe=useMergedState(1,{value:y,defaultValue:E,postState:function(_t){return Math.max(1,Math.min(_t,calculatePage(void 0,fe,w)))}}),ye=_slicedToArray(xe,2),he=ye[0],we=ye[1],Re=React.useState(he),De=_slicedToArray(Re,2),Ae=De[0],Ee=De[1];reactExports.useEffect(function(){Ee(he)},[he]);var Ne=Math.max(1,he-(L?3:5)),_e=Math.min(calculatePage(void 0,fe,w),he+(L?3:5));function ke(St,_t){var zt=St||React.createElement("button",{type:"button","aria-label":_t,className:"".concat(d,"-item-link")});return typeof St=="function"&&(zt=React.createElement(St,_objectSpread2({},c))),zt}function Ke(St){var _t=St.target.value,zt=calculatePage(void 0,fe,w),nr;return _t===""?nr=_t:Number.isNaN(Number(_t))?nr=Ae:_t>=zt?nr=zt:nr=Number(_t),nr}function be(St){return isInteger(St)&&St!==he&&isInteger(w)&&w>0}var Te=w>fe?j:!1;function Le(St){(St.keyCode===KeyCode.UP||St.keyCode===KeyCode.DOWN)&&St.preventDefault()}function Oe(St){var _t=Ke(St);switch(_t!==Ae&&Ee(_t),St.keyCode){case KeyCode.ENTER:Pe(_t);break;case KeyCode.UP:Pe(_t-1);break;case KeyCode.DOWN:Pe(_t+1);break}}function Be(St){Pe(Ke(St))}function Ve(St){var _t=calculatePage(St,fe,w),zt=he>_t&&_t!==0?_t:he;pe(St),Ee(zt),K==null||K(he,St),we(zt),N==null||N(zt,St)}function Pe(St){if(be(St)&&!W){var _t=calculatePage(void 0,fe,w),zt=St;return St>_t?zt=_t:St<1&&(zt=1),zt!==Ae&&Ee(zt),we(zt),N==null||N(zt,fe),zt}return he}var Ge=he>1,qe=he<calculatePage(void 0,fe,w);function Ue(){Ge&&Pe(he-1)}function je(){qe&&Pe(he+1)}function We(){Pe(Ne)}function ut(){Pe(_e)}function gt(St,_t){if(St.key==="Enter"||St.charCode===KeyCode.ENTER||St.keyCode===KeyCode.ENTER){for(var zt=arguments.length,nr=new Array(zt>2?zt-2:0),Rr=2;Rr<zt;Rr++)nr[Rr-2]=arguments[Rr];_t.apply(void 0,nr)}}function kt(St){gt(St,Ue)}function Ut(St){gt(St,je)}function at(St){gt(St,We)}function ct(St){gt(St,ut)}function bt(St){var _t=ie(St,"prev",ke(me,"prev page"));return React.isValidElement(_t)?React.cloneElement(_t,{disabled:!Ge}):_t}function it(St){var _t=ie(St,"next",ke(de,"next page"));return React.isValidElement(_t)?React.cloneElement(_t,{disabled:!qe}):_t}function vt(St){(St.type==="click"||St.keyCode===KeyCode.ENTER)&&Pe(Ae)}var ot=null,rt=pickAttrs(c,{aria:!0,data:!0}),et=te&&React.createElement("li",{className:"".concat(d,"-total-text")},te(w,[w===0?0:(he-1)*fe+1,he*fe>w?w:he*fe])),$t=null,mt=calculatePage(void 0,fe,w);if(A&&w<=fe)return null;var Ze=[],Je={rootPrefixCls:d,onClick:Pe,onKeyPress:gt,showTitle:q,itemRender:ie,page:-1},yt=he-1>0?he-1:0,Ct=he+1<mt?he+1:mt,pt=j&&j.goButton,Rt=_typeof(G)==="object"?G.readOnly:!G,ft=pt,dt=null;G&&(pt&&(typeof pt=="boolean"?ft=React.createElement("button",{type:"button",onClick:vt,onKeyUp:vt},Q.jump_to_confirm):ft=React.createElement("span",{onClick:vt,onKeyUp:vt},pt),ft=React.createElement("li",{title:q?"".concat(Q.jump_to).concat(he,"/").concat(mt):null,className:"".concat(d,"-simple-pager")},ft)),dt=React.createElement("li",{title:q?"".concat(he,"/").concat(mt):null,className:"".concat(d,"-simple-pager")},Rt?Ae:React.createElement("input",{type:"text","aria-label":Q.jump_to,value:Ae,disabled:W,onKeyDown:Le,onKeyUp:Oe,onChange:Oe,onBlur:Be,size:3}),React.createElement("span",{className:"".concat(d,"-slash")},"/"),mt));var xt=L?1:2;if(mt<=3+xt*2){mt||Ze.push(React.createElement(Pager,_extends({},Je,{key:"noPager",page:1,className:"".concat(d,"-item-disabled")})));for(var Tt=1;Tt<=mt;Tt+=1)Ze.push(React.createElement(Pager,_extends({},Je,{key:Tt,page:Tt,active:he===Tt})))}else{var Dt=L?Q.prev_3:Q.prev_5,Vt=L?Q.next_3:Q.next_5,Nt=ie(Ne,"jump-prev",ke(ce,"prev page")),Kt=ie(_e,"jump-next",ke(ue,"next page"));B&&(ot=Nt?React.createElement("li",{title:q?Dt:null,key:"prev",onClick:We,tabIndex:0,onKeyDown:at,className:classNames("".concat(d,"-jump-prev"),_defineProperty({},"".concat(d,"-jump-prev-custom-icon"),!!ce))},Nt):null,$t=Kt?React.createElement("li",{title:q?Vt:null,key:"next",onClick:ut,tabIndex:0,onKeyDown:ct,className:classNames("".concat(d,"-jump-next"),_defineProperty({},"".concat(d,"-jump-next-custom-icon"),!!ue))},Kt):null);var Zt=Math.max(1,he-xt),Gt=Math.min(he+xt,mt);he-1<=xt&&(Gt=1+xt*2),mt-he<=xt&&(Zt=mt-xt*2);for(var tt=Zt;tt<=Gt;tt+=1)Ze.push(React.createElement(Pager,_extends({},Je,{key:tt,page:tt,active:he===tt})));if(he-1>=xt*2&&he!==3&&(Ze[0]=React.cloneElement(Ze[0],{className:classNames("".concat(d,"-item-after-jump-prev"),Ze[0].props.className)}),Ze.unshift(ot)),mt-he>=xt*2&&he!==mt-2){var ht=Ze[Ze.length-1];Ze[Ze.length-1]=React.cloneElement(ht,{className:classNames("".concat(d,"-item-before-jump-next"),ht.props.className)}),Ze.push($t)}Zt!==1&&Ze.unshift(React.createElement(Pager,_extends({},Je,{key:1,page:1}))),Gt!==mt&&Ze.push(React.createElement(Pager,_extends({},Je,{key:mt,page:mt})))}var lt=bt(yt);if(lt){var nt=!Ge||!mt;lt=React.createElement("li",{title:q?Q.prev_page:null,onClick:Ue,tabIndex:nt?null:0,onKeyDown:kt,className:classNames("".concat(d,"-prev"),_defineProperty({},"".concat(d,"-disabled"),nt)),"aria-disabled":nt},lt)}var Ot=it(Ct);if(Ot){var Bt,qt;G?(Bt=!qe,qt=Ge?0:null):(Bt=!qe||!mt,qt=Bt?null:0),Ot=React.createElement("li",{title:q?Q.next_page:null,onClick:je,tabIndex:qt,onKeyDown:Ut,className:classNames("".concat(d,"-next"),_defineProperty({},"".concat(d,"-disabled"),Bt)),"aria-disabled":Bt},Ot)}var er=classNames(d,g,_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(d,"-start"),P==="start"),"".concat(d,"-center"),P==="center"),"".concat(d,"-end"),P==="end"),"".concat(d,"-simple"),G),"".concat(d,"-disabled"),W));return React.createElement("ul",_extends({className:er,style:Y,ref:ge},rt),et,lt,G?dt:Ze,Ot,React.createElement(Options$1,{locale:Q,rootPrefixCls:d,disabled:W,selectPrefixCls:m,changeSize:Ve,pageSize:fe,pageSizeOptions:le,quickGo:Te?Pe:null,goButton:ft,showSizeChanger:V,sizeChangerRender:ne}))};const genPaginationDisabledStyle=a=>{const{componentCls:c}=a;return{[`${c}-disabled`]:{"&, &:hover":{cursor:"not-allowed",[`${c}-item-link`]:{color:a.colorTextDisabled,cursor:"not-allowed"}},"&:focus-visible":{cursor:"not-allowed",[`${c}-item-link`]:{color:a.colorTextDisabled,cursor:"not-allowed"}}},[`&${c}-disabled`]:{cursor:"not-allowed",[`${c}-item`]:{cursor:"not-allowed",backgroundColor:"transparent","&:hover, &:active":{backgroundColor:"transparent"},a:{color:a.colorTextDisabled,backgroundColor:"transparent",border:"none",cursor:"not-allowed"},"&-active":{borderColor:a.colorBorder,backgroundColor:a.itemActiveBgDisabled,"&:hover, &:active":{backgroundColor:a.itemActiveBgDisabled},a:{color:a.itemActiveColorDisabled}}},[`${c}-item-link`]:{color:a.colorTextDisabled,cursor:"not-allowed","&:hover, &:active":{backgroundColor:"transparent"},[`${c}-simple&`]:{backgroundColor:"transparent","&:hover, &:active":{backgroundColor:"transparent"}}},[`${c}-simple-pager`]:{color:a.colorTextDisabled},[`${c}-jump-prev, ${c}-jump-next`]:{[`${c}-item-link-icon`]:{opacity:0},[`${c}-item-ellipsis`]:{opacity:1}}},[`&${c}-simple`]:{[`${c}-prev, ${c}-next`]:{[`&${c}-disabled ${c}-item-link`]:{"&:hover, &:active":{backgroundColor:"transparent"}}}}}},genPaginationMiniStyle=a=>{const{componentCls:c}=a;return{[`&${c}-mini ${c}-total-text, &${c}-mini ${c}-simple-pager`]:{height:a.itemSizeSM,lineHeight:unit$1(a.itemSizeSM)},[`&${c}-mini ${c}-item`]:{minWidth:a.itemSizeSM,height:a.itemSizeSM,margin:0,lineHeight:unit$1(a.calc(a.itemSizeSM).sub(2).equal())},[`&${c}-mini ${c}-prev, &${c}-mini ${c}-next`]:{minWidth:a.itemSizeSM,height:a.itemSizeSM,margin:0,lineHeight:unit$1(a.itemSizeSM)},[`&${c}-mini:not(${c}-disabled)`]:{[`${c}-prev, ${c}-next`]:{[`&:hover ${c}-item-link`]:{backgroundColor:a.colorBgTextHover},[`&:active ${c}-item-link`]:{backgroundColor:a.colorBgTextActive},[`&${c}-disabled:hover ${c}-item-link`]:{backgroundColor:"transparent"}}},[`
    &${c}-mini ${c}-prev ${c}-item-link,
    &${c}-mini ${c}-next ${c}-item-link
    `]:{backgroundColor:"transparent",borderColor:"transparent","&::after":{height:a.itemSizeSM,lineHeight:unit$1(a.itemSizeSM)}},[`&${c}-mini ${c}-jump-prev, &${c}-mini ${c}-jump-next`]:{height:a.itemSizeSM,marginInlineEnd:0,lineHeight:unit$1(a.itemSizeSM)},[`&${c}-mini ${c}-options`]:{marginInlineStart:a.paginationMiniOptionsMarginInlineStart,"&-size-changer":{top:a.miniOptionsSizeChangerTop},"&-quick-jumper":{height:a.itemSizeSM,lineHeight:unit$1(a.itemSizeSM),input:Object.assign(Object.assign({},genInputSmallStyle(a)),{width:a.paginationMiniQuickJumperInputWidth,height:a.controlHeightSM})}}}},genPaginationSimpleStyle=a=>{const{componentCls:c}=a;return{[`
    &${c}-simple ${c}-prev,
    &${c}-simple ${c}-next
    `]:{height:a.itemSizeSM,lineHeight:unit$1(a.itemSizeSM),verticalAlign:"top",[`${c}-item-link`]:{height:a.itemSizeSM,backgroundColor:"transparent",border:0,"&:hover":{backgroundColor:a.colorBgTextHover},"&:active":{backgroundColor:a.colorBgTextActive},"&::after":{height:a.itemSizeSM,lineHeight:unit$1(a.itemSizeSM)}}},[`&${c}-simple ${c}-simple-pager`]:{display:"inline-block",height:a.itemSizeSM,marginInlineEnd:a.marginXS,input:{boxSizing:"border-box",height:"100%",padding:`0 ${unit$1(a.paginationItemPaddingInline)}`,textAlign:"center",backgroundColor:a.itemInputBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderRadius:a.borderRadius,outline:"none",transition:`border-color ${a.motionDurationMid}`,color:"inherit","&:hover":{borderColor:a.colorPrimary},"&:focus":{borderColor:a.colorPrimaryHover,boxShadow:`${unit$1(a.inputOutlineOffset)} 0 ${unit$1(a.controlOutlineWidth)} ${a.controlOutline}`},"&[disabled]":{color:a.colorTextDisabled,backgroundColor:a.colorBgContainerDisabled,borderColor:a.colorBorder,cursor:"not-allowed"}}}}},genPaginationJumpStyle=a=>{const{componentCls:c}=a;return{[`${c}-jump-prev, ${c}-jump-next`]:{outline:0,[`${c}-item-container`]:{position:"relative",[`${c}-item-link-icon`]:{color:a.colorPrimary,fontSize:a.fontSizeSM,opacity:0,transition:`all ${a.motionDurationMid}`,"&-svg":{top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,margin:"auto"}},[`${c}-item-ellipsis`]:{position:"absolute",top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,display:"block",margin:"auto",color:a.colorTextDisabled,letterSpacing:a.paginationEllipsisLetterSpacing,textAlign:"center",textIndent:a.paginationEllipsisTextIndent,opacity:1,transition:`all ${a.motionDurationMid}`}},"&:hover":{[`${c}-item-link-icon`]:{opacity:1},[`${c}-item-ellipsis`]:{opacity:0}}},[`
    ${c}-prev,
    ${c}-jump-prev,
    ${c}-jump-next
    `]:{marginInlineEnd:a.marginXS},[`
    ${c}-prev,
    ${c}-next,
    ${c}-jump-prev,
    ${c}-jump-next
    `]:{display:"inline-block",minWidth:a.itemSize,height:a.itemSize,color:a.colorText,fontFamily:a.fontFamily,lineHeight:unit$1(a.itemSize),textAlign:"center",verticalAlign:"middle",listStyle:"none",borderRadius:a.borderRadius,cursor:"pointer",transition:`all ${a.motionDurationMid}`},[`${c}-prev, ${c}-next`]:{outline:0,button:{color:a.colorText,cursor:"pointer",userSelect:"none"},[`${c}-item-link`]:{display:"block",width:"100%",height:"100%",padding:0,fontSize:a.fontSizeSM,textAlign:"center",backgroundColor:"transparent",border:`${unit$1(a.lineWidth)} ${a.lineType} transparent`,borderRadius:a.borderRadius,outline:"none",transition:`all ${a.motionDurationMid}`},[`&:hover ${c}-item-link`]:{backgroundColor:a.colorBgTextHover},[`&:active ${c}-item-link`]:{backgroundColor:a.colorBgTextActive},[`&${c}-disabled:hover`]:{[`${c}-item-link`]:{backgroundColor:"transparent"}}},[`${c}-slash`]:{marginInlineEnd:a.paginationSlashMarginInlineEnd,marginInlineStart:a.paginationSlashMarginInlineStart},[`${c}-options`]:{display:"inline-block",marginInlineStart:a.margin,verticalAlign:"middle","&-size-changer":{display:"inline-block",width:"auto"},"&-quick-jumper":{display:"inline-block",height:a.controlHeight,marginInlineStart:a.marginXS,lineHeight:unit$1(a.controlHeight),verticalAlign:"top",input:Object.assign(Object.assign(Object.assign({},genBasicInputStyle(a)),genBaseOutlinedStyle(a,{borderColor:a.colorBorder,hoverBorderColor:a.colorPrimaryHover,activeBorderColor:a.colorPrimary,activeShadow:a.activeShadow})),{"&[disabled]":Object.assign({},genDisabledStyle(a)),width:a.calc(a.controlHeightLG).mul(1.25).equal(),height:a.controlHeight,boxSizing:"border-box",margin:0,marginInlineStart:a.marginXS,marginInlineEnd:a.marginXS})}}}},genPaginationItemStyle=a=>{const{componentCls:c}=a;return{[`${c}-item`]:{display:"inline-block",minWidth:a.itemSize,height:a.itemSize,marginInlineEnd:a.marginXS,fontFamily:a.fontFamily,lineHeight:unit$1(a.calc(a.itemSize).sub(2).equal()),textAlign:"center",verticalAlign:"middle",listStyle:"none",backgroundColor:a.itemBg,border:`${unit$1(a.lineWidth)} ${a.lineType} transparent`,borderRadius:a.borderRadius,outline:0,cursor:"pointer",userSelect:"none",a:{display:"block",padding:`0 ${unit$1(a.paginationItemPaddingInline)}`,color:a.colorText,"&:hover":{textDecoration:"none"}},[`&:not(${c}-item-active)`]:{"&:hover":{transition:`all ${a.motionDurationMid}`,backgroundColor:a.colorBgTextHover},"&:active":{backgroundColor:a.colorBgTextActive}},"&-active":{fontWeight:a.fontWeightStrong,backgroundColor:a.itemActiveBg,borderColor:a.colorPrimary,a:{color:a.colorPrimary},"&:hover":{borderColor:a.colorPrimaryHover},"&:hover a":{color:a.colorPrimaryHover}}}}},genPaginationStyle$1=a=>{const{componentCls:c}=a;return{[c]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},resetComponent(a)),{display:"flex","&-start":{justifyContent:"start"},"&-center":{justifyContent:"center"},"&-end":{justifyContent:"end"},"ul, ol":{margin:0,padding:0,listStyle:"none"},"&::after":{display:"block",clear:"both",height:0,overflow:"hidden",visibility:"hidden",content:'""'},[`${c}-total-text`]:{display:"inline-block",height:a.itemSize,marginInlineEnd:a.marginXS,lineHeight:unit$1(a.calc(a.itemSize).sub(2).equal()),verticalAlign:"middle"}}),genPaginationItemStyle(a)),genPaginationJumpStyle(a)),genPaginationSimpleStyle(a)),genPaginationMiniStyle(a)),genPaginationDisabledStyle(a)),{[`@media only screen and (max-width: ${a.screenLG}px)`]:{[`${c}-item`]:{"&-after-jump-prev, &-before-jump-next":{display:"none"}}},[`@media only screen and (max-width: ${a.screenSM}px)`]:{[`${c}-options`]:{display:"none"}}}),[`&${a.componentCls}-rtl`]:{direction:"rtl"}}},genPaginationFocusStyle=a=>{const{componentCls:c}=a;return{[`${c}:not(${c}-disabled)`]:{[`${c}-item`]:Object.assign({},genFocusStyle(a)),[`${c}-jump-prev, ${c}-jump-next`]:{"&:focus-visible":Object.assign({[`${c}-item-link-icon`]:{opacity:1},[`${c}-item-ellipsis`]:{opacity:0}},genFocusOutline(a))},[`${c}-prev, ${c}-next`]:{[`&:focus-visible ${c}-item-link`]:Object.assign({},genFocusOutline(a))}}}},prepareComponentToken$6=a=>Object.assign({itemBg:a.colorBgContainer,itemSize:a.controlHeight,itemSizeSM:a.controlHeightSM,itemActiveBg:a.colorBgContainer,itemLinkBg:a.colorBgContainer,itemActiveColorDisabled:a.colorTextDisabled,itemActiveBgDisabled:a.controlItemBgActiveDisabled,itemInputBg:a.colorBgContainer,miniOptionsSizeChangerTop:0},initComponentToken$1(a)),prepareToken$1=a=>merge$2(a,{inputOutlineOffset:0,paginationMiniOptionsMarginInlineStart:a.calc(a.marginXXS).div(2).equal(),paginationMiniQuickJumperInputWidth:a.calc(a.controlHeightLG).mul(1.1).equal(),paginationItemPaddingInline:a.calc(a.marginXXS).mul(1.5).equal(),paginationEllipsisLetterSpacing:a.calc(a.marginXXS).div(2).equal(),paginationSlashMarginInlineStart:a.marginSM,paginationSlashMarginInlineEnd:a.marginSM,paginationEllipsisTextIndent:"0.13em"},initInputToken(a)),useStyle$6=genStyleHooks("Pagination",a=>{const c=prepareToken$1(a);return[genPaginationStyle$1(c),genPaginationFocusStyle(c)]},prepareComponentToken$6),genBorderedStyle$1=a=>{const{componentCls:c}=a;return{[`${c}${c}-bordered${c}-disabled:not(${c}-mini)`]:{"&, &:hover":{[`${c}-item-link`]:{borderColor:a.colorBorder}},"&:focus-visible":{[`${c}-item-link`]:{borderColor:a.colorBorder}},[`${c}-item, ${c}-item-link`]:{backgroundColor:a.colorBgContainerDisabled,borderColor:a.colorBorder,[`&:hover:not(${c}-item-active)`]:{backgroundColor:a.colorBgContainerDisabled,borderColor:a.colorBorder,a:{color:a.colorTextDisabled}},[`&${c}-item-active`]:{backgroundColor:a.itemActiveBgDisabled}},[`${c}-prev, ${c}-next`]:{"&:hover button":{backgroundColor:a.colorBgContainerDisabled,borderColor:a.colorBorder,color:a.colorTextDisabled},[`${c}-item-link`]:{backgroundColor:a.colorBgContainerDisabled,borderColor:a.colorBorder}}},[`${c}${c}-bordered:not(${c}-mini)`]:{[`${c}-prev, ${c}-next`]:{"&:hover button":{borderColor:a.colorPrimaryHover,backgroundColor:a.itemBg},[`${c}-item-link`]:{backgroundColor:a.itemLinkBg,borderColor:a.colorBorder},[`&:hover ${c}-item-link`]:{borderColor:a.colorPrimary,backgroundColor:a.itemBg,color:a.colorPrimary},[`&${c}-disabled`]:{[`${c}-item-link`]:{borderColor:a.colorBorder,color:a.colorTextDisabled}}},[`${c}-item`]:{backgroundColor:a.itemBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,[`&:hover:not(${c}-item-active)`]:{borderColor:a.colorPrimary,backgroundColor:a.itemBg,a:{color:a.colorPrimary}},"&-active":{borderColor:a.colorPrimary}}}}},BorderedStyle=genSubStyleComponent(["Pagination","bordered"],a=>{const c=prepareToken$1(a);return[genBorderedStyle$1(c)]},prepareComponentToken$6);function useShowSizeChanger(a){return reactExports.useMemo(()=>typeof a=="boolean"?[a,{}]:a&&typeof a=="object"?[!0,a]:[void 0,void 0],[a])}var __rest$c=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Pagination=a=>{const{align:c,prefixCls:u,selectPrefixCls:d,className:f,rootClassName:m,style:g,size:y,locale:b,responsive:E,showSizeChanger:C,selectComponentClass:w,pageSizeOptions:R}=a,_=__rest$c(a,["align","prefixCls","selectPrefixCls","className","rootClassName","style","size","locale","responsive","showSizeChanger","selectComponentClass","pageSizeOptions"]),{xs:M}=useBreakpoint(E),[,I]=useToken$1(),{getPrefixCls:N,direction:A,showSizeChanger:P,className:z,style:B}=useComponentConfig("pagination"),j=N("pagination",u),[L,U,q]=useStyle$6(j),F=useSize(y),K=F==="small"||!!(M&&!F&&E),[X]=useLocale("Pagination",locale$4),Q=Object.assign(Object.assign({},X),b),[Y,Z]=useShowSizeChanger(C),[J,W]=useShowSizeChanger(P),G=Y??J,te=Z??W,ae=w||Select,V=reactExports.useMemo(()=>R?R.map(ue=>Number(ue)):void 0,[R]),ne=ue=>{var me;const{disabled:de,size:ge,onSizeChange:Ce,"aria-label":ve,className:fe,options:pe}=ue,{className:xe,onChange:ye}=te||{},he=(me=pe.find(we=>String(we.value)===String(ge)))===null||me===void 0?void 0:me.value;return reactExports.createElement(ae,Object.assign({disabled:de,showSearch:!0,popupMatchSelectWidth:!1,getPopupContainer:we=>we.parentNode,"aria-label":ve,options:pe},te,{value:he,onChange:(we,Re)=>{Ce==null||Ce(we),ye==null||ye(we,Re)},size:K?"small":"middle",className:classNames(fe,xe)}))},le=reactExports.useMemo(()=>{const ue=reactExports.createElement("span",{className:`${j}-item-ellipsis`},"•••"),me=reactExports.createElement("button",{className:`${j}-item-link`,type:"button",tabIndex:-1},A==="rtl"?reactExports.createElement(RefIcon$8,null):reactExports.createElement(RefIcon$f,null)),de=reactExports.createElement("button",{className:`${j}-item-link`,type:"button",tabIndex:-1},A==="rtl"?reactExports.createElement(RefIcon$f,null):reactExports.createElement(RefIcon$8,null)),ge=reactExports.createElement("a",{className:`${j}-item-link`},reactExports.createElement("div",{className:`${j}-item-container`},A==="rtl"?reactExports.createElement(RefIcon$u,{className:`${j}-item-link-icon`}):reactExports.createElement(RefIcon$v,{className:`${j}-item-link-icon`}),ue)),Ce=reactExports.createElement("a",{className:`${j}-item-link`},reactExports.createElement("div",{className:`${j}-item-container`},A==="rtl"?reactExports.createElement(RefIcon$v,{className:`${j}-item-link-icon`}):reactExports.createElement(RefIcon$u,{className:`${j}-item-link-icon`}),ue));return{prevIcon:me,nextIcon:de,jumpPrevIcon:ge,jumpNextIcon:Ce}},[A,j]),ee=N("select",d),ie=classNames({[`${j}-${c}`]:!!c,[`${j}-mini`]:K,[`${j}-rtl`]:A==="rtl",[`${j}-bordered`]:I.wireframe},z,f,m,U,q),ce=Object.assign(Object.assign({},B),g);return L(reactExports.createElement(reactExports.Fragment,null,I.wireframe&&reactExports.createElement(BorderedStyle,{prefixCls:j}),reactExports.createElement(Pagination$1,Object.assign({},le,_,{style:ce,prefixCls:j,selectPrefixCls:ee,className:ie,locale:Q,pageSizeOptions:V,showSizeChanger:G,sizeChangerRender:ne}))))},viewSize=100,borderWidth=viewSize/5,radius=viewSize/2-borderWidth/2,circumference=radius*2*Math.PI,position$2=50,CustomCircle=a=>{const{dotClassName:c,style:u,hasCircleCls:d}=a;return reactExports.createElement("circle",{className:classNames(`${c}-circle`,{[`${c}-circle-bg`]:d}),r:radius,cx:position$2,cy:position$2,strokeWidth:borderWidth,style:u})},Progress=a=>{let{percent:c,prefixCls:u}=a;const d=`${u}-dot`,f=`${d}-holder`,m=`${f}-hidden`,[g,y]=reactExports.useState(!1);useLayoutEffect$1(()=>{c!==0&&y(!0)},[c!==0]);const b=Math.max(Math.min(c,100),0);if(!g)return null;const E={strokeDashoffset:`${circumference/4}`,strokeDasharray:`${circumference*b/100} ${circumference*(100-b)/100}`};return reactExports.createElement("span",{className:classNames(f,`${d}-progress`,b<=0&&m)},reactExports.createElement("svg",{viewBox:`0 0 ${viewSize} ${viewSize}`,role:"progressbar","aria-valuemin":0,"aria-valuemax":100,"aria-valuenow":b},reactExports.createElement(CustomCircle,{dotClassName:d,hasCircleCls:!0}),reactExports.createElement(CustomCircle,{dotClassName:d,style:E})))};function Looper(a){const{prefixCls:c,percent:u=0}=a,d=`${c}-dot`,f=`${d}-holder`,m=`${f}-hidden`;return reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("span",{className:classNames(f,u>0&&m)},reactExports.createElement("span",{className:classNames(d,`${c}-dot-spin`)},[1,2,3,4].map(g=>reactExports.createElement("i",{className:`${c}-dot-item`,key:g})))),reactExports.createElement(Progress,{prefixCls:c,percent:u}))}function Indicator(a){const{prefixCls:c,indicator:u,percent:d}=a,f=`${c}-dot`;return u&&reactExports.isValidElement(u)?cloneElement(u,{className:classNames(u.props.className,f),percent:d}):reactExports.createElement(Looper,{prefixCls:c,percent:d})}const antSpinMove=new Keyframe("antSpinMove",{to:{opacity:1}}),antRotate=new Keyframe("antRotate",{to:{transform:"rotate(405deg)"}}),genSpinStyle=a=>{const{componentCls:c,calc:u}=a;return{[c]:Object.assign(Object.assign({},resetComponent(a)),{position:"absolute",display:"none",color:a.colorPrimary,fontSize:0,textAlign:"center",verticalAlign:"middle",opacity:0,transition:`transform ${a.motionDurationSlow} ${a.motionEaseInOutCirc}`,"&-spinning":{position:"relative",display:"inline-block",opacity:1},[`${c}-text`]:{fontSize:a.fontSize,paddingTop:u(u(a.dotSize).sub(a.fontSize)).div(2).add(2).equal()},"&-fullscreen":{position:"fixed",width:"100vw",height:"100vh",backgroundColor:a.colorBgMask,zIndex:a.zIndexPopupBase,inset:0,display:"flex",alignItems:"center",flexDirection:"column",justifyContent:"center",opacity:0,visibility:"hidden",transition:`all ${a.motionDurationMid}`,"&-show":{opacity:1,visibility:"visible"},[c]:{[`${c}-dot-holder`]:{color:a.colorWhite},[`${c}-text`]:{color:a.colorTextLightSolid}}},"&-nested-loading":{position:"relative",[`> div > ${c}`]:{position:"absolute",top:0,insetInlineStart:0,zIndex:4,display:"block",width:"100%",height:"100%",maxHeight:a.contentHeight,[`${c}-dot`]:{position:"absolute",top:"50%",insetInlineStart:"50%",margin:u(a.dotSize).mul(-1).div(2).equal()},[`${c}-text`]:{position:"absolute",top:"50%",width:"100%",textShadow:`0 1px 2px ${a.colorBgContainer}`},[`&${c}-show-text ${c}-dot`]:{marginTop:u(a.dotSize).div(2).mul(-1).sub(10).equal()},"&-sm":{[`${c}-dot`]:{margin:u(a.dotSizeSM).mul(-1).div(2).equal()},[`${c}-text`]:{paddingTop:u(u(a.dotSizeSM).sub(a.fontSize)).div(2).add(2).equal()},[`&${c}-show-text ${c}-dot`]:{marginTop:u(a.dotSizeSM).div(2).mul(-1).sub(10).equal()}},"&-lg":{[`${c}-dot`]:{margin:u(a.dotSizeLG).mul(-1).div(2).equal()},[`${c}-text`]:{paddingTop:u(u(a.dotSizeLG).sub(a.fontSize)).div(2).add(2).equal()},[`&${c}-show-text ${c}-dot`]:{marginTop:u(a.dotSizeLG).div(2).mul(-1).sub(10).equal()}}},[`${c}-container`]:{position:"relative",transition:`opacity ${a.motionDurationSlow}`,"&::after":{position:"absolute",top:0,insetInlineEnd:0,bottom:0,insetInlineStart:0,zIndex:10,width:"100%",height:"100%",background:a.colorBgContainer,opacity:0,transition:`all ${a.motionDurationSlow}`,content:'""',pointerEvents:"none"}},[`${c}-blur`]:{clear:"both",opacity:.5,userSelect:"none",pointerEvents:"none","&::after":{opacity:.4,pointerEvents:"auto"}}},"&-tip":{color:a.spinDotDefault},[`${c}-dot-holder`]:{width:"1em",height:"1em",fontSize:a.dotSize,display:"inline-block",transition:`transform ${a.motionDurationSlow} ease, opacity ${a.motionDurationSlow} ease`,transformOrigin:"50% 50%",lineHeight:1,color:a.colorPrimary,"&-hidden":{transform:"scale(0.3)",opacity:0}},[`${c}-dot-progress`]:{position:"absolute",inset:0},[`${c}-dot`]:{position:"relative",display:"inline-block",fontSize:a.dotSize,width:"1em",height:"1em","&-item":{position:"absolute",display:"block",width:u(a.dotSize).sub(u(a.marginXXS).div(2)).div(2).equal(),height:u(a.dotSize).sub(u(a.marginXXS).div(2)).div(2).equal(),background:"currentColor",borderRadius:"100%",transform:"scale(0.75)",transformOrigin:"50% 50%",opacity:.3,animationName:antSpinMove,animationDuration:"1s",animationIterationCount:"infinite",animationTimingFunction:"linear",animationDirection:"alternate","&:nth-child(1)":{top:0,insetInlineStart:0,animationDelay:"0s"},"&:nth-child(2)":{top:0,insetInlineEnd:0,animationDelay:"0.4s"},"&:nth-child(3)":{insetInlineEnd:0,bottom:0,animationDelay:"0.8s"},"&:nth-child(4)":{bottom:0,insetInlineStart:0,animationDelay:"1.2s"}},"&-spin":{transform:"rotate(45deg)",animationName:antRotate,animationDuration:"1.2s",animationIterationCount:"infinite",animationTimingFunction:"linear"},"&-circle":{strokeLinecap:"round",transition:["stroke-dashoffset","stroke-dasharray","stroke","stroke-width","opacity"].map(d=>`${d} ${a.motionDurationSlow} ease`).join(","),fillOpacity:0,stroke:"currentcolor"},"&-circle-bg":{stroke:a.colorFillSecondary}},[`&-sm ${c}-dot`]:{"&, &-holder":{fontSize:a.dotSizeSM}},[`&-sm ${c}-dot-holder`]:{i:{width:u(u(a.dotSizeSM).sub(u(a.marginXXS).div(2))).div(2).equal(),height:u(u(a.dotSizeSM).sub(u(a.marginXXS).div(2))).div(2).equal()}},[`&-lg ${c}-dot`]:{"&, &-holder":{fontSize:a.dotSizeLG}},[`&-lg ${c}-dot-holder`]:{i:{width:u(u(a.dotSizeLG).sub(a.marginXXS)).div(2).equal(),height:u(u(a.dotSizeLG).sub(a.marginXXS)).div(2).equal()}},[`&${c}-show-text ${c}-text`]:{display:"block"}})}},prepareComponentToken$5=a=>{const{controlHeightLG:c,controlHeight:u}=a;return{contentHeight:400,dotSize:c/2,dotSizeSM:c*.35,dotSizeLG:u}},useStyle$5=genStyleHooks("Spin",a=>{const c=merge$2(a,{spinDotDefault:a.colorTextDescription});return[genSpinStyle(c)]},prepareComponentToken$5),AUTO_INTERVAL=200,STEP_BUCKETS=[[30,.05],[70,.03],[96,.01]];function usePercent(a,c){const[u,d]=reactExports.useState(0),f=reactExports.useRef(null),m=c==="auto";return reactExports.useEffect(()=>(m&&a&&(d(0),f.current=setInterval(()=>{d(g=>{const y=100-g;for(let b=0;b<STEP_BUCKETS.length;b+=1){const[E,C]=STEP_BUCKETS[b];if(g<=E)return g+y*C}return g})},AUTO_INTERVAL)),()=>{clearInterval(f.current)}),[m,a]),m?u:c}var __rest$b=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};let defaultIndicator;function shouldDelay(a,c){return!!a&&!!c&&!Number.isNaN(Number(c))}const Spin=a=>{var c;const{prefixCls:u,spinning:d=!0,delay:f=0,className:m,rootClassName:g,size:y="default",tip:b,wrapperClassName:E,style:C,children:w,fullscreen:R=!1,indicator:_,percent:M}=a,I=__rest$b(a,["prefixCls","spinning","delay","className","rootClassName","size","tip","wrapperClassName","style","children","fullscreen","indicator","percent"]),{getPrefixCls:N,direction:A,className:P,style:z,indicator:B}=useComponentConfig("spin"),j=N("spin",u),[L,U,q]=useStyle$5(j),[F,K]=reactExports.useState(()=>d&&!shouldDelay(d,f)),X=usePercent(F,M);reactExports.useEffect(()=>{if(d){const te=debounce(f,()=>{K(!0)});return te(),()=>{var ae;(ae=te==null?void 0:te.cancel)===null||ae===void 0||ae.call(te)}}K(!1)},[f,d]);const Q=reactExports.useMemo(()=>typeof w<"u"&&!R,[w,R]),Y=classNames(j,P,{[`${j}-sm`]:y==="small",[`${j}-lg`]:y==="large",[`${j}-spinning`]:F,[`${j}-show-text`]:!!b,[`${j}-rtl`]:A==="rtl"},m,!R&&g,U,q),Z=classNames(`${j}-container`,{[`${j}-blur`]:F}),J=(c=_??B)!==null&&c!==void 0?c:defaultIndicator,W=Object.assign(Object.assign({},z),C),G=reactExports.createElement("div",Object.assign({},I,{style:W,className:Y,"aria-live":"polite","aria-busy":F}),reactExports.createElement(Indicator,{prefixCls:j,indicator:J,percent:X}),b&&(Q||R)?reactExports.createElement("div",{className:`${j}-text`},b):null);return L(Q?reactExports.createElement("div",Object.assign({},I,{className:classNames(`${j}-nested-loading`,E,U,q)}),F&&reactExports.createElement("div",{key:"loading"},G),reactExports.createElement("div",{className:Z,key:"container"},w)):R?reactExports.createElement("div",{className:classNames(`${j}-fullscreen`,{[`${j}-fullscreen-show`]:F},g,U,q)},G):G)};Spin.setDefaultIndicator=a=>{defaultIndicator=a};const toList$1=function(a){return(arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1)&&a==null?[]:Array.isArray(a)?a:[a]};let message=null,act=a=>a(),taskQueue=[],defaultGlobalConfig={};function getGlobalContext(){const{getContainer:a,duration:c,rtl:u,maxCount:d,top:f}=defaultGlobalConfig,m=(a==null?void 0:a())||document.body;return{getContainer:()=>m,duration:c,rtl:u,maxCount:d,top:f}}const GlobalHolder=React.forwardRef((a,c)=>{const{messageConfig:u,sync:d}=a,{getPrefixCls:f}=reactExports.useContext(ConfigContext),m=defaultGlobalConfig.prefixCls||f("message"),g=reactExports.useContext(AppConfigContext),[y,b]=useInternalMessage(Object.assign(Object.assign(Object.assign({},u),{prefixCls:m}),g.message));return React.useImperativeHandle(c,()=>{const E=Object.assign({},y);return Object.keys(E).forEach(C=>{E[C]=function(){return d(),y[C].apply(y,arguments)}}),{instance:E,sync:d}}),b}),GlobalHolderWrapper=React.forwardRef((a,c)=>{const[u,d]=React.useState(getGlobalContext),f=()=>{d(getGlobalContext)};React.useEffect(f,[]);const m=globalConfig(),g=m.getRootPrefixCls(),y=m.getIconPrefixCls(),b=m.getTheme(),E=React.createElement(GlobalHolder,{ref:c,sync:f,messageConfig:u});return React.createElement(ConfigProvider,{prefixCls:g,iconPrefixCls:y,theme:b},m.holderRender?m.holderRender(E):E)});function flushNotice(){if(!message){const a=document.createDocumentFragment(),c={fragment:a};message=c,act(()=>{getReactRender()(React.createElement(GlobalHolderWrapper,{ref:d=>{const{instance:f,sync:m}=d||{};Promise.resolve().then(()=>{!c.instance&&f&&(c.instance=f,c.sync=m,flushNotice())})}}),a)});return}message.instance&&(taskQueue.forEach(a=>{const{type:c,skipped:u}=a;if(!u)switch(c){case"open":{act(()=>{const d=message.instance.open(Object.assign(Object.assign({},defaultGlobalConfig),a.config));d==null||d.then(a.resolve),a.setCloseFn(d)});break}case"destroy":act(()=>{message==null||message.instance.destroy(a.key)});break;default:act(()=>{var d;const f=(d=message.instance)[c].apply(d,_toConsumableArray(a.args));f==null||f.then(a.resolve),a.setCloseFn(f)})}}),taskQueue=[])}function setMessageGlobalConfig(a){defaultGlobalConfig=Object.assign(Object.assign({},defaultGlobalConfig),a),act(()=>{var c;(c=message==null?void 0:message.sync)===null||c===void 0||c.call(message)})}function open$1(a){const c=wrapPromiseFn(u=>{let d;const f={type:"open",config:a,resolve:u,setCloseFn:m=>{d=m}};return taskQueue.push(f),()=>{d?act(()=>{d()}):f.skipped=!0}});return flushNotice(),c}function typeOpen(a,c){const u=wrapPromiseFn(d=>{let f;const m={type:a,args:c,resolve:d,setCloseFn:g=>{f=g}};return taskQueue.push(m),()=>{f?act(()=>{f()}):m.skipped=!0}});return flushNotice(),u}const destroy=a=>{taskQueue.push({type:"destroy",key:a}),flushNotice()},methods=["success","info","warning","error","loading"],baseStaticMethods={open:open$1,destroy,config:setMessageGlobalConfig,useMessage,_InternalPanelDoNotUseOrYouWillBeFired:PurePanel$5},staticMethods=baseStaticMethods;methods.forEach(a=>{staticMethods[a]=function(){for(var c=arguments.length,u=new Array(c),d=0;d<c;d++)u[d]=arguments[d];return typeOpen(a,u)}});const genBaseStyle$2=a=>{const{componentCls:c,iconCls:u,antCls:d,zIndexPopup:f,colorText:m,colorWarning:g,marginXXS:y,marginXS:b,fontSize:E,fontWeightStrong:C,colorTextHeading:w}=a;return{[c]:{zIndex:f,[`&${d}-popover`]:{fontSize:E},[`${c}-message`]:{marginBottom:b,display:"flex",flexWrap:"nowrap",alignItems:"start",[`> ${c}-message-icon ${u}`]:{color:g,fontSize:E,lineHeight:1,marginInlineEnd:b},[`${c}-title`]:{fontWeight:C,color:w,"&:only-child":{fontWeight:"normal"}},[`${c}-description`]:{marginTop:y,color:m}},[`${c}-buttons`]:{textAlign:"end",whiteSpace:"nowrap",button:{marginInlineStart:b}}}}},prepareComponentToken$4=a=>{const{zIndexPopupBase:c}=a;return{zIndexPopup:c+60}},useStyle$4=genStyleHooks("Popconfirm",a=>genBaseStyle$2(a),prepareComponentToken$4,{resetStyle:!1});var __rest$a=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Overlay=a=>{const{prefixCls:c,okButtonProps:u,cancelButtonProps:d,title:f,description:m,cancelText:g,okText:y,okType:b="primary",icon:E=reactExports.createElement(RefIcon$p,null),showCancel:C=!0,close:w,onConfirm:R,onCancel:_,onPopupClick:M}=a,{getPrefixCls:I}=reactExports.useContext(ConfigContext),[N]=useLocale("Popconfirm",localeValues.Popconfirm),A=getRenderPropValue(f),P=getRenderPropValue(m);return reactExports.createElement("div",{className:`${c}-inner-content`,onClick:M},reactExports.createElement("div",{className:`${c}-message`},E&&reactExports.createElement("span",{className:`${c}-message-icon`},E),reactExports.createElement("div",{className:`${c}-message-text`},A&&reactExports.createElement("div",{className:`${c}-title`},A),P&&reactExports.createElement("div",{className:`${c}-description`},P))),reactExports.createElement("div",{className:`${c}-buttons`},C&&reactExports.createElement(Button$1,Object.assign({onClick:_,size:"small"},d),g||(N==null?void 0:N.cancelText)),reactExports.createElement(ActionButton,{buttonProps:Object.assign(Object.assign({size:"small"},convertLegacyProps(b)),u),actionFn:R,close:w,prefixCls:I("btn"),quitOnNullishReturnValue:!0,emitEvent:!0},y||(N==null?void 0:N.okText))))},PurePanel=a=>{const{prefixCls:c,placement:u,className:d,style:f}=a,m=__rest$a(a,["prefixCls","placement","className","style"]),{getPrefixCls:g}=reactExports.useContext(ConfigContext),y=g("popconfirm",c),[b]=useStyle$4(y);return b(reactExports.createElement(PurePanel$2,{placement:u,className:classNames(y,d),style:f,content:reactExports.createElement(Overlay,Object.assign({prefixCls:y},m))}))};var __rest$9=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalPopconfirm=reactExports.forwardRef((a,c)=>{var u,d;const{prefixCls:f,placement:m="top",trigger:g="click",okType:y="primary",icon:b=reactExports.createElement(RefIcon$p,null),children:E,overlayClassName:C,onOpenChange:w,onVisibleChange:R,overlayStyle:_,styles:M,classNames:I}=a,N=__rest$9(a,["prefixCls","placement","trigger","okType","icon","children","overlayClassName","onOpenChange","onVisibleChange","overlayStyle","styles","classNames"]),{getPrefixCls:A,className:P,style:z,classNames:B,styles:j}=useComponentConfig("popconfirm"),[L,U]=useMergedState(!1,{value:(u=a.open)!==null&&u!==void 0?u:a.visible,defaultValue:(d=a.defaultOpen)!==null&&d!==void 0?d:a.defaultVisible}),q=(G,te)=>{U(G,!0),R==null||R(G),w==null||w(G,te)},F=G=>{q(!1,G)},K=G=>{var te;return(te=a.onConfirm)===null||te===void 0?void 0:te.call(void 0,G)},X=G=>{var te;q(!1,G),(te=a.onCancel)===null||te===void 0||te.call(void 0,G)},Q=(G,te)=>{const{disabled:ae=!1}=a;ae||q(G,te)},Y=A("popconfirm",f),Z=classNames(Y,P,C,B.root,I==null?void 0:I.root),J=classNames(B.body,I==null?void 0:I.body),[W]=useStyle$4(Y);return W(reactExports.createElement(Popover,Object.assign({},omit(N,["title"]),{trigger:g,placement:m,onOpenChange:Q,open:L,ref:c,classNames:{root:Z,body:J},styles:{root:Object.assign(Object.assign(Object.assign(Object.assign({},j.root),z),_),M==null?void 0:M.root),body:Object.assign(Object.assign({},j.body),M==null?void 0:M.body)},content:reactExports.createElement(Overlay,Object.assign({okType:y,icon:b},a,{prefixCls:Y,close:F,onConfirm:K,onCancel:X})),"data-popover-inject":!0}),E))}),Popconfirm=InternalPopconfirm;Popconfirm._InternalPanelDoNotUseOrYouWillBeFired=PurePanel;var EXPAND_COLUMN={},INTERNAL_HOOKS="rc-table-internal-hook";function createContext(a){var c=reactExports.createContext(void 0),u=function(f){var m=f.value,g=f.children,y=reactExports.useRef(m);y.current=m;var b=reactExports.useState(function(){return{getValue:function(){return y.current},listeners:new Set}}),E=_slicedToArray(b,1),C=E[0];return useLayoutEffect$1(function(){reactDomExports.unstable_batchedUpdates(function(){C.listeners.forEach(function(w){w(m)})})},[m]),reactExports.createElement(c.Provider,{value:C},g)};return{Context:c,Provider:u,defaultValue:a}}function useContext(a,c){var u=useEvent(typeof c=="function"?c:function(w){if(c===void 0)return w;if(!Array.isArray(c))return w[c];var R={};return c.forEach(function(_){R[_]=w[_]}),R}),d=reactExports.useContext(a==null?void 0:a.Context),f=d||{},m=f.listeners,g=f.getValue,y=reactExports.useRef();y.current=u(d?g():a==null?void 0:a.defaultValue);var b=reactExports.useState({}),E=_slicedToArray(b,2),C=E[1];return useLayoutEffect$1(function(){if(!d)return;function w(R){var _=u(R);isEqual(y.current,_,!0)||C({})}return m.add(w),function(){m.delete(w)}},[d]),y.current}function createImmutable(){var a=reactExports.createContext(null);function c(){return reactExports.useContext(a)}function u(f,m){var g=supportRef(f),y=function(E,C){var w=g?{ref:C}:{},R=reactExports.useRef(0),_=reactExports.useRef(E),M=c();return M!==null?reactExports.createElement(f,_extends({},E,w)):((!m||m(_.current,E))&&(R.current+=1),_.current=E,reactExports.createElement(a.Provider,{value:R.current},reactExports.createElement(f,_extends({},E,w))))};return g?reactExports.forwardRef(y):y}function d(f,m){var g=supportRef(f),y=function(E,C){var w=g?{ref:C}:{};return c(),reactExports.createElement(f,_extends({},E,w))};return g?reactExports.memo(reactExports.forwardRef(y),m):reactExports.memo(y,m)}return{makeImmutable:u,responseImmutable:d,useImmutableMark:c}}var _createImmutable=createImmutable(),makeImmutable=_createImmutable.makeImmutable,responseImmutable=_createImmutable.responseImmutable,useImmutableMark=_createImmutable.useImmutableMark,TableContext=createContext(),PerfContext=reactExports.createContext({renderWithProps:!1}),INTERNAL_KEY_PREFIX="RC_TABLE_KEY";function toArray$1(a){return a==null?[]:Array.isArray(a)?a:[a]}function getColumnsKey(a){var c=[],u={};return a.forEach(function(d){for(var f=d||{},m=f.key,g=f.dataIndex,y=m||toArray$1(g).join("-")||INTERNAL_KEY_PREFIX;u[y];)y="".concat(y,"_next");u[y]=!0,c.push(y)}),c}function validateValue(a){return a!=null}function validNumberValue(a){return typeof a=="number"&&!Number.isNaN(a)}function isRenderCell(a){return a&&_typeof(a)==="object"&&!Array.isArray(a)&&!reactExports.isValidElement(a)}function useCellRender(a,c,u,d,f,m){var g=reactExports.useContext(PerfContext),y=useImmutableMark(),b=useMemo(function(){if(validateValue(d))return[d];var E=c==null||c===""?[]:Array.isArray(c)?c:[c],C=get(a,E),w=C,R=void 0;if(f){var _=f(C,a,u);isRenderCell(_)?(w=_.children,R=_.props,g.renderWithProps=!0):w=_}return[w,R]},[y,a,d,c,f,u],function(E,C){if(m){var w=_slicedToArray(E,2),R=w[1],_=_slicedToArray(C,2),M=_[1];return m(M,R)}return g.renderWithProps?!0:!isEqual(E,C,!0)});return b}function inHoverRange(a,c,u,d){var f=a+c-1;return a<=d&&f>=u}function useHoverState(a,c){return useContext(TableContext,function(u){var d=inHoverRange(a,c||1,u.hoverStartRow,u.hoverEndRow);return[d,u.onHover]})}var getTitleFromCellRenderChildren=function(c){var u=c.ellipsis,d=c.rowType,f=c.children,m,g=u===!0?{showTitle:!0}:u;return g&&(g.showTitle||d==="header")&&(typeof f=="string"||typeof f=="number"?m=f.toString():reactExports.isValidElement(f)&&typeof f.props.children=="string"&&(m=f.props.children)),m};function Cell(a){var c,u,d,f,m,g,y,b,E=a.component,C=a.children,w=a.ellipsis,R=a.scope,_=a.prefixCls,M=a.className,I=a.align,N=a.record,A=a.render,P=a.dataIndex,z=a.renderIndex,B=a.shouldCellUpdate,j=a.index,L=a.rowType,U=a.colSpan,q=a.rowSpan,F=a.fixLeft,K=a.fixRight,X=a.firstFixLeft,Q=a.lastFixLeft,Y=a.firstFixRight,Z=a.lastFixRight,J=a.appendNode,W=a.additionalProps,G=W===void 0?{}:W,te=a.isSticky,ae="".concat(_,"-cell"),V=useContext(TableContext,["supportSticky","allColumnsFixedLeft","rowHoverable"]),ne=V.supportSticky,le=V.allColumnsFixedLeft,ee=V.rowHoverable,ie=useCellRender(N,P,z,C,A,B),ce=_slicedToArray(ie,2),ue=ce[0],me=ce[1],de={},ge=typeof F=="number"&&ne,Ce=typeof K=="number"&&ne;ge&&(de.position="sticky",de.left=F),Ce&&(de.position="sticky",de.right=K);var ve=(c=(u=(d=me==null?void 0:me.colSpan)!==null&&d!==void 0?d:G.colSpan)!==null&&u!==void 0?u:U)!==null&&c!==void 0?c:1,fe=(f=(m=(g=me==null?void 0:me.rowSpan)!==null&&g!==void 0?g:G.rowSpan)!==null&&m!==void 0?m:q)!==null&&f!==void 0?f:1,pe=useHoverState(j,fe),xe=_slicedToArray(pe,2),ye=xe[0],he=xe[1],we=useEvent(function(ke){var Ke;N&&he(j,j+fe-1),G==null||(Ke=G.onMouseEnter)===null||Ke===void 0||Ke.call(G,ke)}),Re=useEvent(function(ke){var Ke;N&&he(-1,-1),G==null||(Ke=G.onMouseLeave)===null||Ke===void 0||Ke.call(G,ke)});if(ve===0||fe===0)return null;var De=(y=G.title)!==null&&y!==void 0?y:getTitleFromCellRenderChildren({rowType:L,ellipsis:w,children:ue}),Ae=classNames(ae,M,(b={},_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(b,"".concat(ae,"-fix-left"),ge&&ne),"".concat(ae,"-fix-left-first"),X&&ne),"".concat(ae,"-fix-left-last"),Q&&ne),"".concat(ae,"-fix-left-all"),Q&&le&&ne),"".concat(ae,"-fix-right"),Ce&&ne),"".concat(ae,"-fix-right-first"),Y&&ne),"".concat(ae,"-fix-right-last"),Z&&ne),"".concat(ae,"-ellipsis"),w),"".concat(ae,"-with-append"),J),"".concat(ae,"-fix-sticky"),(ge||Ce)&&te&&ne),_defineProperty(b,"".concat(ae,"-row-hover"),!me&&ye)),G.className,me==null?void 0:me.className),Ee={};I&&(Ee.textAlign=I);var Ne=_objectSpread2(_objectSpread2(_objectSpread2(_objectSpread2({},me==null?void 0:me.style),de),Ee),G.style),_e=ue;return _typeof(_e)==="object"&&!Array.isArray(_e)&&!reactExports.isValidElement(_e)&&(_e=null),w&&(Q||Y)&&(_e=reactExports.createElement("span",{className:"".concat(ae,"-content")},_e)),reactExports.createElement(E,_extends({},me,G,{className:Ae,style:Ne,title:De,scope:R,onMouseEnter:ee?we:void 0,onMouseLeave:ee?Re:void 0,colSpan:ve!==1?ve:null,rowSpan:fe!==1?fe:null}),J,_e)}const Cell$1=reactExports.memo(Cell);function getCellFixedInfo(a,c,u,d,f){var m=u[a]||{},g=u[c]||{},y,b;m.fixed==="left"?y=d.left[f==="rtl"?c:a]:g.fixed==="right"&&(b=d.right[f==="rtl"?a:c]);var E=!1,C=!1,w=!1,R=!1,_=u[c+1],M=u[a-1],I=_&&!_.fixed||M&&!M.fixed||u.every(function(B){return B.fixed==="left"});if(f==="rtl"){if(y!==void 0){var N=M&&M.fixed==="left";R=!N&&I}else if(b!==void 0){var A=_&&_.fixed==="right";w=!A&&I}}else if(y!==void 0){var P=_&&_.fixed==="left";E=!P&&I}else if(b!==void 0){var z=M&&M.fixed==="right";C=!z&&I}return{fixLeft:y,fixRight:b,lastFixLeft:E,firstFixRight:C,lastFixRight:w,firstFixLeft:R,isSticky:d.isSticky}}var SummaryContext=reactExports.createContext({});function SummaryCell(a){var c=a.className,u=a.index,d=a.children,f=a.colSpan,m=f===void 0?1:f,g=a.rowSpan,y=a.align,b=useContext(TableContext,["prefixCls","direction"]),E=b.prefixCls,C=b.direction,w=reactExports.useContext(SummaryContext),R=w.scrollColumnIndex,_=w.stickyOffsets,M=w.flattenColumns,I=u+m-1,N=I+1===R?m+1:m,A=getCellFixedInfo(u,u+N-1,M,_,C);return reactExports.createElement(Cell$1,_extends({className:c,index:u,component:"td",prefixCls:E,record:null,dataIndex:null,align:y,colSpan:N,rowSpan:g,render:function(){return d}},A))}var _excluded$8=["children"];function FooterRow(a){var c=a.children,u=_objectWithoutProperties(a,_excluded$8);return reactExports.createElement("tr",u,c)}function Summary(a){var c=a.children;return c}Summary.Row=FooterRow;Summary.Cell=SummaryCell;function Footer(a){var c=a.children,u=a.stickyOffsets,d=a.flattenColumns,f=useContext(TableContext,"prefixCls"),m=d.length-1,g=d[m],y=reactExports.useMemo(function(){return{stickyOffsets:u,flattenColumns:d,scrollColumnIndex:g!=null&&g.scrollbar?m:null}},[g,d,m,u]);return reactExports.createElement(SummaryContext.Provider,{value:y},reactExports.createElement("tfoot",{className:"".concat(f,"-summary")},c))}const Footer$1=responseImmutable(Footer);var FooterComponents=Summary;function Column$1(a){return null}function ColumnGroup$1(a){return null}function fillRecords(a,c,u,d,f,m,g){a.push({record:c,indent:u,index:g});var y=m(c),b=f==null?void 0:f.has(y);if(c&&Array.isArray(c[d])&&b)for(var E=0;E<c[d].length;E+=1)fillRecords(a,c[d][E],u+1,d,f,m,E)}function useFlattenRecords(a,c,u,d){var f=reactExports.useMemo(function(){if(u!=null&&u.size){for(var m=[],g=0;g<(a==null?void 0:a.length);g+=1){var y=a[g];fillRecords(m,y,0,c,u,d,g)}return m}return a==null?void 0:a.map(function(b,E){return{record:b,indent:0,index:E}})},[a,c,u,d]);return f}function useRowInfo(a,c,u,d){var f=useContext(TableContext,["prefixCls","fixedInfoList","flattenColumns","expandableType","expandRowByClick","onTriggerExpand","rowClassName","expandedRowClassName","indentSize","expandIcon","expandedRowRender","expandIconColumnIndex","expandedKeys","childrenColumnName","rowExpandable","onRow"]),m=f.flattenColumns,g=f.expandableType,y=f.expandedKeys,b=f.childrenColumnName,E=f.onTriggerExpand,C=f.rowExpandable,w=f.onRow,R=f.expandRowByClick,_=f.rowClassName,M=g==="nest",I=g==="row"&&(!C||C(a)),N=I||M,A=y&&y.has(c),P=b&&a&&a[b],z=useEvent(E),B=w==null?void 0:w(a,u),j=B==null?void 0:B.onClick,L=function(K){R&&N&&E(a,K);for(var X=arguments.length,Q=new Array(X>1?X-1:0),Y=1;Y<X;Y++)Q[Y-1]=arguments[Y];j==null||j.apply(void 0,[K].concat(Q))},U;typeof _=="string"?U=_:typeof _=="function"&&(U=_(a,u,d));var q=getColumnsKey(m);return _objectSpread2(_objectSpread2({},f),{},{columnsKey:q,nestExpandable:M,expanded:A,hasNestChildren:P,record:a,onTriggerExpand:z,rowSupportExpand:I,expandable:N,rowProps:_objectSpread2(_objectSpread2({},B),{},{className:classNames(U,B==null?void 0:B.className),onClick:L})})}function ExpandedRow(a){var c=a.prefixCls,u=a.children,d=a.component,f=a.cellComponent,m=a.className,g=a.expanded,y=a.colSpan,b=a.isEmpty,E=useContext(TableContext,["scrollbarSize","fixHeader","fixColumn","componentWidth","horizonScroll"]),C=E.scrollbarSize,w=E.fixHeader,R=E.fixColumn,_=E.componentWidth,M=E.horizonScroll,I=u;return(b?M&&_:R)&&(I=reactExports.createElement("div",{style:{width:_-(w&&!b?C:0),position:"sticky",left:0,overflow:"hidden"},className:"".concat(c,"-expanded-row-fixed")},I)),reactExports.createElement(d,{className:m,style:{display:g?null:"none"}},reactExports.createElement(Cell$1,{component:f,prefixCls:c,colSpan:y},I))}function renderExpandIcon$1(a){var c=a.prefixCls,u=a.record,d=a.onExpand,f=a.expanded,m=a.expandable,g="".concat(c,"-row-expand-icon");if(!m)return reactExports.createElement("span",{className:classNames(g,"".concat(c,"-row-spaced"))});var y=function(E){d(u,E),E.stopPropagation()};return reactExports.createElement("span",{className:classNames(g,_defineProperty(_defineProperty({},"".concat(c,"-row-expanded"),f),"".concat(c,"-row-collapsed"),!f)),onClick:y})}function findAllChildrenKeys(a,c,u){var d=[];function f(m){(m||[]).forEach(function(g,y){d.push(c(g,y)),f(g[u])})}return f(a),d}function computedExpandedClassName(a,c,u,d){return typeof a=="string"?a:typeof a=="function"?a(c,u,d):""}function getCellProps(a,c,u,d,f){var m=a.record,g=a.prefixCls,y=a.columnsKey,b=a.fixedInfoList,E=a.expandIconColumnIndex,C=a.nestExpandable,w=a.indentSize,R=a.expandIcon,_=a.expanded,M=a.hasNestChildren,I=a.onTriggerExpand,N=y[u],A=b[u],P;u===(E||0)&&C&&(P=reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("span",{style:{paddingLeft:"".concat(w*d,"px")},className:"".concat(g,"-row-indent indent-level-").concat(d)}),R({prefixCls:g,expanded:_,expandable:M,record:m,onExpand:I})));var z;return c.onCell&&(z=c.onCell(m,f)),{key:N,fixedInfo:A,appendCellNode:P,additionalCellProps:z||{}}}function BodyRow(a){var c=a.className,u=a.style,d=a.record,f=a.index,m=a.renderIndex,g=a.rowKey,y=a.indent,b=y===void 0?0:y,E=a.rowComponent,C=a.cellComponent,w=a.scopeCellComponent,R=useRowInfo(d,g,f,b),_=R.prefixCls,M=R.flattenColumns,I=R.expandedRowClassName,N=R.expandedRowRender,A=R.rowProps,P=R.expanded,z=R.rowSupportExpand,B=reactExports.useRef(!1);B.current||(B.current=P);var j=computedExpandedClassName(I,d,f,b),L=reactExports.createElement(E,_extends({},A,{"data-row-key":g,className:classNames(c,"".concat(_,"-row"),"".concat(_,"-row-level-").concat(b),A==null?void 0:A.className,_defineProperty({},j,b>=1)),style:_objectSpread2(_objectSpread2({},u),A==null?void 0:A.style)}),M.map(function(F,K){var X=F.render,Q=F.dataIndex,Y=F.className,Z=getCellProps(R,F,K,b,f),J=Z.key,W=Z.fixedInfo,G=Z.appendCellNode,te=Z.additionalCellProps;return reactExports.createElement(Cell$1,_extends({className:Y,ellipsis:F.ellipsis,align:F.align,scope:F.rowScope,component:F.rowScope?w:C,prefixCls:_,key:J,record:d,index:f,renderIndex:m,dataIndex:Q,render:X,shouldCellUpdate:F.shouldCellUpdate},W,{appendNode:G,additionalProps:te}))})),U;if(z&&(B.current||P)){var q=N(d,f,b+1,P);U=reactExports.createElement(ExpandedRow,{expanded:P,className:classNames("".concat(_,"-expanded-row"),"".concat(_,"-expanded-row-level-").concat(b+1),j),prefixCls:_,component:E,cellComponent:C,colSpan:M.length,isEmpty:!1},q)}return reactExports.createElement(reactExports.Fragment,null,L,U)}const BodyRow$1=responseImmutable(BodyRow);function MeasureCell(a){var c=a.columnKey,u=a.onColumnResize,d=reactExports.useRef();return reactExports.useEffect(function(){d.current&&u(c,d.current.offsetWidth)},[]),reactExports.createElement(RefResizeObserver,{data:c},reactExports.createElement("td",{ref:d,style:{padding:0,border:0,height:0}},reactExports.createElement("div",{style:{height:0,overflow:"hidden"}}," ")))}function MeasureRow(a){var c=a.prefixCls,u=a.columnsKey,d=a.onColumnResize;return reactExports.createElement("tr",{"aria-hidden":"true",className:"".concat(c,"-measure-row"),style:{height:0,fontSize:0}},reactExports.createElement(RefResizeObserver.Collection,{onBatchResize:function(m){m.forEach(function(g){var y=g.data,b=g.size;d(y,b.offsetWidth)})}},u.map(function(f){return reactExports.createElement(MeasureCell,{key:f,columnKey:f,onColumnResize:d})})))}function Body(a){var c=a.data,u=a.measureColumnWidth,d=useContext(TableContext,["prefixCls","getComponent","onColumnResize","flattenColumns","getRowKey","expandedKeys","childrenColumnName","emptyNode"]),f=d.prefixCls,m=d.getComponent,g=d.onColumnResize,y=d.flattenColumns,b=d.getRowKey,E=d.expandedKeys,C=d.childrenColumnName,w=d.emptyNode,R=useFlattenRecords(c,C,E,b),_=reactExports.useRef({renderWithProps:!1}),M=m(["body","wrapper"],"tbody"),I=m(["body","row"],"tr"),N=m(["body","cell"],"td"),A=m(["body","cell"],"th"),P;c.length?P=R.map(function(B,j){var L=B.record,U=B.indent,q=B.index,F=b(L,j);return reactExports.createElement(BodyRow$1,{key:F,rowKey:F,record:L,index:j,renderIndex:q,rowComponent:I,cellComponent:N,scopeCellComponent:A,indent:U})}):P=reactExports.createElement(ExpandedRow,{expanded:!0,className:"".concat(f,"-placeholder"),prefixCls:f,component:I,cellComponent:N,colSpan:y.length,isEmpty:!0},w);var z=getColumnsKey(y);return reactExports.createElement(PerfContext.Provider,{value:_.current},reactExports.createElement(M,{className:"".concat(f,"-tbody")},u&&reactExports.createElement(MeasureRow,{prefixCls:f,columnsKey:z,onColumnResize:g}),P))}const Body$1=responseImmutable(Body);var _excluded$7=["expandable"],INTERNAL_COL_DEFINE="RC_TABLE_INTERNAL_COL_DEFINE";function getExpandableProps(a){var c=a.expandable,u=_objectWithoutProperties(a,_excluded$7),d;return"expandable"in a?d=_objectSpread2(_objectSpread2({},u),c):d=u,d.showExpandColumn===!1&&(d.expandIconColumnIndex=-1),d}var _excluded$6=["columnType"];function ColGroup(a){for(var c=a.colWidths,u=a.columns,d=a.columCount,f=useContext(TableContext,["tableLayout"]),m=f.tableLayout,g=[],y=d||u.length,b=!1,E=y-1;E>=0;E-=1){var C=c[E],w=u&&u[E],R=void 0,_=void 0;if(w&&(R=w[INTERNAL_COL_DEFINE],m==="auto"&&(_=w.minWidth)),C||_||R||b){var M=R||{};M.columnType;var I=_objectWithoutProperties(M,_excluded$6);g.unshift(reactExports.createElement("col",_extends({key:E,style:{width:C,minWidth:_}},I))),b=!0}}return reactExports.createElement("colgroup",null,g)}var _excluded$5=["className","noData","columns","flattenColumns","colWidths","columCount","stickyOffsets","direction","fixHeader","stickyTopOffset","stickyBottomOffset","stickyClassName","onScroll","maxContentScroll","children"];function useColumnWidth(a,c){return reactExports.useMemo(function(){for(var u=[],d=0;d<c;d+=1){var f=a[d];if(f!==void 0)u[d]=f;else return null}return u},[a.join("_"),c])}var FixedHolder=reactExports.forwardRef(function(a,c){var u=a.className,d=a.noData,f=a.columns,m=a.flattenColumns,g=a.colWidths,y=a.columCount,b=a.stickyOffsets,E=a.direction,C=a.fixHeader,w=a.stickyTopOffset,R=a.stickyBottomOffset,_=a.stickyClassName,M=a.onScroll,I=a.maxContentScroll,N=a.children,A=_objectWithoutProperties(a,_excluded$5),P=useContext(TableContext,["prefixCls","scrollbarSize","isSticky","getComponent"]),z=P.prefixCls,B=P.scrollbarSize,j=P.isSticky,L=P.getComponent,U=L(["header","table"],"table"),q=j&&!C?0:B,F=reactExports.useRef(null),K=reactExports.useCallback(function(te){fillRef(c,te),fillRef(F,te)},[]);reactExports.useEffect(function(){var te;function ae(V){var ne=V,le=ne.currentTarget,ee=ne.deltaX;ee&&(M({currentTarget:le,scrollLeft:le.scrollLeft+ee}),V.preventDefault())}return(te=F.current)===null||te===void 0||te.addEventListener("wheel",ae,{passive:!1}),function(){var V;(V=F.current)===null||V===void 0||V.removeEventListener("wheel",ae)}},[]);var X=reactExports.useMemo(function(){return m.every(function(te){return te.width})},[m]),Q=m[m.length-1],Y={fixed:Q?Q.fixed:null,scrollbar:!0,onHeaderCell:function(){return{className:"".concat(z,"-cell-scrollbar")}}},Z=reactExports.useMemo(function(){return q?[].concat(_toConsumableArray(f),[Y]):f},[q,f]),J=reactExports.useMemo(function(){return q?[].concat(_toConsumableArray(m),[Y]):m},[q,m]),W=reactExports.useMemo(function(){var te=b.right,ae=b.left;return _objectSpread2(_objectSpread2({},b),{},{left:E==="rtl"?[].concat(_toConsumableArray(ae.map(function(V){return V+q})),[0]):ae,right:E==="rtl"?te:[].concat(_toConsumableArray(te.map(function(V){return V+q})),[0]),isSticky:j})},[q,b,j]),G=useColumnWidth(g,y);return reactExports.createElement("div",{style:_objectSpread2({overflow:"hidden"},j?{top:w,bottom:R}:{}),ref:K,className:classNames(u,_defineProperty({},_,!!_))},reactExports.createElement(U,{style:{tableLayout:"fixed",visibility:d||G?null:"hidden"}},(!d||!I||X)&&reactExports.createElement(ColGroup,{colWidths:G?[].concat(_toConsumableArray(G),[q]):[],columCount:y+1,columns:J}),N(_objectSpread2(_objectSpread2({},A),{},{stickyOffsets:W,columns:Z,flattenColumns:J}))))});const FixedHolder$1=reactExports.memo(FixedHolder);var HeaderRow=function(c){var u=c.cells,d=c.stickyOffsets,f=c.flattenColumns,m=c.rowComponent,g=c.cellComponent,y=c.onHeaderRow,b=c.index,E=useContext(TableContext,["prefixCls","direction"]),C=E.prefixCls,w=E.direction,R;y&&(R=y(u.map(function(M){return M.column}),b));var _=getColumnsKey(u.map(function(M){return M.column}));return reactExports.createElement(m,R,u.map(function(M,I){var N=M.column,A=getCellFixedInfo(M.colStart,M.colEnd,f,d,w),P;return N&&N.onHeaderCell&&(P=M.column.onHeaderCell(N)),reactExports.createElement(Cell$1,_extends({},M,{scope:N.title?M.colSpan>1?"colgroup":"col":null,ellipsis:N.ellipsis,align:N.align,component:g,prefixCls:C,key:_[I]},A,{additionalProps:P,rowType:"header"}))}))};function parseHeaderRows(a){var c=[];function u(g,y){var b=arguments.length>2&&arguments[2]!==void 0?arguments[2]:0;c[b]=c[b]||[];var E=y,C=g.filter(Boolean).map(function(w){var R={key:w.key,className:w.className||"",children:w.title,column:w,colStart:E},_=1,M=w.children;return M&&M.length>0&&(_=u(M,E,b+1).reduce(function(I,N){return I+N},0),R.hasSubColumns=!0),"colSpan"in w&&(_=w.colSpan),"rowSpan"in w&&(R.rowSpan=w.rowSpan),R.colSpan=_,R.colEnd=R.colStart+_-1,c[b].push(R),E+=_,_});return C}u(a,0);for(var d=c.length,f=function(y){c[y].forEach(function(b){!("rowSpan"in b)&&!b.hasSubColumns&&(b.rowSpan=d-y)})},m=0;m<d;m+=1)f(m);return c}var Header=function(c){var u=c.stickyOffsets,d=c.columns,f=c.flattenColumns,m=c.onHeaderRow,g=useContext(TableContext,["prefixCls","getComponent"]),y=g.prefixCls,b=g.getComponent,E=reactExports.useMemo(function(){return parseHeaderRows(d)},[d]),C=b(["header","wrapper"],"thead"),w=b(["header","row"],"tr"),R=b(["header","cell"],"th");return reactExports.createElement(C,{className:"".concat(y,"-thead")},E.map(function(_,M){var I=reactExports.createElement(HeaderRow,{key:M,flattenColumns:f,cells:_,stickyOffsets:u,rowComponent:w,cellComponent:R,onHeaderRow:m,index:M});return I}))};const Header$1=responseImmutable(Header);function parseColWidth(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"";return typeof c=="number"?c:c.endsWith("%")?a*parseFloat(c)/100:null}function useWidthColumns(a,c,u){return reactExports.useMemo(function(){if(c&&c>0){var d=0,f=0;a.forEach(function(R){var _=parseColWidth(c,R.width);_?d+=_:f+=1});var m=Math.max(c,u),g=Math.max(m-d,f),y=f,b=g/f,E=0,C=a.map(function(R){var _=_objectSpread2({},R),M=parseColWidth(c,_.width);if(M)_.width=M;else{var I=Math.floor(b);_.width=y===1?g:I,g-=I,y-=1}return E+=_.width,_});if(E<m){var w=m/E;g=m,C.forEach(function(R,_){var M=Math.floor(R.width*w);R.width=_===C.length-1?g:M,g-=M})}return[C,Math.max(E,m)]}return[a,c]},[a,c,u])}var _excluded$4=["children"],_excluded2=["fixed"];function convertChildrenToColumns(a){return toArray$6(a).filter(function(c){return reactExports.isValidElement(c)}).map(function(c){var u=c.key,d=c.props,f=d.children,m=_objectWithoutProperties(d,_excluded$4),g=_objectSpread2({key:u},m);return f&&(g.children=convertChildrenToColumns(f)),g})}function filterHiddenColumns(a){return a.filter(function(c){return c&&_typeof(c)==="object"&&!c.hidden}).map(function(c){var u=c.children;return u&&u.length>0?_objectSpread2(_objectSpread2({},c),{},{children:filterHiddenColumns(u)}):c})}function flatColumns(a){var c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:"key";return a.filter(function(u){return u&&_typeof(u)==="object"}).reduce(function(u,d,f){var m=d.fixed,g=m===!0?"left":m,y="".concat(c,"-").concat(f),b=d.children;return b&&b.length>0?[].concat(_toConsumableArray(u),_toConsumableArray(flatColumns(b,y).map(function(E){return _objectSpread2({fixed:g},E)}))):[].concat(_toConsumableArray(u),[_objectSpread2(_objectSpread2({key:y},d),{},{fixed:g})])},[])}function revertForRtl(a){return a.map(function(c){var u=c.fixed,d=_objectWithoutProperties(c,_excluded2),f=u;return u==="left"?f="right":u==="right"&&(f="left"),_objectSpread2({fixed:f},d)})}function useColumns(a,c){var u=a.prefixCls,d=a.columns,f=a.children,m=a.expandable,g=a.expandedKeys,y=a.columnTitle,b=a.getRowKey,E=a.onTriggerExpand,C=a.expandIcon,w=a.rowExpandable,R=a.expandIconColumnIndex,_=a.direction,M=a.expandRowByClick,I=a.columnWidth,N=a.fixed,A=a.scrollWidth,P=a.clientWidth,z=reactExports.useMemo(function(){var Q=d||convertChildrenToColumns(f)||[];return filterHiddenColumns(Q.slice())},[d,f]),B=reactExports.useMemo(function(){if(m){var Q=z.slice();if(!Q.includes(EXPAND_COLUMN)){var Y=R||0;Y>=0&&(Y||N==="left"||!N)&&Q.splice(Y,0,EXPAND_COLUMN),N==="right"&&Q.splice(z.length,0,EXPAND_COLUMN)}var Z=Q.indexOf(EXPAND_COLUMN);Q=Q.filter(function(te,ae){return te!==EXPAND_COLUMN||ae===Z});var J=z[Z],W;N?W=N:W=J?J.fixed:null;var G=_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},INTERNAL_COL_DEFINE,{className:"".concat(u,"-expand-icon-col"),columnType:"EXPAND_COLUMN"}),"title",y),"fixed",W),"className","".concat(u,"-row-expand-icon-cell")),"width",I),"render",function(ae,V,ne){var le=b(V,ne),ee=g.has(le),ie=w?w(V):!0,ce=C({prefixCls:u,expanded:ee,expandable:ie,record:V,onExpand:E});return M?reactExports.createElement("span",{onClick:function(me){return me.stopPropagation()}},ce):ce});return Q.map(function(te){return te===EXPAND_COLUMN?G:te})}return z.filter(function(te){return te!==EXPAND_COLUMN})},[m,z,b,g,C,_]),j=reactExports.useMemo(function(){var Q=B;return c&&(Q=c(Q)),Q.length||(Q=[{render:function(){return null}}]),Q},[c,B,_]),L=reactExports.useMemo(function(){return _==="rtl"?revertForRtl(flatColumns(j)):flatColumns(j)},[j,_,A]),U=reactExports.useMemo(function(){for(var Q=-1,Y=L.length-1;Y>=0;Y-=1){var Z=L[Y].fixed;if(Z==="left"||Z===!0){Q=Y;break}}if(Q>=0)for(var J=0;J<=Q;J+=1){var W=L[J].fixed;if(W!=="left"&&W!==!0)return!0}var G=L.findIndex(function(V){var ne=V.fixed;return ne==="right"});if(G>=0)for(var te=G;te<L.length;te+=1){var ae=L[te].fixed;if(ae!=="right")return!0}return!1},[L]),q=useWidthColumns(L,A,P),F=_slicedToArray(q,2),K=F[0],X=F[1];return[j,K,X,U]}function useExpand(a,c,u){var d=getExpandableProps(a),f=d.expandIcon,m=d.expandedRowKeys,g=d.defaultExpandedRowKeys,y=d.defaultExpandAllRows,b=d.expandedRowRender,E=d.onExpand,C=d.onExpandedRowsChange,w=d.childrenColumnName,R=f||renderExpandIcon$1,_=w||"children",M=reactExports.useMemo(function(){return b?"row":a.expandable&&a.internalHooks===INTERNAL_HOOKS&&a.expandable.__PARENT_RENDER_ICON__||c.some(function(j){return j&&_typeof(j)==="object"&&j[_]})?"nest":!1},[!!b,c]),I=reactExports.useState(function(){return g||(y?findAllChildrenKeys(c,u,_):[])}),N=_slicedToArray(I,2),A=N[0],P=N[1],z=reactExports.useMemo(function(){return new Set(m||A||[])},[m,A]),B=reactExports.useCallback(function(j){var L=u(j,c.indexOf(j)),U,q=z.has(L);q?(z.delete(L),U=_toConsumableArray(z)):U=[].concat(_toConsumableArray(z),[L]),P(U),E&&E(!q,j),C&&C(U)},[u,z,c,E,C]);return[d,M,z,R,_,B]}function useFixedInfo(a,c,u){var d=a.map(function(f,m){return getCellFixedInfo(m,m,a,c,u)});return useMemo(function(){return d},[d],function(f,m){return!isEqual(f,m)})}function useLayoutState(a){var c=reactExports.useRef(a),u=reactExports.useState({}),d=_slicedToArray(u,2),f=d[1],m=reactExports.useRef(null),g=reactExports.useRef([]);function y(b){g.current.push(b);var E=Promise.resolve();m.current=E,E.then(function(){if(m.current===E){var C=g.current,w=c.current;g.current=[],C.forEach(function(R){c.current=R(c.current)}),m.current=null,w!==c.current&&f({})}})}return reactExports.useEffect(function(){return function(){m.current=null}},[]),[c.current,y]}function useTimeoutLock(a){var c=reactExports.useRef(null),u=reactExports.useRef();function d(){window.clearTimeout(u.current)}function f(g){c.current=g,d(),u.current=window.setTimeout(function(){c.current=null,u.current=void 0},100)}function m(){return c.current}return reactExports.useEffect(function(){return d},[]),[f,m]}function useHover(){var a=reactExports.useState(-1),c=_slicedToArray(a,2),u=c[0],d=c[1],f=reactExports.useState(-1),m=_slicedToArray(f,2),g=m[0],y=m[1],b=reactExports.useCallback(function(E,C){d(E),y(C)},[]);return[u,g,b]}var defaultContainer=canUseDom()?window:null;function useSticky(a,c){var u=_typeof(a)==="object"?a:{},d=u.offsetHeader,f=d===void 0?0:d,m=u.offsetSummary,g=m===void 0?0:m,y=u.offsetScroll,b=y===void 0?0:y,E=u.getContainer,C=E===void 0?function(){return defaultContainer}:E,w=C()||defaultContainer,R=!!a;return reactExports.useMemo(function(){return{isSticky:R,stickyClassName:R?"".concat(c,"-sticky-holder"):"",offsetHeader:f,offsetSummary:g,offsetScroll:b,container:w}},[R,b,f,g,c,w])}function useStickyOffsets(a,c,u){var d=reactExports.useMemo(function(){var f=c.length,m=function(E,C,w){for(var R=[],_=0,M=E;M!==C;M+=w)R.push(_),c[M].fixed&&(_+=a[M]||0);return R},g=m(0,f,1),y=m(f-1,-1,-1).reverse();return u==="rtl"?{left:y,right:g}:{left:g,right:y}},[a,c,u]);return d}function Panel(a){var c=a.className,u=a.children;return reactExports.createElement("div",{className:c},u)}function getOffset(a){var c=getDOM(a),u=c.getBoundingClientRect(),d=document.documentElement;return{left:u.left+(window.pageXOffset||d.scrollLeft)-(d.clientLeft||document.body.clientLeft||0),top:u.top+(window.pageYOffset||d.scrollTop)-(d.clientTop||document.body.clientTop||0)}}var StickyScrollBar=function(c,u){var d,f,m=c.scrollBodyRef,g=c.onScroll,y=c.offsetScroll,b=c.container,E=c.direction,C=useContext(TableContext,"prefixCls"),w=((d=m.current)===null||d===void 0?void 0:d.scrollWidth)||0,R=((f=m.current)===null||f===void 0?void 0:f.clientWidth)||0,_=w&&R*(R/w),M=reactExports.useRef(),I=useLayoutState({scrollLeft:0,isHiddenScrollBar:!0}),N=_slicedToArray(I,2),A=N[0],P=N[1],z=reactExports.useRef({delta:0,x:0}),B=reactExports.useState(!1),j=_slicedToArray(B,2),L=j[0],U=j[1],q=reactExports.useRef(null);reactExports.useEffect(function(){return function(){wrapperRaf.cancel(q.current)}},[]);var F=function(){U(!1)},K=function(J){J.persist(),z.current.delta=J.pageX-A.scrollLeft,z.current.x=0,U(!0),J.preventDefault()},X=function(J){var W,G=J||((W=window)===null||W===void 0?void 0:W.event),te=G.buttons;if(!L||te===0){L&&U(!1);return}var ae=z.current.x+J.pageX-z.current.x-z.current.delta,V=E==="rtl";ae=Math.max(V?_-R:0,Math.min(V?0:R-_,ae));var ne=!V||Math.abs(ae)+Math.abs(_)<R;ne&&(g({scrollLeft:ae/R*(w+2)}),z.current.x=J.pageX)},Q=function(){wrapperRaf.cancel(q.current),q.current=wrapperRaf(function(){if(m.current){var J=getOffset(m.current).top,W=J+m.current.offsetHeight,G=b===window?document.documentElement.scrollTop+window.innerHeight:getOffset(b).top+b.clientHeight;W-getScrollBarSize()<=G||J>=G-y?P(function(te){return _objectSpread2(_objectSpread2({},te),{},{isHiddenScrollBar:!0})}):P(function(te){return _objectSpread2(_objectSpread2({},te),{},{isHiddenScrollBar:!1})})}})},Y=function(J){P(function(W){return _objectSpread2(_objectSpread2({},W),{},{scrollLeft:J/w*R||0})})};return reactExports.useImperativeHandle(u,function(){return{setScrollLeft:Y,checkScrollBarVisible:Q}}),reactExports.useEffect(function(){var Z=addEventListenerWrap(document.body,"mouseup",F,!1),J=addEventListenerWrap(document.body,"mousemove",X,!1);return Q(),function(){Z.remove(),J.remove()}},[_,L]),reactExports.useEffect(function(){if(m.current){for(var Z=[],J=getDOM(m.current);J;)Z.push(J),J=J.parentElement;return Z.forEach(function(W){return W.addEventListener("scroll",Q,!1)}),window.addEventListener("resize",Q,!1),window.addEventListener("scroll",Q,!1),b.addEventListener("scroll",Q,!1),function(){Z.forEach(function(W){return W.removeEventListener("scroll",Q)}),window.removeEventListener("resize",Q),window.removeEventListener("scroll",Q),b.removeEventListener("scroll",Q)}}},[b]),reactExports.useEffect(function(){A.isHiddenScrollBar||P(function(Z){var J=m.current;return J?_objectSpread2(_objectSpread2({},Z),{},{scrollLeft:J.scrollLeft/J.scrollWidth*J.clientWidth}):Z})},[A.isHiddenScrollBar]),w<=R||!_||A.isHiddenScrollBar?null:reactExports.createElement("div",{style:{height:getScrollBarSize(),width:R,bottom:y},className:"".concat(C,"-sticky-scroll")},reactExports.createElement("div",{onMouseDown:K,ref:M,className:classNames("".concat(C,"-sticky-scroll-bar"),_defineProperty({},"".concat(C,"-sticky-scroll-bar-active"),L)),style:{width:"".concat(_,"px"),transform:"translate3d(".concat(A.scrollLeft,"px, 0, 0)")}}))};const StickyScrollBar$1=reactExports.forwardRef(StickyScrollBar);var DEFAULT_PREFIX="rc-table",EMPTY_DATA=[],EMPTY_SCROLL_TARGET={};function defaultEmpty(){return"No Data"}function Table$1(a,c){var u=_objectSpread2({rowKey:"key",prefixCls:DEFAULT_PREFIX,emptyText:defaultEmpty},a),d=u.prefixCls,f=u.className,m=u.rowClassName,g=u.style,y=u.data,b=u.rowKey,E=u.scroll,C=u.tableLayout,w=u.direction,R=u.title,_=u.footer,M=u.summary,I=u.caption,N=u.id,A=u.showHeader,P=u.components,z=u.emptyText,B=u.onRow,j=u.onHeaderRow,L=u.onScroll,U=u.internalHooks,q=u.transformColumns,F=u.internalRefs,K=u.tailor,X=u.getContainerWidth,Q=u.sticky,Y=u.rowHoverable,Z=Y===void 0?!0:Y,J=y||EMPTY_DATA,W=!!J.length,G=U===INTERNAL_HOOKS,te=reactExports.useCallback(function(Pt,It){return get(P,Pt)||It},[P]),ae=reactExports.useMemo(function(){return typeof b=="function"?b:function(Pt){var It=Pt&&Pt[b];return It}},[b]),V=te(["body"]),ne=useHover(),le=_slicedToArray(ne,3),ee=le[0],ie=le[1],ce=le[2],ue=useExpand(u,J,ae),me=_slicedToArray(ue,6),de=me[0],ge=me[1],Ce=me[2],ve=me[3],fe=me[4],pe=me[5],xe=E==null?void 0:E.x,ye=reactExports.useState(0),he=_slicedToArray(ye,2),we=he[0],Re=he[1],De=useColumns(_objectSpread2(_objectSpread2(_objectSpread2({},u),de),{},{expandable:!!de.expandedRowRender,columnTitle:de.columnTitle,expandedKeys:Ce,getRowKey:ae,onTriggerExpand:pe,expandIcon:ve,expandIconColumnIndex:de.expandIconColumnIndex,direction:w,scrollWidth:G&&K&&typeof xe=="number"?xe:null,clientWidth:we}),G?q:null),Ae=_slicedToArray(De,4),Ee=Ae[0],Ne=Ae[1],_e=Ae[2],ke=Ae[3],Ke=_e??xe,be=reactExports.useMemo(function(){return{columns:Ee,flattenColumns:Ne}},[Ee,Ne]),Te=reactExports.useRef(),Le=reactExports.useRef(),Oe=reactExports.useRef(),Be=reactExports.useRef();reactExports.useImperativeHandle(c,function(){return{nativeElement:Te.current,scrollTo:function(It){var Or;if(Oe.current instanceof HTMLElement){var vr=It.index,yr=It.top,Gr=It.key;if(validNumberValue(yr)){var Lr;(Lr=Oe.current)===null||Lr===void 0||Lr.scrollTo({top:yr})}else{var Mr,Ur=Gr??ae(J[vr]);(Mr=Oe.current.querySelector('[data-row-key="'.concat(Ur,'"]')))===null||Mr===void 0||Mr.scrollIntoView()}}else(Or=Oe.current)!==null&&Or!==void 0&&Or.scrollTo&&Oe.current.scrollTo(It)}}});var Ve=reactExports.useRef(),Pe=reactExports.useState(!1),Ge=_slicedToArray(Pe,2),qe=Ge[0],Ue=Ge[1],je=reactExports.useState(!1),We=_slicedToArray(je,2),ut=We[0],gt=We[1],kt=useLayoutState(new Map),Ut=_slicedToArray(kt,2),at=Ut[0],ct=Ut[1],bt=getColumnsKey(Ne),it=bt.map(function(Pt){return at.get(Pt)}),vt=reactExports.useMemo(function(){return it},[it.join("_")]),ot=useStickyOffsets(vt,Ne,w),rt=E&&validateValue(E.y),et=E&&validateValue(Ke)||!!de.fixed,$t=et&&Ne.some(function(Pt){var It=Pt.fixed;return It}),mt=reactExports.useRef(),Ze=useSticky(Q,d),Je=Ze.isSticky,yt=Ze.offsetHeader,Ct=Ze.offsetSummary,pt=Ze.offsetScroll,Rt=Ze.stickyClassName,ft=Ze.container,dt=reactExports.useMemo(function(){return M==null?void 0:M(J)},[M,J]),xt=(rt||Je)&&reactExports.isValidElement(dt)&&dt.type===Summary&&dt.props.fixed,Tt,Dt,Vt;rt&&(Dt={overflowY:W?"scroll":"auto",maxHeight:E.y}),et&&(Tt={overflowX:"auto"},rt||(Dt={overflowY:"hidden"}),Vt={width:Ke===!0?"auto":Ke,minWidth:"100%"});var Nt=reactExports.useCallback(function(Pt,It){isVisible(Te.current)&&ct(function(Or){if(Or.get(Pt)!==It){var vr=new Map(Or);return vr.set(Pt,It),vr}return Or})},[]),Kt=useTimeoutLock(),Zt=_slicedToArray(Kt,2),Gt=Zt[0],tt=Zt[1];function ht(Pt,It){It&&(typeof It=="function"?It(Pt):It.scrollLeft!==Pt&&(It.scrollLeft=Pt,It.scrollLeft!==Pt&&setTimeout(function(){It.scrollLeft=Pt},0)))}var lt=useEvent(function(Pt){var It=Pt.currentTarget,Or=Pt.scrollLeft,vr=w==="rtl",yr=typeof Or=="number"?Or:It.scrollLeft,Gr=It||EMPTY_SCROLL_TARGET;if(!tt()||tt()===Gr){var Lr;Gt(Gr),ht(yr,Le.current),ht(yr,Oe.current),ht(yr,Ve.current),ht(yr,(Lr=mt.current)===null||Lr===void 0?void 0:Lr.setScrollLeft)}var Mr=It||Le.current;if(Mr){var Ur=G&&K&&typeof Ke=="number"?Ke:Mr.scrollWidth,Cn=Mr.clientWidth;if(Ur===Cn){Ue(!1),gt(!1);return}vr?(Ue(-yr<Ur-Cn),gt(-yr>0)):(Ue(yr>0),gt(yr<Ur-Cn))}}),nt=useEvent(function(Pt){lt(Pt),L==null||L(Pt)}),Ot=function(){if(et&&Oe.current){var It;lt({currentTarget:getDOM(Oe.current),scrollLeft:(It=Oe.current)===null||It===void 0?void 0:It.scrollLeft})}else Ue(!1),gt(!1)},Bt=function(It){var Or,vr=It.width;(Or=mt.current)===null||Or===void 0||Or.checkScrollBarVisible();var yr=Te.current?Te.current.offsetWidth:vr;G&&X&&Te.current&&(yr=X(Te.current,yr)||yr),yr!==we&&(Ot(),Re(yr))},qt=reactExports.useRef(!1);reactExports.useEffect(function(){qt.current&&Ot()},[et,y,Ee.length]),reactExports.useEffect(function(){qt.current=!0},[]);var er=reactExports.useState(0),St=_slicedToArray(er,2),_t=St[0],zt=St[1],nr=reactExports.useState(!0),Rr=_slicedToArray(nr,2),Jr=Rr[0],Tr=Rr[1];reactExports.useEffect(function(){(!K||!G)&&(Oe.current instanceof Element?zt(getTargetScrollBarSize(Oe.current).width):zt(getTargetScrollBarSize(Be.current).width)),Tr(isStyleSupport("position","sticky"))},[]),reactExports.useEffect(function(){G&&F&&(F.body.current=Oe.current)});var lr=reactExports.useCallback(function(Pt){return reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(Header$1,Pt),xt==="top"&&reactExports.createElement(Footer$1,Pt,dt))},[xt,dt]),en=reactExports.useCallback(function(Pt){return reactExports.createElement(Footer$1,Pt,dt)},[dt]),tn=te(["table"],"table"),wr=reactExports.useMemo(function(){return C||($t?Ke==="max-content"?"auto":"fixed":rt||Je||Ne.some(function(Pt){var It=Pt.ellipsis;return It})?"fixed":"auto")},[rt,$t,Ne,C,Je]),rn,Wt={colWidths:vt,columCount:Ne.length,stickyOffsets:ot,onHeaderRow:j,fixHeader:rt,scroll:E},wt=reactExports.useMemo(function(){return W?null:typeof z=="function"?z():z},[W,z]),st=reactExports.createElement(Body$1,{data:J,measureColumnWidth:rt||et||Je}),Xt=reactExports.createElement(ColGroup,{colWidths:Ne.map(function(Pt){var It=Pt.width;return It}),columns:Ne}),Qt=I!=null?reactExports.createElement("caption",{className:"".concat(d,"-caption")},I):void 0,or=pickAttrs(u,{data:!0}),ar=pickAttrs(u,{aria:!0});if(rt||Je){var Ir;typeof V=="function"?(Ir=V(J,{scrollbarSize:_t,ref:Oe,onScroll:lt}),Wt.colWidths=Ne.map(function(Pt,It){var Or=Pt.width,vr=It===Ne.length-1?Or-_t:Or;return typeof vr=="number"&&!Number.isNaN(vr)?vr:0})):Ir=reactExports.createElement("div",{style:_objectSpread2(_objectSpread2({},Tt),Dt),onScroll:nt,ref:Oe,className:classNames("".concat(d,"-body"))},reactExports.createElement(tn,_extends({style:_objectSpread2(_objectSpread2({},Vt),{},{tableLayout:wr})},ar),Qt,Xt,st,!xt&&dt&&reactExports.createElement(Footer$1,{stickyOffsets:ot,flattenColumns:Ne},dt)));var _r=_objectSpread2(_objectSpread2(_objectSpread2({noData:!J.length,maxContentScroll:et&&Ke==="max-content"},Wt),be),{},{direction:w,stickyClassName:Rt,onScroll:lt});rn=reactExports.createElement(reactExports.Fragment,null,A!==!1&&reactExports.createElement(FixedHolder$1,_extends({},_r,{stickyTopOffset:yt,className:"".concat(d,"-header"),ref:Le}),lr),Ir,xt&&xt!=="top"&&reactExports.createElement(FixedHolder$1,_extends({},_r,{stickyBottomOffset:Ct,className:"".concat(d,"-summary"),ref:Ve}),en),Je&&Oe.current&&Oe.current instanceof Element&&reactExports.createElement(StickyScrollBar$1,{ref:mt,offsetScroll:pt,scrollBodyRef:Oe,onScroll:lt,container:ft,direction:w}))}else rn=reactExports.createElement("div",{style:_objectSpread2(_objectSpread2({},Tt),Dt),className:classNames("".concat(d,"-content")),onScroll:lt,ref:Oe},reactExports.createElement(tn,_extends({style:_objectSpread2(_objectSpread2({},Vt),{},{tableLayout:wr})},ar),Qt,Xt,A!==!1&&reactExports.createElement(Header$1,_extends({},Wt,be)),st,dt&&reactExports.createElement(Footer$1,{stickyOffsets:ot,flattenColumns:Ne},dt)));var Sr=reactExports.createElement("div",_extends({className:classNames(d,f,_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty({},"".concat(d,"-rtl"),w==="rtl"),"".concat(d,"-ping-left"),qe),"".concat(d,"-ping-right"),ut),"".concat(d,"-layout-fixed"),C==="fixed"),"".concat(d,"-fixed-header"),rt),"".concat(d,"-fixed-column"),$t),"".concat(d,"-fixed-column-gapped"),$t&&ke),"".concat(d,"-scroll-horizontal"),et),"".concat(d,"-has-fix-left"),Ne[0]&&Ne[0].fixed),"".concat(d,"-has-fix-right"),Ne[Ne.length-1]&&Ne[Ne.length-1].fixed==="right")),style:g,id:N,ref:Te},or),R&&reactExports.createElement(Panel,{className:"".concat(d,"-title")},R(J)),reactExports.createElement("div",{ref:Be,className:"".concat(d,"-container")},rn),_&&reactExports.createElement(Panel,{className:"".concat(d,"-footer")},_(J)));et&&(Sr=reactExports.createElement(RefResizeObserver,{onResize:Bt},Sr));var kr=useFixedInfo(Ne,ot,w),jr=reactExports.useMemo(function(){return{scrollX:Ke,prefixCls:d,getComponent:te,scrollbarSize:_t,direction:w,fixedInfoList:kr,isSticky:Je,supportSticky:Jr,componentWidth:we,fixHeader:rt,fixColumn:$t,horizonScroll:et,tableLayout:wr,rowClassName:m,expandedRowClassName:de.expandedRowClassName,expandIcon:ve,expandableType:ge,expandRowByClick:de.expandRowByClick,expandedRowRender:de.expandedRowRender,onTriggerExpand:pe,expandIconColumnIndex:de.expandIconColumnIndex,indentSize:de.indentSize,allColumnsFixedLeft:Ne.every(function(Pt){return Pt.fixed==="left"}),emptyNode:wt,columns:Ee,flattenColumns:Ne,onColumnResize:Nt,hoverStartRow:ee,hoverEndRow:ie,onHover:ce,rowExpandable:de.rowExpandable,onRow:B,getRowKey:ae,expandedKeys:Ce,childrenColumnName:fe,rowHoverable:Z}},[Ke,d,te,_t,w,kr,Je,Jr,we,rt,$t,et,wr,m,de.expandedRowClassName,ve,ge,de.expandRowByClick,de.expandedRowRender,pe,de.expandIconColumnIndex,de.indentSize,wt,Ee,Ne,Nt,ee,ie,ce,de.rowExpandable,B,ae,Ce,fe,Z]);return reactExports.createElement(TableContext.Provider,{value:jr},Sr)}var RefTable=reactExports.forwardRef(Table$1);function genTable(a){return makeImmutable(RefTable,a)}var ImmutableTable=genTable();ImmutableTable.EXPAND_COLUMN=EXPAND_COLUMN;ImmutableTable.INTERNAL_HOOKS=INTERNAL_HOOKS;ImmutableTable.Column=Column$1;ImmutableTable.ColumnGroup=ColumnGroup$1;ImmutableTable.Summary=FooterComponents;var StaticContext=createContext(null),GridContext=createContext(null);function getColumnWidth(a,c,u){var d=c||1;return u[a+d]-(u[a]||0)}function VirtualCell(a){var c=a.rowInfo,u=a.column,d=a.colIndex,f=a.indent,m=a.index,g=a.component,y=a.renderIndex,b=a.record,E=a.style,C=a.className,w=a.inverse,R=a.getHeight,_=u.render,M=u.dataIndex,I=u.className,N=u.width,A=useContext(GridContext,["columnsOffset"]),P=A.columnsOffset,z=getCellProps(c,u,d,f,m),B=z.key,j=z.fixedInfo,L=z.appendCellNode,U=z.additionalCellProps,q=U.style,F=U.colSpan,K=F===void 0?1:F,X=U.rowSpan,Q=X===void 0?1:X,Y=d-1,Z=getColumnWidth(Y,K,P),J=K>1?N-Z:0,W=_objectSpread2(_objectSpread2(_objectSpread2({},q),E),{},{flex:"0 0 ".concat(Z,"px"),width:"".concat(Z,"px"),marginRight:J,pointerEvents:"auto"}),G=reactExports.useMemo(function(){return w?Q<=1:K===0||Q===0||Q>1},[Q,K,w]);G?W.visibility="hidden":w&&(W.height=R==null?void 0:R(Q));var te=G?function(){return null}:_,ae={};return(Q===0||K===0)&&(ae.rowSpan=1,ae.colSpan=1),reactExports.createElement(Cell$1,_extends({className:classNames(I,C),ellipsis:u.ellipsis,align:u.align,scope:u.rowScope,component:g,prefixCls:c.prefixCls,key:B,record:b,index:m,renderIndex:y,dataIndex:M,render:te,shouldCellUpdate:u.shouldCellUpdate},j,{appendNode:L,additionalProps:_objectSpread2(_objectSpread2({},U),{},{style:W},ae)}))}var _excluded$3=["data","index","className","rowKey","style","extra","getHeight"],BodyLine=reactExports.forwardRef(function(a,c){var u=a.data,d=a.index,f=a.className,m=a.rowKey,g=a.style,y=a.extra,b=a.getHeight,E=_objectWithoutProperties(a,_excluded$3),C=u.record,w=u.indent,R=u.index,_=useContext(TableContext,["prefixCls","flattenColumns","fixColumn","componentWidth","scrollX"]),M=_.scrollX,I=_.flattenColumns,N=_.prefixCls,A=_.fixColumn,P=_.componentWidth,z=useContext(StaticContext,["getComponent"]),B=z.getComponent,j=useRowInfo(C,m,d,w),L=B(["body","row"],"div"),U=B(["body","cell"],"div"),q=j.rowSupportExpand,F=j.expanded,K=j.rowProps,X=j.expandedRowRender,Q=j.expandedRowClassName,Y;if(q&&F){var Z=X(C,d,w+1,F),J=computedExpandedClassName(Q,C,d,w),W={};A&&(W={style:_defineProperty({},"--virtual-width","".concat(P,"px"))});var G="".concat(N,"-expanded-row-cell");Y=reactExports.createElement(L,{className:classNames("".concat(N,"-expanded-row"),"".concat(N,"-expanded-row-level-").concat(w+1),J)},reactExports.createElement(Cell$1,{component:U,prefixCls:N,className:classNames(G,_defineProperty({},"".concat(G,"-fixed"),A)),additionalProps:W},Z))}var te=_objectSpread2(_objectSpread2({},g),{},{width:M});y&&(te.position="absolute",te.pointerEvents="none");var ae=reactExports.createElement(L,_extends({},K,E,{"data-row-key":m,ref:q?null:c,className:classNames(f,"".concat(N,"-row"),K==null?void 0:K.className,_defineProperty({},"".concat(N,"-row-extra"),y)),style:_objectSpread2(_objectSpread2({},te),K==null?void 0:K.style)}),I.map(function(V,ne){return reactExports.createElement(VirtualCell,{key:ne,component:U,rowInfo:j,column:V,colIndex:ne,indent:w,index:d,renderIndex:R,record:C,inverse:y,getHeight:b})}));return q?reactExports.createElement("div",{ref:c},ae,Y):ae}),ResponseBodyLine=responseImmutable(BodyLine),Grid=reactExports.forwardRef(function(a,c){var u=a.data,d=a.onScroll,f=useContext(TableContext,["flattenColumns","onColumnResize","getRowKey","prefixCls","expandedKeys","childrenColumnName","scrollX","direction"]),m=f.flattenColumns,g=f.onColumnResize,y=f.getRowKey,b=f.expandedKeys,E=f.prefixCls,C=f.childrenColumnName,w=f.scrollX,R=f.direction,_=useContext(StaticContext),M=_.sticky,I=_.scrollY,N=_.listItemHeight,A=_.getComponent,P=_.onScroll,z=reactExports.useRef(),B=useFlattenRecords(u,C,b,y),j=reactExports.useMemo(function(){var Y=0;return m.map(function(Z){var J=Z.width,W=Z.key;return Y+=J,[W,J,Y]})},[m]),L=reactExports.useMemo(function(){return j.map(function(Y){return Y[2]})},[j]);reactExports.useEffect(function(){j.forEach(function(Y){var Z=_slicedToArray(Y,2),J=Z[0],W=Z[1];g(J,W)})},[j]),reactExports.useImperativeHandle(c,function(){var Y,Z={scrollTo:function(W){var G;(G=z.current)===null||G===void 0||G.scrollTo(W)},nativeElement:(Y=z.current)===null||Y===void 0?void 0:Y.nativeElement};return Object.defineProperty(Z,"scrollLeft",{get:function(){var W;return((W=z.current)===null||W===void 0?void 0:W.getScrollInfo().x)||0},set:function(W){var G;(G=z.current)===null||G===void 0||G.scrollTo({left:W})}}),Z});var U=function(Z,J){var W,G=(W=B[J])===null||W===void 0?void 0:W.record,te=Z.onCell;if(te){var ae,V=te(G,J);return(ae=V==null?void 0:V.rowSpan)!==null&&ae!==void 0?ae:1}return 1},q=function(Z){var J=Z.start,W=Z.end,G=Z.getSize,te=Z.offsetY;if(W<0)return null;for(var ae=m.filter(function(ve){return U(ve,J)===0}),V=J,ne=function(fe){if(ae=ae.filter(function(pe){return U(pe,fe)===0}),!ae.length)return V=fe,1},le=J;le>=0&&!ne(le);le-=1);for(var ee=m.filter(function(ve){return U(ve,W)!==1}),ie=W,ce=function(fe){if(ee=ee.filter(function(pe){return U(pe,fe)!==1}),!ee.length)return ie=Math.max(fe-1,W),1},ue=W;ue<B.length&&!ce(ue);ue+=1);for(var me=[],de=function(fe){var pe=B[fe];if(!pe)return 1;m.some(function(xe){return U(xe,fe)>1})&&me.push(fe)},ge=V;ge<=ie;ge+=1)de(ge);var Ce=me.map(function(ve){var fe=B[ve],pe=y(fe.record,ve),xe=function(we){var Re=ve+we-1,De=y(B[Re].record,Re),Ae=G(pe,De);return Ae.bottom-Ae.top},ye=G(pe);return reactExports.createElement(ResponseBodyLine,{key:ve,data:fe,rowKey:pe,index:ve,style:{top:-te+ye.top},extra:!0,getHeight:xe})});return Ce},F=reactExports.useMemo(function(){return{columnsOffset:L}},[L]),K="".concat(E,"-tbody"),X=A(["body","wrapper"]),Q={};return M&&(Q.position="sticky",Q.bottom=0,_typeof(M)==="object"&&M.offsetScroll&&(Q.bottom=M.offsetScroll)),reactExports.createElement(GridContext.Provider,{value:F},reactExports.createElement(List,{fullHeight:!1,ref:z,prefixCls:"".concat(K,"-virtual"),styles:{horizontalScrollBar:Q},className:K,height:I,itemHeight:N||24,data:B,itemKey:function(Z){return y(Z.record)},component:X,scrollWidth:w,direction:R,onVirtualScroll:function(Z){var J,W=Z.x;d({currentTarget:(J=z.current)===null||J===void 0?void 0:J.nativeElement,scrollLeft:W})},onScroll:P,extraRender:q},function(Y,Z,J){var W=y(Y.record,Z);return reactExports.createElement(ResponseBodyLine,{data:Y,rowKey:W,index:Z,style:J.style})}))}),ResponseGrid=responseImmutable(Grid),renderBody=function(c,u){var d=u.ref,f=u.onScroll;return reactExports.createElement(ResponseGrid,{ref:d,data:c,onScroll:f})};function VirtualTable(a,c){var u=a.data,d=a.columns,f=a.scroll,m=a.sticky,g=a.prefixCls,y=g===void 0?DEFAULT_PREFIX:g,b=a.className,E=a.listItemHeight,C=a.components,w=a.onScroll,R=f||{},_=R.x,M=R.y;typeof _!="number"&&(_=1),typeof M!="number"&&(M=500);var I=useEvent(function(P,z){return get(C,P)||z}),N=useEvent(w),A=reactExports.useMemo(function(){return{sticky:m,scrollY:M,listItemHeight:E,getComponent:I,onScroll:N}},[m,M,E,I,N]);return reactExports.createElement(StaticContext.Provider,{value:A},reactExports.createElement(ImmutableTable,_extends({},a,{className:classNames(b,"".concat(y,"-virtual")),scroll:_objectSpread2(_objectSpread2({},f),{},{x:_}),components:_objectSpread2(_objectSpread2({},C),{},{body:u!=null&&u.length?renderBody:void 0}),columns:d,internalHooks:INTERNAL_HOOKS,tailor:!0,ref:c})))}var RefVirtualTable=reactExports.forwardRef(VirtualTable);function genVirtualTable(a){return makeImmutable(RefVirtualTable,a)}genVirtualTable();const Column=a=>null,ColumnGroup=a=>null;var TreeContext=reactExports.createContext(null),UnstableContext=reactExports.createContext({}),Indent=function(c){for(var u=c.prefixCls,d=c.level,f=c.isStart,m=c.isEnd,g="".concat(u,"-indent-unit"),y=[],b=0;b<d;b+=1)y.push(reactExports.createElement("span",{key:b,className:classNames(g,_defineProperty(_defineProperty({},"".concat(g,"-start"),f[b]),"".concat(g,"-end"),m[b]))}));return reactExports.createElement("span",{"aria-hidden":"true",className:"".concat(u,"-indent")},y)};const Indent$1=reactExports.memo(Indent);var _excluded$2=["eventKey","className","style","dragOver","dragOverGapTop","dragOverGapBottom","isLeaf","isStart","isEnd","expanded","selected","checked","halfChecked","loading","domRef","active","data","onMouseMove","selectable"],ICON_OPEN="open",ICON_CLOSE="close",defaultTitle="---",TreeNode=function(c){var u,d,f,m=c.eventKey,g=c.className,y=c.style,b=c.dragOver,E=c.dragOverGapTop,C=c.dragOverGapBottom,w=c.isLeaf,R=c.isStart,_=c.isEnd,M=c.expanded,I=c.selected,N=c.checked,A=c.halfChecked,P=c.loading,z=c.domRef,B=c.active,j=c.data,L=c.onMouseMove,U=c.selectable,q=_objectWithoutProperties(c,_excluded$2),F=React.useContext(TreeContext),K=React.useContext(UnstableContext),X=React.useRef(null),Q=React.useState(!1),Y=_slicedToArray(Q,2),Z=Y[0],J=Y[1],W=!!(F.disabled||c.disabled||(u=K.nodeDisabled)!==null&&u!==void 0&&u.call(K,j)),G=React.useMemo(function(){return!F.checkable||c.checkable===!1?!1:F.checkable},[F.checkable,c.checkable]),te=function(Pe){W||F.onNodeSelect(Pe,convertNodePropsToEventData(c))},ae=function(Pe){W||!G||c.disableCheckbox||F.onNodeCheck(Pe,convertNodePropsToEventData(c),!N)},V=React.useMemo(function(){return typeof U=="boolean"?U:F.selectable},[U,F.selectable]),ne=function(Pe){F.onNodeClick(Pe,convertNodePropsToEventData(c)),V?te(Pe):ae(Pe)},le=function(Pe){F.onNodeDoubleClick(Pe,convertNodePropsToEventData(c))},ee=function(Pe){F.onNodeMouseEnter(Pe,convertNodePropsToEventData(c))},ie=function(Pe){F.onNodeMouseLeave(Pe,convertNodePropsToEventData(c))},ce=function(Pe){F.onNodeContextMenu(Pe,convertNodePropsToEventData(c))},ue=React.useMemo(function(){return!!(F.draggable&&(!F.draggable.nodeDraggable||F.draggable.nodeDraggable(j)))},[F.draggable,j]),me=function(Pe){Pe.stopPropagation(),J(!0),F.onNodeDragStart(Pe,c);try{Pe.dataTransfer.setData("text/plain","")}catch{}},de=function(Pe){Pe.preventDefault(),Pe.stopPropagation(),F.onNodeDragEnter(Pe,c)},ge=function(Pe){Pe.preventDefault(),Pe.stopPropagation(),F.onNodeDragOver(Pe,c)},Ce=function(Pe){Pe.stopPropagation(),F.onNodeDragLeave(Pe,c)},ve=function(Pe){Pe.stopPropagation(),J(!1),F.onNodeDragEnd(Pe,c)},fe=function(Pe){Pe.preventDefault(),Pe.stopPropagation(),J(!1),F.onNodeDrop(Pe,c)},pe=function(Pe){P||F.onNodeExpand(Pe,convertNodePropsToEventData(c))},xe=React.useMemo(function(){var Ve=getEntity(F.keyEntities,m)||{},Pe=Ve.children;return!!(Pe||[]).length},[F.keyEntities,m]),ye=React.useMemo(function(){return w===!1?!1:w||!F.loadData&&!xe||F.loadData&&c.loaded&&!xe},[w,F.loadData,xe,c.loaded]);React.useEffect(function(){P||typeof F.loadData=="function"&&M&&!ye&&!c.loaded&&F.onNodeLoad(convertNodePropsToEventData(c))},[P,F.loadData,F.onNodeLoad,M,ye,c]);var he=React.useMemo(function(){var Ve;return(Ve=F.draggable)!==null&&Ve!==void 0&&Ve.icon?React.createElement("span",{className:"".concat(F.prefixCls,"-draggable-icon")},F.draggable.icon):null},[F.draggable]),we=function(Pe){var Ge=c.switcherIcon||F.switcherIcon;return typeof Ge=="function"?Ge(_objectSpread2(_objectSpread2({},c),{},{isLeaf:Pe})):Ge},Re=function(){if(ye){var Pe=we(!0);return Pe!==!1?React.createElement("span",{className:classNames("".concat(F.prefixCls,"-switcher"),"".concat(F.prefixCls,"-switcher-noop"))},Pe):null}var Ge=we(!1);return Ge!==!1?React.createElement("span",{onClick:pe,className:classNames("".concat(F.prefixCls,"-switcher"),"".concat(F.prefixCls,"-switcher_").concat(M?ICON_OPEN:ICON_CLOSE))},Ge):null},De=React.useMemo(function(){if(!G)return null;var Ve=typeof G!="boolean"?G:null;return React.createElement("span",{className:classNames("".concat(F.prefixCls,"-checkbox"),_defineProperty(_defineProperty(_defineProperty({},"".concat(F.prefixCls,"-checkbox-checked"),N),"".concat(F.prefixCls,"-checkbox-indeterminate"),!N&&A),"".concat(F.prefixCls,"-checkbox-disabled"),W||c.disableCheckbox)),onClick:ae,role:"checkbox","aria-checked":A?"mixed":N,"aria-disabled":W||c.disableCheckbox,"aria-label":"Select ".concat(typeof c.title=="string"?c.title:"tree node")},Ve)},[G,N,A,W,c.disableCheckbox,c.title]),Ae=React.useMemo(function(){return ye?null:M?ICON_OPEN:ICON_CLOSE},[ye,M]),Ee=React.useMemo(function(){return React.createElement("span",{className:classNames("".concat(F.prefixCls,"-iconEle"),"".concat(F.prefixCls,"-icon__").concat(Ae||"docu"),_defineProperty({},"".concat(F.prefixCls,"-icon_loading"),P))})},[F.prefixCls,Ae,P]),Ne=React.useMemo(function(){var Ve=!!F.draggable,Pe=!c.disabled&&Ve&&F.dragOverNodeKey===m;return Pe?F.dropIndicatorRender({dropPosition:F.dropPosition,dropLevelOffset:F.dropLevelOffset,indent:F.indent,prefixCls:F.prefixCls,direction:F.direction}):null},[F.dropPosition,F.dropLevelOffset,F.indent,F.prefixCls,F.direction,F.draggable,F.dragOverNodeKey,F.dropIndicatorRender]),_e=React.useMemo(function(){var Ve=c.title,Pe=Ve===void 0?defaultTitle:Ve,Ge="".concat(F.prefixCls,"-node-content-wrapper"),qe;if(F.showIcon){var Ue=c.icon||F.icon;qe=Ue?React.createElement("span",{className:classNames("".concat(F.prefixCls,"-iconEle"),"".concat(F.prefixCls,"-icon__customize"))},typeof Ue=="function"?Ue(c):Ue):Ee}else F.loadData&&P&&(qe=Ee);var je;return typeof Pe=="function"?je=Pe(j):F.titleRender?je=F.titleRender(j):je=Pe,React.createElement("span",{ref:X,title:typeof Pe=="string"?Pe:"",className:classNames(Ge,"".concat(Ge,"-").concat(Ae||"normal"),_defineProperty({},"".concat(F.prefixCls,"-node-selected"),!W&&(I||Z))),onMouseEnter:ee,onMouseLeave:ie,onContextMenu:ce,onClick:ne,onDoubleClick:le},qe,React.createElement("span",{className:"".concat(F.prefixCls,"-title")},je),Ne)},[F.prefixCls,F.showIcon,c,F.icon,Ee,F.titleRender,j,Ae,ee,ie,ce,ne,le]),ke=pickAttrs(q,{aria:!0,data:!0}),Ke=getEntity(F.keyEntities,m)||{},be=Ke.level,Te=_[_.length-1],Le=!W&&ue,Oe=F.draggingNodeKey===m,Be=U!==void 0?{"aria-selected":!!U}:void 0;return React.createElement("div",_extends({ref:z,role:"treeitem","aria-expanded":w?void 0:M,className:classNames(g,"".concat(F.prefixCls,"-treenode"),(f={},_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(f,"".concat(F.prefixCls,"-treenode-disabled"),W),"".concat(F.prefixCls,"-treenode-switcher-").concat(M?"open":"close"),!w),"".concat(F.prefixCls,"-treenode-checkbox-checked"),N),"".concat(F.prefixCls,"-treenode-checkbox-indeterminate"),A),"".concat(F.prefixCls,"-treenode-selected"),I),"".concat(F.prefixCls,"-treenode-loading"),P),"".concat(F.prefixCls,"-treenode-active"),B),"".concat(F.prefixCls,"-treenode-leaf-last"),Te),"".concat(F.prefixCls,"-treenode-draggable"),ue),"dragging",Oe),_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(_defineProperty(f,"drop-target",F.dropTargetKey===m),"drop-container",F.dropContainerKey===m),"drag-over",!W&&b),"drag-over-gap-top",!W&&E),"drag-over-gap-bottom",!W&&C),"filter-node",(d=F.filterTreeNode)===null||d===void 0?void 0:d.call(F,convertNodePropsToEventData(c))),"".concat(F.prefixCls,"-treenode-leaf"),ye))),style:y,draggable:Le,onDragStart:Le?me:void 0,onDragEnter:ue?de:void 0,onDragOver:ue?ge:void 0,onDragLeave:ue?Ce:void 0,onDrop:ue?fe:void 0,onDragEnd:ue?ve:void 0,onMouseMove:L},Be,ke),React.createElement(Indent$1,{prefixCls:F.prefixCls,level:be,isStart:R,isEnd:_}),he,Re(),De,_e)};TreeNode.isTreeNode=1;function arrDel(a,c){if(!a)return[];var u=a.slice(),d=u.indexOf(c);return d>=0&&u.splice(d,1),u}function arrAdd(a,c){var u=(a||[]).slice();return u.indexOf(c)===-1&&u.push(c),u}function posToArr(a){return a.split("-")}function getDragChildrenKeys(a,c){var u=[],d=getEntity(c,a);function f(){var m=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[];m.forEach(function(g){var y=g.key,b=g.children;u.push(y),f(b)})}return f(d.children),u}function isLastChild(a){if(a.parent){var c=posToArr(a.pos);return Number(c[c.length-1])===a.parent.children.length-1}return!1}function isFirstChild(a){var c=posToArr(a.pos);return Number(c[c.length-1])===0}function calcDropPosition(a,c,u,d,f,m,g,y,b,E){var C,w=a.clientX,R=a.clientY,_=a.target.getBoundingClientRect(),M=_.top,I=_.height,N=(E==="rtl"?-1:1)*(((f==null?void 0:f.x)||0)-w),A=(N-12)/d,P=b.filter(function(W){var G;return(G=y[W])===null||G===void 0||(G=G.children)===null||G===void 0?void 0:G.length}),z=getEntity(y,u.eventKey);if(R<M+I/2){var B=g.findIndex(function(W){return W.key===z.key}),j=B<=0?0:B-1,L=g[j].key;z=getEntity(y,L)}var U=z.key,q=z,F=z.key,K=0,X=0;if(!P.includes(U))for(var Q=0;Q<A&&isLastChild(z);Q+=1)z=z.parent,X+=1;var Y=c.data,Z=z.node,J=!0;return isFirstChild(z)&&z.level===0&&R<M+I/2&&m({dragNode:Y,dropNode:Z,dropPosition:-1})&&z.key===u.eventKey?K=-1:(q.children||[]).length&&P.includes(F)?m({dragNode:Y,dropNode:Z,dropPosition:0})?K=0:J=!1:X===0?A>-1.5?m({dragNode:Y,dropNode:Z,dropPosition:1})?K=1:J=!1:m({dragNode:Y,dropNode:Z,dropPosition:0})?K=0:m({dragNode:Y,dropNode:Z,dropPosition:1})?K=1:J=!1:m({dragNode:Y,dropNode:Z,dropPosition:1})?K=1:J=!1,{dropPosition:K,dropLevelOffset:X,dropTargetKey:z.key,dropTargetPos:z.pos,dragOverNodeKey:F,dropContainerKey:K===0?null:((C=z.parent)===null||C===void 0?void 0:C.key)||null,dropAllowed:J}}function calcSelectedKeys(a,c){if(a){var u=c.multiple;return u?a.slice():a.length?[a[0]]:a}}function parseCheckedKeys(a){if(!a)return null;var c;if(Array.isArray(a))c={checkedKeys:a,halfCheckedKeys:void 0};else if(_typeof(a)==="object")c={checkedKeys:a.checked||void 0,halfCheckedKeys:a.halfChecked||void 0};else return warningOnce$1(!1,"`checkedKeys` is not an array or an object"),null;return c}function conductExpandParent(a,c){var u=new Set;function d(f){if(!u.has(f)){var m=getEntity(c,f);if(m){u.add(f);var g=m.parent,y=m.node;y.disabled||g&&d(g.key)}}}return(a||[]).forEach(function(f){d(f)}),_toConsumableArray(u)}function useMultipleSelect(a){const[c,u]=reactExports.useState(null);return[reactExports.useCallback((m,g,y)=>{const b=c??m,E=Math.min(b||0,m),C=Math.max(b||0,m),w=g.slice(E,C+1).map(M=>a(M)),R=w.some(M=>!y.has(M)),_=[];return w.forEach(M=>{R?(y.has(M)||_.push(M),y.add(M)):(y.delete(M),_.push(M))}),u(R?C:null),_},[c]),m=>{u(m)}]}const SELECTION_COLUMN={},SELECTION_ALL="SELECT_ALL",SELECTION_INVERT="SELECT_INVERT",SELECTION_NONE="SELECT_NONE",EMPTY_LIST$1=[],flattenData=(a,c)=>{let u=[];return(c||[]).forEach(d=>{u.push(d),d&&typeof d=="object"&&a in d&&(u=[].concat(_toConsumableArray(u),_toConsumableArray(flattenData(a,d[a]))))}),u},useSelection=(a,c)=>{const{preserveSelectedRowKeys:u,selectedRowKeys:d,defaultSelectedRowKeys:f,getCheckboxProps:m,onChange:g,onSelect:y,onSelectAll:b,onSelectInvert:E,onSelectNone:C,onSelectMultiple:w,columnWidth:R,type:_,selections:M,fixed:I,renderCell:N,hideSelectAll:A,checkStrictly:P=!0}=c||{},{prefixCls:z,data:B,pageData:j,getRecordByKey:L,getRowKey:U,expandType:q,childrenColumnName:F,locale:K,getPopupContainer:X}=a,Q=devUseWarning(),[Y,Z]=useMultipleSelect(ve=>ve),[J,W]=useMergedState(d||f||EMPTY_LIST$1,{value:d}),G=reactExports.useRef(new Map),te=reactExports.useCallback(ve=>{if(u){const fe=new Map;ve.forEach(pe=>{let xe=L(pe);!xe&&G.current.has(pe)&&(xe=G.current.get(pe)),fe.set(pe,xe)}),G.current=fe}},[L,u]);reactExports.useEffect(()=>{te(J)},[J]);const ae=reactExports.useMemo(()=>flattenData(F,j),[F,j]),{keyEntities:V}=reactExports.useMemo(()=>{if(P)return{keyEntities:null};let ve=B;if(u){const fe=new Set(ae.map((xe,ye)=>U(xe,ye))),pe=Array.from(G.current).reduce((xe,ye)=>{let[he,we]=ye;return fe.has(he)?xe:xe.concat(we)},[]);ve=[].concat(_toConsumableArray(ve),_toConsumableArray(pe))}return convertDataToEntities(ve,{externalGetKey:U,childrenPropName:F})},[B,U,P,F,u,ae]),ne=reactExports.useMemo(()=>{const ve=new Map;return ae.forEach((fe,pe)=>{const xe=U(fe,pe),ye=(m?m(fe):null)||{};ve.set(xe,ye)}),ve},[ae,U,m]),le=reactExports.useCallback(ve=>{const fe=U(ve);let pe;return ne.has(fe)?pe=ne.get(U(ve)):pe=m?m(ve):void 0,!!(pe!=null&&pe.disabled)},[ne,U]),[ee,ie]=reactExports.useMemo(()=>{if(P)return[J||[],[]];const{checkedKeys:ve,halfCheckedKeys:fe}=conductCheck(J,!0,V,le);return[ve||[],fe]},[J,P,V,le]),ce=reactExports.useMemo(()=>{const ve=_==="radio"?ee.slice(0,1):ee;return new Set(ve)},[ee,_]),ue=reactExports.useMemo(()=>_==="radio"?new Set:new Set(ie),[ie,_]);reactExports.useEffect(()=>{c||W(EMPTY_LIST$1)},[!!c]);const me=reactExports.useCallback((ve,fe)=>{let pe,xe;te(ve),u?(pe=ve,xe=ve.map(ye=>G.current.get(ye))):(pe=[],xe=[],ve.forEach(ye=>{const he=L(ye);he!==void 0&&(pe.push(ye),xe.push(he))})),W(pe),g==null||g(pe,xe,{type:fe})},[W,L,g,u]),de=reactExports.useCallback((ve,fe,pe,xe)=>{if(y){const ye=pe.map(he=>L(he));y(L(ve),fe,ye,xe)}me(pe,"single")},[y,L,me]),ge=reactExports.useMemo(()=>!M||A?null:(M===!0?[SELECTION_ALL,SELECTION_INVERT,SELECTION_NONE]:M).map(fe=>fe===SELECTION_ALL?{key:"all",text:K.selectionAll,onSelect(){me(B.map((pe,xe)=>U(pe,xe)).filter(pe=>{const xe=ne.get(pe);return!(xe!=null&&xe.disabled)||ce.has(pe)}),"all")}}:fe===SELECTION_INVERT?{key:"invert",text:K.selectInvert,onSelect(){const pe=new Set(ce);j.forEach((ye,he)=>{const we=U(ye,he),Re=ne.get(we);Re!=null&&Re.disabled||(pe.has(we)?pe.delete(we):pe.add(we))});const xe=Array.from(pe);E&&(Q.deprecated(!1,"onSelectInvert","onChange"),E(xe)),me(xe,"invert")}}:fe===SELECTION_NONE?{key:"none",text:K.selectNone,onSelect(){C==null||C(),me(Array.from(ce).filter(pe=>{const xe=ne.get(pe);return xe==null?void 0:xe.disabled}),"none")}}:fe).map(fe=>Object.assign(Object.assign({},fe),{onSelect:function(){for(var pe,xe,ye=arguments.length,he=new Array(ye),we=0;we<ye;we++)he[we]=arguments[we];(xe=fe.onSelect)===null||xe===void 0||(pe=xe).call.apply(pe,[fe].concat(he)),Z(null)}})),[M,ce,j,U,E,me]);return[reactExports.useCallback(ve=>{var fe;if(!c)return ve.filter(Be=>Be!==SELECTION_COLUMN);let pe=_toConsumableArray(ve);const xe=new Set(ce),ye=ae.map(U).filter(Be=>!ne.get(Be).disabled),he=ye.every(Be=>xe.has(Be)),we=ye.some(Be=>xe.has(Be)),Re=()=>{const Be=[];he?ye.forEach(Pe=>{xe.delete(Pe),Be.push(Pe)}):ye.forEach(Pe=>{xe.has(Pe)||(xe.add(Pe),Be.push(Pe))});const Ve=Array.from(xe);b==null||b(!he,Ve.map(Pe=>L(Pe)),Be.map(Pe=>L(Pe))),me(Ve,"all"),Z(null)};let De,Ae;if(_!=="radio"){let Be;if(ge){const Ue={getPopupContainer:X,items:ge.map((je,We)=>{const{key:ut,text:gt,onSelect:kt}=je;return{key:ut??We,onClick:()=>{kt==null||kt(ye)},label:gt}})};Be=reactExports.createElement("div",{className:`${z}-selection-extra`},reactExports.createElement(Dropdown,{menu:Ue,getPopupContainer:X},reactExports.createElement("span",null,reactExports.createElement(RefIcon$t,null))))}const Ve=ae.map((Ue,je)=>{const We=U(Ue,je),ut=ne.get(We)||{};return Object.assign({checked:xe.has(We)},ut)}).filter(Ue=>{let{disabled:je}=Ue;return je}),Pe=!!Ve.length&&Ve.length===ae.length,Ge=Pe&&Ve.every(Ue=>{let{checked:je}=Ue;return je}),qe=Pe&&Ve.some(Ue=>{let{checked:je}=Ue;return je});Ae=reactExports.createElement(Checkbox,{checked:Pe?Ge:!!ae.length&&he,indeterminate:Pe?!Ge&&qe:!he&&we,onChange:Re,disabled:ae.length===0||Pe,"aria-label":Be?"Custom selection":"Select all",skipGroup:!0}),De=!A&&reactExports.createElement("div",{className:`${z}-selection`},Ae,Be)}let Ee;_==="radio"?Ee=(Be,Ve,Pe)=>{const Ge=U(Ve,Pe),qe=xe.has(Ge),Ue=ne.get(Ge);return{node:reactExports.createElement(Radio,Object.assign({},Ue,{checked:qe,onClick:je=>{var We;je.stopPropagation(),(We=Ue==null?void 0:Ue.onClick)===null||We===void 0||We.call(Ue,je)},onChange:je=>{var We;xe.has(Ge)||de(Ge,!0,[Ge],je.nativeEvent),(We=Ue==null?void 0:Ue.onChange)===null||We===void 0||We.call(Ue,je)}})),checked:qe}}:Ee=(Be,Ve,Pe)=>{var Ge;const qe=U(Ve,Pe),Ue=xe.has(qe),je=ue.has(qe),We=ne.get(qe);let ut;return q==="nest"?ut=je:ut=(Ge=We==null?void 0:We.indeterminate)!==null&&Ge!==void 0?Ge:je,{node:reactExports.createElement(Checkbox,Object.assign({},We,{indeterminate:ut,checked:Ue,skipGroup:!0,onClick:gt=>{var kt;gt.stopPropagation(),(kt=We==null?void 0:We.onClick)===null||kt===void 0||kt.call(We,gt)},onChange:gt=>{var kt;const{nativeEvent:Ut}=gt,{shiftKey:at}=Ut,ct=ye.findIndex(it=>it===qe),bt=ee.some(it=>ye.includes(it));if(at&&P&&bt){const it=Y(ct,ye,xe),vt=Array.from(xe);w==null||w(!Ue,vt.map(ot=>L(ot)),it.map(ot=>L(ot))),me(vt,"multiple")}else{const it=ee;if(P){const vt=Ue?arrDel(it,qe):arrAdd(it,qe);de(qe,!Ue,vt,Ut)}else{const vt=conductCheck([].concat(_toConsumableArray(it),[qe]),!0,V,le),{checkedKeys:ot,halfCheckedKeys:rt}=vt;let et=ot;if(Ue){const $t=new Set(ot);$t.delete(qe),et=conductCheck(Array.from($t),{halfCheckedKeys:rt},V,le).checkedKeys}de(qe,!Ue,et,Ut)}}Z(Ue?null:ct),(kt=We==null?void 0:We.onChange)===null||kt===void 0||kt.call(We,gt)}})),checked:Ue}};const Ne=(Be,Ve,Pe)=>{const{node:Ge,checked:qe}=Ee(Be,Ve,Pe);return N?N(qe,Ve,Pe,Ge):Ge};if(!pe.includes(SELECTION_COLUMN))if(pe.findIndex(Be=>{var Ve;return((Ve=Be[INTERNAL_COL_DEFINE])===null||Ve===void 0?void 0:Ve.columnType)==="EXPAND_COLUMN"})===0){const[Be,...Ve]=pe;pe=[Be,SELECTION_COLUMN].concat(_toConsumableArray(Ve))}else pe=[SELECTION_COLUMN].concat(_toConsumableArray(pe));const _e=pe.indexOf(SELECTION_COLUMN);pe=pe.filter((Be,Ve)=>Be!==SELECTION_COLUMN||Ve===_e);const ke=pe[_e-1],Ke=pe[_e+1];let be=I;be===void 0&&((Ke==null?void 0:Ke.fixed)!==void 0?be=Ke.fixed:(ke==null?void 0:ke.fixed)!==void 0&&(be=ke.fixed)),be&&ke&&((fe=ke[INTERNAL_COL_DEFINE])===null||fe===void 0?void 0:fe.columnType)==="EXPAND_COLUMN"&&ke.fixed===void 0&&(ke.fixed=be);const Te=classNames(`${z}-selection-col`,{[`${z}-selection-col-with-dropdown`]:M&&_==="checkbox"}),Le=()=>c!=null&&c.columnTitle?typeof c.columnTitle=="function"?c.columnTitle(Ae):c.columnTitle:De,Oe={fixed:be,width:R,className:`${z}-selection-column`,title:Le(),render:Ne,onCell:c.onCell,[INTERNAL_COL_DEFINE]:{className:Te}};return pe.map(Be=>Be===SELECTION_COLUMN?Oe:Be)},[U,ae,c,ee,ce,ue,R,ge,q,ne,w,de,le]),ce]};function fillProxy(a,c){return a._antProxy=a._antProxy||{},Object.keys(c).forEach(u=>{if(!(u in a._antProxy)){const d=a[u];a._antProxy[u]=d,a[u]=c[u]}}),a}function useProxyImperativeHandle(a,c){return reactExports.useImperativeHandle(a,()=>{const u=c(),{nativeElement:d}=u;return typeof Proxy<"u"?new Proxy(d,{get(f,m){return u[m]?u[m]:Reflect.get(f,m)}}):fillProxy(d,u)})}function renderExpandIcon(a){return c=>{const{prefixCls:u,onExpand:d,record:f,expanded:m,expandable:g}=c,y=`${u}-row-expand-icon`;return reactExports.createElement("button",{type:"button",onClick:b=>{d(f,b),b.stopPropagation()},className:classNames(y,{[`${y}-spaced`]:!g,[`${y}-expanded`]:g&&m,[`${y}-collapsed`]:g&&!m}),"aria-label":m?a.collapse:a.expand,"aria-expanded":m})}}function useContainerWidth(a){return(u,d)=>{const f=u.querySelector(`.${a}-container`);let m=d;if(f){const g=getComputedStyle(f),y=parseInt(g.borderLeftWidth,10),b=parseInt(g.borderRightWidth,10);m=d-y-b}return m}}const getColumnKey=(a,c)=>"key"in a&&a.key!==void 0&&a.key!==null?a.key:a.dataIndex?Array.isArray(a.dataIndex)?a.dataIndex.join("."):a.dataIndex:c;function getColumnPos(a,c){return c?`${c}-${a}`:`${a}`}const renderColumnTitle=(a,c)=>typeof a=="function"?a(c):a,safeColumnTitle=(a,c)=>{const u=renderColumnTitle(a,c);return Object.prototype.toString.call(u)==="[object Object]"?"":u};function useSyncState(a){const c=reactExports.useRef(a),u=useForceUpdate();return[()=>c.current,d=>{c.current=d,u()}]}var DropIndicator=function(c){var u=c.dropPosition,d=c.dropLevelOffset,f=c.indent,m={pointerEvents:"none",position:"absolute",right:0,backgroundColor:"red",height:2};switch(u){case-1:m.top=0,m.left=-d*f;break;case 1:m.bottom=0,m.left=-d*f;break;case 0:m.bottom=0,m.left=f;break}return React.createElement("div",{style:m})};function _objectDestructuringEmpty(a){if(a==null)throw new TypeError("Cannot destructure "+a)}function useUnmount(a,c){var u=reactExports.useState(!1),d=_slicedToArray(u,2),f=d[0],m=d[1];useLayoutEffect$1(function(){if(f)return a(),function(){c()}},[f]),useLayoutEffect$1(function(){return m(!0),function(){m(!1)}},[])}var _excluded$1=["className","style","motion","motionNodes","motionType","onMotionStart","onMotionEnd","active","treeNodeRequiredProps"],MotionTreeNode=reactExports.forwardRef(function(a,c){var u=a.className,d=a.style,f=a.motion,m=a.motionNodes,g=a.motionType,y=a.onMotionStart,b=a.onMotionEnd,E=a.active,C=a.treeNodeRequiredProps,w=_objectWithoutProperties(a,_excluded$1),R=reactExports.useState(!0),_=_slicedToArray(R,2),M=_[0],I=_[1],N=reactExports.useContext(TreeContext),A=N.prefixCls,P=m&&g!=="hide";useLayoutEffect$1(function(){m&&P!==M&&I(P)},[m]);var z=function(){m&&y()},B=reactExports.useRef(!1),j=function(){m&&!B.current&&(B.current=!0,b())};useUnmount(z,j);var L=function(q){P===q&&j()};return m?reactExports.createElement(CSSMotion,_extends({ref:c,visible:M},f,{motionAppear:g==="show",onVisibleChanged:L}),function(U,q){var F=U.className,K=U.style;return reactExports.createElement("div",{ref:q,className:classNames("".concat(A,"-treenode-motion"),F),style:K},m.map(function(X){var Q=Object.assign({},(_objectDestructuringEmpty(X.data),X.data)),Y=X.title,Z=X.key,J=X.isStart,W=X.isEnd;delete Q.children;var G=getTreeNodeProps(Z,C);return reactExports.createElement(TreeNode,_extends({},Q,G,{title:Y,active:E,data:X.data,key:Z,isStart:J,isEnd:W}))}))}):reactExports.createElement(TreeNode,_extends({domRef:c,className:u,style:d},w,{active:E}))});function findExpandedKeys(){var a=arguments.length>0&&arguments[0]!==void 0?arguments[0]:[],c=arguments.length>1&&arguments[1]!==void 0?arguments[1]:[],u=a.length,d=c.length;if(Math.abs(u-d)!==1)return{add:!1,key:null};function f(m,g){var y=new Map;m.forEach(function(E){y.set(E,!0)});var b=g.filter(function(E){return!y.has(E)});return b.length===1?b[0]:null}return u<d?{add:!0,key:f(a,c)}:{add:!1,key:f(c,a)}}function getExpandRange(a,c,u){var d=a.findIndex(function(y){return y.key===u}),f=a[d+1],m=c.findIndex(function(y){return y.key===u});if(f){var g=c.findIndex(function(y){return y.key===f.key});return c.slice(m+1,g)}return c.slice(m+1)}var _excluded=["prefixCls","data","selectable","checkable","expandedKeys","selectedKeys","checkedKeys","loadedKeys","loadingKeys","halfCheckedKeys","keyEntities","disabled","dragging","dragOverNodeKey","dropPosition","motion","height","itemHeight","virtual","scrollWidth","focusable","activeItem","focused","tabIndex","onKeyDown","onFocus","onBlur","onActiveChange","onListChangeStart","onListChangeEnd"],HIDDEN_STYLE={width:0,height:0,display:"flex",overflow:"hidden",opacity:0,border:0,padding:0,margin:0},noop$2=function(){},MOTION_KEY="RC_TREE_MOTION_".concat(Math.random()),MotionNode={key:MOTION_KEY},MotionEntity={key:MOTION_KEY,level:0,index:0,pos:"0",node:MotionNode,nodes:[MotionNode]},MotionFlattenData={parent:null,children:[],pos:MotionEntity.pos,data:MotionNode,title:null,key:MOTION_KEY,isStart:[],isEnd:[]};function getMinimumRangeTransitionRange(a,c,u,d){return c===!1||!u?a:a.slice(0,Math.ceil(u/d)+1)}function itemKey(a){var c=a.key,u=a.pos;return getKey(c,u)}function getAccessibilityPath(a){for(var c=String(a.data.key),u=a;u.parent;)u=u.parent,c="".concat(u.data.key," > ").concat(c);return c}var NodeList=reactExports.forwardRef(function(a,c){var u=a.prefixCls,d=a.data;a.selectable,a.checkable;var f=a.expandedKeys,m=a.selectedKeys,g=a.checkedKeys,y=a.loadedKeys,b=a.loadingKeys,E=a.halfCheckedKeys,C=a.keyEntities,w=a.disabled,R=a.dragging,_=a.dragOverNodeKey,M=a.dropPosition,I=a.motion,N=a.height,A=a.itemHeight,P=a.virtual,z=a.scrollWidth,B=a.focusable,j=a.activeItem,L=a.focused,U=a.tabIndex,q=a.onKeyDown,F=a.onFocus,K=a.onBlur,X=a.onActiveChange,Q=a.onListChangeStart,Y=a.onListChangeEnd,Z=_objectWithoutProperties(a,_excluded),J=reactExports.useRef(null),W=reactExports.useRef(null);reactExports.useImperativeHandle(c,function(){return{scrollTo:function(Ne){J.current.scrollTo(Ne)},getIndentWidth:function(){return W.current.offsetWidth}}});var G=reactExports.useState(f),te=_slicedToArray(G,2),ae=te[0],V=te[1],ne=reactExports.useState(d),le=_slicedToArray(ne,2),ee=le[0],ie=le[1],ce=reactExports.useState(d),ue=_slicedToArray(ce,2),me=ue[0],de=ue[1],ge=reactExports.useState([]),Ce=_slicedToArray(ge,2),ve=Ce[0],fe=Ce[1],pe=reactExports.useState(null),xe=_slicedToArray(pe,2),ye=xe[0],he=xe[1],we=reactExports.useRef(d);we.current=d;function Re(){var Ee=we.current;ie(Ee),de(Ee),fe([]),he(null),Y()}useLayoutEffect$1(function(){V(f);var Ee=findExpandedKeys(ae,f);if(Ee.key!==null)if(Ee.add){var Ne=ee.findIndex(function(Le){var Oe=Le.key;return Oe===Ee.key}),_e=getMinimumRangeTransitionRange(getExpandRange(ee,d,Ee.key),P,N,A),ke=ee.slice();ke.splice(Ne+1,0,MotionFlattenData),de(ke),fe(_e),he("show")}else{var Ke=d.findIndex(function(Le){var Oe=Le.key;return Oe===Ee.key}),be=getMinimumRangeTransitionRange(getExpandRange(d,ee,Ee.key),P,N,A),Te=d.slice();Te.splice(Ke+1,0,MotionFlattenData),de(Te),fe(be),he("hide")}else ee!==d&&(ie(d),de(d))},[f,d]),reactExports.useEffect(function(){R||Re()},[R]);var De=I?me:d,Ae={expandedKeys:f,selectedKeys:m,loadedKeys:y,loadingKeys:b,checkedKeys:g,halfCheckedKeys:E,dragOverNodeKey:_,dropPosition:M,keyEntities:C};return reactExports.createElement(reactExports.Fragment,null,L&&j&&reactExports.createElement("span",{style:HIDDEN_STYLE,"aria-live":"assertive"},getAccessibilityPath(j)),reactExports.createElement("div",null,reactExports.createElement("input",{style:HIDDEN_STYLE,disabled:B===!1||w,tabIndex:B!==!1?U:null,onKeyDown:q,onFocus:F,onBlur:K,value:"",onChange:noop$2,"aria-label":"for screen reader"})),reactExports.createElement("div",{className:"".concat(u,"-treenode"),"aria-hidden":!0,style:{position:"absolute",pointerEvents:"none",visibility:"hidden",height:0,overflow:"hidden",border:0,padding:0}},reactExports.createElement("div",{className:"".concat(u,"-indent")},reactExports.createElement("div",{ref:W,className:"".concat(u,"-indent-unit")}))),reactExports.createElement(List,_extends({},Z,{data:De,itemKey,height:N,fullHeight:!1,virtual:P,itemHeight:A,scrollWidth:z,prefixCls:"".concat(u,"-list"),ref:J,role:"tree",onVisibleChange:function(Ne){Ne.every(function(_e){return itemKey(_e)!==MOTION_KEY})&&Re()}}),function(Ee){var Ne=Ee.pos,_e=Object.assign({},(_objectDestructuringEmpty(Ee.data),Ee.data)),ke=Ee.title,Ke=Ee.key,be=Ee.isStart,Te=Ee.isEnd,Le=getKey(Ke,Ne);delete _e.key,delete _e.children;var Oe=getTreeNodeProps(Le,Ae);return reactExports.createElement(MotionTreeNode,_extends({},_e,Oe,{title:ke,active:!!j&&Ke===j.key,pos:Ne,data:Ee.data,isStart:be,isEnd:Te,motion:I,motionNodes:Ke===MOTION_KEY?ve:null,motionType:ye,onMotionStart:Q,onMotionEnd:Re,treeNodeRequiredProps:Ae,onMouseMove:function(){X(null)}}))}))}),MAX_RETRY_TIMES=10,Tree$2=function(a){_inherits(u,a);var c=_createSuper(u);function u(){var d;_classCallCheck(this,u);for(var f=arguments.length,m=new Array(f),g=0;g<f;g++)m[g]=arguments[g];return d=c.call.apply(c,[this].concat(m)),_defineProperty(_assertThisInitialized(d),"destroyed",!1),_defineProperty(_assertThisInitialized(d),"delayedDragEnterLogic",void 0),_defineProperty(_assertThisInitialized(d),"loadingRetryTimes",{}),_defineProperty(_assertThisInitialized(d),"state",{keyEntities:{},indent:null,selectedKeys:[],checkedKeys:[],halfCheckedKeys:[],loadedKeys:[],loadingKeys:[],expandedKeys:[],draggingNodeKey:null,dragChildrenKeys:[],dropTargetKey:null,dropPosition:null,dropContainerKey:null,dropLevelOffset:null,dropTargetPos:null,dropAllowed:!0,dragOverNodeKey:null,treeData:[],flattenNodes:[],focused:!1,activeKey:null,listChanging:!1,prevProps:null,fieldNames:fillFieldNames()}),_defineProperty(_assertThisInitialized(d),"dragStartMousePosition",null),_defineProperty(_assertThisInitialized(d),"dragNodeProps",null),_defineProperty(_assertThisInitialized(d),"currentMouseOverDroppableNodeKey",null),_defineProperty(_assertThisInitialized(d),"listRef",reactExports.createRef()),_defineProperty(_assertThisInitialized(d),"onNodeDragStart",function(y,b){var E=d.state,C=E.expandedKeys,w=E.keyEntities,R=d.props.onDragStart,_=b.eventKey;d.dragNodeProps=b,d.dragStartMousePosition={x:y.clientX,y:y.clientY};var M=arrDel(C,_);d.setState({draggingNodeKey:_,dragChildrenKeys:getDragChildrenKeys(_,w),indent:d.listRef.current.getIndentWidth()}),d.setExpandedKeys(M),window.addEventListener("dragend",d.onWindowDragEnd),R==null||R({event:y,node:convertNodePropsToEventData(b)})}),_defineProperty(_assertThisInitialized(d),"onNodeDragEnter",function(y,b){var E=d.state,C=E.expandedKeys,w=E.keyEntities,R=E.dragChildrenKeys,_=E.flattenNodes,M=E.indent,I=d.props,N=I.onDragEnter,A=I.onExpand,P=I.allowDrop,z=I.direction,B=b.pos,j=b.eventKey;if(d.currentMouseOverDroppableNodeKey!==j&&(d.currentMouseOverDroppableNodeKey=j),!d.dragNodeProps){d.resetDragState();return}var L=calcDropPosition(y,d.dragNodeProps,b,M,d.dragStartMousePosition,P,_,w,C,z),U=L.dropPosition,q=L.dropLevelOffset,F=L.dropTargetKey,K=L.dropContainerKey,X=L.dropTargetPos,Q=L.dropAllowed,Y=L.dragOverNodeKey;if(R.includes(F)||!Q){d.resetDragState();return}if(d.delayedDragEnterLogic||(d.delayedDragEnterLogic={}),Object.keys(d.delayedDragEnterLogic).forEach(function(Z){clearTimeout(d.delayedDragEnterLogic[Z])}),d.dragNodeProps.eventKey!==b.eventKey&&(y.persist(),d.delayedDragEnterLogic[B]=window.setTimeout(function(){if(d.state.draggingNodeKey!==null){var Z=_toConsumableArray(C),J=getEntity(w,b.eventKey);J&&(J.children||[]).length&&(Z=arrAdd(C,b.eventKey)),d.props.hasOwnProperty("expandedKeys")||d.setExpandedKeys(Z),A==null||A(Z,{node:convertNodePropsToEventData(b),expanded:!0,nativeEvent:y.nativeEvent})}},800)),d.dragNodeProps.eventKey===F&&q===0){d.resetDragState();return}d.setState({dragOverNodeKey:Y,dropPosition:U,dropLevelOffset:q,dropTargetKey:F,dropContainerKey:K,dropTargetPos:X,dropAllowed:Q}),N==null||N({event:y,node:convertNodePropsToEventData(b),expandedKeys:C})}),_defineProperty(_assertThisInitialized(d),"onNodeDragOver",function(y,b){var E=d.state,C=E.dragChildrenKeys,w=E.flattenNodes,R=E.keyEntities,_=E.expandedKeys,M=E.indent,I=d.props,N=I.onDragOver,A=I.allowDrop,P=I.direction;if(d.dragNodeProps){var z=calcDropPosition(y,d.dragNodeProps,b,M,d.dragStartMousePosition,A,w,R,_,P),B=z.dropPosition,j=z.dropLevelOffset,L=z.dropTargetKey,U=z.dropContainerKey,q=z.dropTargetPos,F=z.dropAllowed,K=z.dragOverNodeKey;C.includes(L)||!F||(d.dragNodeProps.eventKey===L&&j===0?d.state.dropPosition===null&&d.state.dropLevelOffset===null&&d.state.dropTargetKey===null&&d.state.dropContainerKey===null&&d.state.dropTargetPos===null&&d.state.dropAllowed===!1&&d.state.dragOverNodeKey===null||d.resetDragState():B===d.state.dropPosition&&j===d.state.dropLevelOffset&&L===d.state.dropTargetKey&&U===d.state.dropContainerKey&&q===d.state.dropTargetPos&&F===d.state.dropAllowed&&K===d.state.dragOverNodeKey||d.setState({dropPosition:B,dropLevelOffset:j,dropTargetKey:L,dropContainerKey:U,dropTargetPos:q,dropAllowed:F,dragOverNodeKey:K}),N==null||N({event:y,node:convertNodePropsToEventData(b)}))}}),_defineProperty(_assertThisInitialized(d),"onNodeDragLeave",function(y,b){d.currentMouseOverDroppableNodeKey===b.eventKey&&!y.currentTarget.contains(y.relatedTarget)&&(d.resetDragState(),d.currentMouseOverDroppableNodeKey=null);var E=d.props.onDragLeave;E==null||E({event:y,node:convertNodePropsToEventData(b)})}),_defineProperty(_assertThisInitialized(d),"onWindowDragEnd",function(y){d.onNodeDragEnd(y,null,!0),window.removeEventListener("dragend",d.onWindowDragEnd)}),_defineProperty(_assertThisInitialized(d),"onNodeDragEnd",function(y,b){var E=d.props.onDragEnd;d.setState({dragOverNodeKey:null}),d.cleanDragState(),E==null||E({event:y,node:convertNodePropsToEventData(b)}),d.dragNodeProps=null,window.removeEventListener("dragend",d.onWindowDragEnd)}),_defineProperty(_assertThisInitialized(d),"onNodeDrop",function(y,b){var E,C=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1,w=d.state,R=w.dragChildrenKeys,_=w.dropPosition,M=w.dropTargetKey,I=w.dropTargetPos,N=w.dropAllowed;if(N){var A=d.props.onDrop;if(d.setState({dragOverNodeKey:null}),d.cleanDragState(),M!==null){var P=_objectSpread2(_objectSpread2({},getTreeNodeProps(M,d.getTreeNodeRequiredProps())),{},{active:((E=d.getActiveItem())===null||E===void 0?void 0:E.key)===M,data:getEntity(d.state.keyEntities,M).node}),z=R.includes(M);warningOnce$1(!z,"Can not drop to dragNode's children node. This is a bug of rc-tree. Please report an issue.");var B=posToArr(I),j={event:y,node:convertNodePropsToEventData(P),dragNode:d.dragNodeProps?convertNodePropsToEventData(d.dragNodeProps):null,dragNodesKeys:[d.dragNodeProps.eventKey].concat(R),dropToGap:_!==0,dropPosition:_+Number(B[B.length-1])};C||A==null||A(j),d.dragNodeProps=null}}}),_defineProperty(_assertThisInitialized(d),"cleanDragState",function(){var y=d.state.draggingNodeKey;y!==null&&d.setState({draggingNodeKey:null,dropPosition:null,dropContainerKey:null,dropTargetKey:null,dropLevelOffset:null,dropAllowed:!0,dragOverNodeKey:null}),d.dragStartMousePosition=null,d.currentMouseOverDroppableNodeKey=null}),_defineProperty(_assertThisInitialized(d),"triggerExpandActionExpand",function(y,b){var E=d.state,C=E.expandedKeys,w=E.flattenNodes,R=b.expanded,_=b.key,M=b.isLeaf;if(!(M||y.shiftKey||y.metaKey||y.ctrlKey)){var I=w.filter(function(A){return A.key===_})[0],N=convertNodePropsToEventData(_objectSpread2(_objectSpread2({},getTreeNodeProps(_,d.getTreeNodeRequiredProps())),{},{data:I.data}));d.setExpandedKeys(R?arrDel(C,_):arrAdd(C,_)),d.onNodeExpand(y,N)}}),_defineProperty(_assertThisInitialized(d),"onNodeClick",function(y,b){var E=d.props,C=E.onClick,w=E.expandAction;w==="click"&&d.triggerExpandActionExpand(y,b),C==null||C(y,b)}),_defineProperty(_assertThisInitialized(d),"onNodeDoubleClick",function(y,b){var E=d.props,C=E.onDoubleClick,w=E.expandAction;w==="doubleClick"&&d.triggerExpandActionExpand(y,b),C==null||C(y,b)}),_defineProperty(_assertThisInitialized(d),"onNodeSelect",function(y,b){var E=d.state.selectedKeys,C=d.state,w=C.keyEntities,R=C.fieldNames,_=d.props,M=_.onSelect,I=_.multiple,N=b.selected,A=b[R.key],P=!N;P?I?E=arrAdd(E,A):E=[A]:E=arrDel(E,A);var z=E.map(function(B){var j=getEntity(w,B);return j?j.node:null}).filter(Boolean);d.setUncontrolledState({selectedKeys:E}),M==null||M(E,{event:"select",selected:P,node:b,selectedNodes:z,nativeEvent:y.nativeEvent})}),_defineProperty(_assertThisInitialized(d),"onNodeCheck",function(y,b,E){var C=d.state,w=C.keyEntities,R=C.checkedKeys,_=C.halfCheckedKeys,M=d.props,I=M.checkStrictly,N=M.onCheck,A=b.key,P,z={event:"check",node:b,checked:E,nativeEvent:y.nativeEvent};if(I){var B=E?arrAdd(R,A):arrDel(R,A),j=arrDel(_,A);P={checked:B,halfChecked:j},z.checkedNodes=B.map(function(X){return getEntity(w,X)}).filter(Boolean).map(function(X){return X.node}),d.setUncontrolledState({checkedKeys:B})}else{var L=conductCheck([].concat(_toConsumableArray(R),[A]),!0,w),U=L.checkedKeys,q=L.halfCheckedKeys;if(!E){var F=new Set(U);F.delete(A);var K=conductCheck(Array.from(F),{halfCheckedKeys:q},w);U=K.checkedKeys,q=K.halfCheckedKeys}P=U,z.checkedNodes=[],z.checkedNodesPositions=[],z.halfCheckedKeys=q,U.forEach(function(X){var Q=getEntity(w,X);if(Q){var Y=Q.node,Z=Q.pos;z.checkedNodes.push(Y),z.checkedNodesPositions.push({node:Y,pos:Z})}}),d.setUncontrolledState({checkedKeys:U},!1,{halfCheckedKeys:q})}N==null||N(P,z)}),_defineProperty(_assertThisInitialized(d),"onNodeLoad",function(y){var b,E=y.key,C=d.state.keyEntities,w=getEntity(C,E);if(!(w!=null&&(b=w.children)!==null&&b!==void 0&&b.length)){var R=new Promise(function(_,M){d.setState(function(I){var N=I.loadedKeys,A=N===void 0?[]:N,P=I.loadingKeys,z=P===void 0?[]:P,B=d.props,j=B.loadData,L=B.onLoad;if(!j||A.includes(E)||z.includes(E))return null;var U=j(y);return U.then(function(){var q=d.state.loadedKeys,F=arrAdd(q,E);L==null||L(F,{event:"load",node:y}),d.setUncontrolledState({loadedKeys:F}),d.setState(function(K){return{loadingKeys:arrDel(K.loadingKeys,E)}}),_()}).catch(function(q){if(d.setState(function(K){return{loadingKeys:arrDel(K.loadingKeys,E)}}),d.loadingRetryTimes[E]=(d.loadingRetryTimes[E]||0)+1,d.loadingRetryTimes[E]>=MAX_RETRY_TIMES){var F=d.state.loadedKeys;warningOnce$1(!1,"Retry for `loadData` many times but still failed. No more retry."),d.setUncontrolledState({loadedKeys:arrAdd(F,E)}),_()}M(q)}),{loadingKeys:arrAdd(z,E)}})});return R.catch(function(){}),R}}),_defineProperty(_assertThisInitialized(d),"onNodeMouseEnter",function(y,b){var E=d.props.onMouseEnter;E==null||E({event:y,node:b})}),_defineProperty(_assertThisInitialized(d),"onNodeMouseLeave",function(y,b){var E=d.props.onMouseLeave;E==null||E({event:y,node:b})}),_defineProperty(_assertThisInitialized(d),"onNodeContextMenu",function(y,b){var E=d.props.onRightClick;E&&(y.preventDefault(),E({event:y,node:b}))}),_defineProperty(_assertThisInitialized(d),"onFocus",function(){var y=d.props.onFocus;d.setState({focused:!0});for(var b=arguments.length,E=new Array(b),C=0;C<b;C++)E[C]=arguments[C];y==null||y.apply(void 0,E)}),_defineProperty(_assertThisInitialized(d),"onBlur",function(){var y=d.props.onBlur;d.setState({focused:!1}),d.onActiveChange(null);for(var b=arguments.length,E=new Array(b),C=0;C<b;C++)E[C]=arguments[C];y==null||y.apply(void 0,E)}),_defineProperty(_assertThisInitialized(d),"getTreeNodeRequiredProps",function(){var y=d.state,b=y.expandedKeys,E=y.selectedKeys,C=y.loadedKeys,w=y.loadingKeys,R=y.checkedKeys,_=y.halfCheckedKeys,M=y.dragOverNodeKey,I=y.dropPosition,N=y.keyEntities;return{expandedKeys:b||[],selectedKeys:E||[],loadedKeys:C||[],loadingKeys:w||[],checkedKeys:R||[],halfCheckedKeys:_||[],dragOverNodeKey:M,dropPosition:I,keyEntities:N}}),_defineProperty(_assertThisInitialized(d),"setExpandedKeys",function(y){var b=d.state,E=b.treeData,C=b.fieldNames,w=flattenTreeData(E,y,C);d.setUncontrolledState({expandedKeys:y,flattenNodes:w},!0)}),_defineProperty(_assertThisInitialized(d),"onNodeExpand",function(y,b){var E=d.state.expandedKeys,C=d.state,w=C.listChanging,R=C.fieldNames,_=d.props,M=_.onExpand,I=_.loadData,N=b.expanded,A=b[R.key];if(!w){var P=E.includes(A),z=!N;if(warningOnce$1(N&&P||!N&&!P,"Expand state not sync with index check"),E=z?arrAdd(E,A):arrDel(E,A),d.setExpandedKeys(E),M==null||M(E,{node:b,expanded:z,nativeEvent:y.nativeEvent}),z&&I){var B=d.onNodeLoad(b);B&&B.then(function(){var j=flattenTreeData(d.state.treeData,E,R);d.setUncontrolledState({flattenNodes:j})}).catch(function(){var j=d.state.expandedKeys,L=arrDel(j,A);d.setExpandedKeys(L)})}}}),_defineProperty(_assertThisInitialized(d),"onListChangeStart",function(){d.setUncontrolledState({listChanging:!0})}),_defineProperty(_assertThisInitialized(d),"onListChangeEnd",function(){setTimeout(function(){d.setUncontrolledState({listChanging:!1})})}),_defineProperty(_assertThisInitialized(d),"onActiveChange",function(y){var b=d.state.activeKey,E=d.props,C=E.onActiveChange,w=E.itemScrollOffset,R=w===void 0?0:w;b!==y&&(d.setState({activeKey:y}),y!==null&&d.scrollTo({key:y,offset:R}),C==null||C(y))}),_defineProperty(_assertThisInitialized(d),"getActiveItem",function(){var y=d.state,b=y.activeKey,E=y.flattenNodes;return b===null?null:E.find(function(C){var w=C.key;return w===b})||null}),_defineProperty(_assertThisInitialized(d),"offsetActiveKey",function(y){var b=d.state,E=b.flattenNodes,C=b.activeKey,w=E.findIndex(function(M){var I=M.key;return I===C});w===-1&&y<0&&(w=E.length),w=(w+y+E.length)%E.length;var R=E[w];if(R){var _=R.key;d.onActiveChange(_)}else d.onActiveChange(null)}),_defineProperty(_assertThisInitialized(d),"onKeyDown",function(y){var b=d.state,E=b.activeKey,C=b.expandedKeys,w=b.checkedKeys,R=b.fieldNames,_=d.props,M=_.onKeyDown,I=_.checkable,N=_.selectable;switch(y.which){case KeyCode.UP:{d.offsetActiveKey(-1),y.preventDefault();break}case KeyCode.DOWN:{d.offsetActiveKey(1),y.preventDefault();break}}var A=d.getActiveItem();if(A&&A.data){var P=d.getTreeNodeRequiredProps(),z=A.data.isLeaf===!1||!!(A.data[R.children]||[]).length,B=convertNodePropsToEventData(_objectSpread2(_objectSpread2({},getTreeNodeProps(E,P)),{},{data:A.data,active:!0}));switch(y.which){case KeyCode.LEFT:{z&&C.includes(E)?d.onNodeExpand({},B):A.parent&&d.onActiveChange(A.parent.key),y.preventDefault();break}case KeyCode.RIGHT:{z&&!C.includes(E)?d.onNodeExpand({},B):A.children&&A.children.length&&d.onActiveChange(A.children[0].key),y.preventDefault();break}case KeyCode.ENTER:case KeyCode.SPACE:{I&&!B.disabled&&B.checkable!==!1&&!B.disableCheckbox?d.onNodeCheck({},B,!w.includes(E)):!I&&N&&!B.disabled&&B.selectable!==!1&&d.onNodeSelect({},B);break}}}M==null||M(y)}),_defineProperty(_assertThisInitialized(d),"setUncontrolledState",function(y){var b=arguments.length>1&&arguments[1]!==void 0?arguments[1]:!1,E=arguments.length>2&&arguments[2]!==void 0?arguments[2]:null;if(!d.destroyed){var C=!1,w=!0,R={};Object.keys(y).forEach(function(_){if(d.props.hasOwnProperty(_)){w=!1;return}C=!0,R[_]=y[_]}),C&&(!b||w)&&d.setState(_objectSpread2(_objectSpread2({},R),E))}}),_defineProperty(_assertThisInitialized(d),"scrollTo",function(y){d.listRef.current.scrollTo(y)}),d}return _createClass(u,[{key:"componentDidMount",value:function(){this.destroyed=!1,this.onUpdated()}},{key:"componentDidUpdate",value:function(){this.onUpdated()}},{key:"onUpdated",value:function(){var f=this.props,m=f.activeKey,g=f.itemScrollOffset,y=g===void 0?0:g;m!==void 0&&m!==this.state.activeKey&&(this.setState({activeKey:m}),m!==null&&this.scrollTo({key:m,offset:y}))}},{key:"componentWillUnmount",value:function(){window.removeEventListener("dragend",this.onWindowDragEnd),this.destroyed=!0}},{key:"resetDragState",value:function(){this.setState({dragOverNodeKey:null,dropPosition:null,dropLevelOffset:null,dropTargetKey:null,dropContainerKey:null,dropTargetPos:null,dropAllowed:!1})}},{key:"render",value:function(){var f=this.state,m=f.focused,g=f.flattenNodes,y=f.keyEntities,b=f.draggingNodeKey,E=f.activeKey,C=f.dropLevelOffset,w=f.dropContainerKey,R=f.dropTargetKey,_=f.dropPosition,M=f.dragOverNodeKey,I=f.indent,N=this.props,A=N.prefixCls,P=N.className,z=N.style,B=N.showLine,j=N.focusable,L=N.tabIndex,U=L===void 0?0:L,q=N.selectable,F=N.showIcon,K=N.icon,X=N.switcherIcon,Q=N.draggable,Y=N.checkable,Z=N.checkStrictly,J=N.disabled,W=N.motion,G=N.loadData,te=N.filterTreeNode,ae=N.height,V=N.itemHeight,ne=N.scrollWidth,le=N.virtual,ee=N.titleRender,ie=N.dropIndicatorRender,ce=N.onContextMenu,ue=N.onScroll,me=N.direction,de=N.rootClassName,ge=N.rootStyle,Ce=pickAttrs(this.props,{aria:!0,data:!0}),ve;Q&&(_typeof(Q)==="object"?ve=Q:typeof Q=="function"?ve={nodeDraggable:Q}:ve={});var fe={prefixCls:A,selectable:q,showIcon:F,icon:K,switcherIcon:X,draggable:ve,draggingNodeKey:b,checkable:Y,checkStrictly:Z,disabled:J,keyEntities:y,dropLevelOffset:C,dropContainerKey:w,dropTargetKey:R,dropPosition:_,dragOverNodeKey:M,indent:I,direction:me,dropIndicatorRender:ie,loadData:G,filterTreeNode:te,titleRender:ee,onNodeClick:this.onNodeClick,onNodeDoubleClick:this.onNodeDoubleClick,onNodeExpand:this.onNodeExpand,onNodeSelect:this.onNodeSelect,onNodeCheck:this.onNodeCheck,onNodeLoad:this.onNodeLoad,onNodeMouseEnter:this.onNodeMouseEnter,onNodeMouseLeave:this.onNodeMouseLeave,onNodeContextMenu:this.onNodeContextMenu,onNodeDragStart:this.onNodeDragStart,onNodeDragEnter:this.onNodeDragEnter,onNodeDragOver:this.onNodeDragOver,onNodeDragLeave:this.onNodeDragLeave,onNodeDragEnd:this.onNodeDragEnd,onNodeDrop:this.onNodeDrop};return reactExports.createElement(TreeContext.Provider,{value:fe},reactExports.createElement("div",{className:classNames(A,P,de,_defineProperty(_defineProperty(_defineProperty({},"".concat(A,"-show-line"),B),"".concat(A,"-focused"),m),"".concat(A,"-active-focused"),E!==null)),style:ge},reactExports.createElement(NodeList,_extends({ref:this.listRef,prefixCls:A,style:z,data:g,disabled:J,selectable:q,checkable:!!Y,motion:W,dragging:b!==null,height:ae,itemHeight:V,virtual:le,focusable:j,focused:m,tabIndex:U,activeItem:this.getActiveItem(),onFocus:this.onFocus,onBlur:this.onBlur,onKeyDown:this.onKeyDown,onActiveChange:this.onActiveChange,onListChangeStart:this.onListChangeStart,onListChangeEnd:this.onListChangeEnd,onContextMenu:ce,onScroll:ue,scrollWidth:ne},this.getTreeNodeRequiredProps(),Ce))))}}],[{key:"getDerivedStateFromProps",value:function(f,m){var g=m.prevProps,y={prevProps:f};function b(U){return!g&&f.hasOwnProperty(U)||g&&g[U]!==f[U]}var E,C=m.fieldNames;if(b("fieldNames")&&(C=fillFieldNames(f.fieldNames),y.fieldNames=C),b("treeData")?E=f.treeData:b("children")&&(warningOnce$1(!1,"`children` of Tree is deprecated. Please use `treeData` instead."),E=convertTreeToData(f.children)),E){y.treeData=E;var w=convertDataToEntities(E,{fieldNames:C});y.keyEntities=_objectSpread2(_defineProperty({},MOTION_KEY,MotionEntity),w.keyEntities)}var R=y.keyEntities||m.keyEntities;if(b("expandedKeys")||g&&b("autoExpandParent"))y.expandedKeys=f.autoExpandParent||!g&&f.defaultExpandParent?conductExpandParent(f.expandedKeys,R):f.expandedKeys;else if(!g&&f.defaultExpandAll){var _=_objectSpread2({},R);delete _[MOTION_KEY];var M=[];Object.keys(_).forEach(function(U){var q=_[U];q.children&&q.children.length&&M.push(q.key)}),y.expandedKeys=M}else!g&&f.defaultExpandedKeys&&(y.expandedKeys=f.autoExpandParent||f.defaultExpandParent?conductExpandParent(f.defaultExpandedKeys,R):f.defaultExpandedKeys);if(y.expandedKeys||delete y.expandedKeys,E||y.expandedKeys){var I=flattenTreeData(E||m.treeData,y.expandedKeys||m.expandedKeys,C);y.flattenNodes=I}if(f.selectable&&(b("selectedKeys")?y.selectedKeys=calcSelectedKeys(f.selectedKeys,f):!g&&f.defaultSelectedKeys&&(y.selectedKeys=calcSelectedKeys(f.defaultSelectedKeys,f))),f.checkable){var N;if(b("checkedKeys")?N=parseCheckedKeys(f.checkedKeys)||{}:!g&&f.defaultCheckedKeys?N=parseCheckedKeys(f.defaultCheckedKeys)||{}:E&&(N=parseCheckedKeys(f.checkedKeys)||{checkedKeys:m.checkedKeys,halfCheckedKeys:m.halfCheckedKeys}),N){var A=N,P=A.checkedKeys,z=P===void 0?[]:P,B=A.halfCheckedKeys,j=B===void 0?[]:B;if(!f.checkStrictly){var L=conductCheck(z,!0,R);z=L.checkedKeys,j=L.halfCheckedKeys}y.checkedKeys=z,y.halfCheckedKeys=j}}return b("loadedKeys")&&(y.loadedKeys=f.loadedKeys),y}}]),u}(reactExports.Component);_defineProperty(Tree$2,"defaultProps",{prefixCls:"rc-tree",showLine:!1,showIcon:!0,selectable:!0,multiple:!1,checkable:!1,disabled:!1,checkStrictly:!1,draggable:!1,defaultExpandParent:!0,autoExpandParent:!1,defaultExpandAll:!1,defaultExpandedKeys:[],defaultCheckedKeys:[],defaultSelectedKeys:[],dropIndicatorRender:DropIndicator,allowDrop:function(){return!0},expandAction:!1});_defineProperty(Tree$2,"TreeNode",TreeNode);const genDirectoryStyle=a=>{let{treeCls:c,treeNodeCls:u,directoryNodeSelectedBg:d,directoryNodeSelectedColor:f,motionDurationMid:m,borderRadius:g,controlItemBgHover:y}=a;return{[`${c}${c}-directory ${u}`]:{[`${c}-node-content-wrapper`]:{position:"static",[`> *:not(${c}-drop-indicator)`]:{position:"relative"},"&:hover":{background:"transparent"},"&:before":{position:"absolute",inset:0,transition:`background-color ${m}`,content:'""',borderRadius:g},"&:hover:before":{background:y}},[`${c}-switcher, ${c}-checkbox, ${c}-draggable-icon`]:{zIndex:1},"&-selected":{[`${c}-switcher, ${c}-draggable-icon`]:{color:f},[`${c}-node-content-wrapper`]:{color:f,background:"transparent","&:before, &:hover:before":{background:d}}}}}},treeNodeFX=new Keyframe("ant-tree-node-fx-do-not-use",{"0%":{opacity:0},"100%":{opacity:1}}),getSwitchStyle=(a,c)=>({[`.${a}-switcher-icon`]:{display:"inline-block",fontSize:10,verticalAlign:"baseline",svg:{transition:`transform ${c.motionDurationSlow}`}}}),getDropIndicatorStyle=(a,c)=>({[`.${a}-drop-indicator`]:{position:"absolute",zIndex:1,height:2,backgroundColor:c.colorPrimary,borderRadius:1,pointerEvents:"none","&:after":{position:"absolute",top:-3,insetInlineStart:-6,width:8,height:8,backgroundColor:"transparent",border:`${unit$1(c.lineWidthBold)} solid ${c.colorPrimary}`,borderRadius:"50%",content:'""'}}}),genBaseStyle$1=(a,c)=>{const{treeCls:u,treeNodeCls:d,treeNodePadding:f,titleHeight:m,indentSize:g,nodeSelectedBg:y,nodeHoverBg:b,colorTextQuaternary:E,controlItemBgActiveDisabled:C}=c;return{[u]:Object.assign(Object.assign({},resetComponent(c)),{background:c.colorBgContainer,borderRadius:c.borderRadius,transition:`background-color ${c.motionDurationSlow}`,"&-rtl":{direction:"rtl"},[`&${u}-rtl ${u}-switcher_close ${u}-switcher-icon svg`]:{transform:"rotate(90deg)"},[`&-focused:not(:hover):not(${u}-active-focused)`]:Object.assign({},genFocusOutline(c)),[`${u}-list-holder-inner`]:{alignItems:"flex-start"},[`&${u}-block-node`]:{[`${u}-list-holder-inner`]:{alignItems:"stretch",[`${u}-node-content-wrapper`]:{flex:"auto"},[`${d}.dragging:after`]:{position:"absolute",inset:0,border:`1px solid ${c.colorPrimary}`,opacity:0,animationName:treeNodeFX,animationDuration:c.motionDurationSlow,animationPlayState:"running",animationFillMode:"forwards",content:'""',pointerEvents:"none",borderRadius:c.borderRadius}}},[d]:{display:"flex",alignItems:"flex-start",marginBottom:f,lineHeight:unit$1(m),position:"relative","&:before":{content:'""',position:"absolute",zIndex:1,insetInlineStart:0,width:"100%",top:"100%",height:f},[`&-disabled ${u}-node-content-wrapper`]:{color:c.colorTextDisabled,cursor:"not-allowed","&:hover":{background:"transparent"}},[`${u}-checkbox-disabled + ${u}-node-selected,&${d}-disabled${d}-selected ${u}-node-content-wrapper`]:{backgroundColor:C},[`${u}-checkbox-disabled`]:{pointerEvents:"unset"},[`&:not(${d}-disabled)`]:{[`${u}-node-content-wrapper`]:{"&:hover":{color:c.nodeHoverColor}}},[`&-active ${u}-node-content-wrapper`]:{background:c.controlItemBgHover},[`&:not(${d}-disabled).filter-node ${u}-title`]:{color:c.colorPrimary,fontWeight:500},"&-draggable":{cursor:"grab",[`${u}-draggable-icon`]:{flexShrink:0,width:m,textAlign:"center",visibility:"visible",color:E},[`&${d}-disabled ${u}-draggable-icon`]:{visibility:"hidden"}}},[`${u}-indent`]:{alignSelf:"stretch",whiteSpace:"nowrap",userSelect:"none","&-unit":{display:"inline-block",width:g}},[`${u}-draggable-icon`]:{visibility:"hidden"},[`${u}-switcher, ${u}-checkbox`]:{marginInlineEnd:c.calc(c.calc(m).sub(c.controlInteractiveSize)).div(2).equal()},[`${u}-switcher`]:Object.assign(Object.assign({},getSwitchStyle(a,c)),{position:"relative",flex:"none",alignSelf:"stretch",width:m,textAlign:"center",cursor:"pointer",userSelect:"none",transition:`all ${c.motionDurationSlow}`,"&-noop":{cursor:"unset"},"&:before":{pointerEvents:"none",content:'""',width:m,height:m,position:"absolute",left:{_skip_check_:!0,value:0},top:0,borderRadius:c.borderRadius,transition:`all ${c.motionDurationSlow}`},[`&:not(${u}-switcher-noop):hover:before`]:{backgroundColor:c.colorBgTextHover},[`&_close ${u}-switcher-icon svg`]:{transform:"rotate(-90deg)"},"&-loading-icon":{color:c.colorPrimary},"&-leaf-line":{position:"relative",zIndex:1,display:"inline-block",width:"100%",height:"100%","&:before":{position:"absolute",top:0,insetInlineEnd:c.calc(m).div(2).equal(),bottom:c.calc(f).mul(-1).equal(),marginInlineStart:-1,borderInlineEnd:`1px solid ${c.colorBorder}`,content:'""'},"&:after":{position:"absolute",width:c.calc(c.calc(m).div(2).equal()).mul(.8).equal(),height:c.calc(m).div(2).equal(),borderBottom:`1px solid ${c.colorBorder}`,content:'""'}}}),[`${u}-node-content-wrapper`]:Object.assign(Object.assign({position:"relative",minHeight:m,paddingBlock:0,paddingInline:c.paddingXS,background:"transparent",borderRadius:c.borderRadius,cursor:"pointer",transition:`all ${c.motionDurationMid}, border 0s, line-height 0s, box-shadow 0s`},getDropIndicatorStyle(a,c)),{"&:hover":{backgroundColor:b},[`&${u}-node-selected`]:{color:c.nodeSelectedColor,backgroundColor:y},[`${u}-iconEle`]:{display:"inline-block",width:m,height:m,textAlign:"center",verticalAlign:"top","&:empty":{display:"none"}}}),[`${u}-unselectable ${u}-node-content-wrapper:hover`]:{backgroundColor:"transparent"},[`${d}.drop-container > [draggable]`]:{boxShadow:`0 0 0 2px ${c.colorPrimary}`},"&-show-line":{[`${u}-indent-unit`]:{position:"relative",height:"100%","&:before":{position:"absolute",top:0,insetInlineEnd:c.calc(m).div(2).equal(),bottom:c.calc(f).mul(-1).equal(),borderInlineEnd:`1px solid ${c.colorBorder}`,content:'""'},"&-end:before":{display:"none"}},[`${u}-switcher`]:{background:"transparent","&-line-icon":{verticalAlign:"-0.15em"}}},[`${d}-leaf-last ${u}-switcher-leaf-line:before`]:{top:"auto !important",bottom:"auto !important",height:`${unit$1(c.calc(m).div(2).equal())} !important`}})}},genTreeStyle=function(a,c){let u=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!0;const d=`.${a}`,f=`${d}-treenode`,m=c.calc(c.paddingXS).div(2).equal(),g=merge$2(c,{treeCls:d,treeNodeCls:f,treeNodePadding:m});return[genBaseStyle$1(a,g),u&&genDirectoryStyle(g)].filter(Boolean)},initComponentToken=a=>{const{controlHeightSM:c,controlItemBgHover:u,controlItemBgActive:d}=a,f=c;return{titleHeight:f,indentSize:f,nodeHoverBg:u,nodeHoverColor:a.colorText,nodeSelectedBg:d,nodeSelectedColor:a.colorText}},prepareComponentToken$3=a=>{const{colorTextLightSolid:c,colorPrimary:u}=a;return Object.assign(Object.assign({},initComponentToken(a)),{directoryNodeSelectedColor:c,directoryNodeSelectedBg:u})},useStyle$3=genStyleHooks("Tree",(a,c)=>{let{prefixCls:u}=c;return[{[a.componentCls]:getStyle(`${u}-checkbox`,a)},genTreeStyle(u,a),genCollapseMotion(a)]},prepareComponentToken$3),offset=4;function dropIndicatorRender(a){const{dropPosition:c,dropLevelOffset:u,prefixCls:d,indent:f,direction:m="ltr"}=a,g=m==="ltr"?"left":"right",y=m==="ltr"?"right":"left",b={[g]:-u*f+offset,[y]:0};switch(c){case-1:b.top=-3;break;case 1:b.bottom=-3;break;default:b.bottom=-3,b[g]=f+offset;break}return React.createElement("div",{style:b,className:`${d}-drop-indicator`})}const SwitcherIconCom=a=>{const{prefixCls:c,switcherIcon:u,treeNodeProps:d,showLine:f,switcherLoadingIcon:m}=a,{isLeaf:g,expanded:y,loading:b}=d;if(b)return reactExports.isValidElement(m)?m:reactExports.createElement(RefIcon$e,{className:`${c}-switcher-loading-icon`});let E;if(f&&typeof f=="object"&&(E=f.showLeafIcon),g){if(!f)return null;if(typeof E!="boolean"&&E){const R=typeof E=="function"?E(d):E,_=`${c}-switcher-line-custom-icon`;return reactExports.isValidElement(R)?cloneElement(R,{className:classNames(R.props.className||"",_)}):R}return E?reactExports.createElement(RefIcon$m,{className:`${c}-switcher-line-icon`}):reactExports.createElement("span",{className:`${c}-switcher-leaf-line`})}const C=`${c}-switcher-icon`,w=typeof u=="function"?u(d):u;return reactExports.isValidElement(w)?cloneElement(w,{className:classNames(w.props.className||"",C)}):w!==void 0?w:f?y?reactExports.createElement(RefIcon$d,{className:`${c}-switcher-line-icon`}):reactExports.createElement(RefIcon$a,{className:`${c}-switcher-line-icon`}):reactExports.createElement(RefIcon$D,{className:C})},Tree$1=React.forwardRef((a,c)=>{var u;const{getPrefixCls:d,direction:f,virtual:m,tree:g}=React.useContext(ConfigContext),{prefixCls:y,className:b,showIcon:E=!1,showLine:C,switcherIcon:w,switcherLoadingIcon:R,blockNode:_=!1,children:M,checkable:I=!1,selectable:N=!0,draggable:A,motion:P,style:z}=a,B=d("tree",y),j=d(),L=P??Object.assign(Object.assign({},initCollapseMotion(j)),{motionAppear:!1}),U=Object.assign(Object.assign({},a),{checkable:I,selectable:N,showIcon:E,motion:L,blockNode:_,showLine:!!C,dropIndicatorRender}),[q,F,K]=useStyle$3(B),[,X]=useToken$1(),Q=X.paddingXS/2+(((u=X.Tree)===null||u===void 0?void 0:u.titleHeight)||X.controlHeightSM),Y=React.useMemo(()=>{if(!A)return!1;let J={};switch(typeof A){case"function":J.nodeDraggable=A;break;case"object":J=Object.assign({},A);break}return J.icon!==!1&&(J.icon=J.icon||React.createElement(RefIcon$i,null)),J},[A]),Z=J=>React.createElement(SwitcherIconCom,{prefixCls:B,switcherIcon:w,switcherLoadingIcon:R,treeNodeProps:J,showLine:C});return q(React.createElement(Tree$2,Object.assign({itemHeight:Q,ref:c,virtual:m},U,{style:Object.assign(Object.assign({},g==null?void 0:g.style),z),prefixCls:B,className:classNames({[`${B}-icon-hide`]:!E,[`${B}-block-node`]:_,[`${B}-unselectable`]:!N,[`${B}-rtl`]:f==="rtl"},g==null?void 0:g.className,b,F,K),direction:f,checkable:I&&React.createElement("span",{className:`${B}-checkbox-inner`}),selectable:N,switcherIcon:Z,draggable:Y}),M))}),RECORD_NONE=0,RECORD_START=1,RECORD_END=2;function traverseNodesKey(a,c,u){const{key:d,children:f}=u;function m(g){const y=g[d],b=g[f];c(y,g)!==!1&&traverseNodesKey(b||[],c,u)}a.forEach(m)}function calcRangeKeys(a){let{treeData:c,expandedKeys:u,startKey:d,endKey:f,fieldNames:m}=a;const g=[];let y=RECORD_NONE;if(d&&d===f)return[d];if(!d||!f)return[];function b(E){return E===d||E===f}return traverseNodesKey(c,E=>{if(y===RECORD_END)return!1;if(b(E)){if(g.push(E),y===RECORD_NONE)y=RECORD_START;else if(y===RECORD_START)return y=RECORD_END,!1}else y===RECORD_START&&g.push(E);return u.includes(E)},fillFieldNames(m)),g}function convertDirectoryKeysToNodes(a,c,u){const d=_toConsumableArray(c),f=[];return traverseNodesKey(a,(m,g)=>{const y=d.indexOf(m);return y!==-1&&(f.push(g),d.splice(y,1)),!!d.length},fillFieldNames(u)),f}var __rest$8=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function getIcon(a){const{isLeaf:c,expanded:u}=a;return c?reactExports.createElement(RefIcon$m,null):u?reactExports.createElement(RefIcon$k,null):reactExports.createElement(RefIcon$j,null)}function getTreeData(a){let{treeData:c,children:u}=a;return c||convertTreeToData(u)}const DirectoryTree=(a,c)=>{var{defaultExpandAll:u,defaultExpandParent:d,defaultExpandedKeys:f}=a,m=__rest$8(a,["defaultExpandAll","defaultExpandParent","defaultExpandedKeys"]);const g=reactExports.useRef(null),y=reactExports.useRef(null),b=()=>{const{keyEntities:q}=convertDataToEntities(getTreeData(m));let F;return u?F=Object.keys(q):d?F=conductExpandParent(m.expandedKeys||f||[],q):F=m.expandedKeys||f||[],F},[E,C]=reactExports.useState(m.selectedKeys||m.defaultSelectedKeys||[]),[w,R]=reactExports.useState(()=>b());reactExports.useEffect(()=>{"selectedKeys"in m&&C(m.selectedKeys)},[m.selectedKeys]),reactExports.useEffect(()=>{"expandedKeys"in m&&R(m.expandedKeys)},[m.expandedKeys]);const _=(q,F)=>{var K;return"expandedKeys"in m||R(q),(K=m.onExpand)===null||K===void 0?void 0:K.call(m,q,F)},M=(q,F)=>{var K;const{multiple:X,fieldNames:Q}=m,{node:Y,nativeEvent:Z}=F,{key:J=""}=Y,W=getTreeData(m),G=Object.assign(Object.assign({},F),{selected:!0}),te=(Z==null?void 0:Z.ctrlKey)||(Z==null?void 0:Z.metaKey),ae=Z==null?void 0:Z.shiftKey;let V;X&&te?(V=q,g.current=J,y.current=V,G.selectedNodes=convertDirectoryKeysToNodes(W,V,Q)):X&&ae?(V=Array.from(new Set([].concat(_toConsumableArray(y.current||[]),_toConsumableArray(calcRangeKeys({treeData:W,expandedKeys:w,startKey:J,endKey:g.current,fieldNames:Q}))))),G.selectedNodes=convertDirectoryKeysToNodes(W,V,Q)):(V=[J],g.current=J,y.current=V,G.selectedNodes=convertDirectoryKeysToNodes(W,V,Q)),(K=m.onSelect)===null||K===void 0||K.call(m,V,G),"selectedKeys"in m||C(V)},{getPrefixCls:I,direction:N}=reactExports.useContext(ConfigContext),{prefixCls:A,className:P,showIcon:z=!0,expandAction:B="click"}=m,j=__rest$8(m,["prefixCls","className","showIcon","expandAction"]),L=I("tree",A),U=classNames(`${L}-directory`,{[`${L}-directory-rtl`]:N==="rtl"},P);return reactExports.createElement(Tree$1,Object.assign({icon:getIcon,ref:c,blockNode:!0},j,{showIcon:z,expandAction:B,prefixCls:L,className:U,expandedKeys:w,selectedKeys:E,onSelect:M,onExpand:_}))},ForwardDirectoryTree=reactExports.forwardRef(DirectoryTree),Tree=Tree$1;Tree.DirectoryTree=ForwardDirectoryTree;Tree.TreeNode=TreeNode;const FilterSearch=a=>{const{value:c,filterSearch:u,tablePrefixCls:d,locale:f,onChange:m}=a;return u?reactExports.createElement("div",{className:`${d}-filter-dropdown-search`},reactExports.createElement(Input$1,{prefix:reactExports.createElement(RefIcon$5,null),placeholder:f.filterSearchPlaceholder,onChange:m,value:c,htmlSize:1,className:`${d}-filter-dropdown-search-input`})):null},onKeyDown=a=>{const{keyCode:c}=a;c===KeyCode.ENTER&&a.stopPropagation()},FilterDropdownMenuWrapper=reactExports.forwardRef((a,c)=>reactExports.createElement("div",{className:a.className,onClick:u=>u.stopPropagation(),onKeyDown,ref:c},a.children));function flattenKeys(a){let c=[];return(a||[]).forEach(u=>{let{value:d,children:f}=u;c.push(d),f&&(c=[].concat(_toConsumableArray(c),_toConsumableArray(flattenKeys(f))))}),c}function hasSubMenu(a){return a.some(c=>{let{children:u}=c;return u})}function searchValueMatched(a,c){return typeof c=="string"||typeof c=="number"?c==null?void 0:c.toString().toLowerCase().includes(a.trim().toLowerCase()):!1}function renderFilterItems(a){let{filters:c,prefixCls:u,filteredKeys:d,filterMultiple:f,searchValue:m,filterSearch:g}=a;return c.map((y,b)=>{const E=String(y.value);if(y.children)return{key:E||b,label:y.text,popupClassName:`${u}-dropdown-submenu`,children:renderFilterItems({filters:y.children,prefixCls:u,filteredKeys:d,filterMultiple:f,searchValue:m,filterSearch:g})};const C=f?Checkbox:Radio,w={key:y.value!==void 0?E:b,label:reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(C,{checked:d.includes(E)}),reactExports.createElement("span",null,y.text))};return m.trim()?typeof g=="function"?g(m,y)?w:null:searchValueMatched(m,y.text)?w:null:w})}function wrapStringListType(a){return a||[]}const FilterDropdown=a=>{var c,u,d,f;const{tablePrefixCls:m,prefixCls:g,column:y,dropdownPrefixCls:b,columnKey:E,filterOnClose:C,filterMultiple:w,filterMode:R="menu",filterSearch:_=!1,filterState:M,triggerFilter:I,locale:N,children:A,getPopupContainer:P,rootClassName:z}=a,{filterResetToDefaultFilteredValue:B,defaultFilteredValue:j,filterDropdownProps:L={},filterDropdownOpen:U,filterDropdownVisible:q,onFilterDropdownVisibleChange:F,onFilterDropdownOpenChange:K}=y,[X,Q]=reactExports.useState(!1),Y=!!(M&&(!((c=M.filteredKeys)===null||c===void 0)&&c.length||M.forceFiltered)),Z=Ee=>{var Ne;Q(Ee),(Ne=L.onOpenChange)===null||Ne===void 0||Ne.call(L,Ee),K==null||K(Ee),F==null||F(Ee)},J=(f=(d=(u=L.open)!==null&&u!==void 0?u:U)!==null&&d!==void 0?d:q)!==null&&f!==void 0?f:X,W=M==null?void 0:M.filteredKeys,[G,te]=useSyncState(wrapStringListType(W)),ae=Ee=>{let{selectedKeys:Ne}=Ee;te(Ne)},V=(Ee,Ne)=>{let{node:_e,checked:ke}=Ne;ae(w?{selectedKeys:Ee}:{selectedKeys:ke&&_e.key?[_e.key]:[]})};reactExports.useEffect(()=>{X&&ae({selectedKeys:wrapStringListType(W)})},[W]);const[ne,le]=reactExports.useState([]),ee=Ee=>{le(Ee)},[ie,ce]=reactExports.useState(""),ue=Ee=>{const{value:Ne}=Ee.target;ce(Ne)};reactExports.useEffect(()=>{X||ce("")},[X]);const me=Ee=>{const Ne=Ee!=null&&Ee.length?Ee:null;if(Ne===null&&(!M||!M.filteredKeys)||isEqual(Ne,M==null?void 0:M.filteredKeys,!0))return null;I({column:y,key:E,filteredKeys:Ne})},de=()=>{Z(!1),me(G())},ge=function(){let{confirm:Ee,closeDropdown:Ne}=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{confirm:!1,closeDropdown:!1};Ee&&me([]),Ne&&Z(!1),ce(""),te(B?(j||[]).map(_e=>String(_e)):[])},Ce=function(){let{closeDropdown:Ee}=arguments.length>0&&arguments[0]!==void 0?arguments[0]:{closeDropdown:!0};Ee&&Z(!1),me(G())},ve=(Ee,Ne)=>{Ne.source==="trigger"&&(Ee&&W!==void 0&&te(wrapStringListType(W)),Z(Ee),!Ee&&!y.filterDropdown&&C&&de())},fe=classNames({[`${b}-menu-without-submenu`]:!hasSubMenu(y.filters||[])}),pe=Ee=>{if(Ee.target.checked){const Ne=flattenKeys(y==null?void 0:y.filters).map(_e=>String(_e));te(Ne)}else te([])},xe=Ee=>{let{filters:Ne}=Ee;return(Ne||[]).map((_e,ke)=>{const Ke=String(_e.value),be={title:_e.text,key:_e.value!==void 0?Ke:String(ke)};return _e.children&&(be.children=xe({filters:_e.children})),be})},ye=Ee=>{var Ne;return Object.assign(Object.assign({},Ee),{text:Ee.title,value:Ee.key,children:((Ne=Ee.children)===null||Ne===void 0?void 0:Ne.map(_e=>ye(_e)))||[]})};let he;const{direction:we,renderEmpty:Re}=reactExports.useContext(ConfigContext);if(typeof y.filterDropdown=="function")he=y.filterDropdown({prefixCls:`${b}-custom`,setSelectedKeys:Ee=>ae({selectedKeys:Ee}),selectedKeys:G(),confirm:Ce,clearFilters:ge,filters:y.filters,visible:J,close:()=>{Z(!1)}});else if(y.filterDropdown)he=y.filterDropdown;else{const Ee=G()||[],Ne=()=>{var ke,Ke;const be=(ke=Re==null?void 0:Re("Table.filter"))!==null&&ke!==void 0?ke:reactExports.createElement(Empty,{image:Empty.PRESENTED_IMAGE_SIMPLE,description:N.filterEmptyText,styles:{image:{height:24}},style:{margin:0,padding:"16px 0"}});if((y.filters||[]).length===0)return be;if(R==="tree")return reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(FilterSearch,{filterSearch:_,value:ie,onChange:ue,tablePrefixCls:m,locale:N}),reactExports.createElement("div",{className:`${m}-filter-dropdown-tree`},w?reactExports.createElement(Checkbox,{checked:Ee.length===flattenKeys(y.filters).length,indeterminate:Ee.length>0&&Ee.length<flattenKeys(y.filters).length,className:`${m}-filter-dropdown-checkall`,onChange:pe},(Ke=N==null?void 0:N.filterCheckall)!==null&&Ke!==void 0?Ke:N==null?void 0:N.filterCheckAll):null,reactExports.createElement(Tree,{checkable:!0,selectable:!1,blockNode:!0,multiple:w,checkStrictly:!w,className:`${b}-menu`,onCheck:V,checkedKeys:Ee,selectedKeys:Ee,showIcon:!1,treeData:xe({filters:y.filters}),autoExpandParent:!0,defaultExpandAll:!0,filterTreeNode:ie.trim()?Oe=>typeof _=="function"?_(ie,ye(Oe)):searchValueMatched(ie,Oe.title):void 0})));const Te=renderFilterItems({filters:y.filters||[],filterSearch:_,prefixCls:g,filteredKeys:G(),filterMultiple:w,searchValue:ie}),Le=Te.every(Oe=>Oe===null);return reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(FilterSearch,{filterSearch:_,value:ie,onChange:ue,tablePrefixCls:m,locale:N}),Le?be:reactExports.createElement(Menu,{selectable:!0,multiple:w,prefixCls:`${b}-menu`,className:fe,onSelect:ae,onDeselect:ae,selectedKeys:Ee,getPopupContainer:P,openKeys:ne,onOpenChange:ee,items:Te}))},_e=()=>B?isEqual((j||[]).map(ke=>String(ke)),Ee,!0):Ee.length===0;he=reactExports.createElement(reactExports.Fragment,null,Ne(),reactExports.createElement("div",{className:`${g}-dropdown-btns`},reactExports.createElement(Button$1,{type:"link",size:"small",disabled:_e(),onClick:()=>ge()},N.filterReset),reactExports.createElement(Button$1,{type:"primary",size:"small",onClick:de},N.filterConfirm)))}y.filterDropdown&&(he=reactExports.createElement(OverrideProvider,{selectable:void 0},he)),he=reactExports.createElement(FilterDropdownMenuWrapper,{className:`${g}-dropdown`},he);const Ae=extendsObject({trigger:["click"],placement:we==="rtl"?"bottomLeft":"bottomRight",children:(()=>{let Ee;return typeof y.filterIcon=="function"?Ee=y.filterIcon(Y):y.filterIcon?Ee=y.filterIcon:Ee=reactExports.createElement(RefIcon$l,null),reactExports.createElement("span",{role:"button",tabIndex:-1,className:classNames(`${g}-trigger`,{active:Y}),onClick:Ne=>{Ne.stopPropagation()}},Ee)})(),getPopupContainer:P},Object.assign(Object.assign({},L),{rootClassName:classNames(z,L.rootClassName),open:J,onOpenChange:ve,dropdownRender:()=>typeof(L==null?void 0:L.dropdownRender)=="function"?L.dropdownRender(he):he}));return reactExports.createElement("div",{className:`${g}-column`},reactExports.createElement("span",{className:`${m}-column-title`},A),reactExports.createElement(Dropdown,Object.assign({},Ae)))},collectFilterStates=(a,c,u)=>{let d=[];return(a||[]).forEach((f,m)=>{var g;const y=getColumnPos(m,u),b=f.filterDropdown!==void 0;if(f.filters||b||"onFilter"in f)if("filteredValue"in f){let E=f.filteredValue;b||(E=(g=E==null?void 0:E.map(String))!==null&&g!==void 0?g:E),d.push({column:f,key:getColumnKey(f,y),filteredKeys:E,forceFiltered:f.filtered})}else d.push({column:f,key:getColumnKey(f,y),filteredKeys:c&&f.defaultFilteredValue?f.defaultFilteredValue:void 0,forceFiltered:f.filtered});"children"in f&&(d=[].concat(_toConsumableArray(d),_toConsumableArray(collectFilterStates(f.children,c,y))))}),d};function injectFilter(a,c,u,d,f,m,g,y,b){return u.map((E,C)=>{const w=getColumnPos(C,y),{filterOnClose:R=!0,filterMultiple:_=!0,filterMode:M,filterSearch:I}=E;let N=E;if(N.filters||N.filterDropdown){const A=getColumnKey(N,w),P=d.find(z=>{let{key:B}=z;return A===B});N=Object.assign(Object.assign({},N),{title:z=>reactExports.createElement(FilterDropdown,{tablePrefixCls:a,prefixCls:`${a}-filter`,dropdownPrefixCls:c,column:N,columnKey:A,filterState:P,filterOnClose:R,filterMultiple:_,filterMode:M,filterSearch:I,triggerFilter:m,locale:f,getPopupContainer:g,rootClassName:b},renderColumnTitle(E.title,z))})}return"children"in N&&(N=Object.assign(Object.assign({},N),{children:injectFilter(a,c,N.children,d,f,m,g,w,b)})),N})}const generateFilterInfo=a=>{const c={};return a.forEach(u=>{let{key:d,filteredKeys:f,column:m}=u;const g=d,{filters:y,filterDropdown:b}=m;if(b)c[g]=f||null;else if(Array.isArray(f)){const E=flattenKeys(y);c[g]=E.filter(C=>f.includes(String(C)))}else c[g]=null}),c},getFilterData=(a,c,u)=>c.reduce((f,m)=>{const{column:{onFilter:g,filters:y},filteredKeys:b}=m;return g&&b&&b.length?f.map(E=>Object.assign({},E)).filter(E=>b.some(C=>{const w=flattenKeys(y),R=w.findIndex(M=>String(M)===String(C)),_=R!==-1?w[R]:C;return E[u]&&(E[u]=getFilterData(E[u],c,u)),g(_,E)})):f},a),getMergedColumns=a=>a.flatMap(c=>"children"in c?[c].concat(_toConsumableArray(getMergedColumns(c.children||[]))):[c]),useFilter=a=>{const{prefixCls:c,dropdownPrefixCls:u,mergedColumns:d,onFilterChange:f,getPopupContainer:m,locale:g,rootClassName:y}=a;devUseWarning();const b=reactExports.useMemo(()=>getMergedColumns(d||[]),[d]),[E,C]=reactExports.useState(()=>collectFilterStates(b,!0)),w=reactExports.useMemo(()=>{const I=collectFilterStates(b,!1);if(I.length===0)return I;let N=!0;if(I.forEach(A=>{let{filteredKeys:P}=A;P!==void 0&&(N=!1)}),N){const A=(b||[]).map((P,z)=>getColumnKey(P,getColumnPos(z)));return E.filter(P=>{let{key:z}=P;return A.includes(z)}).map(P=>{const z=b[A.findIndex(B=>B===P.key)];return Object.assign(Object.assign({},P),{column:Object.assign(Object.assign({},P.column),z),forceFiltered:z.filtered})})}return I},[b,E]),R=reactExports.useMemo(()=>generateFilterInfo(w),[w]),_=I=>{const N=w.filter(A=>{let{key:P}=A;return P!==I.key});N.push(I),C(N),f(generateFilterInfo(N),N)};return[I=>injectFilter(c,u,I,w,g,_,m,void 0,y),w,R]},useLazyKVMap=(a,c,u)=>{const d=reactExports.useRef({});function f(m){var g;if(!d.current||d.current.data!==a||d.current.childrenColumnName!==c||d.current.getRowKey!==u){let b=function(E){E.forEach((C,w)=>{const R=u(C,w);y.set(R,C),C&&typeof C=="object"&&c in C&&b(C[c]||[])})};const y=new Map;b(a),d.current={data:a,childrenColumnName:c,kvMap:y,getRowKey:u}}return(g=d.current.kvMap)===null||g===void 0?void 0:g.get(m)}return[f]};var __rest$7=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const DEFAULT_PAGE_SIZE=10;function getPaginationParam(a,c){const u={current:a.current,pageSize:a.pageSize};return Object.keys(c&&typeof c=="object"?c:{}).forEach(f=>{const m=a[f];typeof m!="function"&&(u[f]=m)}),u}function usePagination(a,c,u){const d=u&&typeof u=="object"?u:{},{total:f=0}=d,m=__rest$7(d,["total"]),[g,y]=reactExports.useState(()=>({current:"defaultCurrent"in m?m.defaultCurrent:1,pageSize:"defaultPageSize"in m?m.defaultPageSize:DEFAULT_PAGE_SIZE})),b=extendsObject(g,m,{total:f>0?f:a}),E=Math.ceil((f||a)/b.pageSize);b.current>E&&(b.current=E||1);const C=(R,_)=>{y({current:R??1,pageSize:_||b.pageSize})},w=(R,_)=>{var M;u&&((M=u.onChange)===null||M===void 0||M.call(u,R,_)),C(R,_),c(R,_||(b==null?void 0:b.pageSize))};return u===!1?[{},()=>{}]:[Object.assign(Object.assign({},b),{onChange:w}),C]}const ASCEND="ascend",DESCEND="descend",getMultiplePriority=a=>typeof a.sorter=="object"&&typeof a.sorter.multiple=="number"?a.sorter.multiple:!1,getSortFunction=a=>typeof a=="function"?a:a&&typeof a=="object"&&a.compare?a.compare:!1,nextSortDirection=(a,c)=>c?a[a.indexOf(c)+1]:a[0],collectSortStates=(a,c,u)=>{let d=[];const f=(m,g)=>{d.push({column:m,key:getColumnKey(m,g),multiplePriority:getMultiplePriority(m),sortOrder:m.sortOrder})};return(a||[]).forEach((m,g)=>{const y=getColumnPos(g,u);m.children?("sortOrder"in m&&f(m,y),d=[].concat(_toConsumableArray(d),_toConsumableArray(collectSortStates(m.children,c,y)))):m.sorter&&("sortOrder"in m?f(m,y):c&&m.defaultSortOrder&&d.push({column:m,key:getColumnKey(m,y),multiplePriority:getMultiplePriority(m),sortOrder:m.defaultSortOrder}))}),d},injectSorter=(a,c,u,d,f,m,g,y)=>(c||[]).map((E,C)=>{const w=getColumnPos(C,y);let R=E;if(R.sorter){const _=R.sortDirections||f,M=R.showSorterTooltip===void 0?g:R.showSorterTooltip,I=getColumnKey(R,w),N=u.find(F=>{let{key:K}=F;return K===I}),A=N?N.sortOrder:null,P=nextSortDirection(_,A);let z;if(E.sortIcon)z=E.sortIcon({sortOrder:A});else{const F=_.includes(ASCEND)&&reactExports.createElement(RefIcon$B,{className:classNames(`${a}-column-sorter-up`,{active:A===ASCEND})}),K=_.includes(DESCEND)&&reactExports.createElement(RefIcon$C,{className:classNames(`${a}-column-sorter-down`,{active:A===DESCEND})});z=reactExports.createElement("span",{className:classNames(`${a}-column-sorter`,{[`${a}-column-sorter-full`]:!!(F&&K)})},reactExports.createElement("span",{className:`${a}-column-sorter-inner`,"aria-hidden":"true"},F,K))}const{cancelSort:B,triggerAsc:j,triggerDesc:L}=m||{};let U=B;P===DESCEND?U=L:P===ASCEND&&(U=j);const q=typeof M=="object"?Object.assign({title:U},M):{title:U};R=Object.assign(Object.assign({},R),{className:classNames(R.className,{[`${a}-column-sort`]:A}),title:F=>{const K=`${a}-column-sorters`,X=reactExports.createElement("span",{className:`${a}-column-title`},renderColumnTitle(E.title,F)),Q=reactExports.createElement("div",{className:K},X,z);return M?typeof M!="boolean"&&(M==null?void 0:M.target)==="sorter-icon"?reactExports.createElement("div",{className:`${K} ${a}-column-sorters-tooltip-target-sorter`},X,reactExports.createElement(Tooltip,Object.assign({},q),z)):reactExports.createElement(Tooltip,Object.assign({},q),Q):Q},onHeaderCell:F=>{var K;const X=((K=E.onHeaderCell)===null||K===void 0?void 0:K.call(E,F))||{},Q=X.onClick,Y=X.onKeyDown;X.onClick=W=>{d({column:E,key:I,sortOrder:P,multiplePriority:getMultiplePriority(E)}),Q==null||Q(W)},X.onKeyDown=W=>{W.keyCode===KeyCode.ENTER&&(d({column:E,key:I,sortOrder:P,multiplePriority:getMultiplePriority(E)}),Y==null||Y(W))};const Z=safeColumnTitle(E.title,{}),J=Z==null?void 0:Z.toString();return A&&(X["aria-sort"]=A==="ascend"?"ascending":"descending"),X["aria-label"]=J||"",X.className=classNames(X.className,`${a}-column-has-sorters`),X.tabIndex=0,E.ellipsis&&(X.title=(Z??"").toString()),X}})}return"children"in R&&(R=Object.assign(Object.assign({},R),{children:injectSorter(a,R.children,u,d,f,m,g,w)})),R}),stateToInfo=a=>{const{column:c,sortOrder:u}=a;return{column:c,order:u,field:c.dataIndex,columnKey:c.key}},generateSorterInfo=a=>{const c=a.filter(u=>{let{sortOrder:d}=u;return d}).map(stateToInfo);if(c.length===0&&a.length){const u=a.length-1;return Object.assign(Object.assign({},stateToInfo(a[u])),{column:void 0,order:void 0,field:void 0,columnKey:void 0})}return c.length<=1?c[0]||{}:c},getSortData=(a,c,u)=>{const d=c.slice().sort((g,y)=>y.multiplePriority-g.multiplePriority),f=a.slice(),m=d.filter(g=>{let{column:{sorter:y},sortOrder:b}=g;return getSortFunction(y)&&b});return m.length?f.sort((g,y)=>{for(let b=0;b<m.length;b+=1){const E=m[b],{column:{sorter:C},sortOrder:w}=E,R=getSortFunction(C);if(R&&w){const _=R(g,y,w);if(_!==0)return w===ASCEND?_:-_}}return 0}).map(g=>{const y=g[u];return y?Object.assign(Object.assign({},g),{[u]:getSortData(y,c,u)}):g}):f},useFilterSorter=a=>{const{prefixCls:c,mergedColumns:u,sortDirections:d,tableLocale:f,showSorterTooltip:m,onSorterChange:g}=a,[y,b]=reactExports.useState(collectSortStates(u,!0)),E=(I,N)=>{const A=[];return I.forEach((P,z)=>{const B=getColumnPos(z,N);if(A.push(getColumnKey(P,B)),Array.isArray(P.children)){const j=E(P.children,B);A.push.apply(A,_toConsumableArray(j))}}),A},C=reactExports.useMemo(()=>{let I=!0;const N=collectSortStates(u,!1);if(!N.length){const B=E(u);return y.filter(j=>{let{key:L}=j;return B.includes(L)})}const A=[];function P(B){I?A.push(B):A.push(Object.assign(Object.assign({},B),{sortOrder:null}))}let z=null;return N.forEach(B=>{z===null?(P(B),B.sortOrder&&(B.multiplePriority===!1?I=!1:z=!0)):(z&&B.multiplePriority!==!1||(I=!1),P(B))}),A},[u,y]),w=reactExports.useMemo(()=>{var I,N;const A=C.map(P=>{let{column:z,sortOrder:B}=P;return{column:z,order:B}});return{sortColumns:A,sortColumn:(I=A[0])===null||I===void 0?void 0:I.column,sortOrder:(N=A[0])===null||N===void 0?void 0:N.order}},[C]),R=I=>{let N;I.multiplePriority===!1||!C.length||C[0].multiplePriority===!1?N=[I]:N=[].concat(_toConsumableArray(C.filter(A=>{let{key:P}=A;return P!==I.key})),[I]),b(N),g(generateSorterInfo(N),N)};return[I=>injectSorter(c,I,C,R,d,f,m),C,w,()=>generateSorterInfo(C)]},fillTitle=(a,c)=>a.map(d=>{const f=Object.assign({},d);return f.title=renderColumnTitle(d.title,c),"children"in f&&(f.children=fillTitle(f.children,c)),f}),useTitleColumns=a=>[reactExports.useCallback(u=>fillTitle(u,a),[a])],RcTable=genTable((a,c)=>{const{_renderTimes:u}=a,{_renderTimes:d}=c;return u!==d}),RcVirtualTable=genVirtualTable((a,c)=>{const{_renderTimes:u}=a,{_renderTimes:d}=c;return u!==d}),genBorderedStyle=a=>{const{componentCls:c,lineWidth:u,lineType:d,tableBorderColor:f,tableHeaderBg:m,tablePaddingVertical:g,tablePaddingHorizontal:y,calc:b}=a,E=`${unit$1(u)} ${d} ${f}`,C=(w,R,_)=>({[`&${c}-${w}`]:{[`> ${c}-container`]:{[`> ${c}-content, > ${c}-body`]:{"\n            > table > tbody > tr > th,\n            > table > tbody > tr > td\n          ":{[`> ${c}-expanded-row-fixed`]:{margin:`${unit$1(b(R).mul(-1).equal())}
              ${unit$1(b(b(_).add(u)).mul(-1).equal())}`}}}}}});return{[`${c}-wrapper`]:{[`${c}${c}-bordered`]:Object.assign(Object.assign(Object.assign({[`> ${c}-title`]:{border:E,borderBottom:0},[`> ${c}-container`]:{borderInlineStart:E,borderTop:E,[`
            > ${c}-content,
            > ${c}-header,
            > ${c}-body,
            > ${c}-summary
          `]:{"> table":{"\n                > thead > tr > th,\n                > thead > tr > td,\n                > tbody > tr > th,\n                > tbody > tr > td,\n                > tfoot > tr > th,\n                > tfoot > tr > td\n              ":{borderInlineEnd:E},"> thead":{"> tr:not(:last-child) > th":{borderBottom:E},"> tr > th::before":{backgroundColor:"transparent !important"}},"\n                > thead > tr,\n                > tbody > tr,\n                > tfoot > tr\n              ":{[`> ${c}-cell-fix-right-first::after`]:{borderInlineEnd:E}},"\n                > tbody > tr > th,\n                > tbody > tr > td\n              ":{[`> ${c}-expanded-row-fixed`]:{margin:`${unit$1(b(g).mul(-1).equal())} ${unit$1(b(b(y).add(u)).mul(-1).equal())}`,"&::after":{position:"absolute",top:0,insetInlineEnd:u,bottom:0,borderInlineEnd:E,content:'""'}}}}}},[`&${c}-scroll-horizontal`]:{[`> ${c}-container > ${c}-body`]:{"> table > tbody":{[`
                > tr${c}-expanded-row,
                > tr${c}-placeholder
              `]:{"> th, > td":{borderInlineEnd:0}}}}}},C("middle",a.tablePaddingVerticalMiddle,a.tablePaddingHorizontalMiddle)),C("small",a.tablePaddingVerticalSmall,a.tablePaddingHorizontalSmall)),{[`> ${c}-footer`]:{border:E,borderTop:0}}),[`${c}-cell`]:{[`${c}-container:first-child`]:{borderTop:0},"&-scrollbar:not([rowspan])":{boxShadow:`0 ${unit$1(u)} 0 ${unit$1(u)} ${m}`}},[`${c}-bordered ${c}-cell-scrollbar`]:{borderInlineEnd:E}}}},genEllipsisStyle=a=>{const{componentCls:c}=a;return{[`${c}-wrapper`]:{[`${c}-cell-ellipsis`]:Object.assign(Object.assign({},textEllipsis),{wordBreak:"keep-all",[`
          &${c}-cell-fix-left-last,
          &${c}-cell-fix-right-first
        `]:{overflow:"visible",[`${c}-cell-content`]:{display:"block",overflow:"hidden",textOverflow:"ellipsis"}},[`${c}-column-title`]:{overflow:"hidden",textOverflow:"ellipsis",wordBreak:"keep-all"}})}}},genEmptyStyle=a=>{const{componentCls:c}=a;return{[`${c}-wrapper`]:{[`${c}-tbody > tr${c}-placeholder`]:{textAlign:"center",color:a.colorTextDisabled,"\n          &:hover > th,\n          &:hover > td,\n        ":{background:a.colorBgContainer}}}}},genExpandStyle=a=>{const{componentCls:c,antCls:u,motionDurationSlow:d,lineWidth:f,paddingXS:m,lineType:g,tableBorderColor:y,tableExpandIconBg:b,tableExpandColumnWidth:E,borderRadius:C,tablePaddingVertical:w,tablePaddingHorizontal:R,tableExpandedRowBg:_,paddingXXS:M,expandIconMarginTop:I,expandIconSize:N,expandIconHalfInner:A,expandIconScale:P,calc:z}=a,B=`${unit$1(f)} ${g} ${y}`,j=z(M).sub(f).equal();return{[`${c}-wrapper`]:{[`${c}-expand-icon-col`]:{width:E},[`${c}-row-expand-icon-cell`]:{textAlign:"center",[`${c}-row-expand-icon`]:{display:"inline-flex",float:"none",verticalAlign:"sub"}},[`${c}-row-indent`]:{height:1,float:"left"},[`${c}-row-expand-icon`]:Object.assign(Object.assign({},operationUnit(a)),{position:"relative",float:"left",width:N,height:N,color:"inherit",lineHeight:unit$1(N),background:b,border:B,borderRadius:C,transform:`scale(${P})`,"&:focus, &:hover, &:active":{borderColor:"currentcolor"},"&::before, &::after":{position:"absolute",background:"currentcolor",transition:`transform ${d} ease-out`,content:'""'},"&::before":{top:A,insetInlineEnd:j,insetInlineStart:j,height:f},"&::after":{top:j,bottom:j,insetInlineStart:A,width:f,transform:"rotate(90deg)"},"&-collapsed::before":{transform:"rotate(-180deg)"},"&-collapsed::after":{transform:"rotate(0deg)"},"&-spaced":{"&::before, &::after":{display:"none",content:"none"},background:"transparent",border:0,visibility:"hidden"}}),[`${c}-row-indent + ${c}-row-expand-icon`]:{marginTop:I,marginInlineEnd:m},[`tr${c}-expanded-row`]:{"&, &:hover":{"> th, > td":{background:_}},[`${u}-descriptions-view`]:{display:"flex",table:{flex:"auto",width:"100%"}}},[`${c}-expanded-row-fixed`]:{position:"relative",margin:`${unit$1(z(w).mul(-1).equal())} ${unit$1(z(R).mul(-1).equal())}`,padding:`${unit$1(w)} ${unit$1(R)}`}}}},genFilterStyle=a=>{const{componentCls:c,antCls:u,iconCls:d,tableFilterDropdownWidth:f,tableFilterDropdownSearchWidth:m,paddingXXS:g,paddingXS:y,colorText:b,lineWidth:E,lineType:C,tableBorderColor:w,headerIconColor:R,fontSizeSM:_,tablePaddingHorizontal:M,borderRadius:I,motionDurationSlow:N,colorIcon:A,colorPrimary:P,tableHeaderFilterActiveBg:z,colorTextDisabled:B,tableFilterDropdownBg:j,tableFilterDropdownHeight:L,controlItemBgHover:U,controlItemBgActive:q,boxShadowSecondary:F,filterDropdownMenuBg:K,calc:X}=a,Q=`${u}-dropdown`,Y=`${c}-filter-dropdown`,Z=`${u}-tree`,J=`${unit$1(E)} ${C} ${w}`;return[{[`${c}-wrapper`]:{[`${c}-filter-column`]:{display:"flex",justifyContent:"space-between"},[`${c}-filter-trigger`]:{position:"relative",display:"flex",alignItems:"center",marginBlock:X(g).mul(-1).equal(),marginInline:`${unit$1(g)} ${unit$1(X(M).div(2).mul(-1).equal())}`,padding:`0 ${unit$1(g)}`,color:R,fontSize:_,borderRadius:I,cursor:"pointer",transition:`all ${N}`,"&:hover":{color:A,background:z},"&.active":{color:P}}}},{[`${u}-dropdown`]:{[Y]:Object.assign(Object.assign({},resetComponent(a)),{minWidth:f,backgroundColor:j,borderRadius:I,boxShadow:F,overflow:"hidden",[`${Q}-menu`]:{maxHeight:L,overflowX:"hidden",border:0,boxShadow:"none",borderRadius:"unset",backgroundColor:K,"&:empty::after":{display:"block",padding:`${unit$1(y)} 0`,color:B,fontSize:_,textAlign:"center",content:'"Not Found"'}},[`${Y}-tree`]:{paddingBlock:`${unit$1(y)} 0`,paddingInline:y,[Z]:{padding:0},[`${Z}-treenode ${Z}-node-content-wrapper:hover`]:{backgroundColor:U},[`${Z}-treenode-checkbox-checked ${Z}-node-content-wrapper`]:{"&, &:hover":{backgroundColor:q}}},[`${Y}-search`]:{padding:y,borderBottom:J,"&-input":{input:{minWidth:m},[d]:{color:B}}},[`${Y}-checkall`]:{width:"100%",marginBottom:g,marginInlineStart:g},[`${Y}-btns`]:{display:"flex",justifyContent:"space-between",padding:`${unit$1(X(y).sub(E).equal())} ${unit$1(y)}`,overflow:"hidden",borderTop:J}})}},{[`${u}-dropdown ${Y}, ${Y}-submenu`]:{[`${u}-checkbox-wrapper + span`]:{paddingInlineStart:y,color:b},"> ul":{maxHeight:"calc(100vh - 130px)",overflowX:"hidden",overflowY:"auto"}}}]},genFixedStyle=a=>{const{componentCls:c,lineWidth:u,colorSplit:d,motionDurationSlow:f,zIndexTableFixed:m,tableBg:g,zIndexTableSticky:y,calc:b}=a,E=d;return{[`${c}-wrapper`]:{[`
        ${c}-cell-fix-left,
        ${c}-cell-fix-right
      `]:{position:"sticky !important",zIndex:m,background:g},[`
        ${c}-cell-fix-left-first::after,
        ${c}-cell-fix-left-last::after
      `]:{position:"absolute",top:0,right:{_skip_check_:!0,value:0},bottom:b(u).mul(-1).equal(),width:30,transform:"translateX(100%)",transition:`box-shadow ${f}`,content:'""',pointerEvents:"none"},[`${c}-cell-fix-left-all::after`]:{display:"none"},[`
        ${c}-cell-fix-right-first::after,
        ${c}-cell-fix-right-last::after
      `]:{position:"absolute",top:0,bottom:b(u).mul(-1).equal(),left:{_skip_check_:!0,value:0},width:30,transform:"translateX(-100%)",transition:`box-shadow ${f}`,content:'""',pointerEvents:"none"},[`${c}-container`]:{position:"relative","&::before, &::after":{position:"absolute",top:0,bottom:0,zIndex:b(y).add(1).equal({unit:!1}),width:30,transition:`box-shadow ${f}`,content:'""',pointerEvents:"none"},"&::before":{insetInlineStart:0},"&::after":{insetInlineEnd:0}},[`${c}-ping-left`]:{[`&:not(${c}-has-fix-left) ${c}-container::before`]:{boxShadow:`inset 10px 0 8px -8px ${E}`},[`
          ${c}-cell-fix-left-first::after,
          ${c}-cell-fix-left-last::after
        `]:{boxShadow:`inset 10px 0 8px -8px ${E}`},[`${c}-cell-fix-left-last::before`]:{backgroundColor:"transparent !important"}},[`${c}-ping-right`]:{[`&:not(${c}-has-fix-right) ${c}-container::after`]:{boxShadow:`inset -10px 0 8px -8px ${E}`},[`
          ${c}-cell-fix-right-first::after,
          ${c}-cell-fix-right-last::after
        `]:{boxShadow:`inset -10px 0 8px -8px ${E}`}},[`${c}-fixed-column-gapped`]:{[`
        ${c}-cell-fix-left-first::after,
        ${c}-cell-fix-left-last::after,
        ${c}-cell-fix-right-first::after,
        ${c}-cell-fix-right-last::after
      `]:{boxShadow:"none"}}}}},genPaginationStyle=a=>{const{componentCls:c,antCls:u,margin:d}=a;return{[`${c}-wrapper`]:{[`${c}-pagination${u}-pagination`]:{margin:`${unit$1(d)} 0`},[`${c}-pagination`]:{display:"flex",flexWrap:"wrap",rowGap:a.paddingXS,"> *":{flex:"none"},"&-left":{justifyContent:"flex-start"},"&-center":{justifyContent:"center"},"&-right":{justifyContent:"flex-end"}}}}},genRadiusStyle=a=>{const{componentCls:c,tableRadius:u}=a;return{[`${c}-wrapper`]:{[c]:{[`${c}-title, ${c}-header`]:{borderRadius:`${unit$1(u)} ${unit$1(u)} 0 0`},[`${c}-title + ${c}-container`]:{borderStartStartRadius:0,borderStartEndRadius:0,[`${c}-header, table`]:{borderRadius:0},"table > thead > tr:first-child":{"th:first-child, th:last-child, td:first-child, td:last-child":{borderRadius:0}}},"&-container":{borderStartStartRadius:u,borderStartEndRadius:u,"table > thead > tr:first-child":{"> *:first-child":{borderStartStartRadius:u},"> *:last-child":{borderStartEndRadius:u}}},"&-footer":{borderRadius:`0 0 ${unit$1(u)} ${unit$1(u)}`}}}}},genStyle=a=>{const{componentCls:c}=a;return{[`${c}-wrapper-rtl`]:{direction:"rtl",table:{direction:"rtl"},[`${c}-pagination-left`]:{justifyContent:"flex-end"},[`${c}-pagination-right`]:{justifyContent:"flex-start"},[`${c}-row-expand-icon`]:{float:"right","&::after":{transform:"rotate(-90deg)"},"&-collapsed::before":{transform:"rotate(180deg)"},"&-collapsed::after":{transform:"rotate(0deg)"}},[`${c}-container`]:{"&::before":{insetInlineStart:"unset",insetInlineEnd:0},"&::after":{insetInlineStart:0,insetInlineEnd:"unset"},[`${c}-row-indent`]:{float:"right"}}}}},genSelectionStyle=a=>{const{componentCls:c,antCls:u,iconCls:d,fontSizeIcon:f,padding:m,paddingXS:g,headerIconColor:y,headerIconHoverColor:b,tableSelectionColumnWidth:E,tableSelectedRowBg:C,tableSelectedRowHoverBg:w,tableRowHoverBg:R,tablePaddingHorizontal:_,calc:M}=a;return{[`${c}-wrapper`]:{[`${c}-selection-col`]:{width:E,[`&${c}-selection-col-with-dropdown`]:{width:M(E).add(f).add(M(m).div(4)).equal()}},[`${c}-bordered ${c}-selection-col`]:{width:M(E).add(M(g).mul(2)).equal(),[`&${c}-selection-col-with-dropdown`]:{width:M(E).add(f).add(M(m).div(4)).add(M(g).mul(2)).equal()}},[`
        table tr th${c}-selection-column,
        table tr td${c}-selection-column,
        ${c}-selection-column
      `]:{paddingInlineEnd:a.paddingXS,paddingInlineStart:a.paddingXS,textAlign:"center",[`${u}-radio-wrapper`]:{marginInlineEnd:0}},[`table tr th${c}-selection-column${c}-cell-fix-left`]:{zIndex:M(a.zIndexTableFixed).add(1).equal({unit:!1})},[`table tr th${c}-selection-column::after`]:{backgroundColor:"transparent !important"},[`${c}-selection`]:{position:"relative",display:"inline-flex",flexDirection:"column"},[`${c}-selection-extra`]:{position:"absolute",top:0,zIndex:1,cursor:"pointer",transition:`all ${a.motionDurationSlow}`,marginInlineStart:"100%",paddingInlineStart:unit$1(M(_).div(4).equal()),[d]:{color:y,fontSize:f,verticalAlign:"baseline","&:hover":{color:b}}},[`${c}-tbody`]:{[`${c}-row`]:{[`&${c}-row-selected`]:{[`> ${c}-cell`]:{background:C,"&-row-hover":{background:w}}},[`> ${c}-cell-row-hover`]:{background:R}}}}}},genSizeStyle=a=>{const{componentCls:c,tableExpandColumnWidth:u,calc:d}=a,f=(m,g,y,b)=>({[`${c}${c}-${m}`]:{fontSize:b,[`
        ${c}-title,
        ${c}-footer,
        ${c}-cell,
        ${c}-thead > tr > th,
        ${c}-tbody > tr > th,
        ${c}-tbody > tr > td,
        tfoot > tr > th,
        tfoot > tr > td
      `]:{padding:`${unit$1(g)} ${unit$1(y)}`},[`${c}-filter-trigger`]:{marginInlineEnd:unit$1(d(y).div(2).mul(-1).equal())},[`${c}-expanded-row-fixed`]:{margin:`${unit$1(d(g).mul(-1).equal())} ${unit$1(d(y).mul(-1).equal())}`},[`${c}-tbody`]:{[`${c}-wrapper:only-child ${c}`]:{marginBlock:unit$1(d(g).mul(-1).equal()),marginInline:`${unit$1(d(u).sub(y).equal())} ${unit$1(d(y).mul(-1).equal())}`}},[`${c}-selection-extra`]:{paddingInlineStart:unit$1(d(y).div(4).equal())}}});return{[`${c}-wrapper`]:Object.assign(Object.assign({},f("middle",a.tablePaddingVerticalMiddle,a.tablePaddingHorizontalMiddle,a.tableFontSizeMiddle)),f("small",a.tablePaddingVerticalSmall,a.tablePaddingHorizontalSmall,a.tableFontSizeSmall))}},genSorterStyle=a=>{const{componentCls:c,marginXXS:u,fontSizeIcon:d,headerIconColor:f,headerIconHoverColor:m}=a;return{[`${c}-wrapper`]:{[`${c}-thead th${c}-column-has-sorters`]:{outline:"none",cursor:"pointer",transition:`all ${a.motionDurationSlow}, left 0s`,"&:hover":{background:a.tableHeaderSortHoverBg,"&::before":{backgroundColor:"transparent !important"}},"&:focus-visible":{color:a.colorPrimary},[`
          &${c}-cell-fix-left:hover,
          &${c}-cell-fix-right:hover
        `]:{background:a.tableFixedHeaderSortActiveBg}},[`${c}-thead th${c}-column-sort`]:{background:a.tableHeaderSortBg,"&::before":{backgroundColor:"transparent !important"}},[`td${c}-column-sort`]:{background:a.tableBodySortBg},[`${c}-column-title`]:{position:"relative",zIndex:1,flex:1,minWidth:0},[`${c}-column-sorters`]:{display:"flex",flex:"auto",alignItems:"center",justifyContent:"space-between","&::after":{position:"absolute",inset:0,width:"100%",height:"100%",content:'""'}},[`${c}-column-sorters-tooltip-target-sorter`]:{"&::after":{content:"none"}},[`${c}-column-sorter`]:{marginInlineStart:u,color:f,fontSize:0,transition:`color ${a.motionDurationSlow}`,"&-inner":{display:"inline-flex",flexDirection:"column",alignItems:"center"},"&-up, &-down":{fontSize:d,"&.active":{color:a.colorPrimary}},[`${c}-column-sorter-up + ${c}-column-sorter-down`]:{marginTop:"-0.3em"}},[`${c}-column-sorters:hover ${c}-column-sorter`]:{color:m}}}},genStickyStyle=a=>{const{componentCls:c,opacityLoading:u,tableScrollThumbBg:d,tableScrollThumbBgHover:f,tableScrollThumbSize:m,tableScrollBg:g,zIndexTableSticky:y,stickyScrollBarBorderRadius:b,lineWidth:E,lineType:C,tableBorderColor:w}=a,R=`${unit$1(E)} ${C} ${w}`;return{[`${c}-wrapper`]:{[`${c}-sticky`]:{"&-holder":{position:"sticky",zIndex:y,background:a.colorBgContainer},"&-scroll":{position:"sticky",bottom:0,height:`${unit$1(m)} !important`,zIndex:y,display:"flex",alignItems:"center",background:g,borderTop:R,opacity:u,"&:hover":{transformOrigin:"center bottom"},"&-bar":{height:m,backgroundColor:d,borderRadius:b,transition:`all ${a.motionDurationSlow}, transform 0s`,position:"absolute",bottom:0,"&:hover, &-active":{backgroundColor:f}}}}}}},genSummaryStyle=a=>{const{componentCls:c,lineWidth:u,tableBorderColor:d,calc:f}=a,m=`${unit$1(u)} ${a.lineType} ${d}`;return{[`${c}-wrapper`]:{[`${c}-summary`]:{position:"relative",zIndex:a.zIndexTableFixed,background:a.tableBg,"> tr":{"> th, > td":{borderBottom:m}}},[`div${c}-summary`]:{boxShadow:`0 ${unit$1(f(u).mul(-1).equal())} 0 ${d}`}}}},genVirtualStyle=a=>{const{componentCls:c,motionDurationMid:u,lineWidth:d,lineType:f,tableBorderColor:m,calc:g}=a,y=`${unit$1(d)} ${f} ${m}`,b=`${c}-expanded-row-cell`;return{[`${c}-wrapper`]:{[`${c}-tbody-virtual`]:{[`${c}-tbody-virtual-holder-inner`]:{[`
            & > ${c}-row, 
            & > div:not(${c}-row) > ${c}-row
          `]:{display:"flex",boxSizing:"border-box",width:"100%"}},[`${c}-cell`]:{borderBottom:y,transition:`background ${u}`},[`${c}-expanded-row`]:{[`${b}${b}-fixed`]:{position:"sticky",insetInlineStart:0,overflow:"hidden",width:`calc(var(--virtual-width) - ${unit$1(d)})`,borderInlineEnd:"none"}}},[`${c}-bordered`]:{[`${c}-tbody-virtual`]:{"&:after":{content:'""',insetInline:0,bottom:0,borderBottom:y,position:"absolute"},[`${c}-cell`]:{borderInlineEnd:y,[`&${c}-cell-fix-right-first:before`]:{content:'""',position:"absolute",insetBlock:0,insetInlineStart:g(d).mul(-1).equal(),borderInlineStart:y}}},[`&${c}-virtual`]:{[`${c}-placeholder ${c}-cell`]:{borderInlineEnd:y,borderBottom:y}}}}}},genTableStyle=a=>{const{componentCls:c,fontWeightStrong:u,tablePaddingVertical:d,tablePaddingHorizontal:f,tableExpandColumnWidth:m,lineWidth:g,lineType:y,tableBorderColor:b,tableFontSize:E,tableBg:C,tableRadius:w,tableHeaderTextColor:R,motionDurationMid:_,tableHeaderBg:M,tableHeaderCellSplitColor:I,tableFooterTextColor:N,tableFooterBg:A,calc:P}=a,z=`${unit$1(g)} ${y} ${b}`;return{[`${c}-wrapper`]:Object.assign(Object.assign({clear:"both",maxWidth:"100%"},clearFix()),{[c]:Object.assign(Object.assign({},resetComponent(a)),{fontSize:E,background:C,borderRadius:`${unit$1(w)} ${unit$1(w)} 0 0`,scrollbarColor:`${a.tableScrollThumbBg} ${a.tableScrollBg}`}),table:{width:"100%",textAlign:"start",borderRadius:`${unit$1(w)} ${unit$1(w)} 0 0`,borderCollapse:"separate",borderSpacing:0},[`
          ${c}-cell,
          ${c}-thead > tr > th,
          ${c}-tbody > tr > th,
          ${c}-tbody > tr > td,
          tfoot > tr > th,
          tfoot > tr > td
        `]:{position:"relative",padding:`${unit$1(d)} ${unit$1(f)}`,overflowWrap:"break-word"},[`${c}-title`]:{padding:`${unit$1(d)} ${unit$1(f)}`},[`${c}-thead`]:{"\n          > tr > th,\n          > tr > td\n        ":{position:"relative",color:R,fontWeight:u,textAlign:"start",background:M,borderBottom:z,transition:`background ${_} ease`,"&[colspan]:not([colspan='1'])":{textAlign:"center"},[`&:not(:last-child):not(${c}-selection-column):not(${c}-row-expand-icon-cell):not([colspan])::before`]:{position:"absolute",top:"50%",insetInlineEnd:0,width:1,height:"1.6em",backgroundColor:I,transform:"translateY(-50%)",transition:`background-color ${_}`,content:'""'}},"> tr:not(:last-child) > th[colspan]":{borderBottom:0}},[`${c}-tbody`]:{"> tr":{"> th, > td":{transition:`background ${_}, border-color ${_}`,borderBottom:z,[`
              > ${c}-wrapper:only-child,
              > ${c}-expanded-row-fixed > ${c}-wrapper:only-child
            `]:{[c]:{marginBlock:unit$1(P(d).mul(-1).equal()),marginInline:`${unit$1(P(m).sub(f).equal())}
                ${unit$1(P(f).mul(-1).equal())}`,[`${c}-tbody > tr:last-child > td`]:{borderBottomWidth:0,"&:first-child, &:last-child":{borderRadius:0}}}}},"> th":{position:"relative",color:R,fontWeight:u,textAlign:"start",background:M,borderBottom:z,transition:`background ${_} ease`}}},[`${c}-footer`]:{padding:`${unit$1(d)} ${unit$1(f)}`,color:N,background:A}})}},prepareComponentToken$2=a=>{const{colorFillAlter:c,colorBgContainer:u,colorTextHeading:d,colorFillSecondary:f,colorFillContent:m,controlItemBgActive:g,controlItemBgActiveHover:y,padding:b,paddingSM:E,paddingXS:C,colorBorderSecondary:w,borderRadiusLG:R,controlHeight:_,colorTextPlaceholder:M,fontSize:I,fontSizeSM:N,lineHeight:A,lineWidth:P,colorIcon:z,colorIconHover:B,opacityLoading:j,controlInteractiveSize:L}=a,U=new FastColor(f).onBackground(u).toHexString(),q=new FastColor(m).onBackground(u).toHexString(),F=new FastColor(c).onBackground(u).toHexString(),K=new FastColor(z),X=new FastColor(B),Q=L/2-P,Y=Q*2+P*3;return{headerBg:F,headerColor:d,headerSortActiveBg:U,headerSortHoverBg:q,bodySortBg:F,rowHoverBg:F,rowSelectedBg:g,rowSelectedHoverBg:y,rowExpandedBg:c,cellPaddingBlock:b,cellPaddingInline:b,cellPaddingBlockMD:E,cellPaddingInlineMD:C,cellPaddingBlockSM:C,cellPaddingInlineSM:C,borderColor:w,headerBorderRadius:R,footerBg:F,footerColor:d,cellFontSize:I,cellFontSizeMD:I,cellFontSizeSM:I,headerSplitColor:w,fixedHeaderSortActiveBg:U,headerFilterHoverBg:m,filterDropdownMenuBg:u,filterDropdownBg:u,expandIconBg:u,selectionColumnWidth:_,stickyScrollBarBg:M,stickyScrollBarBorderRadius:100,expandIconMarginTop:(I*A-P*3)/2-Math.ceil((N*1.4-P*3)/2),headerIconColor:K.clone().setA(K.a*j).toRgbString(),headerIconHoverColor:X.clone().setA(X.a*j).toRgbString(),expandIconHalfInner:Q,expandIconSize:Y,expandIconScale:L/Y}},zIndexTableFixed=2,useStyle$2=genStyleHooks("Table",a=>{const{colorTextHeading:c,colorSplit:u,colorBgContainer:d,controlInteractiveSize:f,headerBg:m,headerColor:g,headerSortActiveBg:y,headerSortHoverBg:b,bodySortBg:E,rowHoverBg:C,rowSelectedBg:w,rowSelectedHoverBg:R,rowExpandedBg:_,cellPaddingBlock:M,cellPaddingInline:I,cellPaddingBlockMD:N,cellPaddingInlineMD:A,cellPaddingBlockSM:P,cellPaddingInlineSM:z,borderColor:B,footerBg:j,footerColor:L,headerBorderRadius:U,cellFontSize:q,cellFontSizeMD:F,cellFontSizeSM:K,headerSplitColor:X,fixedHeaderSortActiveBg:Q,headerFilterHoverBg:Y,filterDropdownBg:Z,expandIconBg:J,selectionColumnWidth:W,stickyScrollBarBg:G,calc:te}=a,ae=merge$2(a,{tableFontSize:q,tableBg:d,tableRadius:U,tablePaddingVertical:M,tablePaddingHorizontal:I,tablePaddingVerticalMiddle:N,tablePaddingHorizontalMiddle:A,tablePaddingVerticalSmall:P,tablePaddingHorizontalSmall:z,tableBorderColor:B,tableHeaderTextColor:g,tableHeaderBg:m,tableFooterTextColor:L,tableFooterBg:j,tableHeaderCellSplitColor:X,tableHeaderSortBg:y,tableHeaderSortHoverBg:b,tableBodySortBg:E,tableFixedHeaderSortActiveBg:Q,tableHeaderFilterActiveBg:Y,tableFilterDropdownBg:Z,tableRowHoverBg:C,tableSelectedRowBg:w,tableSelectedRowHoverBg:R,zIndexTableFixed,zIndexTableSticky:te(zIndexTableFixed).add(1).equal({unit:!1}),tableFontSizeMiddle:F,tableFontSizeSmall:K,tableSelectionColumnWidth:W,tableExpandIconBg:J,tableExpandColumnWidth:te(f).add(te(a.padding).mul(2)).equal(),tableExpandedRowBg:_,tableFilterDropdownWidth:120,tableFilterDropdownHeight:264,tableFilterDropdownSearchWidth:140,tableScrollThumbSize:8,tableScrollThumbBg:G,tableScrollThumbBgHover:c,tableScrollBg:u});return[genTableStyle(ae),genPaginationStyle(ae),genSummaryStyle(ae),genSorterStyle(ae),genFilterStyle(ae),genBorderedStyle(ae),genRadiusStyle(ae),genExpandStyle(ae),genSummaryStyle(ae),genEmptyStyle(ae),genSelectionStyle(ae),genFixedStyle(ae),genStickyStyle(ae),genEllipsisStyle(ae),genSizeStyle(ae),genStyle(ae),genVirtualStyle(ae)]},prepareComponentToken$2,{unitless:{expandIconScale:!0}}),EMPTY_LIST=[],InternalTable=(a,c)=>{var u,d;const{prefixCls:f,className:m,rootClassName:g,style:y,size:b,bordered:E,dropdownPrefixCls:C,dataSource:w,pagination:R,rowSelection:_,rowKey:M="key",rowClassName:I,columns:N,children:A,childrenColumnName:P,onChange:z,getPopupContainer:B,loading:j,expandIcon:L,expandable:U,expandedRowRender:q,expandIconColumnIndex:F,indentSize:K,scroll:X,sortDirections:Q,locale:Y,showSorterTooltip:Z={target:"full-header"},virtual:J}=a;devUseWarning();const W=reactExports.useMemo(()=>N||convertChildrenToColumns(A),[N,A]),G=reactExports.useMemo(()=>W.some(ft=>ft.responsive),[W]),te=useBreakpoint(G),ae=reactExports.useMemo(()=>{const ft=new Set(Object.keys(te).filter(dt=>te[dt]));return W.filter(dt=>!dt.responsive||dt.responsive.some(xt=>ft.has(xt)))},[W,te]),V=omit(a,["className","style","columns"]),{locale:ne=localeValues,direction:le,table:ee,renderEmpty:ie,getPrefixCls:ce,getPopupContainer:ue}=reactExports.useContext(ConfigContext),me=useSize(b),de=Object.assign(Object.assign({},ne.Table),Y),ge=w||EMPTY_LIST,Ce=ce("table",f),ve=ce("dropdown",C),[,fe]=useToken$1(),pe=useCSSVarCls(Ce),[xe,ye,he]=useStyle$2(Ce,pe),we=Object.assign(Object.assign({childrenColumnName:P,expandIconColumnIndex:F},U),{expandIcon:(u=U==null?void 0:U.expandIcon)!==null&&u!==void 0?u:(d=ee==null?void 0:ee.expandable)===null||d===void 0?void 0:d.expandIcon}),{childrenColumnName:Re="children"}=we,De=reactExports.useMemo(()=>ge.some(ft=>ft==null?void 0:ft[Re])?"nest":q||U!=null&&U.expandedRowRender?"row":null,[ge]),Ae={body:reactExports.useRef(null)},Ee=useContainerWidth(Ce),Ne=reactExports.useRef(null),_e=reactExports.useRef(null);useProxyImperativeHandle(c,()=>Object.assign(Object.assign({},_e.current),{nativeElement:Ne.current}));const ke=reactExports.useMemo(()=>typeof M=="function"?M:ft=>ft==null?void 0:ft[M],[M]),[Ke]=useLazyKVMap(ge,Re,ke),be={},Te=function(ft,dt){let xt=arguments.length>2&&arguments[2]!==void 0?arguments[2]:!1;var Tt,Dt,Vt,Nt;const Kt=Object.assign(Object.assign({},be),ft);xt&&((Tt=be.resetPagination)===null||Tt===void 0||Tt.call(be),!((Dt=Kt.pagination)===null||Dt===void 0)&&Dt.current&&(Kt.pagination.current=1),R&&((Vt=R.onChange)===null||Vt===void 0||Vt.call(R,1,(Nt=Kt.pagination)===null||Nt===void 0?void 0:Nt.pageSize))),X&&X.scrollToFirstRowOnChange!==!1&&Ae.body.current&&scrollTo(0,{getContainer:()=>Ae.body.current}),z==null||z(Kt.pagination,Kt.filters,Kt.sorter,{currentDataSource:getFilterData(getSortData(ge,Kt.sorterStates,Re),Kt.filterStates,Re),action:dt})},Le=(ft,dt)=>{Te({sorter:ft,sorterStates:dt},"sort",!1)},[Oe,Be,Ve,Pe]=useFilterSorter({prefixCls:Ce,mergedColumns:ae,onSorterChange:Le,sortDirections:Q||["ascend","descend"],tableLocale:de,showSorterTooltip:Z}),Ge=reactExports.useMemo(()=>getSortData(ge,Be,Re),[ge,Be]);be.sorter=Pe(),be.sorterStates=Be;const qe=(ft,dt)=>{Te({filters:ft,filterStates:dt},"filter",!0)},[Ue,je,We]=useFilter({prefixCls:Ce,locale:de,dropdownPrefixCls:ve,mergedColumns:ae,onFilterChange:qe,getPopupContainer:B||ue,rootClassName:classNames(g,pe)}),ut=getFilterData(Ge,je,Re);be.filters=We,be.filterStates=je;const gt=reactExports.useMemo(()=>{const ft={};return Object.keys(We).forEach(dt=>{We[dt]!==null&&(ft[dt]=We[dt])}),Object.assign(Object.assign({},Ve),{filters:ft})},[Ve,We]),[kt]=useTitleColumns(gt),Ut=(ft,dt)=>{Te({pagination:Object.assign(Object.assign({},be.pagination),{current:ft,pageSize:dt})},"paginate")},[at,ct]=usePagination(ut.length,Ut,R);be.pagination=R===!1?{}:getPaginationParam(at,R),be.resetPagination=ct;const bt=reactExports.useMemo(()=>{if(R===!1||!at.pageSize)return ut;const{current:ft=1,total:dt,pageSize:xt=DEFAULT_PAGE_SIZE}=at;return ut.length<dt?ut.length>xt?ut.slice((ft-1)*xt,ft*xt):ut:ut.slice((ft-1)*xt,ft*xt)},[!!R,ut,at==null?void 0:at.current,at==null?void 0:at.pageSize,at==null?void 0:at.total]),[it,vt]=useSelection({prefixCls:Ce,data:ut,pageData:bt,getRowKey:ke,getRecordByKey:Ke,expandType:De,childrenColumnName:Re,locale:de,getPopupContainer:B||ue},_),ot=(ft,dt,xt)=>{let Tt;return typeof I=="function"?Tt=classNames(I(ft,dt,xt)):Tt=classNames(I),classNames({[`${Ce}-row-selected`]:vt.has(ke(ft,dt))},Tt)};we.__PARENT_RENDER_ICON__=we.expandIcon,we.expandIcon=we.expandIcon||L||renderExpandIcon(de),De==="nest"&&we.expandIconColumnIndex===void 0?we.expandIconColumnIndex=_?1:0:we.expandIconColumnIndex>0&&_&&(we.expandIconColumnIndex-=1),typeof we.indentSize!="number"&&(we.indentSize=typeof K=="number"?K:15);const rt=reactExports.useCallback(ft=>kt(it(Ue(Oe(ft)))),[Oe,Ue,it]);let et,$t;if(R!==!1&&(at!=null&&at.total)){let ft;at.size?ft=at.size:ft=me==="small"||me==="middle"?"small":void 0;const dt=Dt=>reactExports.createElement(Pagination,Object.assign({},at,{className:classNames(`${Ce}-pagination ${Ce}-pagination-${Dt}`,at.className),size:ft})),xt=le==="rtl"?"left":"right",{position:Tt}=at;if(Tt!==null&&Array.isArray(Tt)){const Dt=Tt.find(Kt=>Kt.includes("top")),Vt=Tt.find(Kt=>Kt.includes("bottom")),Nt=Tt.every(Kt=>`${Kt}`=="none");!Dt&&!Vt&&!Nt&&($t=dt(xt)),Dt&&(et=dt(Dt.toLowerCase().replace("top",""))),Vt&&($t=dt(Vt.toLowerCase().replace("bottom","")))}else $t=dt(xt)}let mt;typeof j=="boolean"?mt={spinning:j}:typeof j=="object"&&(mt=Object.assign({spinning:!0},j));const Ze=classNames(he,pe,`${Ce}-wrapper`,ee==null?void 0:ee.className,{[`${Ce}-wrapper-rtl`]:le==="rtl"},m,g,ye),Je=Object.assign(Object.assign({},ee==null?void 0:ee.style),y),yt=typeof(Y==null?void 0:Y.emptyText)<"u"?Y.emptyText:(ie==null?void 0:ie("Table"))||reactExports.createElement(DefaultRenderEmpty,{componentName:"Table"}),Ct=J?RcVirtualTable:RcTable,pt={},Rt=reactExports.useMemo(()=>{const{fontSize:ft,lineHeight:dt,lineWidth:xt,padding:Tt,paddingXS:Dt,paddingSM:Vt}=fe,Nt=Math.floor(ft*dt);switch(me){case"middle":return Vt*2+Nt+xt;case"small":return Dt*2+Nt+xt;default:return Tt*2+Nt+xt}},[fe,me]);return J&&(pt.listItemHeight=Rt),xe(reactExports.createElement("div",{ref:Ne,className:Ze,style:Je},reactExports.createElement(Spin,Object.assign({spinning:!1},mt),et,reactExports.createElement(Ct,Object.assign({},pt,V,{ref:_e,columns:ae,direction:le,expandable:we,prefixCls:Ce,className:classNames({[`${Ce}-middle`]:me==="middle",[`${Ce}-small`]:me==="small",[`${Ce}-bordered`]:E,[`${Ce}-empty`]:ge.length===0},he,pe,ye),data:bt,rowKey:ke,rowClassName:ot,emptyText:yt,internalHooks:INTERNAL_HOOKS,internalRefs:Ae,transformColumns:rt,getContainerWidth:Ee})),$t)))},InternalTable$1=reactExports.forwardRef(InternalTable),Table=(a,c)=>{const u=reactExports.useRef(0);return u.current+=1,reactExports.createElement(InternalTable$1,Object.assign({},a,{ref:c,_renderTimes:u.current}))},ForwardTable=reactExports.forwardRef(Table);ForwardTable.SELECTION_COLUMN=SELECTION_COLUMN;ForwardTable.EXPAND_COLUMN=EXPAND_COLUMN;ForwardTable.SELECTION_ALL=SELECTION_ALL;ForwardTable.SELECTION_INVERT=SELECTION_INVERT;ForwardTable.SELECTION_NONE=SELECTION_NONE;ForwardTable.Column=Column;ForwardTable.ColumnGroup=ColumnGroup;ForwardTable.Summary=FooterComponents;const genBaseStyle=a=>{const{paddingXXS:c,lineWidth:u,tagPaddingHorizontal:d,componentCls:f,calc:m}=a,g=m(d).sub(u).equal(),y=m(c).sub(u).equal();return{[f]:Object.assign(Object.assign({},resetComponent(a)),{display:"inline-block",height:"auto",marginInlineEnd:a.marginXS,paddingInline:g,fontSize:a.tagFontSize,lineHeight:a.tagLineHeight,whiteSpace:"nowrap",background:a.defaultBg,border:`${unit$1(a.lineWidth)} ${a.lineType} ${a.colorBorder}`,borderRadius:a.borderRadiusSM,opacity:1,transition:`all ${a.motionDurationMid}`,textAlign:"start",position:"relative",[`&${f}-rtl`]:{direction:"rtl"},"&, a, a:hover":{color:a.defaultColor},[`${f}-close-icon`]:{marginInlineStart:y,fontSize:a.tagIconSize,color:a.colorIcon,cursor:"pointer",transition:`all ${a.motionDurationMid}`,"&:hover":{color:a.colorTextHeading}},[`&${f}-has-color`]:{borderColor:"transparent",[`&, a, a:hover, ${a.iconCls}-close, ${a.iconCls}-close:hover`]:{color:a.colorTextLightSolid}},"&-checkable":{backgroundColor:"transparent",borderColor:"transparent",cursor:"pointer",[`&:not(${f}-checkable-checked):hover`]:{color:a.colorPrimary,backgroundColor:a.colorFillSecondary},"&:active, &-checked":{color:a.colorTextLightSolid},"&-checked":{backgroundColor:a.colorPrimary,"&:hover":{backgroundColor:a.colorPrimaryHover}},"&:active":{backgroundColor:a.colorPrimaryActive}},"&-hidden":{display:"none"},[`> ${a.iconCls} + span, > span + ${a.iconCls}`]:{marginInlineStart:g}}),[`${f}-borderless`]:{borderColor:"transparent",background:a.tagBorderlessBg}}},prepareToken=a=>{const{lineWidth:c,fontSizeIcon:u,calc:d}=a,f=a.fontSizeSM;return merge$2(a,{tagFontSize:f,tagLineHeight:unit$1(d(a.lineHeightSM).mul(f).equal()),tagIconSize:d(u).sub(d(c).mul(2)).equal(),tagPaddingHorizontal:8,tagBorderlessBg:a.defaultBg})},prepareComponentToken$1=a=>({defaultBg:new FastColor(a.colorFillQuaternary).onBackground(a.colorBgContainer).toHexString(),defaultColor:a.colorText}),useStyle$1=genStyleHooks("Tag",a=>{const c=prepareToken(a);return genBaseStyle(c)},prepareComponentToken$1);var __rest$6=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const CheckableTag=reactExports.forwardRef((a,c)=>{const{prefixCls:u,style:d,className:f,checked:m,onChange:g,onClick:y}=a,b=__rest$6(a,["prefixCls","style","className","checked","onChange","onClick"]),{getPrefixCls:E,tag:C}=reactExports.useContext(ConfigContext),w=A=>{g==null||g(!m),y==null||y(A)},R=E("tag",u),[_,M,I]=useStyle$1(R),N=classNames(R,`${R}-checkable`,{[`${R}-checkable-checked`]:m},C==null?void 0:C.className,f,M,I);return _(reactExports.createElement("span",Object.assign({},b,{ref:c,style:Object.assign(Object.assign({},d),C==null?void 0:C.style),className:N,onClick:w})))}),genPresetStyle=a=>genPresetColor(a,(c,u)=>{let{textColor:d,lightBorderColor:f,lightColor:m,darkColor:g}=u;return{[`${a.componentCls}${a.componentCls}-${c}`]:{color:d,background:m,borderColor:f,"&-inverse":{color:a.colorTextLightSolid,background:g,borderColor:g},[`&${a.componentCls}-borderless`]:{borderColor:"transparent"}}}}),PresetCmp=genSubStyleComponent(["Tag","preset"],a=>{const c=prepareToken(a);return genPresetStyle(c)},prepareComponentToken$1);function capitalize(a){return typeof a!="string"?a:a.charAt(0).toUpperCase()+a.slice(1)}const genTagStatusStyle=(a,c,u)=>{const d=capitalize(u);return{[`${a.componentCls}${a.componentCls}-${c}`]:{color:a[`color${u}`],background:a[`color${d}Bg`],borderColor:a[`color${d}Border`],[`&${a.componentCls}-borderless`]:{borderColor:"transparent"}}}},StatusCmp=genSubStyleComponent(["Tag","status"],a=>{const c=prepareToken(a);return[genTagStatusStyle(c,"success","Success"),genTagStatusStyle(c,"processing","Info"),genTagStatusStyle(c,"error","Error"),genTagStatusStyle(c,"warning","Warning")]},prepareComponentToken$1);var __rest$5=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const InternalTag=reactExports.forwardRef((a,c)=>{const{prefixCls:u,className:d,rootClassName:f,style:m,children:g,icon:y,color:b,onClose:E,bordered:C=!0,visible:w}=a,R=__rest$5(a,["prefixCls","className","rootClassName","style","children","icon","color","onClose","bordered","visible"]),{getPrefixCls:_,direction:M,tag:I}=reactExports.useContext(ConfigContext),[N,A]=reactExports.useState(!0),P=omit(R,["closeIcon","closable"]);reactExports.useEffect(()=>{w!==void 0&&A(w)},[w]);const z=isPresetColor(b),B=isPresetStatusColor(b),j=z||B,L=Object.assign(Object.assign({backgroundColor:b&&!j?b:void 0},I==null?void 0:I.style),m),U=_("tag",u),[q,F,K]=useStyle$1(U),X=classNames(U,I==null?void 0:I.className,{[`${U}-${b}`]:j,[`${U}-has-color`]:b&&!j,[`${U}-hidden`]:!N,[`${U}-rtl`]:M==="rtl",[`${U}-borderless`]:!C},d,f,F,K),Q=te=>{te.stopPropagation(),E==null||E(te),!te.defaultPrevented&&A(!1)},[,Y]=useClosable(pickClosable(a),pickClosable(I),{closable:!1,closeIconRender:te=>{const ae=reactExports.createElement("span",{className:`${U}-close-icon`,onClick:Q},te);return replaceElement(te,ae,V=>({onClick:ne=>{var le;(le=V==null?void 0:V.onClick)===null||le===void 0||le.call(V,ne),Q(ne)},className:classNames(V==null?void 0:V.className,`${U}-close-icon`)}))}}),Z=typeof R.onClick=="function"||g&&g.type==="a",J=y||null,W=J?reactExports.createElement(reactExports.Fragment,null,J,g&&reactExports.createElement("span",null,g)):g,G=reactExports.createElement("span",Object.assign({},P,{ref:c,className:X,style:L}),W,Y,z&&reactExports.createElement(PresetCmp,{key:"preset",prefixCls:U}),B&&reactExports.createElement(StatusCmp,{key:"status",prefixCls:U}));return q(Z?reactExports.createElement(Wave,{component:"Tag"},G):G)}),Tag=InternalTag;Tag.CheckableTag=CheckableTag;const getDesignToken=a=>{const c=a!=null&&a.algorithm?createTheme(a.algorithm):defaultTheme,u=Object.assign(Object.assign({},seedToken),a==null?void 0:a.token);return getComputedToken$1(u,{override:a==null?void 0:a.token},c,formatToken)};function genSizeMapToken(a){const{sizeUnit:c,sizeStep:u}=a,d=u-2;return{sizeXXL:c*(d+10),sizeXL:c*(d+6),sizeLG:c*(d+2),sizeMD:c*(d+2),sizeMS:c*(d+1),size:c*d,sizeSM:c*d,sizeXS:c*(d-1),sizeXXS:c*(d-1)}}const derivative$1=(a,c)=>{const u=c??derivative$2(a),d=u.fontSizeSM,f=u.controlHeight-4;return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({},u),genSizeMapToken(c??a)),genFontMapToken(d)),{controlHeight:f}),genControlHeight(Object.assign(Object.assign({},u),{controlHeight:f})))},getAlphaColor=(a,c)=>new FastColor(a).setA(c).toRgbString(),getSolidColor=(a,c)=>new FastColor(a).lighten(c).toHexString(),generateColorPalettes=a=>{const c=generate$1(a,{theme:"dark"});return{1:c[0],2:c[1],3:c[2],4:c[3],5:c[6],6:c[5],7:c[4],8:c[6],9:c[5],10:c[4]}},generateNeutralColorPalettes=(a,c)=>{const u=a||"#000",d=c||"#fff";return{colorBgBase:u,colorTextBase:d,colorText:getAlphaColor(d,.85),colorTextSecondary:getAlphaColor(d,.65),colorTextTertiary:getAlphaColor(d,.45),colorTextQuaternary:getAlphaColor(d,.25),colorFill:getAlphaColor(d,.18),colorFillSecondary:getAlphaColor(d,.12),colorFillTertiary:getAlphaColor(d,.08),colorFillQuaternary:getAlphaColor(d,.04),colorBgSolid:getAlphaColor(d,.95),colorBgSolidHover:getAlphaColor(d,1),colorBgSolidActive:getAlphaColor(d,.9),colorBgElevated:getSolidColor(u,12),colorBgContainer:getSolidColor(u,8),colorBgLayout:getSolidColor(u,0),colorBgSpotlight:getSolidColor(u,26),colorBgBlur:getAlphaColor(d,.04),colorBorder:getSolidColor(u,26),colorBorderSecondary:getSolidColor(u,19)}},derivative=(a,c)=>{const u=Object.keys(defaultPresetColors).map(f=>{const m=generate$1(a[f],{theme:"dark"});return Array.from({length:10},()=>1).reduce((g,y,b)=>(g[`${f}-${b+1}`]=m[b],g[`${f}${b+1}`]=m[b],g),{})}).reduce((f,m)=>(f=Object.assign(Object.assign({},f),m),f),{}),d=c??derivative$2(a);return Object.assign(Object.assign(Object.assign({},d),u),genColorMapToken(a,{generateColorPalettes,generateNeutralColorPalettes}))};function useToken(){const[a,c,u]=useToken$1();return{theme:a,token:c,hashId:u}}const theme={defaultSeed:defaultConfig.token,useToken,defaultAlgorithm:derivative$2,darkAlgorithm:derivative,compactAlgorithm:derivative$1,getDesignToken,defaultConfig,_internalContext:DesignTokenContext},getTitleStyle=(a,c,u,d)=>{const{titleMarginBottom:f,fontWeightStrong:m}=d;return{marginBottom:f,color:u,fontWeight:m,fontSize:a,lineHeight:c}},getTitleStyles=a=>{const c=[1,2,3,4,5],u={};return c.forEach(d=>{u[`
      h${d}&,
      div&-h${d},
      div&-h${d} > textarea,
      h${d}
    `]=getTitleStyle(a[`fontSizeHeading${d}`],a[`lineHeightHeading${d}`],a.colorTextHeading,a)}),u},getLinkStyles=a=>{const{componentCls:c}=a;return{"a&, a":Object.assign(Object.assign({},operationUnit(a)),{userSelect:"text",[`&[disabled], &${c}-disabled`]:{color:a.colorTextDisabled,cursor:"not-allowed","&:active, &:hover":{color:a.colorTextDisabled},"&:active":{pointerEvents:"none"}}})}},getResetStyles=a=>({code:{margin:"0 0.2em",paddingInline:"0.4em",paddingBlock:"0.2em 0.1em",fontSize:"85%",fontFamily:a.fontFamilyCode,background:"rgba(150, 150, 150, 0.1)",border:"1px solid rgba(100, 100, 100, 0.2)",borderRadius:3},kbd:{margin:"0 0.2em",paddingInline:"0.4em",paddingBlock:"0.15em 0.1em",fontSize:"90%",fontFamily:a.fontFamilyCode,background:"rgba(150, 150, 150, 0.06)",border:"1px solid rgba(100, 100, 100, 0.2)",borderBottomWidth:2,borderRadius:3},mark:{padding:0,backgroundColor:gold[2]},"u, ins":{textDecoration:"underline",textDecorationSkipInk:"auto"},"s, del":{textDecoration:"line-through"},strong:{fontWeight:600},"ul, ol":{marginInline:0,marginBlock:"0 1em",padding:0,li:{marginInline:"20px 0",marginBlock:0,paddingInline:"4px 0",paddingBlock:0}},ul:{listStyleType:"circle",ul:{listStyleType:"disc"}},ol:{listStyleType:"decimal"},"pre, blockquote":{margin:"1em 0"},pre:{padding:"0.4em 0.6em",whiteSpace:"pre-wrap",wordWrap:"break-word",background:"rgba(150, 150, 150, 0.1)",border:"1px solid rgba(100, 100, 100, 0.2)",borderRadius:3,fontFamily:a.fontFamilyCode,code:{display:"inline",margin:0,padding:0,fontSize:"inherit",fontFamily:"inherit",background:"transparent",border:0}},blockquote:{paddingInline:"0.6em 0",paddingBlock:0,borderInlineStart:"4px solid rgba(100, 100, 100, 0.2)",opacity:.85}}),getEditableStyles=a=>{const{componentCls:c,paddingSM:u}=a,d=u;return{"&-edit-content":{position:"relative","div&":{insetInlineStart:a.calc(a.paddingSM).mul(-1).equal(),marginTop:a.calc(d).mul(-1).equal(),marginBottom:`calc(1em - ${unit$1(d)})`},[`${c}-edit-content-confirm`]:{position:"absolute",insetInlineEnd:a.calc(a.marginXS).add(2).equal(),insetBlockEnd:a.marginXS,color:a.colorIcon,fontWeight:"normal",fontSize:a.fontSize,fontStyle:"normal",pointerEvents:"none"},textarea:{margin:"0!important",MozTransition:"none",height:"1em"}}}},getCopyableStyles=a=>({[`${a.componentCls}-copy-success`]:{"\n    &,\n    &:hover,\n    &:focus":{color:a.colorSuccess}},[`${a.componentCls}-copy-icon-only`]:{marginInlineStart:0}}),getEllipsisStyles=()=>({"\n  a&-ellipsis,\n  span&-ellipsis\n  ":{display:"inline-block",maxWidth:"100%"},"&-ellipsis-single-line":{whiteSpace:"nowrap",overflow:"hidden",textOverflow:"ellipsis","a&, span&":{verticalAlign:"bottom"},"> code":{paddingBlock:0,maxWidth:"calc(100% - 1.2em)",display:"inline-block",overflow:"hidden",textOverflow:"ellipsis",verticalAlign:"bottom",boxSizing:"content-box"}},"&-ellipsis-multiple-line":{display:"-webkit-box",overflow:"hidden",WebkitLineClamp:3,WebkitBoxOrient:"vertical"}}),genTypographyStyle=a=>{const{componentCls:c,titleMarginTop:u}=a;return{[c]:Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({color:a.colorText,wordBreak:"break-word",lineHeight:a.lineHeight,[`&${c}-secondary`]:{color:a.colorTextDescription},[`&${c}-success`]:{color:a.colorSuccessText},[`&${c}-warning`]:{color:a.colorWarningText},[`&${c}-danger`]:{color:a.colorErrorText,"a&:active, a&:focus":{color:a.colorErrorTextActive},"a&:hover":{color:a.colorErrorTextHover}},[`&${c}-disabled`]:{color:a.colorTextDisabled,cursor:"not-allowed",userSelect:"none"},"\n        div&,\n        p\n      ":{marginBottom:"1em"}},getTitleStyles(a)),{[`
      & + h1${c},
      & + h2${c},
      & + h3${c},
      & + h4${c},
      & + h5${c}
      `]:{marginTop:u},"\n      div,\n      ul,\n      li,\n      p,\n      h1,\n      h2,\n      h3,\n      h4,\n      h5":{"\n        + h1,\n        + h2,\n        + h3,\n        + h4,\n        + h5\n        ":{marginTop:u}}}),getResetStyles(a)),getLinkStyles(a)),{[`
        ${c}-expand,
        ${c}-collapse,
        ${c}-edit,
        ${c}-copy
      `]:Object.assign(Object.assign({},operationUnit(a)),{marginInlineStart:a.marginXXS})}),getEditableStyles(a)),getCopyableStyles(a)),getEllipsisStyles()),{"&-rtl":{direction:"rtl"}})}},prepareComponentToken=()=>({titleMarginTop:"1.2em",titleMarginBottom:"0.5em"}),useStyle=genStyleHooks("Typography",a=>[genTypographyStyle(a)],prepareComponentToken),Editable=a=>{const{prefixCls:c,"aria-label":u,className:d,style:f,direction:m,maxLength:g,autoSize:y=!0,value:b,onSave:E,onCancel:C,onEnd:w,component:R,enterIcon:_=reactExports.createElement(RefIcon$q,null)}=a,M=reactExports.useRef(null),I=reactExports.useRef(!1),N=reactExports.useRef(null),[A,P]=reactExports.useState(b);reactExports.useEffect(()=>{P(b)},[b]),reactExports.useEffect(()=>{var Z;if(!((Z=M.current)===null||Z===void 0)&&Z.resizableTextArea){const{textArea:J}=M.current.resizableTextArea;J.focus();const{length:W}=J.value;J.setSelectionRange(W,W)}},[]);const z=Z=>{let{target:J}=Z;P(J.value.replace(/[\n\r]/g,""))},B=()=>{I.current=!0},j=()=>{I.current=!1},L=Z=>{let{keyCode:J}=Z;I.current||(N.current=J)},U=()=>{E(A.trim())},q=Z=>{let{keyCode:J,ctrlKey:W,altKey:G,metaKey:te,shiftKey:ae}=Z;N.current!==J||I.current||W||G||te||ae||(J===KeyCode.ENTER?(U(),w==null||w()):J===KeyCode.ESC&&C())},F=()=>{U()},[K,X,Q]=useStyle(c),Y=classNames(c,`${c}-edit-content`,{[`${c}-rtl`]:m==="rtl",[`${c}-${R}`]:!!R},d,X,Q);return K(reactExports.createElement("div",{className:Y,style:f},reactExports.createElement(TextArea,{ref:M,maxLength:g,value:A,onChange:z,onKeyDown:L,onKeyUp:q,onCompositionStart:B,onCompositionEnd:j,onBlur:F,"aria-label":u,rows:1,autoSize:y}),_!==null?cloneElement(_,{className:`${c}-edit-content-confirm`}):null))};var toggleSelection,hasRequiredToggleSelection;function requireToggleSelection(){return hasRequiredToggleSelection||(hasRequiredToggleSelection=1,toggleSelection=function(){var a=document.getSelection();if(!a.rangeCount)return function(){};for(var c=document.activeElement,u=[],d=0;d<a.rangeCount;d++)u.push(a.getRangeAt(d));switch(c.tagName.toUpperCase()){case"INPUT":case"TEXTAREA":c.blur();break;default:c=null;break}return a.removeAllRanges(),function(){a.type==="Caret"&&a.removeAllRanges(),a.rangeCount||u.forEach(function(f){a.addRange(f)}),c&&c.focus()}}),toggleSelection}var copyToClipboard,hasRequiredCopyToClipboard;function requireCopyToClipboard(){if(hasRequiredCopyToClipboard)return copyToClipboard;hasRequiredCopyToClipboard=1;var a=requireToggleSelection(),c={"text/plain":"Text","text/html":"Url",default:"Text"},u="Copy to clipboard: #{key}, Enter";function d(m){var g=(/mac os x/i.test(navigator.userAgent)?"⌘":"Ctrl")+"+C";return m.replace(/#{\s*key\s*}/g,g)}function f(m,g){var y,b,E,C,w,R,_=!1;g||(g={}),y=g.debug||!1;try{E=a(),C=document.createRange(),w=document.getSelection(),R=document.createElement("span"),R.textContent=m,R.ariaHidden="true",R.style.all="unset",R.style.position="fixed",R.style.top=0,R.style.clip="rect(0, 0, 0, 0)",R.style.whiteSpace="pre",R.style.webkitUserSelect="text",R.style.MozUserSelect="text",R.style.msUserSelect="text",R.style.userSelect="text",R.addEventListener("copy",function(I){if(I.stopPropagation(),g.format)if(I.preventDefault(),typeof I.clipboardData>"u"){y&&console.warn("unable to use e.clipboardData"),y&&console.warn("trying IE specific stuff"),window.clipboardData.clearData();var N=c[g.format]||c.default;window.clipboardData.setData(N,m)}else I.clipboardData.clearData(),I.clipboardData.setData(g.format,m);g.onCopy&&(I.preventDefault(),g.onCopy(I.clipboardData))}),document.body.appendChild(R),C.selectNodeContents(R),w.addRange(C);var M=document.execCommand("copy");if(!M)throw new Error("copy command was unsuccessful");_=!0}catch(I){y&&console.error("unable to copy using execCommand: ",I),y&&console.warn("trying IE specific stuff");try{window.clipboardData.setData(g.format||"text",m),g.onCopy&&g.onCopy(window.clipboardData),_=!0}catch(N){y&&console.error("unable to copy using clipboardData: ",N),y&&console.error("falling back to prompt"),b=d("message"in g?g.message:u),window.prompt(b,m)}}finally{w&&(typeof w.removeRange=="function"?w.removeRange(C):w.removeAllRanges()),R&&document.body.removeChild(R),E()}return _}return copyToClipboard=f,copyToClipboard}var copyToClipboardExports=requireCopyToClipboard();const copy=getDefaultExportFromCjs(copyToClipboardExports);var __awaiter=function(a,c,u,d){function f(m){return m instanceof u?m:new u(function(g){g(m)})}return new(u||(u=Promise))(function(m,g){function y(C){try{E(d.next(C))}catch(w){g(w)}}function b(C){try{E(d.throw(C))}catch(w){g(w)}}function E(C){C.done?m(C.value):f(C.value).then(y,b)}E((d=d.apply(a,c||[])).next())})};const useCopyClick=a=>{let{copyConfig:c,children:u}=a;const[d,f]=reactExports.useState(!1),[m,g]=reactExports.useState(!1),y=reactExports.useRef(null),b=()=>{y.current&&clearTimeout(y.current)},E={};c.format&&(E.format=c.format),reactExports.useEffect(()=>b,[]);const C=useEvent(w=>__awaiter(void 0,void 0,void 0,function*(){var R;w==null||w.preventDefault(),w==null||w.stopPropagation(),g(!0);try{const _=typeof c.text=="function"?yield c.text():c.text;copy(_||toList$1(u,!0).join("")||"",E),g(!1),f(!0),b(),y.current=setTimeout(()=>{f(!1)},3e3),(R=c.onCopy)===null||R===void 0||R.call(c,w)}catch(_){throw g(!1),_}}));return{copied:d,copyLoading:m,onClick:C}};function useMergedConfig(a,c){return reactExports.useMemo(()=>{const u=!!a;return[u,Object.assign(Object.assign({},c),u&&typeof a=="object"?a:null)]},[a])}const usePrevious=a=>{const c=reactExports.useRef(void 0);return reactExports.useEffect(()=>{c.current=a}),c.current},useTooltipProps=(a,c,u)=>reactExports.useMemo(()=>a===!0?{title:c??u}:reactExports.isValidElement(a)?{title:a}:typeof a=="object"?Object.assign({title:c??u},a):{title:a},[a,c,u]);var __rest$4=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Typography$1=reactExports.forwardRef((a,c)=>{const{prefixCls:u,component:d="article",className:f,rootClassName:m,setContentRef:g,children:y,direction:b,style:E}=a,C=__rest$4(a,["prefixCls","component","className","rootClassName","setContentRef","children","direction","style"]),{getPrefixCls:w,direction:R,className:_,style:M}=useComponentConfig("typography"),I=b??R,N=g?composeRef(c,g):c,A=w("typography",u),[P,z,B]=useStyle(A),j=classNames(A,_,{[`${A}-rtl`]:I==="rtl"},f,m,z,B),L=Object.assign(Object.assign({},M),E);return P(reactExports.createElement(d,Object.assign({className:j,style:L,ref:N},C),y))});function toList(a){return a===!1?[!1,!1]:Array.isArray(a)?a:[a]}function getNode(a,c,u){return a===!0||a===void 0?c:a||u&&c}function isEleEllipsis(a){const c=document.createElement("em");a.appendChild(c);const u=a.getBoundingClientRect(),d=c.getBoundingClientRect();return a.removeChild(c),u.left>d.left||d.right>u.right||u.top>d.top||d.bottom>u.bottom}const isValidText=a=>["string","number"].includes(typeof a),CopyBtn=a=>{let{prefixCls:c,copied:u,locale:d,iconOnly:f,tooltips:m,icon:g,tabIndex:y,onCopy:b,loading:E}=a;const C=toList(m),w=toList(g),{copied:R,copy:_}=d??{},M=u?R:_,I=getNode(C[u?1:0],M),N=typeof I=="string"?I:M;return reactExports.createElement(Tooltip,{title:I},reactExports.createElement("button",{type:"button",className:classNames(`${c}-copy`,{[`${c}-copy-success`]:u,[`${c}-copy-icon-only`]:f}),onClick:b,"aria-label":N,tabIndex:y},u?getNode(w[1],reactExports.createElement(RefIcon$z,null),!0):getNode(w[0],E?reactExports.createElement(RefIcon$e,null):reactExports.createElement(RefIcon$w,null),!0)))},MeasureText=reactExports.forwardRef((a,c)=>{let{style:u,children:d}=a;const f=reactExports.useRef(null);return reactExports.useImperativeHandle(c,()=>({isExceed:()=>{const m=f.current;return m.scrollHeight>m.clientHeight},getHeight:()=>f.current.clientHeight})),reactExports.createElement("span",{"aria-hidden":!0,ref:f,style:Object.assign({position:"fixed",display:"block",left:0,top:0,pointerEvents:"none",backgroundColor:"rgba(255, 0, 0, 0.65)"},u)},d)}),getNodesLen=a=>a.reduce((c,u)=>c+(isValidText(u)?String(u).length:1),0);function sliceNodes(a,c){let u=0;const d=[];for(let f=0;f<a.length;f+=1){if(u===c)return d;const m=a[f],y=isValidText(m)?String(m).length:1,b=u+y;if(b>c){const E=c-u;return d.push(String(m).slice(0,E)),d}d.push(m),u=b}return a}const STATUS_MEASURE_NONE=0,STATUS_MEASURE_PREPARE=1,STATUS_MEASURE_START=2,STATUS_MEASURE_NEED_ELLIPSIS=3,STATUS_MEASURE_NO_NEED_ELLIPSIS=4,lineClipStyle={display:"-webkit-box",overflow:"hidden",WebkitBoxOrient:"vertical"};function EllipsisMeasure(a){const{enableMeasure:c,width:u,text:d,children:f,rows:m,expanded:g,miscDeps:y,onEllipsis:b}=a,E=reactExports.useMemo(()=>toArray$6(d),[d]),C=reactExports.useMemo(()=>getNodesLen(E),[d]),w=reactExports.useMemo(()=>f(E,!1),[d]),[R,_]=reactExports.useState(null),M=reactExports.useRef(null),I=reactExports.useRef(null),N=reactExports.useRef(null),A=reactExports.useRef(null),P=reactExports.useRef(null),[z,B]=reactExports.useState(!1),[j,L]=reactExports.useState(STATUS_MEASURE_NONE),[U,q]=reactExports.useState(0),[F,K]=reactExports.useState(null);useLayoutEffect$1(()=>{L(c&&u&&C?STATUS_MEASURE_PREPARE:STATUS_MEASURE_NONE)},[u,d,m,c,E]),useLayoutEffect$1(()=>{var Z,J,W,G;if(j===STATUS_MEASURE_PREPARE){L(STATUS_MEASURE_START);const te=I.current&&getComputedStyle(I.current).whiteSpace;K(te)}else if(j===STATUS_MEASURE_START){const te=!!(!((Z=N.current)===null||Z===void 0)&&Z.isExceed());L(te?STATUS_MEASURE_NEED_ELLIPSIS:STATUS_MEASURE_NO_NEED_ELLIPSIS),_(te?[0,C]:null),B(te);const ae=((J=N.current)===null||J===void 0?void 0:J.getHeight())||0,V=m===1?0:((W=A.current)===null||W===void 0?void 0:W.getHeight())||0,ne=((G=P.current)===null||G===void 0?void 0:G.getHeight())||0,le=Math.max(ae,V+ne);q(le+1),b(te)}},[j]);const X=R?Math.ceil((R[0]+R[1])/2):0;useLayoutEffect$1(()=>{var Z;const[J,W]=R||[0,0];if(J!==W){const te=(((Z=M.current)===null||Z===void 0?void 0:Z.getHeight())||0)>U;let ae=X;W-J===1&&(ae=te?J:W),_(te?[J,ae]:[ae,W])}},[R,X]);const Q=reactExports.useMemo(()=>{if(!c)return f(E,!1);if(j!==STATUS_MEASURE_NEED_ELLIPSIS||!R||R[0]!==R[1]){const Z=f(E,!1);return[STATUS_MEASURE_NO_NEED_ELLIPSIS,STATUS_MEASURE_NONE].includes(j)?Z:reactExports.createElement("span",{style:Object.assign(Object.assign({},lineClipStyle),{WebkitLineClamp:m})},Z)}return f(g?E:sliceNodes(E,R[0]),z)},[g,j,R,E].concat(_toConsumableArray(y))),Y={width:u,margin:0,padding:0,whiteSpace:F==="nowrap"?"normal":"inherit"};return reactExports.createElement(reactExports.Fragment,null,Q,j===STATUS_MEASURE_START&&reactExports.createElement(reactExports.Fragment,null,reactExports.createElement(MeasureText,{style:Object.assign(Object.assign(Object.assign({},Y),lineClipStyle),{WebkitLineClamp:m}),ref:N},w),reactExports.createElement(MeasureText,{style:Object.assign(Object.assign(Object.assign({},Y),lineClipStyle),{WebkitLineClamp:m-1}),ref:A},w),reactExports.createElement(MeasureText,{style:Object.assign(Object.assign(Object.assign({},Y),lineClipStyle),{WebkitLineClamp:1}),ref:P},f([],!0))),j===STATUS_MEASURE_NEED_ELLIPSIS&&R&&R[0]!==R[1]&&reactExports.createElement(MeasureText,{style:Object.assign(Object.assign({},Y),{top:400}),ref:M},f(sliceNodes(E,X),!0)),j===STATUS_MEASURE_PREPARE&&reactExports.createElement("span",{style:{whiteSpace:"inherit"},ref:I}))}const EllipsisTooltip=a=>{let{enableEllipsis:c,isEllipsis:u,children:d,tooltipProps:f}=a;return!(f!=null&&f.title)||!c?d:reactExports.createElement(Tooltip,Object.assign({open:u?void 0:!1},f),d)};var __rest$3=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};function wrapperDecorations(a,c){let{mark:u,code:d,underline:f,delete:m,strong:g,keyboard:y,italic:b}=a,E=c;function C(w,R){R&&(E=reactExports.createElement(w,{},E))}return C("strong",g),C("u",f),C("del",m),C("code",d),C("mark",u),C("kbd",y),C("i",b),E}const ELLIPSIS_STR="...",Base=reactExports.forwardRef((a,c)=>{var u;const{prefixCls:d,className:f,style:m,type:g,disabled:y,children:b,ellipsis:E,editable:C,copyable:w,component:R,title:_}=a,M=__rest$3(a,["prefixCls","className","style","type","disabled","children","ellipsis","editable","copyable","component","title"]),{getPrefixCls:I,direction:N}=reactExports.useContext(ConfigContext),[A]=useLocale("Text"),P=reactExports.useRef(null),z=reactExports.useRef(null),B=I("typography",d),j=omit(M,["mark","code","delete","underline","strong","keyboard","italic"]),[L,U]=useMergedConfig(C),[q,F]=useMergedState(!1,{value:U.editing}),{triggerType:K=["icon"]}=U,X=je=>{var We;je&&((We=U.onStart)===null||We===void 0||We.call(U)),F(je)},Q=usePrevious(q);useLayoutEffect$1(()=>{var je;!q&&Q&&((je=z.current)===null||je===void 0||je.focus())},[q]);const Y=je=>{je==null||je.preventDefault(),X(!0)},Z=je=>{var We;(We=U.onChange)===null||We===void 0||We.call(U,je),X(!1)},J=()=>{var je;(je=U.onCancel)===null||je===void 0||je.call(U),X(!1)},[W,G]=useMergedConfig(w),{copied:te,copyLoading:ae,onClick:V}=useCopyClick({copyConfig:G,children:b}),[ne,le]=reactExports.useState(!1),[ee,ie]=reactExports.useState(!1),[ce,ue]=reactExports.useState(!1),[me,de]=reactExports.useState(!1),[ge,Ce]=reactExports.useState(!0),[ve,fe]=useMergedConfig(E,{expandable:!1,symbol:je=>je?A==null?void 0:A.collapse:A==null?void 0:A.expand}),[pe,xe]=useMergedState(fe.defaultExpanded||!1,{value:fe.expanded}),ye=ve&&(!pe||fe.expandable==="collapsible"),{rows:he=1}=fe,we=reactExports.useMemo(()=>ye&&(fe.suffix!==void 0||fe.onEllipsis||fe.expandable||L||W),[ye,fe,L,W]);useLayoutEffect$1(()=>{ve&&!we&&(le(isStyleSupport("webkitLineClamp")),ie(isStyleSupport("textOverflow")))},[we,ve]);const[Re,De]=reactExports.useState(ye),Ae=reactExports.useMemo(()=>we?!1:he===1?ee:ne,[we,ee,ne]);useLayoutEffect$1(()=>{De(Ae&&ye)},[Ae,ye]);const Ee=ye&&(Re?me:ce),Ne=ye&&he===1&&Re,_e=ye&&he>1&&Re,ke=(je,We)=>{var ut;xe(We.expanded),(ut=fe.onExpand)===null||ut===void 0||ut.call(fe,je,We)},[Ke,be]=reactExports.useState(0),Te=je=>{let{offsetWidth:We}=je;be(We)},Le=je=>{var We;ue(je),ce!==je&&((We=fe.onEllipsis)===null||We===void 0||We.call(fe,je))};reactExports.useEffect(()=>{const je=P.current;if(ve&&Re&&je){const We=isEleEllipsis(je);me!==We&&de(We)}},[ve,Re,b,_e,ge,Ke]),reactExports.useEffect(()=>{const je=P.current;if(typeof IntersectionObserver>"u"||!je||!Re||!ye)return;const We=new IntersectionObserver(()=>{Ce(!!je.offsetParent)});return We.observe(je),()=>{We.disconnect()}},[Re,ye]);const Oe=useTooltipProps(fe.tooltip,U.text,b),Be=reactExports.useMemo(()=>{if(!(!ve||Re))return[U.text,b,_,Oe.title].find(isValidText)},[ve,Re,_,Oe.title,Ee]);if(q)return reactExports.createElement(Editable,{value:(u=U.text)!==null&&u!==void 0?u:typeof b=="string"?b:"",onSave:Z,onCancel:J,onEnd:U.onEnd,prefixCls:B,className:f,style:m,direction:N,component:R,maxLength:U.maxLength,autoSize:U.autoSize,enterIcon:U.enterIcon});const Ve=()=>{const{expandable:je,symbol:We}=fe;return je?reactExports.createElement("button",{type:"button",key:"expand",className:`${B}-${pe?"collapse":"expand"}`,onClick:ut=>ke(ut,{expanded:!pe}),"aria-label":pe?A.collapse:A==null?void 0:A.expand},typeof We=="function"?We(pe):We):null},Pe=()=>{if(!L)return;const{icon:je,tooltip:We,tabIndex:ut}=U,gt=toArray$6(We)[0]||(A==null?void 0:A.edit),kt=typeof gt=="string"?gt:"";return K.includes("icon")?reactExports.createElement(Tooltip,{key:"edit",title:We===!1?"":gt},reactExports.createElement("button",{type:"button",ref:z,className:`${B}-edit`,onClick:Y,"aria-label":kt,tabIndex:ut},je||reactExports.createElement(RefIcon$s,{role:"button"}))):null},Ge=()=>W?reactExports.createElement(CopyBtn,Object.assign({key:"copy"},G,{prefixCls:B,copied:te,locale:A,onCopy:V,loading:ae,iconOnly:b==null})):null,qe=je=>[je&&Ve(),Pe(),Ge()],Ue=je=>[je&&!pe&&reactExports.createElement("span",{"aria-hidden":!0,key:"ellipsis"},ELLIPSIS_STR),fe.suffix,qe(je)];return reactExports.createElement(RefResizeObserver,{onResize:Te,disabled:!ye},je=>reactExports.createElement(EllipsisTooltip,{tooltipProps:Oe,enableEllipsis:ye,isEllipsis:Ee},reactExports.createElement(Typography$1,Object.assign({className:classNames({[`${B}-${g}`]:g,[`${B}-disabled`]:y,[`${B}-ellipsis`]:ve,[`${B}-ellipsis-single-line`]:Ne,[`${B}-ellipsis-multiple-line`]:_e},f),prefixCls:d,style:Object.assign(Object.assign({},m),{WebkitLineClamp:_e?he:void 0}),component:R,ref:composeRef(je,P,c),direction:N,onClick:K.includes("text")?Y:void 0,"aria-label":Be==null?void 0:Be.toString(),title:_},j),reactExports.createElement(EllipsisMeasure,{enableMeasure:ye&&!Re,text:b,rows:he,width:Ke,onEllipsis:Le,expanded:pe,miscDeps:[te,pe,ae,L,W,A]},(We,ut)=>wrapperDecorations(a,reactExports.createElement(reactExports.Fragment,null,We.length>0&&ut&&!pe&&Be?reactExports.createElement("span",{key:"show-content","aria-hidden":!0},We):We,Ue(ut)))))))});var __rest$2=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Link$1=reactExports.forwardRef((a,c)=>{var{ellipsis:u,rel:d}=a,f=__rest$2(a,["ellipsis","rel"]);const m=Object.assign(Object.assign({},f),{rel:d===void 0&&f.target==="_blank"?"noopener noreferrer":d});return delete m.navigate,reactExports.createElement(Base,Object.assign({},m,{ref:c,ellipsis:!!u,component:"a"}))}),Paragraph$1=reactExports.forwardRef((a,c)=>reactExports.createElement(Base,Object.assign({ref:c},a,{component:"div"})));var __rest$1=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const Text=(a,c)=>{var{ellipsis:u}=a,d=__rest$1(a,["ellipsis"]);const f=reactExports.useMemo(()=>u&&typeof u=="object"?omit(u,["expandable","rows"]):u,[u]);return reactExports.createElement(Base,Object.assign({ref:c},d,{ellipsis:f,component:"span"}))},Text$1=reactExports.forwardRef(Text);var __rest=function(a,c){var u={};for(var d in a)Object.prototype.hasOwnProperty.call(a,d)&&c.indexOf(d)<0&&(u[d]=a[d]);if(a!=null&&typeof Object.getOwnPropertySymbols=="function")for(var f=0,d=Object.getOwnPropertySymbols(a);f<d.length;f++)c.indexOf(d[f])<0&&Object.prototype.propertyIsEnumerable.call(a,d[f])&&(u[d[f]]=a[d[f]]);return u};const TITLE_ELE_LIST=[1,2,3,4,5],Title=reactExports.forwardRef((a,c)=>{const{level:u=1}=a,d=__rest(a,["level"]),f=TITLE_ELE_LIST.includes(u)?`h${u}`:"h1";return reactExports.createElement(Base,Object.assign({ref:c},d,{component:f}))}),Typography=Typography$1;Typography.Text=Text$1;Typography.Link=Link$1;Typography.Title=Title;Typography.Paragraph=Paragraph$1;var dist={},hasRequiredDist;function requireDist(){if(hasRequiredDist)return dist;hasRequiredDist=1,Object.defineProperty(dist,"__esModule",{value:!0}),dist.parse=g,dist.serialize=E;const a=/^[\u0021-\u003A\u003C\u003E-\u007E]+$/,c=/^[\u0021-\u003A\u003C-\u007E]*$/,u=/^([.]?[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?)([.][a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?)*$/i,d=/^[\u0020-\u003A\u003D-\u007E]*$/,f=Object.prototype.toString,m=(()=>{const R=function(){};return R.prototype=Object.create(null),R})();function g(R,_){const M=new m,I=R.length;if(I<2)return M;const N=(_==null?void 0:_.decode)||C;let A=0;do{const P=R.indexOf("=",A);if(P===-1)break;const z=R.indexOf(";",A),B=z===-1?I:z;if(P>B){A=R.lastIndexOf(";",P-1)+1;continue}const j=y(R,A,P),L=b(R,P,j),U=R.slice(j,L);if(M[U]===void 0){let q=y(R,P+1,B),F=b(R,B,q);const K=N(R.slice(q,F));M[U]=K}A=B+1}while(A<I);return M}function y(R,_,M){do{const I=R.charCodeAt(_);if(I!==32&&I!==9)return _}while(++_<M);return M}function b(R,_,M){for(;_>M;){const I=R.charCodeAt(--_);if(I!==32&&I!==9)return _+1}return M}function E(R,_,M){const I=(M==null?void 0:M.encode)||encodeURIComponent;if(!a.test(R))throw new TypeError(`argument name is invalid: ${R}`);const N=I(_);if(!c.test(N))throw new TypeError(`argument val is invalid: ${_}`);let A=R+"="+N;if(!M)return A;if(M.maxAge!==void 0){if(!Number.isInteger(M.maxAge))throw new TypeError(`option maxAge is invalid: ${M.maxAge}`);A+="; Max-Age="+M.maxAge}if(M.domain){if(!u.test(M.domain))throw new TypeError(`option domain is invalid: ${M.domain}`);A+="; Domain="+M.domain}if(M.path){if(!d.test(M.path))throw new TypeError(`option path is invalid: ${M.path}`);A+="; Path="+M.path}if(M.expires){if(!w(M.expires)||!Number.isFinite(M.expires.valueOf()))throw new TypeError(`option expires is invalid: ${M.expires}`);A+="; Expires="+M.expires.toUTCString()}if(M.httpOnly&&(A+="; HttpOnly"),M.secure&&(A+="; Secure"),M.partitioned&&(A+="; Partitioned"),M.priority)switch(typeof M.priority=="string"?M.priority.toLowerCase():void 0){case"low":A+="; Priority=Low";break;case"medium":A+="; Priority=Medium";break;case"high":A+="; Priority=High";break;default:throw new TypeError(`option priority is invalid: ${M.priority}`)}if(M.sameSite)switch(typeof M.sameSite=="string"?M.sameSite.toLowerCase():M.sameSite){case!0:case"strict":A+="; SameSite=Strict";break;case"lax":A+="; SameSite=Lax";break;case"none":A+="; SameSite=None";break;default:throw new TypeError(`option sameSite is invalid: ${M.sameSite}`)}return A}function C(R){if(R.indexOf("%")===-1)return R;try{return decodeURIComponent(R)}catch{return R}}function w(R){return f.call(R)==="[object Date]"}return dist}requireDist();/**
 * react-router v7.5.1
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var PopStateEventType="popstate";function createHashHistory(a={}){function c(f,m){let{pathname:g="/",search:y="",hash:b=""}=parsePath(f.location.hash.substring(1));return!g.startsWith("/")&&!g.startsWith(".")&&(g="/"+g),createLocation("",{pathname:g,search:y,hash:b},m.state&&m.state.usr||null,m.state&&m.state.key||"default")}function u(f,m){let g=f.document.querySelector("base"),y="";if(g&&g.getAttribute("href")){let b=f.location.href,E=b.indexOf("#");y=E===-1?b:b.slice(0,E)}return y+"#"+(typeof m=="string"?m:createPath(m))}function d(f,m){warning(f.pathname.charAt(0)==="/",`relative pathnames are not supported in hash history.push(${JSON.stringify(m)})`)}return getUrlBasedHistory(c,u,d,a)}function invariant(a,c){if(a===!1||a===null||typeof a>"u")throw new Error(c)}function warning(a,c){if(!a){typeof console<"u"&&console.warn(c);try{throw new Error(c)}catch{}}}function createKey(){return Math.random().toString(36).substring(2,10)}function getHistoryState(a,c){return{usr:a.state,key:a.key,idx:c}}function createLocation(a,c,u=null,d){return{pathname:typeof a=="string"?a:a.pathname,search:"",hash:"",...typeof c=="string"?parsePath(c):c,state:u,key:c&&c.key||d||createKey()}}function createPath({pathname:a="/",search:c="",hash:u=""}){return c&&c!=="?"&&(a+=c.charAt(0)==="?"?c:"?"+c),u&&u!=="#"&&(a+=u.charAt(0)==="#"?u:"#"+u),a}function parsePath(a){let c={};if(a){let u=a.indexOf("#");u>=0&&(c.hash=a.substring(u),a=a.substring(0,u));let d=a.indexOf("?");d>=0&&(c.search=a.substring(d),a=a.substring(0,d)),a&&(c.pathname=a)}return c}function getUrlBasedHistory(a,c,u,d={}){let{window:f=document.defaultView,v5Compat:m=!1}=d,g=f.history,y="POP",b=null,E=C();E==null&&(E=0,g.replaceState({...g.state,idx:E},""));function C(){return(g.state||{idx:null}).idx}function w(){y="POP";let N=C(),A=N==null?null:N-E;E=N,b&&b({action:y,location:I.location,delta:A})}function R(N,A){y="PUSH";let P=createLocation(I.location,N,A);u&&u(P,N),E=C()+1;let z=getHistoryState(P,E),B=I.createHref(P);try{g.pushState(z,"",B)}catch(j){if(j instanceof DOMException&&j.name==="DataCloneError")throw j;f.location.assign(B)}m&&b&&b({action:y,location:I.location,delta:1})}function _(N,A){y="REPLACE";let P=createLocation(I.location,N,A);u&&u(P,N),E=C();let z=getHistoryState(P,E),B=I.createHref(P);g.replaceState(z,"",B),m&&b&&b({action:y,location:I.location,delta:0})}function M(N){let A=f.location.origin!=="null"?f.location.origin:f.location.href,P=typeof N=="string"?N:createPath(N);return P=P.replace(/ $/,"%20"),invariant(A,`No window.location.(origin|href) available to create URL for href: ${P}`),new URL(P,A)}let I={get action(){return y},get location(){return a(f,g)},listen(N){if(b)throw new Error("A history only accepts one active listener");return f.addEventListener(PopStateEventType,w),b=N,()=>{f.removeEventListener(PopStateEventType,w),b=null}},createHref(N){return c(f,N)},createURL:M,encodeLocation(N){let A=M(N);return{pathname:A.pathname,search:A.search,hash:A.hash}},push:R,replace:_,go(N){return g.go(N)}};return I}function matchRoutes(a,c,u="/"){return matchRoutesImpl(a,c,u,!1)}function matchRoutesImpl(a,c,u,d){let f=typeof c=="string"?parsePath(c):c,m=stripBasename(f.pathname||"/",u);if(m==null)return null;let g=flattenRoutes(a);rankRouteBranches(g);let y=null;for(let b=0;y==null&&b<g.length;++b){let E=decodePath(m);y=matchRouteBranch(g[b],E,d)}return y}function flattenRoutes(a,c=[],u=[],d=""){let f=(m,g,y)=>{let b={relativePath:y===void 0?m.path||"":y,caseSensitive:m.caseSensitive===!0,childrenIndex:g,route:m};b.relativePath.startsWith("/")&&(invariant(b.relativePath.startsWith(d),`Absolute route path "${b.relativePath}" nested under path "${d}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),b.relativePath=b.relativePath.slice(d.length));let E=joinPaths([d,b.relativePath]),C=u.concat(b);m.children&&m.children.length>0&&(invariant(m.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${E}".`),flattenRoutes(m.children,c,C,E)),!(m.path==null&&!m.index)&&c.push({path:E,score:computeScore(E,m.index),routesMeta:C})};return a.forEach((m,g)=>{var y;if(m.path===""||!((y=m.path)!=null&&y.includes("?")))f(m,g);else for(let b of explodeOptionalSegments(m.path))f(m,g,b)}),c}function explodeOptionalSegments(a){let c=a.split("/");if(c.length===0)return[];let[u,...d]=c,f=u.endsWith("?"),m=u.replace(/\?$/,"");if(d.length===0)return f?[m,""]:[m];let g=explodeOptionalSegments(d.join("/")),y=[];return y.push(...g.map(b=>b===""?m:[m,b].join("/"))),f&&y.push(...g),y.map(b=>a.startsWith("/")&&b===""?"/":b)}function rankRouteBranches(a){a.sort((c,u)=>c.score!==u.score?u.score-c.score:compareIndexes(c.routesMeta.map(d=>d.childrenIndex),u.routesMeta.map(d=>d.childrenIndex)))}var paramRe=/^:[\w-]+$/,dynamicSegmentValue=3,indexRouteValue=2,emptySegmentValue=1,staticSegmentValue=10,splatPenalty=-2,isSplat=a=>a==="*";function computeScore(a,c){let u=a.split("/"),d=u.length;return u.some(isSplat)&&(d+=splatPenalty),c&&(d+=indexRouteValue),u.filter(f=>!isSplat(f)).reduce((f,m)=>f+(paramRe.test(m)?dynamicSegmentValue:m===""?emptySegmentValue:staticSegmentValue),d)}function compareIndexes(a,c){return a.length===c.length&&a.slice(0,-1).every((d,f)=>d===c[f])?a[a.length-1]-c[c.length-1]:0}function matchRouteBranch(a,c,u=!1){let{routesMeta:d}=a,f={},m="/",g=[];for(let y=0;y<d.length;++y){let b=d[y],E=y===d.length-1,C=m==="/"?c:c.slice(m.length)||"/",w=matchPath({path:b.relativePath,caseSensitive:b.caseSensitive,end:E},C),R=b.route;if(!w&&E&&u&&!d[d.length-1].route.index&&(w=matchPath({path:b.relativePath,caseSensitive:b.caseSensitive,end:!1},C)),!w)return null;Object.assign(f,w.params),g.push({params:f,pathname:joinPaths([m,w.pathname]),pathnameBase:normalizePathname(joinPaths([m,w.pathnameBase])),route:R}),w.pathnameBase!=="/"&&(m=joinPaths([m,w.pathnameBase]))}return g}function matchPath(a,c){typeof a=="string"&&(a={path:a,caseSensitive:!1,end:!0});let[u,d]=compilePath(a.path,a.caseSensitive,a.end),f=c.match(u);if(!f)return null;let m=f[0],g=m.replace(/(.)\/+$/,"$1"),y=f.slice(1);return{params:d.reduce((E,{paramName:C,isOptional:w},R)=>{if(C==="*"){let M=y[R]||"";g=m.slice(0,m.length-M.length).replace(/(.)\/+$/,"$1")}const _=y[R];return w&&!_?E[C]=void 0:E[C]=(_||"").replace(/%2F/g,"/"),E},{}),pathname:m,pathnameBase:g,pattern:a}}function compilePath(a,c=!1,u=!0){warning(a==="*"||!a.endsWith("*")||a.endsWith("/*"),`Route path "${a}" will be treated as if it were "${a.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${a.replace(/\*$/,"/*")}".`);let d=[],f="^"+a.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(g,y,b)=>(d.push({paramName:y,isOptional:b!=null}),b?"/?([^\\/]+)?":"/([^\\/]+)"));return a.endsWith("*")?(d.push({paramName:"*"}),f+=a==="*"||a==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):u?f+="\\/*$":a!==""&&a!=="/"&&(f+="(?:(?=\\/|$))"),[new RegExp(f,c?void 0:"i"),d]}function decodePath(a){try{return a.split("/").map(c=>decodeURIComponent(c).replace(/\//g,"%2F")).join("/")}catch(c){return warning(!1,`The URL path "${a}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${c}).`),a}}function stripBasename(a,c){if(c==="/")return a;if(!a.toLowerCase().startsWith(c.toLowerCase()))return null;let u=c.endsWith("/")?c.length-1:c.length,d=a.charAt(u);return d&&d!=="/"?null:a.slice(u)||"/"}function resolvePath(a,c="/"){let{pathname:u,search:d="",hash:f=""}=typeof a=="string"?parsePath(a):a;return{pathname:u?u.startsWith("/")?u:resolvePathname(u,c):c,search:normalizeSearch(d),hash:normalizeHash(f)}}function resolvePathname(a,c){let u=c.replace(/\/+$/,"").split("/");return a.split("/").forEach(f=>{f===".."?u.length>1&&u.pop():f!=="."&&u.push(f)}),u.length>1?u.join("/"):"/"}function getInvalidPathError(a,c,u,d){return`Cannot include a '${a}' character in a manually specified \`to.${c}\` field [${JSON.stringify(d)}].  Please separate it out to the \`to.${u}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function getPathContributingMatches(a){return a.filter((c,u)=>u===0||c.route.path&&c.route.path.length>0)}function getResolveToMatches(a){let c=getPathContributingMatches(a);return c.map((u,d)=>d===c.length-1?u.pathname:u.pathnameBase)}function resolveTo(a,c,u,d=!1){let f;typeof a=="string"?f=parsePath(a):(f={...a},invariant(!f.pathname||!f.pathname.includes("?"),getInvalidPathError("?","pathname","search",f)),invariant(!f.pathname||!f.pathname.includes("#"),getInvalidPathError("#","pathname","hash",f)),invariant(!f.search||!f.search.includes("#"),getInvalidPathError("#","search","hash",f)));let m=a===""||f.pathname==="",g=m?"/":f.pathname,y;if(g==null)y=u;else{let w=c.length-1;if(!d&&g.startsWith("..")){let R=g.split("/");for(;R[0]==="..";)R.shift(),w-=1;f.pathname=R.join("/")}y=w>=0?c[w]:"/"}let b=resolvePath(f,y),E=g&&g!=="/"&&g.endsWith("/"),C=(m||g===".")&&u.endsWith("/");return!b.pathname.endsWith("/")&&(E||C)&&(b.pathname+="/"),b}var joinPaths=a=>a.join("/").replace(/\/\/+/g,"/"),normalizePathname=a=>a.replace(/\/+$/,"").replace(/^\/*/,"/"),normalizeSearch=a=>!a||a==="?"?"":a.startsWith("?")?a:"?"+a,normalizeHash=a=>!a||a==="#"?"":a.startsWith("#")?a:"#"+a;function isRouteErrorResponse(a){return a!=null&&typeof a.status=="number"&&typeof a.statusText=="string"&&typeof a.internal=="boolean"&&"data"in a}var validMutationMethodsArr=["POST","PUT","PATCH","DELETE"];new Set(validMutationMethodsArr);var validRequestMethodsArr=["GET",...validMutationMethodsArr];new Set(validRequestMethodsArr);var DataRouterContext=reactExports.createContext(null);DataRouterContext.displayName="DataRouter";var DataRouterStateContext=reactExports.createContext(null);DataRouterStateContext.displayName="DataRouterState";var ViewTransitionContext=reactExports.createContext({isTransitioning:!1});ViewTransitionContext.displayName="ViewTransition";var FetchersContext=reactExports.createContext(new Map);FetchersContext.displayName="Fetchers";var AwaitContext=reactExports.createContext(null);AwaitContext.displayName="Await";var NavigationContext=reactExports.createContext(null);NavigationContext.displayName="Navigation";var LocationContext=reactExports.createContext(null);LocationContext.displayName="Location";var RouteContext=reactExports.createContext({outlet:null,matches:[],isDataRoute:!1});RouteContext.displayName="Route";var RouteErrorContext=reactExports.createContext(null);RouteErrorContext.displayName="RouteError";function useHref(a,{relative:c}={}){invariant(useInRouterContext(),"useHref() may be used only in the context of a <Router> component.");let{basename:u,navigator:d}=reactExports.useContext(NavigationContext),{hash:f,pathname:m,search:g}=useResolvedPath(a,{relative:c}),y=m;return u!=="/"&&(y=m==="/"?u:joinPaths([u,m])),d.createHref({pathname:y,search:g,hash:f})}function useInRouterContext(){return reactExports.useContext(LocationContext)!=null}function useLocation(){return invariant(useInRouterContext(),"useLocation() may be used only in the context of a <Router> component."),reactExports.useContext(LocationContext).location}var navigateEffectWarning="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function useIsomorphicLayoutEffect$1(a){reactExports.useContext(NavigationContext).static||reactExports.useLayoutEffect(a)}function useNavigate(){let{isDataRoute:a}=reactExports.useContext(RouteContext);return a?useNavigateStable():useNavigateUnstable()}function useNavigateUnstable(){invariant(useInRouterContext(),"useNavigate() may be used only in the context of a <Router> component.");let a=reactExports.useContext(DataRouterContext),{basename:c,navigator:u}=reactExports.useContext(NavigationContext),{matches:d}=reactExports.useContext(RouteContext),{pathname:f}=useLocation(),m=JSON.stringify(getResolveToMatches(d)),g=reactExports.useRef(!1);return useIsomorphicLayoutEffect$1(()=>{g.current=!0}),reactExports.useCallback((b,E={})=>{if(warning(g.current,navigateEffectWarning),!g.current)return;if(typeof b=="number"){u.go(b);return}let C=resolveTo(b,JSON.parse(m),f,E.relative==="path");a==null&&c!=="/"&&(C.pathname=C.pathname==="/"?c:joinPaths([c,C.pathname])),(E.replace?u.replace:u.push)(C,E.state,E)},[c,u,m,f,a])}var OutletContext=reactExports.createContext(null);function useOutletContext(){return reactExports.useContext(OutletContext)}function useOutlet(a){let c=reactExports.useContext(RouteContext).outlet;return c&&reactExports.createElement(OutletContext.Provider,{value:a},c)}function useParams(){let{matches:a}=reactExports.useContext(RouteContext),c=a[a.length-1];return c?c.params:{}}function useResolvedPath(a,{relative:c}={}){let{matches:u}=reactExports.useContext(RouteContext),{pathname:d}=useLocation(),f=JSON.stringify(getResolveToMatches(u));return reactExports.useMemo(()=>resolveTo(a,JSON.parse(f),d,c==="path"),[a,f,d,c])}function useRoutes(a,c){return useRoutesImpl(a)}function useRoutesImpl(a,c,u,d){invariant(useInRouterContext(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:f,static:m}=reactExports.useContext(NavigationContext),{matches:g}=reactExports.useContext(RouteContext),y=g[g.length-1],b=y?y.params:{},E=y?y.pathname:"/",C=y?y.pathnameBase:"/",w=y&&y.route;{let P=w&&w.path||"";warningOnce(E,!w||P.endsWith("*")||P.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${E}" (under <Route path="${P}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${P}"> to <Route path="${P==="/"?"*":`${P}/*`}">.`)}let R=useLocation(),_;_=R;let M=_.pathname||"/",I=M;if(C!=="/"){let P=C.replace(/^\//,"").split("/");I="/"+M.replace(/^\//,"").split("/").slice(P.length).join("/")}let N=!m&&u&&u.matches&&u.matches.length>0?u.matches:matchRoutes(a,{pathname:I});return warning(w||N!=null,`No routes matched location "${_.pathname}${_.search}${_.hash}" `),warning(N==null||N[N.length-1].route.element!==void 0||N[N.length-1].route.Component!==void 0||N[N.length-1].route.lazy!==void 0,`Matched leaf route at location "${_.pathname}${_.search}${_.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`),_renderMatches(N&&N.map(P=>Object.assign({},P,{params:Object.assign({},b,P.params),pathname:joinPaths([C,f.encodeLocation?f.encodeLocation(P.pathname).pathname:P.pathname]),pathnameBase:P.pathnameBase==="/"?C:joinPaths([C,f.encodeLocation?f.encodeLocation(P.pathnameBase).pathname:P.pathnameBase])})),g,u,d)}function DefaultErrorComponent(){let a=useRouteError(),c=isRouteErrorResponse(a)?`${a.status} ${a.statusText}`:a instanceof Error?a.message:JSON.stringify(a),u=a instanceof Error?a.stack:null,d="rgba(200,200,200, 0.5)",f={padding:"0.5rem",backgroundColor:d},m={padding:"2px 4px",backgroundColor:d},g=null;return console.error("Error handled by React Router default ErrorBoundary:",a),g=reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("p",null,"💿 Hey developer 👋"),reactExports.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",reactExports.createElement("code",{style:m},"ErrorBoundary")," or"," ",reactExports.createElement("code",{style:m},"errorElement")," prop on your route.")),reactExports.createElement(reactExports.Fragment,null,reactExports.createElement("h2",null,"Unexpected Application Error!"),reactExports.createElement("h3",{style:{fontStyle:"italic"}},c),u?reactExports.createElement("pre",{style:f},u):null,g)}var defaultErrorElement=reactExports.createElement(DefaultErrorComponent,null),RenderErrorBoundary=class extends reactExports.Component{constructor(a){super(a),this.state={location:a.location,revalidation:a.revalidation,error:a.error}}static getDerivedStateFromError(a){return{error:a}}static getDerivedStateFromProps(a,c){return c.location!==a.location||c.revalidation!=="idle"&&a.revalidation==="idle"?{error:a.error,location:a.location,revalidation:a.revalidation}:{error:a.error!==void 0?a.error:c.error,location:c.location,revalidation:a.revalidation||c.revalidation}}componentDidCatch(a,c){console.error("React Router caught the following error during render",a,c)}render(){return this.state.error!==void 0?reactExports.createElement(RouteContext.Provider,{value:this.props.routeContext},reactExports.createElement(RouteErrorContext.Provider,{value:this.state.error,children:this.props.component})):this.props.children}};function RenderedRoute({routeContext:a,match:c,children:u}){let d=reactExports.useContext(DataRouterContext);return d&&d.static&&d.staticContext&&(c.route.errorElement||c.route.ErrorBoundary)&&(d.staticContext._deepestRenderedBoundaryId=c.route.id),reactExports.createElement(RouteContext.Provider,{value:a},u)}function _renderMatches(a,c=[],u=null,d=null){if(a==null){if(!u)return null;if(u.errors)a=u.matches;else if(c.length===0&&!u.initialized&&u.matches.length>0)a=u.matches;else return null}let f=a,m=u==null?void 0:u.errors;if(m!=null){let b=f.findIndex(E=>E.route.id&&(m==null?void 0:m[E.route.id])!==void 0);invariant(b>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(m).join(",")}`),f=f.slice(0,Math.min(f.length,b+1))}let g=!1,y=-1;if(u)for(let b=0;b<f.length;b++){let E=f[b];if((E.route.HydrateFallback||E.route.hydrateFallbackElement)&&(y=b),E.route.id){let{loaderData:C,errors:w}=u,R=E.route.loader&&!C.hasOwnProperty(E.route.id)&&(!w||w[E.route.id]===void 0);if(E.route.lazy||R){g=!0,y>=0?f=f.slice(0,y+1):f=[f[0]];break}}}return f.reduceRight((b,E,C)=>{let w,R=!1,_=null,M=null;u&&(w=m&&E.route.id?m[E.route.id]:void 0,_=E.route.errorElement||defaultErrorElement,g&&(y<0&&C===0?(warningOnce("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),R=!0,M=null):y===C&&(R=!0,M=E.route.hydrateFallbackElement||null)));let I=c.concat(f.slice(0,C+1)),N=()=>{let A;return w?A=_:R?A=M:E.route.Component?A=reactExports.createElement(E.route.Component,null):E.route.element?A=E.route.element:A=b,reactExports.createElement(RenderedRoute,{match:E,routeContext:{outlet:b,matches:I,isDataRoute:u!=null},children:A})};return u&&(E.route.ErrorBoundary||E.route.errorElement||C===0)?reactExports.createElement(RenderErrorBoundary,{location:u.location,revalidation:u.revalidation,component:_,error:w,children:N(),routeContext:{outlet:null,matches:I,isDataRoute:!0}}):N()},null)}function getDataRouterConsoleError(a){return`${a} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function useDataRouterContext(a){let c=reactExports.useContext(DataRouterContext);return invariant(c,getDataRouterConsoleError(a)),c}function useDataRouterState(a){let c=reactExports.useContext(DataRouterStateContext);return invariant(c,getDataRouterConsoleError(a)),c}function useRouteContext(a){let c=reactExports.useContext(RouteContext);return invariant(c,getDataRouterConsoleError(a)),c}function useCurrentRouteId(a){let c=useRouteContext(a),u=c.matches[c.matches.length-1];return invariant(u.route.id,`${a} can only be used on routes that contain a unique "id"`),u.route.id}function useRouteId(){return useCurrentRouteId("useRouteId")}function useRouteError(){var d;let a=reactExports.useContext(RouteErrorContext),c=useDataRouterState("useRouteError"),u=useCurrentRouteId("useRouteError");return a!==void 0?a:(d=c.errors)==null?void 0:d[u]}function useNavigateStable(){let{router:a}=useDataRouterContext("useNavigate"),c=useCurrentRouteId("useNavigate"),u=reactExports.useRef(!1);return useIsomorphicLayoutEffect$1(()=>{u.current=!0}),reactExports.useCallback(async(f,m={})=>{warning(u.current,navigateEffectWarning),u.current&&(typeof f=="number"?a.navigate(f):await a.navigate(f,{fromRouteId:c,...m}))},[a,c])}var alreadyWarned={};function warningOnce(a,c,u){!c&&!alreadyWarned[a]&&(alreadyWarned[a]=!0,warning(!1,u))}reactExports.memo(DataRoutes);function DataRoutes({routes:a,future:c,state:u}){return useRoutesImpl(a,void 0,u,c)}function Outlet(a){return useOutlet(a.context)}function Router({basename:a="/",children:c=null,location:u,navigationType:d="POP",navigator:f,static:m=!1}){invariant(!useInRouterContext(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let g=a.replace(/^\/*/,"/"),y=reactExports.useMemo(()=>({basename:g,navigator:f,static:m,future:{}}),[g,f,m]);typeof u=="string"&&(u=parsePath(u));let{pathname:b="/",search:E="",hash:C="",state:w=null,key:R="default"}=u,_=reactExports.useMemo(()=>{let M=stripBasename(b,g);return M==null?null:{location:{pathname:M,search:E,hash:C,state:w,key:R},navigationType:d}},[g,b,E,C,w,R,d]);return warning(_!=null,`<Router basename="${g}"> is not able to match the URL "${b}${E}${C}" because it does not start with the basename, so the <Router> won't render anything.`),_==null?null:reactExports.createElement(NavigationContext.Provider,{value:y},reactExports.createElement(LocationContext.Provider,{children:c,value:_}))}var defaultMethod="get",defaultEncType="application/x-www-form-urlencoded";function isHtmlElement(a){return a!=null&&typeof a.tagName=="string"}function isButtonElement(a){return isHtmlElement(a)&&a.tagName.toLowerCase()==="button"}function isFormElement(a){return isHtmlElement(a)&&a.tagName.toLowerCase()==="form"}function isInputElement(a){return isHtmlElement(a)&&a.tagName.toLowerCase()==="input"}function isModifiedEvent(a){return!!(a.metaKey||a.altKey||a.ctrlKey||a.shiftKey)}function shouldProcessLinkClick(a,c){return a.button===0&&(!c||c==="_self")&&!isModifiedEvent(a)}var _formDataSupportsSubmitter=null;function isFormDataSubmitterSupported(){if(_formDataSupportsSubmitter===null)try{new FormData(document.createElement("form"),0),_formDataSupportsSubmitter=!1}catch{_formDataSupportsSubmitter=!0}return _formDataSupportsSubmitter}var supportedFormEncTypes=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function getFormEncType(a){return a!=null&&!supportedFormEncTypes.has(a)?(warning(!1,`"${a}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${defaultEncType}"`),null):a}function getFormSubmissionInfo(a,c){let u,d,f,m,g;if(isFormElement(a)){let y=a.getAttribute("action");d=y?stripBasename(y,c):null,u=a.getAttribute("method")||defaultMethod,f=getFormEncType(a.getAttribute("enctype"))||defaultEncType,m=new FormData(a)}else if(isButtonElement(a)||isInputElement(a)&&(a.type==="submit"||a.type==="image")){let y=a.form;if(y==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let b=a.getAttribute("formaction")||y.getAttribute("action");if(d=b?stripBasename(b,c):null,u=a.getAttribute("formmethod")||y.getAttribute("method")||defaultMethod,f=getFormEncType(a.getAttribute("formenctype"))||getFormEncType(y.getAttribute("enctype"))||defaultEncType,m=new FormData(y,a),!isFormDataSubmitterSupported()){let{name:E,type:C,value:w}=a;if(C==="image"){let R=E?`${E}.`:"";m.append(`${R}x`,"0"),m.append(`${R}y`,"0")}else E&&m.append(E,w)}}else{if(isHtmlElement(a))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');u=defaultMethod,d=null,f=defaultEncType,g=a}return m&&f==="text/plain"&&(g=m,m=void 0),{action:d,method:u.toLowerCase(),encType:f,formData:m,body:g}}function invariant2(a,c){if(a===!1||a===null||typeof a>"u")throw new Error(c)}async function loadRouteModule(a,c){if(a.id in c)return c[a.id];try{let u=await import(a.module);return c[a.id]=u,u}catch(u){return console.error(`Error loading route module \`${a.module}\`, reloading page...`),console.error(u),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function isHtmlLinkDescriptor(a){return a==null?!1:a.href==null?a.rel==="preload"&&typeof a.imageSrcSet=="string"&&typeof a.imageSizes=="string":typeof a.rel=="string"&&typeof a.href=="string"}async function getKeyedPrefetchLinks(a,c,u){let d=await Promise.all(a.map(async f=>{let m=c.routes[f.route.id];if(m){let g=await loadRouteModule(m,u);return g.links?g.links():[]}return[]}));return dedupeLinkDescriptors(d.flat(1).filter(isHtmlLinkDescriptor).filter(f=>f.rel==="stylesheet"||f.rel==="preload").map(f=>f.rel==="stylesheet"?{...f,rel:"prefetch",as:"style"}:{...f,rel:"prefetch"}))}function getNewMatchesForLinks(a,c,u,d,f,m){let g=(b,E)=>u[E]?b.route.id!==u[E].route.id:!0,y=(b,E)=>{var C;return u[E].pathname!==b.pathname||((C=u[E].route.path)==null?void 0:C.endsWith("*"))&&u[E].params["*"]!==b.params["*"]};return m==="assets"?c.filter((b,E)=>g(b,E)||y(b,E)):m==="data"?c.filter((b,E)=>{var w;let C=d.routes[b.route.id];if(!C||!C.hasLoader)return!1;if(g(b,E)||y(b,E))return!0;if(b.route.shouldRevalidate){let R=b.route.shouldRevalidate({currentUrl:new URL(f.pathname+f.search+f.hash,window.origin),currentParams:((w=u[0])==null?void 0:w.params)||{},nextUrl:new URL(a,window.origin),nextParams:b.params,defaultShouldRevalidate:!0});if(typeof R=="boolean")return R}return!0}):[]}function getModuleLinkHrefs(a,c,{includeHydrateFallback:u}={}){return dedupeHrefs(a.map(d=>{let f=c.routes[d.route.id];if(!f)return[];let m=[f.module];return f.clientActionModule&&(m=m.concat(f.clientActionModule)),f.clientLoaderModule&&(m=m.concat(f.clientLoaderModule)),u&&f.hydrateFallbackModule&&(m=m.concat(f.hydrateFallbackModule)),f.imports&&(m=m.concat(f.imports)),m}).flat(1))}function dedupeHrefs(a){return[...new Set(a)]}function sortKeys(a){let c={},u=Object.keys(a).sort();for(let d of u)c[d]=a[d];return c}function dedupeLinkDescriptors(a,c){let u=new Set;return new Set(c),a.reduce((d,f)=>{let m=JSON.stringify(sortKeys(f));return u.has(m)||(u.add(m),d.push({key:m,link:f})),d},[])}var NO_BODY_STATUS_CODES=new Set([100,101,204,205]);function singleFetchUrl(a,c){let u=typeof a=="string"?new URL(a,typeof window>"u"?"server://singlefetch/":window.location.origin):a;return u.pathname==="/"?u.pathname="_root.data":c&&stripBasename(u.pathname,c)==="/"?u.pathname=`${c.replace(/\/$/,"")}/_root.data`:u.pathname=`${u.pathname.replace(/\/$/,"")}.data`,u}function useDataRouterContext2(){let a=reactExports.useContext(DataRouterContext);return invariant2(a,"You must render this element inside a <DataRouterContext.Provider> element"),a}function useDataRouterStateContext(){let a=reactExports.useContext(DataRouterStateContext);return invariant2(a,"You must render this element inside a <DataRouterStateContext.Provider> element"),a}var FrameworkContext=reactExports.createContext(void 0);FrameworkContext.displayName="FrameworkContext";function useFrameworkContext(){let a=reactExports.useContext(FrameworkContext);return invariant2(a,"You must render this element inside a <HydratedRouter> element"),a}function usePrefetchBehavior(a,c){let u=reactExports.useContext(FrameworkContext),[d,f]=reactExports.useState(!1),[m,g]=reactExports.useState(!1),{onFocus:y,onBlur:b,onMouseEnter:E,onMouseLeave:C,onTouchStart:w}=c,R=reactExports.useRef(null);reactExports.useEffect(()=>{if(a==="render"&&g(!0),a==="viewport"){let I=A=>{A.forEach(P=>{g(P.isIntersecting)})},N=new IntersectionObserver(I,{threshold:.5});return R.current&&N.observe(R.current),()=>{N.disconnect()}}},[a]),reactExports.useEffect(()=>{if(d){let I=setTimeout(()=>{g(!0)},100);return()=>{clearTimeout(I)}}},[d]);let _=()=>{f(!0)},M=()=>{f(!1),g(!1)};return u?a!=="intent"?[m,R,{}]:[m,R,{onFocus:composeEventHandlers(y,_),onBlur:composeEventHandlers(b,M),onMouseEnter:composeEventHandlers(E,_),onMouseLeave:composeEventHandlers(C,M),onTouchStart:composeEventHandlers(w,_)}]:[!1,R,{}]}function composeEventHandlers(a,c){return u=>{a&&a(u),u.defaultPrevented||c(u)}}function PrefetchPageLinks({page:a,...c}){let{router:u}=useDataRouterContext2(),d=reactExports.useMemo(()=>matchRoutes(u.routes,a,u.basename),[u.routes,a,u.basename]);return d?reactExports.createElement(PrefetchPageLinksImpl,{page:a,matches:d,...c}):null}function useKeyedPrefetchLinks(a){let{manifest:c,routeModules:u}=useFrameworkContext(),[d,f]=reactExports.useState([]);return reactExports.useEffect(()=>{let m=!1;return getKeyedPrefetchLinks(a,c,u).then(g=>{m||f(g)}),()=>{m=!0}},[a,c,u]),d}function PrefetchPageLinksImpl({page:a,matches:c,...u}){let d=useLocation(),{manifest:f,routeModules:m}=useFrameworkContext(),{basename:g}=useDataRouterContext2(),{loaderData:y,matches:b}=useDataRouterStateContext(),E=reactExports.useMemo(()=>getNewMatchesForLinks(a,c,b,f,d,"data"),[a,c,b,f,d]),C=reactExports.useMemo(()=>getNewMatchesForLinks(a,c,b,f,d,"assets"),[a,c,b,f,d]),w=reactExports.useMemo(()=>{if(a===d.pathname+d.search+d.hash)return[];let M=new Set,I=!1;if(c.forEach(A=>{var z;let P=f.routes[A.route.id];!P||!P.hasLoader||(!E.some(B=>B.route.id===A.route.id)&&A.route.id in y&&((z=m[A.route.id])!=null&&z.shouldRevalidate)||P.hasClientLoader?I=!0:M.add(A.route.id))}),M.size===0)return[];let N=singleFetchUrl(a,g);return I&&M.size>0&&N.searchParams.set("_routes",c.filter(A=>M.has(A.route.id)).map(A=>A.route.id).join(",")),[N.pathname+N.search]},[g,y,d,f,E,c,a,m]),R=reactExports.useMemo(()=>getModuleLinkHrefs(C,f),[C,f]),_=useKeyedPrefetchLinks(C);return reactExports.createElement(reactExports.Fragment,null,w.map(M=>reactExports.createElement("link",{key:M,rel:"prefetch",as:"fetch",href:M,...u})),R.map(M=>reactExports.createElement("link",{key:M,rel:"modulepreload",href:M,...u})),_.map(({key:M,link:I})=>reactExports.createElement("link",{key:M,...I})))}function mergeRefs(...a){return c=>{a.forEach(u=>{typeof u=="function"?u(c):u!=null&&(u.current=c)})}}var isBrowser=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{isBrowser&&(window.__reactRouterVersion="7.5.1")}catch{}function HashRouter({basename:a,children:c,window:u}){let d=reactExports.useRef();d.current==null&&(d.current=createHashHistory({window:u,v5Compat:!0}));let f=d.current,[m,g]=reactExports.useState({action:f.action,location:f.location}),y=reactExports.useCallback(b=>{reactExports.startTransition(()=>g(b))},[g]);return reactExports.useLayoutEffect(()=>f.listen(y),[f,y]),reactExports.createElement(Router,{basename:a,children:c,location:m.location,navigationType:m.action,navigator:f})}var ABSOLUTE_URL_REGEX2=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,Link=reactExports.forwardRef(function({onClick:c,discover:u="render",prefetch:d="none",relative:f,reloadDocument:m,replace:g,state:y,target:b,to:E,preventScrollReset:C,viewTransition:w,...R},_){let{basename:M}=reactExports.useContext(NavigationContext),I=typeof E=="string"&&ABSOLUTE_URL_REGEX2.test(E),N,A=!1;if(typeof E=="string"&&I&&(N=E,isBrowser))try{let F=new URL(window.location.href),K=E.startsWith("//")?new URL(F.protocol+E):new URL(E),X=stripBasename(K.pathname,M);K.origin===F.origin&&X!=null?E=X+K.search+K.hash:A=!0}catch{warning(!1,`<Link to="${E}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}let P=useHref(E,{relative:f}),[z,B,j]=usePrefetchBehavior(d,R),L=useLinkClickHandler(E,{replace:g,state:y,target:b,preventScrollReset:C,relative:f,viewTransition:w});function U(F){c&&c(F),F.defaultPrevented||L(F)}let q=reactExports.createElement("a",{...R,...j,href:N||P,onClick:A||m?c:U,ref:mergeRefs(_,B),target:b,"data-discover":!I&&u==="render"?"true":void 0});return z&&!I?reactExports.createElement(reactExports.Fragment,null,q,reactExports.createElement(PrefetchPageLinks,{page:P})):q});Link.displayName="Link";var NavLink=reactExports.forwardRef(function({"aria-current":c="page",caseSensitive:u=!1,className:d="",end:f=!1,style:m,to:g,viewTransition:y,children:b,...E},C){let w=useResolvedPath(g,{relative:E.relative}),R=useLocation(),_=reactExports.useContext(DataRouterStateContext),{navigator:M,basename:I}=reactExports.useContext(NavigationContext),N=_!=null&&useViewTransitionState(w)&&y===!0,A=M.encodeLocation?M.encodeLocation(w).pathname:w.pathname,P=R.pathname,z=_&&_.navigation&&_.navigation.location?_.navigation.location.pathname:null;u||(P=P.toLowerCase(),z=z?z.toLowerCase():null,A=A.toLowerCase()),z&&I&&(z=stripBasename(z,I)||z);const B=A!=="/"&&A.endsWith("/")?A.length-1:A.length;let j=P===A||!f&&P.startsWith(A)&&P.charAt(B)==="/",L=z!=null&&(z===A||!f&&z.startsWith(A)&&z.charAt(A.length)==="/"),U={isActive:j,isPending:L,isTransitioning:N},q=j?c:void 0,F;typeof d=="function"?F=d(U):F=[d,j?"active":null,L?"pending":null,N?"transitioning":null].filter(Boolean).join(" ");let K=typeof m=="function"?m(U):m;return reactExports.createElement(Link,{...E,"aria-current":q,className:F,ref:C,style:K,to:g,viewTransition:y},typeof b=="function"?b(U):b)});NavLink.displayName="NavLink";var Form=reactExports.forwardRef(({discover:a="render",fetcherKey:c,navigate:u,reloadDocument:d,replace:f,state:m,method:g=defaultMethod,action:y,onSubmit:b,relative:E,preventScrollReset:C,viewTransition:w,...R},_)=>{let M=useSubmit(),I=useFormAction(y,{relative:E}),N=g.toLowerCase()==="get"?"get":"post",A=typeof y=="string"&&ABSOLUTE_URL_REGEX2.test(y),P=z=>{if(b&&b(z),z.defaultPrevented)return;z.preventDefault();let B=z.nativeEvent.submitter,j=(B==null?void 0:B.getAttribute("formmethod"))||g;M(B||z.currentTarget,{fetcherKey:c,method:j,navigate:u,replace:f,state:m,relative:E,preventScrollReset:C,viewTransition:w})};return reactExports.createElement("form",{ref:_,method:N,action:I,onSubmit:d?b:P,...R,"data-discover":!A&&a==="render"?"true":void 0})});Form.displayName="Form";function getDataRouterConsoleError2(a){return`${a} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function useDataRouterContext3(a){let c=reactExports.useContext(DataRouterContext);return invariant(c,getDataRouterConsoleError2(a)),c}function useLinkClickHandler(a,{target:c,replace:u,state:d,preventScrollReset:f,relative:m,viewTransition:g}={}){let y=useNavigate(),b=useLocation(),E=useResolvedPath(a,{relative:m});return reactExports.useCallback(C=>{if(shouldProcessLinkClick(C,c)){C.preventDefault();let w=u!==void 0?u:createPath(b)===createPath(E);y(a,{replace:w,state:d,preventScrollReset:f,relative:m,viewTransition:g})}},[b,y,E,u,d,c,a,f,m,g])}var fetcherId=0,getUniqueFetcherId=()=>`__${String(++fetcherId)}__`;function useSubmit(){let{router:a}=useDataRouterContext3("useSubmit"),{basename:c}=reactExports.useContext(NavigationContext),u=useRouteId();return reactExports.useCallback(async(d,f={})=>{let{action:m,method:g,encType:y,formData:b,body:E}=getFormSubmissionInfo(d,c);if(f.navigate===!1){let C=f.fetcherKey||getUniqueFetcherId();await a.fetch(C,u,f.action||m,{preventScrollReset:f.preventScrollReset,formData:b,body:E,formMethod:f.method||g,formEncType:f.encType||y,flushSync:f.flushSync})}else await a.navigate(f.action||m,{preventScrollReset:f.preventScrollReset,formData:b,body:E,formMethod:f.method||g,formEncType:f.encType||y,replace:f.replace,state:f.state,fromRouteId:u,flushSync:f.flushSync,viewTransition:f.viewTransition})},[a,c,u])}function useFormAction(a,{relative:c}={}){let{basename:u}=reactExports.useContext(NavigationContext),d=reactExports.useContext(RouteContext);invariant(d,"useFormAction must be used inside a RouteContext");let[f]=d.matches.slice(-1),m={...useResolvedPath(a||".",{relative:c})},g=useLocation();if(a==null){m.search=g.search;let y=new URLSearchParams(m.search),b=y.getAll("index");if(b.some(C=>C==="")){y.delete("index"),b.filter(w=>w).forEach(w=>y.append("index",w));let C=y.toString();m.search=C?`?${C}`:""}}return(!a||a===".")&&f.route.index&&(m.search=m.search?m.search.replace(/^\?/,"?index&"):"?index"),u!=="/"&&(m.pathname=m.pathname==="/"?u:joinPaths([u,m.pathname])),createPath(m)}function useViewTransitionState(a,c={}){let u=reactExports.useContext(ViewTransitionContext);invariant(u!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:d}=useDataRouterContext3("useViewTransitionState"),f=useResolvedPath(a,{relative:c.relative});if(!u.isTransitioning)return!1;let m=stripBasename(u.currentLocation.pathname,d)||u.currentLocation.pathname,g=stripBasename(u.nextLocation.pathname,d)||u.nextLocation.pathname;return matchPath(f.pathname,g)!=null||matchPath(f.pathname,m)!=null}new TextEncoder;[...NO_BODY_STATUS_CODES];var withSelector={exports:{}},useSyncExternalStoreWithSelector_production={};/**
 * @license React
 * use-sync-external-store-with-selector.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hasRequiredUseSyncExternalStoreWithSelector_production;function requireUseSyncExternalStoreWithSelector_production(){if(hasRequiredUseSyncExternalStoreWithSelector_production)return useSyncExternalStoreWithSelector_production;hasRequiredUseSyncExternalStoreWithSelector_production=1;var a=requireReact();function c(b,E){return b===E&&(b!==0||1/b===1/E)||b!==b&&E!==E}var u=typeof Object.is=="function"?Object.is:c,d=a.useSyncExternalStore,f=a.useRef,m=a.useEffect,g=a.useMemo,y=a.useDebugValue;return useSyncExternalStoreWithSelector_production.useSyncExternalStoreWithSelector=function(b,E,C,w,R){var _=f(null);if(_.current===null){var M={hasValue:!1,value:null};_.current=M}else M=_.current;_=g(function(){function N(j){if(!A){if(A=!0,P=j,j=w(j),R!==void 0&&M.hasValue){var L=M.value;if(R(L,j))return z=L}return z=j}if(L=z,u(P,j))return L;var U=w(j);return R!==void 0&&R(L,U)?(P=j,L):(P=j,z=U)}var A=!1,P,z,B=C===void 0?null:C;return[function(){return N(E())},B===null?void 0:function(){return N(B())}]},[E,C,w,R]);var I=d(b,_[0],_[1]);return m(function(){M.hasValue=!0,M.value=I},[I]),y(I),I},useSyncExternalStoreWithSelector_production}var hasRequiredWithSelector;function requireWithSelector(){return hasRequiredWithSelector||(hasRequiredWithSelector=1,withSelector.exports=requireUseSyncExternalStoreWithSelector_production()),withSelector.exports}var withSelectorExports=requireWithSelector();function defaultNoopBatch(a){a()}function createListenerCollection(){let a=null,c=null;return{clear(){a=null,c=null},notify(){defaultNoopBatch(()=>{let u=a;for(;u;)u.callback(),u=u.next})},get(){const u=[];let d=a;for(;d;)u.push(d),d=d.next;return u},subscribe(u){let d=!0;const f=c={callback:u,next:null,prev:c};return f.prev?f.prev.next=f:a=f,function(){!d||a===null||(d=!1,f.next?f.next.prev=f.prev:c=f.prev,f.prev?f.prev.next=f.next:a=f.next)}}}}var nullListeners={notify(){},get:()=>[]};function createSubscription(a,c){let u,d=nullListeners,f=0,m=!1;function g(I){C();const N=d.subscribe(I);let A=!1;return()=>{A||(A=!0,N(),w())}}function y(){d.notify()}function b(){M.onStateChange&&M.onStateChange()}function E(){return m}function C(){f++,u||(u=a.subscribe(b),d=createListenerCollection())}function w(){f--,u&&f===0&&(u(),u=void 0,d.clear(),d=nullListeners)}function R(){m||(m=!0,C())}function _(){m&&(m=!1,w())}const M={addNestedSub:g,notifyNestedSubs:y,handleChangeWrapper:b,isSubscribed:E,trySubscribe:R,tryUnsubscribe:_,getListeners:()=>d};return M}var canUseDOM=()=>typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u",isDOM=canUseDOM(),isRunningInReactNative=()=>typeof navigator<"u"&&navigator.product==="ReactNative",isReactNative=isRunningInReactNative(),getUseIsomorphicLayoutEffect=()=>isDOM||isReactNative?reactExports.useLayoutEffect:reactExports.useEffect,useIsomorphicLayoutEffect=getUseIsomorphicLayoutEffect(),ContextKey=Symbol.for("react-redux-context"),gT=typeof globalThis<"u"?globalThis:{};function getContext(){if(!reactExports.createContext)return{};const a=gT[ContextKey]??(gT[ContextKey]=new Map);let c=a.get(reactExports.createContext);return c||(c=reactExports.createContext(null),a.set(reactExports.createContext,c)),c}var ReactReduxContext=getContext();function Provider(a){const{children:c,context:u,serverState:d,store:f}=a,m=reactExports.useMemo(()=>{const b=createSubscription(f);return{store:f,subscription:b,getServerState:d?()=>d:void 0}},[f,d]),g=reactExports.useMemo(()=>f.getState(),[f]);useIsomorphicLayoutEffect(()=>{const{subscription:b}=m;return b.onStateChange=b.notifyNestedSubs,b.trySubscribe(),g!==f.getState()&&b.notifyNestedSubs(),()=>{b.tryUnsubscribe(),b.onStateChange=void 0}},[m,g]);const y=u||ReactReduxContext;return reactExports.createElement(y.Provider,{value:m},c)}var Provider_default=Provider;function createReduxContextHook(a=ReactReduxContext){return function(){return reactExports.useContext(a)}}var useReduxContext=createReduxContextHook();function createStoreHook(a=ReactReduxContext){const c=a===ReactReduxContext?useReduxContext:createReduxContextHook(a),u=()=>{const{store:d}=c();return d};return Object.assign(u,{withTypes:()=>u}),u}var useStore=createStoreHook();function createDispatchHook(a=ReactReduxContext){const c=a===ReactReduxContext?useStore:createStoreHook(a),u=()=>c().dispatch;return Object.assign(u,{withTypes:()=>u}),u}var useDispatch=createDispatchHook(),refEquality=(a,c)=>a===c;function createSelectorHook(a=ReactReduxContext){const c=a===ReactReduxContext?useReduxContext:createReduxContextHook(a),u=(d,f={})=>{const{equalityFn:m=refEquality}=typeof f=="function"?{equalityFn:f}:f,g=c(),{store:y,subscription:b,getServerState:E}=g;reactExports.useRef(!0);const C=reactExports.useCallback({[d.name](R){return d(R)}}[d.name],[d]),w=withSelectorExports.useSyncExternalStoreWithSelector(b.addNestedSub,y.getState,E||y.getState,C,m);return reactExports.useDebugValue(w),w};return Object.assign(u,{withTypes:()=>u}),u}var useSelector=createSelectorHook();function bind(a,c){return function(){return a.apply(c,arguments)}}const{toString:toString$2}=Object.prototype,{getPrototypeOf:getPrototypeOf$1}=Object,kindOf=(a=>c=>{const u=toString$2.call(c);return a[u]||(a[u]=u.slice(8,-1).toLowerCase())})(Object.create(null)),kindOfTest=a=>(a=a.toLowerCase(),c=>kindOf(c)===a),typeOfTest=a=>c=>typeof c===a,{isArray}=Array,isUndefined=typeOfTest("undefined");function isBuffer(a){return a!==null&&!isUndefined(a)&&a.constructor!==null&&!isUndefined(a.constructor)&&isFunction(a.constructor.isBuffer)&&a.constructor.isBuffer(a)}const isArrayBuffer=kindOfTest("ArrayBuffer");function isArrayBufferView(a){let c;return typeof ArrayBuffer<"u"&&ArrayBuffer.isView?c=ArrayBuffer.isView(a):c=a&&a.buffer&&isArrayBuffer(a.buffer),c}const isString=typeOfTest("string"),isFunction=typeOfTest("function"),isNumber=typeOfTest("number"),isObject=a=>a!==null&&typeof a=="object",isBoolean$1=a=>a===!0||a===!1,isPlainObject$3=a=>{if(kindOf(a)!=="object")return!1;const c=getPrototypeOf$1(a);return(c===null||c===Object.prototype||Object.getPrototypeOf(c)===null)&&!(Symbol.toStringTag in a)&&!(Symbol.iterator in a)},isDate=kindOfTest("Date"),isFile=kindOfTest("File"),isBlob=kindOfTest("Blob"),isFileList=kindOfTest("FileList"),isStream=a=>isObject(a)&&isFunction(a.pipe),isFormData=a=>{let c;return a&&(typeof FormData=="function"&&a instanceof FormData||isFunction(a.append)&&((c=kindOf(a))==="formdata"||c==="object"&&isFunction(a.toString)&&a.toString()==="[object FormData]"))},isURLSearchParams=kindOfTest("URLSearchParams"),[isReadableStream,isRequest,isResponse,isHeaders]=["ReadableStream","Request","Response","Headers"].map(kindOfTest),trim=a=>a.trim?a.trim():a.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"");function forEach(a,c,{allOwnKeys:u=!1}={}){if(a===null||typeof a>"u")return;let d,f;if(typeof a!="object"&&(a=[a]),isArray(a))for(d=0,f=a.length;d<f;d++)c.call(null,a[d],d,a);else{const m=u?Object.getOwnPropertyNames(a):Object.keys(a),g=m.length;let y;for(d=0;d<g;d++)y=m[d],c.call(null,a[y],y,a)}}function findKey(a,c){c=c.toLowerCase();const u=Object.keys(a);let d=u.length,f;for(;d-- >0;)if(f=u[d],c===f.toLowerCase())return f;return null}const _global=typeof globalThis<"u"?globalThis:typeof self<"u"?self:typeof window<"u"?window:global,isContextDefined=a=>!isUndefined(a)&&a!==_global;function merge$1(){const{caseless:a}=isContextDefined(this)&&this||{},c={},u=(d,f)=>{const m=a&&findKey(c,f)||f;isPlainObject$3(c[m])&&isPlainObject$3(d)?c[m]=merge$1(c[m],d):isPlainObject$3(d)?c[m]=merge$1({},d):isArray(d)?c[m]=d.slice():c[m]=d};for(let d=0,f=arguments.length;d<f;d++)arguments[d]&&forEach(arguments[d],u);return c}const extend$2=(a,c,u,{allOwnKeys:d}={})=>(forEach(c,(f,m)=>{u&&isFunction(f)?a[m]=bind(f,u):a[m]=f},{allOwnKeys:d}),a),stripBOM=a=>(a.charCodeAt(0)===65279&&(a=a.slice(1)),a),inherits=(a,c,u,d)=>{a.prototype=Object.create(c.prototype,d),a.prototype.constructor=a,Object.defineProperty(a,"super",{value:c.prototype}),u&&Object.assign(a.prototype,u)},toFlatObject=(a,c,u,d)=>{let f,m,g;const y={};if(c=c||{},a==null)return c;do{for(f=Object.getOwnPropertyNames(a),m=f.length;m-- >0;)g=f[m],(!d||d(g,a,c))&&!y[g]&&(c[g]=a[g],y[g]=!0);a=u!==!1&&getPrototypeOf$1(a)}while(a&&(!u||u(a,c))&&a!==Object.prototype);return c},endsWith=(a,c,u)=>{a=String(a),(u===void 0||u>a.length)&&(u=a.length),u-=c.length;const d=a.indexOf(c,u);return d!==-1&&d===u},toArray=a=>{if(!a)return null;if(isArray(a))return a;let c=a.length;if(!isNumber(c))return null;const u=new Array(c);for(;c-- >0;)u[c]=a[c];return u},isTypedArray=(a=>c=>a&&c instanceof a)(typeof Uint8Array<"u"&&getPrototypeOf$1(Uint8Array)),forEachEntry=(a,c)=>{const d=(a&&a[Symbol.iterator]).call(a);let f;for(;(f=d.next())&&!f.done;){const m=f.value;c.call(a,m[0],m[1])}},matchAll=(a,c)=>{let u;const d=[];for(;(u=a.exec(c))!==null;)d.push(u);return d},isHTMLForm=kindOfTest("HTMLFormElement"),toCamelCase=a=>a.toLowerCase().replace(/[-_\s]([a-z\d])(\w*)/g,function(u,d,f){return d.toUpperCase()+f}),hasOwnProperty$1=(({hasOwnProperty:a})=>(c,u)=>a.call(c,u))(Object.prototype),isRegExp=kindOfTest("RegExp"),reduceDescriptors=(a,c)=>{const u=Object.getOwnPropertyDescriptors(a),d={};forEach(u,(f,m)=>{let g;(g=c(f,m,a))!==!1&&(d[m]=g||f)}),Object.defineProperties(a,d)},freezeMethods=a=>{reduceDescriptors(a,(c,u)=>{if(isFunction(a)&&["arguments","caller","callee"].indexOf(u)!==-1)return!1;const d=a[u];if(isFunction(d)){if(c.enumerable=!1,"writable"in c){c.writable=!1;return}c.set||(c.set=()=>{throw Error("Can not rewrite read-only method '"+u+"'")})}})},toObjectSet=(a,c)=>{const u={},d=f=>{f.forEach(m=>{u[m]=!0})};return isArray(a)?d(a):d(String(a).split(c)),u},noop$1=()=>{},toFiniteNumber=(a,c)=>a!=null&&Number.isFinite(a=+a)?a:c;function isSpecCompliantForm(a){return!!(a&&isFunction(a.append)&&a[Symbol.toStringTag]==="FormData"&&a[Symbol.iterator])}const toJSONObject=a=>{const c=new Array(10),u=(d,f)=>{if(isObject(d)){if(c.indexOf(d)>=0)return;if(!("toJSON"in d)){c[f]=d;const m=isArray(d)?[]:{};return forEach(d,(g,y)=>{const b=u(g,f+1);!isUndefined(b)&&(m[y]=b)}),c[f]=void 0,m}}return d};return u(a,0)},isAsyncFn=kindOfTest("AsyncFunction"),isThenable=a=>a&&(isObject(a)||isFunction(a))&&isFunction(a.then)&&isFunction(a.catch),_setImmediate=((a,c)=>a?setImmediate:c?((u,d)=>(_global.addEventListener("message",({source:f,data:m})=>{f===_global&&m===u&&d.length&&d.shift()()},!1),f=>{d.push(f),_global.postMessage(u,"*")}))(`axios@${Math.random()}`,[]):u=>setTimeout(u))(typeof setImmediate=="function",isFunction(_global.postMessage)),asap=typeof queueMicrotask<"u"?queueMicrotask.bind(_global):typeof process<"u"&&process.nextTick||_setImmediate,utils$2={isArray,isArrayBuffer,isBuffer,isFormData,isArrayBufferView,isString,isNumber,isBoolean:isBoolean$1,isObject,isPlainObject:isPlainObject$3,isReadableStream,isRequest,isResponse,isHeaders,isUndefined,isDate,isFile,isBlob,isRegExp,isFunction,isStream,isURLSearchParams,isTypedArray,isFileList,forEach,merge:merge$1,extend:extend$2,trim,stripBOM,inherits,toFlatObject,kindOf,kindOfTest,endsWith,toArray,forEachEntry,matchAll,isHTMLForm,hasOwnProperty:hasOwnProperty$1,hasOwnProp:hasOwnProperty$1,reduceDescriptors,freezeMethods,toObjectSet,toCamelCase,noop:noop$1,toFiniteNumber,findKey,global:_global,isContextDefined,isSpecCompliantForm,toJSONObject,isAsyncFn,isThenable,setImmediate:_setImmediate,asap};function AxiosError$1(a,c,u,d,f){Error.call(this),Error.captureStackTrace?Error.captureStackTrace(this,this.constructor):this.stack=new Error().stack,this.message=a,this.name="AxiosError",c&&(this.code=c),u&&(this.config=u),d&&(this.request=d),f&&(this.response=f,this.status=f.status?f.status:null)}utils$2.inherits(AxiosError$1,Error,{toJSON:function(){return{message:this.message,name:this.name,description:this.description,number:this.number,fileName:this.fileName,lineNumber:this.lineNumber,columnNumber:this.columnNumber,stack:this.stack,config:utils$2.toJSONObject(this.config),code:this.code,status:this.status}}});const prototype$1=AxiosError$1.prototype,descriptors={};["ERR_BAD_OPTION_VALUE","ERR_BAD_OPTION","ECONNABORTED","ETIMEDOUT","ERR_NETWORK","ERR_FR_TOO_MANY_REDIRECTS","ERR_DEPRECATED","ERR_BAD_RESPONSE","ERR_BAD_REQUEST","ERR_CANCELED","ERR_NOT_SUPPORT","ERR_INVALID_URL"].forEach(a=>{descriptors[a]={value:a}});Object.defineProperties(AxiosError$1,descriptors);Object.defineProperty(prototype$1,"isAxiosError",{value:!0});AxiosError$1.from=(a,c,u,d,f,m)=>{const g=Object.create(prototype$1);return utils$2.toFlatObject(a,g,function(b){return b!==Error.prototype},y=>y!=="isAxiosError"),AxiosError$1.call(g,a.message,c,u,d,f),g.cause=a,g.name=a.name,m&&Object.assign(g,m),g};const httpAdapter=null;function isVisitable(a){return utils$2.isPlainObject(a)||utils$2.isArray(a)}function removeBrackets(a){return utils$2.endsWith(a,"[]")?a.slice(0,-2):a}function renderKey(a,c,u){return a?a.concat(c).map(function(f,m){return f=removeBrackets(f),!u&&m?"["+f+"]":f}).join(u?".":""):c}function isFlatArray(a){return utils$2.isArray(a)&&!a.some(isVisitable)}const predicates=utils$2.toFlatObject(utils$2,{},null,function(c){return/^is[A-Z]/.test(c)});function toFormData$1(a,c,u){if(!utils$2.isObject(a))throw new TypeError("target must be an object");c=c||new FormData,u=utils$2.toFlatObject(u,{metaTokens:!0,dots:!1,indexes:!1},!1,function(I,N){return!utils$2.isUndefined(N[I])});const d=u.metaTokens,f=u.visitor||C,m=u.dots,g=u.indexes,b=(u.Blob||typeof Blob<"u"&&Blob)&&utils$2.isSpecCompliantForm(c);if(!utils$2.isFunction(f))throw new TypeError("visitor must be a function");function E(M){if(M===null)return"";if(utils$2.isDate(M))return M.toISOString();if(!b&&utils$2.isBlob(M))throw new AxiosError$1("Blob is not supported. Use a Buffer instead.");return utils$2.isArrayBuffer(M)||utils$2.isTypedArray(M)?b&&typeof Blob=="function"?new Blob([M]):Buffer.from(M):M}function C(M,I,N){let A=M;if(M&&!N&&typeof M=="object"){if(utils$2.endsWith(I,"{}"))I=d?I:I.slice(0,-2),M=JSON.stringify(M);else if(utils$2.isArray(M)&&isFlatArray(M)||(utils$2.isFileList(M)||utils$2.endsWith(I,"[]"))&&(A=utils$2.toArray(M)))return I=removeBrackets(I),A.forEach(function(z,B){!(utils$2.isUndefined(z)||z===null)&&c.append(g===!0?renderKey([I],B,m):g===null?I:I+"[]",E(z))}),!1}return isVisitable(M)?!0:(c.append(renderKey(N,I,m),E(M)),!1)}const w=[],R=Object.assign(predicates,{defaultVisitor:C,convertValue:E,isVisitable});function _(M,I){if(!utils$2.isUndefined(M)){if(w.indexOf(M)!==-1)throw Error("Circular reference detected in "+I.join("."));w.push(M),utils$2.forEach(M,function(A,P){(!(utils$2.isUndefined(A)||A===null)&&f.call(c,A,utils$2.isString(P)?P.trim():P,I,R))===!0&&_(A,I?I.concat(P):[P])}),w.pop()}}if(!utils$2.isObject(a))throw new TypeError("data must be an object");return _(a),c}function encode$1(a){const c={"!":"%21","'":"%27","(":"%28",")":"%29","~":"%7E","%20":"+","%00":"\0"};return encodeURIComponent(a).replace(/[!'()~]|%20|%00/g,function(d){return c[d]})}function AxiosURLSearchParams(a,c){this._pairs=[],a&&toFormData$1(a,this,c)}const prototype=AxiosURLSearchParams.prototype;prototype.append=function(c,u){this._pairs.push([c,u])};prototype.toString=function(c){const u=c?function(d){return c.call(this,d,encode$1)}:encode$1;return this._pairs.map(function(f){return u(f[0])+"="+u(f[1])},"").join("&")};function encode(a){return encodeURIComponent(a).replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",").replace(/%20/g,"+").replace(/%5B/gi,"[").replace(/%5D/gi,"]")}function buildURL(a,c,u){if(!c)return a;const d=u&&u.encode||encode;utils$2.isFunction(u)&&(u={serialize:u});const f=u&&u.serialize;let m;if(f?m=f(c,u):m=utils$2.isURLSearchParams(c)?c.toString():new AxiosURLSearchParams(c,u).toString(d),m){const g=a.indexOf("#");g!==-1&&(a=a.slice(0,g)),a+=(a.indexOf("?")===-1?"?":"&")+m}return a}class InterceptorManager{constructor(){this.handlers=[]}use(c,u,d){return this.handlers.push({fulfilled:c,rejected:u,synchronous:d?d.synchronous:!1,runWhen:d?d.runWhen:null}),this.handlers.length-1}eject(c){this.handlers[c]&&(this.handlers[c]=null)}clear(){this.handlers&&(this.handlers=[])}forEach(c){utils$2.forEach(this.handlers,function(d){d!==null&&c(d)})}}const transitionalDefaults={silentJSONParsing:!0,forcedJSONParsing:!0,clarifyTimeoutError:!1},URLSearchParams$1=typeof URLSearchParams<"u"?URLSearchParams:AxiosURLSearchParams,FormData$1=typeof FormData<"u"?FormData:null,Blob$1=typeof Blob<"u"?Blob:null,platform$1={isBrowser:!0,classes:{URLSearchParams:URLSearchParams$1,FormData:FormData$1,Blob:Blob$1},protocols:["http","https","file","blob","url","data"]},hasBrowserEnv=typeof window<"u"&&typeof document<"u",_navigator=typeof navigator=="object"&&navigator||void 0,hasStandardBrowserEnv=hasBrowserEnv&&(!_navigator||["ReactNative","NativeScript","NS"].indexOf(_navigator.product)<0),hasStandardBrowserWebWorkerEnv=typeof WorkerGlobalScope<"u"&&self instanceof WorkerGlobalScope&&typeof self.importScripts=="function",origin=hasBrowserEnv&&window.location.href||"http://localhost",utils$1=Object.freeze(Object.defineProperty({__proto__:null,hasBrowserEnv,hasStandardBrowserEnv,hasStandardBrowserWebWorkerEnv,navigator:_navigator,origin},Symbol.toStringTag,{value:"Module"})),platform={...utils$1,...platform$1};function toURLEncodedForm(a,c){return toFormData$1(a,new platform.classes.URLSearchParams,Object.assign({visitor:function(u,d,f,m){return platform.isNode&&utils$2.isBuffer(u)?(this.append(d,u.toString("base64")),!1):m.defaultVisitor.apply(this,arguments)}},c))}function parsePropPath(a){return utils$2.matchAll(/\w+|\[(\w*)]/g,a).map(c=>c[0]==="[]"?"":c[1]||c[0])}function arrayToObject(a){const c={},u=Object.keys(a);let d;const f=u.length;let m;for(d=0;d<f;d++)m=u[d],c[m]=a[m];return c}function formDataToJSON(a){function c(u,d,f,m){let g=u[m++];if(g==="__proto__")return!0;const y=Number.isFinite(+g),b=m>=u.length;return g=!g&&utils$2.isArray(f)?f.length:g,b?(utils$2.hasOwnProp(f,g)?f[g]=[f[g],d]:f[g]=d,!y):((!f[g]||!utils$2.isObject(f[g]))&&(f[g]=[]),c(u,d,f[g],m)&&utils$2.isArray(f[g])&&(f[g]=arrayToObject(f[g])),!y)}if(utils$2.isFormData(a)&&utils$2.isFunction(a.entries)){const u={};return utils$2.forEachEntry(a,(d,f)=>{c(parsePropPath(d),f,u,0)}),u}return null}function stringifySafely(a,c,u){if(utils$2.isString(a))try{return(c||JSON.parse)(a),utils$2.trim(a)}catch(d){if(d.name!=="SyntaxError")throw d}return(u||JSON.stringify)(a)}const defaults={transitional:transitionalDefaults,adapter:["xhr","http","fetch"],transformRequest:[function(c,u){const d=u.getContentType()||"",f=d.indexOf("application/json")>-1,m=utils$2.isObject(c);if(m&&utils$2.isHTMLForm(c)&&(c=new FormData(c)),utils$2.isFormData(c))return f?JSON.stringify(formDataToJSON(c)):c;if(utils$2.isArrayBuffer(c)||utils$2.isBuffer(c)||utils$2.isStream(c)||utils$2.isFile(c)||utils$2.isBlob(c)||utils$2.isReadableStream(c))return c;if(utils$2.isArrayBufferView(c))return c.buffer;if(utils$2.isURLSearchParams(c))return u.setContentType("application/x-www-form-urlencoded;charset=utf-8",!1),c.toString();let y;if(m){if(d.indexOf("application/x-www-form-urlencoded")>-1)return toURLEncodedForm(c,this.formSerializer).toString();if((y=utils$2.isFileList(c))||d.indexOf("multipart/form-data")>-1){const b=this.env&&this.env.FormData;return toFormData$1(y?{"files[]":c}:c,b&&new b,this.formSerializer)}}return m||f?(u.setContentType("application/json",!1),stringifySafely(c)):c}],transformResponse:[function(c){const u=this.transitional||defaults.transitional,d=u&&u.forcedJSONParsing,f=this.responseType==="json";if(utils$2.isResponse(c)||utils$2.isReadableStream(c))return c;if(c&&utils$2.isString(c)&&(d&&!this.responseType||f)){const g=!(u&&u.silentJSONParsing)&&f;try{return JSON.parse(c)}catch(y){if(g)throw y.name==="SyntaxError"?AxiosError$1.from(y,AxiosError$1.ERR_BAD_RESPONSE,this,null,this.response):y}}return c}],timeout:0,xsrfCookieName:"XSRF-TOKEN",xsrfHeaderName:"X-XSRF-TOKEN",maxContentLength:-1,maxBodyLength:-1,env:{FormData:platform.classes.FormData,Blob:platform.classes.Blob},validateStatus:function(c){return c>=200&&c<300},headers:{common:{Accept:"application/json, text/plain, */*","Content-Type":void 0}}};utils$2.forEach(["delete","get","head","post","put","patch"],a=>{defaults.headers[a]={}});const ignoreDuplicateOf=utils$2.toObjectSet(["age","authorization","content-length","content-type","etag","expires","from","host","if-modified-since","if-unmodified-since","last-modified","location","max-forwards","proxy-authorization","referer","retry-after","user-agent"]),parseHeaders=a=>{const c={};let u,d,f;return a&&a.split(`
`).forEach(function(g){f=g.indexOf(":"),u=g.substring(0,f).trim().toLowerCase(),d=g.substring(f+1).trim(),!(!u||c[u]&&ignoreDuplicateOf[u])&&(u==="set-cookie"?c[u]?c[u].push(d):c[u]=[d]:c[u]=c[u]?c[u]+", "+d:d)}),c},$internals=Symbol("internals");function normalizeHeader(a){return a&&String(a).trim().toLowerCase()}function normalizeValue(a){return a===!1||a==null?a:utils$2.isArray(a)?a.map(normalizeValue):String(a)}function parseTokens(a){const c=Object.create(null),u=/([^\s,;=]+)\s*(?:=\s*([^,;]+))?/g;let d;for(;d=u.exec(a);)c[d[1]]=d[2];return c}const isValidHeaderName=a=>/^[-_a-zA-Z0-9^`|~,!#$%&'*+.]+$/.test(a.trim());function matchHeaderValue(a,c,u,d,f){if(utils$2.isFunction(d))return d.call(this,c,u);if(f&&(c=u),!!utils$2.isString(c)){if(utils$2.isString(d))return c.indexOf(d)!==-1;if(utils$2.isRegExp(d))return d.test(c)}}function formatHeader(a){return a.trim().toLowerCase().replace(/([a-z\d])(\w*)/g,(c,u,d)=>u.toUpperCase()+d)}function buildAccessors(a,c){const u=utils$2.toCamelCase(" "+c);["get","set","has"].forEach(d=>{Object.defineProperty(a,d+u,{value:function(f,m,g){return this[d].call(this,c,f,m,g)},configurable:!0})})}let AxiosHeaders$1=class{constructor(c){c&&this.set(c)}set(c,u,d){const f=this;function m(y,b,E){const C=normalizeHeader(b);if(!C)throw new Error("header name must be a non-empty string");const w=utils$2.findKey(f,C);(!w||f[w]===void 0||E===!0||E===void 0&&f[w]!==!1)&&(f[w||b]=normalizeValue(y))}const g=(y,b)=>utils$2.forEach(y,(E,C)=>m(E,C,b));if(utils$2.isPlainObject(c)||c instanceof this.constructor)g(c,u);else if(utils$2.isString(c)&&(c=c.trim())&&!isValidHeaderName(c))g(parseHeaders(c),u);else if(utils$2.isHeaders(c))for(const[y,b]of c.entries())m(b,y,d);else c!=null&&m(u,c,d);return this}get(c,u){if(c=normalizeHeader(c),c){const d=utils$2.findKey(this,c);if(d){const f=this[d];if(!u)return f;if(u===!0)return parseTokens(f);if(utils$2.isFunction(u))return u.call(this,f,d);if(utils$2.isRegExp(u))return u.exec(f);throw new TypeError("parser must be boolean|regexp|function")}}}has(c,u){if(c=normalizeHeader(c),c){const d=utils$2.findKey(this,c);return!!(d&&this[d]!==void 0&&(!u||matchHeaderValue(this,this[d],d,u)))}return!1}delete(c,u){const d=this;let f=!1;function m(g){if(g=normalizeHeader(g),g){const y=utils$2.findKey(d,g);y&&(!u||matchHeaderValue(d,d[y],y,u))&&(delete d[y],f=!0)}}return utils$2.isArray(c)?c.forEach(m):m(c),f}clear(c){const u=Object.keys(this);let d=u.length,f=!1;for(;d--;){const m=u[d];(!c||matchHeaderValue(this,this[m],m,c,!0))&&(delete this[m],f=!0)}return f}normalize(c){const u=this,d={};return utils$2.forEach(this,(f,m)=>{const g=utils$2.findKey(d,m);if(g){u[g]=normalizeValue(f),delete u[m];return}const y=c?formatHeader(m):String(m).trim();y!==m&&delete u[m],u[y]=normalizeValue(f),d[y]=!0}),this}concat(...c){return this.constructor.concat(this,...c)}toJSON(c){const u=Object.create(null);return utils$2.forEach(this,(d,f)=>{d!=null&&d!==!1&&(u[f]=c&&utils$2.isArray(d)?d.join(", "):d)}),u}[Symbol.iterator](){return Object.entries(this.toJSON())[Symbol.iterator]()}toString(){return Object.entries(this.toJSON()).map(([c,u])=>c+": "+u).join(`
`)}get[Symbol.toStringTag](){return"AxiosHeaders"}static from(c){return c instanceof this?c:new this(c)}static concat(c,...u){const d=new this(c);return u.forEach(f=>d.set(f)),d}static accessor(c){const d=(this[$internals]=this[$internals]={accessors:{}}).accessors,f=this.prototype;function m(g){const y=normalizeHeader(g);d[y]||(buildAccessors(f,g),d[y]=!0)}return utils$2.isArray(c)?c.forEach(m):m(c),this}};AxiosHeaders$1.accessor(["Content-Type","Content-Length","Accept","Accept-Encoding","User-Agent","Authorization"]);utils$2.reduceDescriptors(AxiosHeaders$1.prototype,({value:a},c)=>{let u=c[0].toUpperCase()+c.slice(1);return{get:()=>a,set(d){this[u]=d}}});utils$2.freezeMethods(AxiosHeaders$1);function transformData(a,c){const u=this||defaults,d=c||u,f=AxiosHeaders$1.from(d.headers);let m=d.data;return utils$2.forEach(a,function(y){m=y.call(u,m,f.normalize(),c?c.status:void 0)}),f.normalize(),m}function isCancel$1(a){return!!(a&&a.__CANCEL__)}function CanceledError$1(a,c,u){AxiosError$1.call(this,a??"canceled",AxiosError$1.ERR_CANCELED,c,u),this.name="CanceledError"}utils$2.inherits(CanceledError$1,AxiosError$1,{__CANCEL__:!0});function settle(a,c,u){const d=u.config.validateStatus;!u.status||!d||d(u.status)?a(u):c(new AxiosError$1("Request failed with status code "+u.status,[AxiosError$1.ERR_BAD_REQUEST,AxiosError$1.ERR_BAD_RESPONSE][Math.floor(u.status/100)-4],u.config,u.request,u))}function parseProtocol(a){const c=/^([-+\w]{1,25})(:?\/\/|:)/.exec(a);return c&&c[1]||""}function speedometer(a,c){a=a||10;const u=new Array(a),d=new Array(a);let f=0,m=0,g;return c=c!==void 0?c:1e3,function(b){const E=Date.now(),C=d[m];g||(g=E),u[f]=b,d[f]=E;let w=m,R=0;for(;w!==f;)R+=u[w++],w=w%a;if(f=(f+1)%a,f===m&&(m=(m+1)%a),E-g<c)return;const _=C&&E-C;return _?Math.round(R*1e3/_):void 0}}function throttle(a,c){let u=0,d=1e3/c,f,m;const g=(E,C=Date.now())=>{u=C,f=null,m&&(clearTimeout(m),m=null),a.apply(null,E)};return[(...E)=>{const C=Date.now(),w=C-u;w>=d?g(E,C):(f=E,m||(m=setTimeout(()=>{m=null,g(f)},d-w)))},()=>f&&g(f)]}const progressEventReducer=(a,c,u=3)=>{let d=0;const f=speedometer(50,250);return throttle(m=>{const g=m.loaded,y=m.lengthComputable?m.total:void 0,b=g-d,E=f(b),C=g<=y;d=g;const w={loaded:g,total:y,progress:y?g/y:void 0,bytes:b,rate:E||void 0,estimated:E&&y&&C?(y-g)/E:void 0,event:m,lengthComputable:y!=null,[c?"download":"upload"]:!0};a(w)},u)},progressEventDecorator=(a,c)=>{const u=a!=null;return[d=>c[0]({lengthComputable:u,total:a,loaded:d}),c[1]]},asyncDecorator=a=>(...c)=>utils$2.asap(()=>a(...c)),isURLSameOrigin=platform.hasStandardBrowserEnv?((a,c)=>u=>(u=new URL(u,platform.origin),a.protocol===u.protocol&&a.host===u.host&&(c||a.port===u.port)))(new URL(platform.origin),platform.navigator&&/(msie|trident)/i.test(platform.navigator.userAgent)):()=>!0,cookies=platform.hasStandardBrowserEnv?{write(a,c,u,d,f,m){const g=[a+"="+encodeURIComponent(c)];utils$2.isNumber(u)&&g.push("expires="+new Date(u).toGMTString()),utils$2.isString(d)&&g.push("path="+d),utils$2.isString(f)&&g.push("domain="+f),m===!0&&g.push("secure"),document.cookie=g.join("; ")},read(a){const c=document.cookie.match(new RegExp("(^|;\\s*)("+a+")=([^;]*)"));return c?decodeURIComponent(c[3]):null},remove(a){this.write(a,"",Date.now()-864e5)}}:{write(){},read(){return null},remove(){}};function isAbsoluteURL(a){return/^([a-z][a-z\d+\-.]*:)?\/\//i.test(a)}function combineURLs(a,c){return c?a.replace(/\/?\/$/,"")+"/"+c.replace(/^\/+/,""):a}function buildFullPath(a,c,u){let d=!isAbsoluteURL(c);return a&&(d||u==!1)?combineURLs(a,c):c}const headersToObject=a=>a instanceof AxiosHeaders$1?{...a}:a;function mergeConfig$1(a,c){c=c||{};const u={};function d(E,C,w,R){return utils$2.isPlainObject(E)&&utils$2.isPlainObject(C)?utils$2.merge.call({caseless:R},E,C):utils$2.isPlainObject(C)?utils$2.merge({},C):utils$2.isArray(C)?C.slice():C}function f(E,C,w,R){if(utils$2.isUndefined(C)){if(!utils$2.isUndefined(E))return d(void 0,E,w,R)}else return d(E,C,w,R)}function m(E,C){if(!utils$2.isUndefined(C))return d(void 0,C)}function g(E,C){if(utils$2.isUndefined(C)){if(!utils$2.isUndefined(E))return d(void 0,E)}else return d(void 0,C)}function y(E,C,w){if(w in c)return d(E,C);if(w in a)return d(void 0,E)}const b={url:m,method:m,data:m,baseURL:g,transformRequest:g,transformResponse:g,paramsSerializer:g,timeout:g,timeoutMessage:g,withCredentials:g,withXSRFToken:g,adapter:g,responseType:g,xsrfCookieName:g,xsrfHeaderName:g,onUploadProgress:g,onDownloadProgress:g,decompress:g,maxContentLength:g,maxBodyLength:g,beforeRedirect:g,transport:g,httpAgent:g,httpsAgent:g,cancelToken:g,socketPath:g,responseEncoding:g,validateStatus:y,headers:(E,C,w)=>f(headersToObject(E),headersToObject(C),w,!0)};return utils$2.forEach(Object.keys(Object.assign({},a,c)),function(C){const w=b[C]||f,R=w(a[C],c[C],C);utils$2.isUndefined(R)&&w!==y||(u[C]=R)}),u}const resolveConfig=a=>{const c=mergeConfig$1({},a);let{data:u,withXSRFToken:d,xsrfHeaderName:f,xsrfCookieName:m,headers:g,auth:y}=c;c.headers=g=AxiosHeaders$1.from(g),c.url=buildURL(buildFullPath(c.baseURL,c.url,c.allowAbsoluteUrls),a.params,a.paramsSerializer),y&&g.set("Authorization","Basic "+btoa((y.username||"")+":"+(y.password?unescape(encodeURIComponent(y.password)):"")));let b;if(utils$2.isFormData(u)){if(platform.hasStandardBrowserEnv||platform.hasStandardBrowserWebWorkerEnv)g.setContentType(void 0);else if((b=g.getContentType())!==!1){const[E,...C]=b?b.split(";").map(w=>w.trim()).filter(Boolean):[];g.setContentType([E||"multipart/form-data",...C].join("; "))}}if(platform.hasStandardBrowserEnv&&(d&&utils$2.isFunction(d)&&(d=d(c)),d||d!==!1&&isURLSameOrigin(c.url))){const E=f&&m&&cookies.read(m);E&&g.set(f,E)}return c},isXHRAdapterSupported=typeof XMLHttpRequest<"u",xhrAdapter=isXHRAdapterSupported&&function(a){return new Promise(function(u,d){const f=resolveConfig(a);let m=f.data;const g=AxiosHeaders$1.from(f.headers).normalize();let{responseType:y,onUploadProgress:b,onDownloadProgress:E}=f,C,w,R,_,M;function I(){_&&_(),M&&M(),f.cancelToken&&f.cancelToken.unsubscribe(C),f.signal&&f.signal.removeEventListener("abort",C)}let N=new XMLHttpRequest;N.open(f.method.toUpperCase(),f.url,!0),N.timeout=f.timeout;function A(){if(!N)return;const z=AxiosHeaders$1.from("getAllResponseHeaders"in N&&N.getAllResponseHeaders()),j={data:!y||y==="text"||y==="json"?N.responseText:N.response,status:N.status,statusText:N.statusText,headers:z,config:a,request:N};settle(function(U){u(U),I()},function(U){d(U),I()},j),N=null}"onloadend"in N?N.onloadend=A:N.onreadystatechange=function(){!N||N.readyState!==4||N.status===0&&!(N.responseURL&&N.responseURL.indexOf("file:")===0)||setTimeout(A)},N.onabort=function(){N&&(d(new AxiosError$1("Request aborted",AxiosError$1.ECONNABORTED,a,N)),N=null)},N.onerror=function(){d(new AxiosError$1("Network Error",AxiosError$1.ERR_NETWORK,a,N)),N=null},N.ontimeout=function(){let B=f.timeout?"timeout of "+f.timeout+"ms exceeded":"timeout exceeded";const j=f.transitional||transitionalDefaults;f.timeoutErrorMessage&&(B=f.timeoutErrorMessage),d(new AxiosError$1(B,j.clarifyTimeoutError?AxiosError$1.ETIMEDOUT:AxiosError$1.ECONNABORTED,a,N)),N=null},m===void 0&&g.setContentType(null),"setRequestHeader"in N&&utils$2.forEach(g.toJSON(),function(B,j){N.setRequestHeader(j,B)}),utils$2.isUndefined(f.withCredentials)||(N.withCredentials=!!f.withCredentials),y&&y!=="json"&&(N.responseType=f.responseType),E&&([R,M]=progressEventReducer(E,!0),N.addEventListener("progress",R)),b&&N.upload&&([w,_]=progressEventReducer(b),N.upload.addEventListener("progress",w),N.upload.addEventListener("loadend",_)),(f.cancelToken||f.signal)&&(C=z=>{N&&(d(!z||z.type?new CanceledError$1(null,a,N):z),N.abort(),N=null)},f.cancelToken&&f.cancelToken.subscribe(C),f.signal&&(f.signal.aborted?C():f.signal.addEventListener("abort",C)));const P=parseProtocol(f.url);if(P&&platform.protocols.indexOf(P)===-1){d(new AxiosError$1("Unsupported protocol "+P+":",AxiosError$1.ERR_BAD_REQUEST,a));return}N.send(m||null)})},composeSignals=(a,c)=>{const{length:u}=a=a?a.filter(Boolean):[];if(c||u){let d=new AbortController,f;const m=function(E){if(!f){f=!0,y();const C=E instanceof Error?E:this.reason;d.abort(C instanceof AxiosError$1?C:new CanceledError$1(C instanceof Error?C.message:C))}};let g=c&&setTimeout(()=>{g=null,m(new AxiosError$1(`timeout ${c} of ms exceeded`,AxiosError$1.ETIMEDOUT))},c);const y=()=>{a&&(g&&clearTimeout(g),g=null,a.forEach(E=>{E.unsubscribe?E.unsubscribe(m):E.removeEventListener("abort",m)}),a=null)};a.forEach(E=>E.addEventListener("abort",m));const{signal:b}=d;return b.unsubscribe=()=>utils$2.asap(y),b}},streamChunk=function*(a,c){let u=a.byteLength;if(u<c){yield a;return}let d=0,f;for(;d<u;)f=d+c,yield a.slice(d,f),d=f},readBytes=async function*(a,c){for await(const u of readStream(a))yield*streamChunk(u,c)},readStream=async function*(a){if(a[Symbol.asyncIterator]){yield*a;return}const c=a.getReader();try{for(;;){const{done:u,value:d}=await c.read();if(u)break;yield d}}finally{await c.cancel()}},trackStream=(a,c,u,d)=>{const f=readBytes(a,c);let m=0,g,y=b=>{g||(g=!0,d&&d(b))};return new ReadableStream({async pull(b){try{const{done:E,value:C}=await f.next();if(E){y(),b.close();return}let w=C.byteLength;if(u){let R=m+=w;u(R)}b.enqueue(new Uint8Array(C))}catch(E){throw y(E),E}},cancel(b){return y(b),f.return()}},{highWaterMark:2})},isFetchSupported=typeof fetch=="function"&&typeof Request=="function"&&typeof Response=="function",isReadableStreamSupported=isFetchSupported&&typeof ReadableStream=="function",encodeText=isFetchSupported&&(typeof TextEncoder=="function"?(a=>c=>a.encode(c))(new TextEncoder):async a=>new Uint8Array(await new Response(a).arrayBuffer())),test=(a,...c)=>{try{return!!a(...c)}catch{return!1}},supportsRequestStream=isReadableStreamSupported&&test(()=>{let a=!1;const c=new Request(platform.origin,{body:new ReadableStream,method:"POST",get duplex(){return a=!0,"half"}}).headers.has("Content-Type");return a&&!c}),DEFAULT_CHUNK_SIZE=64*1024,supportsResponseStream=isReadableStreamSupported&&test(()=>utils$2.isReadableStream(new Response("").body)),resolvers={stream:supportsResponseStream&&(a=>a.body)};isFetchSupported&&(a=>{["text","arrayBuffer","blob","formData","stream"].forEach(c=>{!resolvers[c]&&(resolvers[c]=utils$2.isFunction(a[c])?u=>u[c]():(u,d)=>{throw new AxiosError$1(`Response type '${c}' is not supported`,AxiosError$1.ERR_NOT_SUPPORT,d)})})})(new Response);const getBodyLength=async a=>{if(a==null)return 0;if(utils$2.isBlob(a))return a.size;if(utils$2.isSpecCompliantForm(a))return(await new Request(platform.origin,{method:"POST",body:a}).arrayBuffer()).byteLength;if(utils$2.isArrayBufferView(a)||utils$2.isArrayBuffer(a))return a.byteLength;if(utils$2.isURLSearchParams(a)&&(a=a+""),utils$2.isString(a))return(await encodeText(a)).byteLength},resolveBodyLength=async(a,c)=>{const u=utils$2.toFiniteNumber(a.getContentLength());return u??getBodyLength(c)},fetchAdapter=isFetchSupported&&(async a=>{let{url:c,method:u,data:d,signal:f,cancelToken:m,timeout:g,onDownloadProgress:y,onUploadProgress:b,responseType:E,headers:C,withCredentials:w="same-origin",fetchOptions:R}=resolveConfig(a);E=E?(E+"").toLowerCase():"text";let _=composeSignals([f,m&&m.toAbortSignal()],g),M;const I=_&&_.unsubscribe&&(()=>{_.unsubscribe()});let N;try{if(b&&supportsRequestStream&&u!=="get"&&u!=="head"&&(N=await resolveBodyLength(C,d))!==0){let j=new Request(c,{method:"POST",body:d,duplex:"half"}),L;if(utils$2.isFormData(d)&&(L=j.headers.get("content-type"))&&C.setContentType(L),j.body){const[U,q]=progressEventDecorator(N,progressEventReducer(asyncDecorator(b)));d=trackStream(j.body,DEFAULT_CHUNK_SIZE,U,q)}}utils$2.isString(w)||(w=w?"include":"omit");const A="credentials"in Request.prototype;M=new Request(c,{...R,signal:_,method:u.toUpperCase(),headers:C.normalize().toJSON(),body:d,duplex:"half",credentials:A?w:void 0});let P=await fetch(M);const z=supportsResponseStream&&(E==="stream"||E==="response");if(supportsResponseStream&&(y||z&&I)){const j={};["status","statusText","headers"].forEach(F=>{j[F]=P[F]});const L=utils$2.toFiniteNumber(P.headers.get("content-length")),[U,q]=y&&progressEventDecorator(L,progressEventReducer(asyncDecorator(y),!0))||[];P=new Response(trackStream(P.body,DEFAULT_CHUNK_SIZE,U,()=>{q&&q(),I&&I()}),j)}E=E||"text";let B=await resolvers[utils$2.findKey(resolvers,E)||"text"](P,a);return!z&&I&&I(),await new Promise((j,L)=>{settle(j,L,{data:B,headers:AxiosHeaders$1.from(P.headers),status:P.status,statusText:P.statusText,config:a,request:M})})}catch(A){throw I&&I(),A&&A.name==="TypeError"&&/fetch/i.test(A.message)?Object.assign(new AxiosError$1("Network Error",AxiosError$1.ERR_NETWORK,a,M),{cause:A.cause||A}):AxiosError$1.from(A,A&&A.code,a,M)}}),knownAdapters={http:httpAdapter,xhr:xhrAdapter,fetch:fetchAdapter};utils$2.forEach(knownAdapters,(a,c)=>{if(a){try{Object.defineProperty(a,"name",{value:c})}catch{}Object.defineProperty(a,"adapterName",{value:c})}});const renderReason=a=>`- ${a}`,isResolvedHandle=a=>utils$2.isFunction(a)||a===null||a===!1,adapters={getAdapter:a=>{a=utils$2.isArray(a)?a:[a];const{length:c}=a;let u,d;const f={};for(let m=0;m<c;m++){u=a[m];let g;if(d=u,!isResolvedHandle(u)&&(d=knownAdapters[(g=String(u)).toLowerCase()],d===void 0))throw new AxiosError$1(`Unknown adapter '${g}'`);if(d)break;f[g||"#"+m]=d}if(!d){const m=Object.entries(f).map(([y,b])=>`adapter ${y} `+(b===!1?"is not supported by the environment":"is not available in the build"));let g=c?m.length>1?`since :
`+m.map(renderReason).join(`
`):" "+renderReason(m[0]):"as no adapter specified";throw new AxiosError$1("There is no suitable adapter to dispatch the request "+g,"ERR_NOT_SUPPORT")}return d},adapters:knownAdapters};function throwIfCancellationRequested(a){if(a.cancelToken&&a.cancelToken.throwIfRequested(),a.signal&&a.signal.aborted)throw new CanceledError$1(null,a)}function dispatchRequest(a){return throwIfCancellationRequested(a),a.headers=AxiosHeaders$1.from(a.headers),a.data=transformData.call(a,a.transformRequest),["post","put","patch"].indexOf(a.method)!==-1&&a.headers.setContentType("application/x-www-form-urlencoded",!1),adapters.getAdapter(a.adapter||defaults.adapter)(a).then(function(d){return throwIfCancellationRequested(a),d.data=transformData.call(a,a.transformResponse,d),d.headers=AxiosHeaders$1.from(d.headers),d},function(d){return isCancel$1(d)||(throwIfCancellationRequested(a),d&&d.response&&(d.response.data=transformData.call(a,a.transformResponse,d.response),d.response.headers=AxiosHeaders$1.from(d.response.headers))),Promise.reject(d)})}const VERSION$1="1.8.4",validators$1={};["object","boolean","number","function","string","symbol"].forEach((a,c)=>{validators$1[a]=function(d){return typeof d===a||"a"+(c<1?"n ":" ")+a}});const deprecatedWarnings={};validators$1.transitional=function(c,u,d){function f(m,g){return"[Axios v"+VERSION$1+"] Transitional option '"+m+"'"+g+(d?". "+d:"")}return(m,g,y)=>{if(c===!1)throw new AxiosError$1(f(g," has been removed"+(u?" in "+u:"")),AxiosError$1.ERR_DEPRECATED);return u&&!deprecatedWarnings[g]&&(deprecatedWarnings[g]=!0,console.warn(f(g," has been deprecated since v"+u+" and will be removed in the near future"))),c?c(m,g,y):!0}};validators$1.spelling=function(c){return(u,d)=>(console.warn(`${d} is likely a misspelling of ${c}`),!0)};function assertOptions(a,c,u){if(typeof a!="object")throw new AxiosError$1("options must be an object",AxiosError$1.ERR_BAD_OPTION_VALUE);const d=Object.keys(a);let f=d.length;for(;f-- >0;){const m=d[f],g=c[m];if(g){const y=a[m],b=y===void 0||g(y,m,a);if(b!==!0)throw new AxiosError$1("option "+m+" must be "+b,AxiosError$1.ERR_BAD_OPTION_VALUE);continue}if(u!==!0)throw new AxiosError$1("Unknown option "+m,AxiosError$1.ERR_BAD_OPTION)}}const validator={assertOptions,validators:validators$1},validators=validator.validators;let Axios$1=class{constructor(c){this.defaults=c,this.interceptors={request:new InterceptorManager,response:new InterceptorManager}}async request(c,u){try{return await this._request(c,u)}catch(d){if(d instanceof Error){let f={};Error.captureStackTrace?Error.captureStackTrace(f):f=new Error;const m=f.stack?f.stack.replace(/^.+\n/,""):"";try{d.stack?m&&!String(d.stack).endsWith(m.replace(/^.+\n.+\n/,""))&&(d.stack+=`
`+m):d.stack=m}catch{}}throw d}}_request(c,u){typeof c=="string"?(u=u||{},u.url=c):u=c||{},u=mergeConfig$1(this.defaults,u);const{transitional:d,paramsSerializer:f,headers:m}=u;d!==void 0&&validator.assertOptions(d,{silentJSONParsing:validators.transitional(validators.boolean),forcedJSONParsing:validators.transitional(validators.boolean),clarifyTimeoutError:validators.transitional(validators.boolean)},!1),f!=null&&(utils$2.isFunction(f)?u.paramsSerializer={serialize:f}:validator.assertOptions(f,{encode:validators.function,serialize:validators.function},!0)),u.allowAbsoluteUrls!==void 0||(this.defaults.allowAbsoluteUrls!==void 0?u.allowAbsoluteUrls=this.defaults.allowAbsoluteUrls:u.allowAbsoluteUrls=!0),validator.assertOptions(u,{baseUrl:validators.spelling("baseURL"),withXsrfToken:validators.spelling("withXSRFToken")},!0),u.method=(u.method||this.defaults.method||"get").toLowerCase();let g=m&&utils$2.merge(m.common,m[u.method]);m&&utils$2.forEach(["delete","get","head","post","put","patch","common"],M=>{delete m[M]}),u.headers=AxiosHeaders$1.concat(g,m);const y=[];let b=!0;this.interceptors.request.forEach(function(I){typeof I.runWhen=="function"&&I.runWhen(u)===!1||(b=b&&I.synchronous,y.unshift(I.fulfilled,I.rejected))});const E=[];this.interceptors.response.forEach(function(I){E.push(I.fulfilled,I.rejected)});let C,w=0,R;if(!b){const M=[dispatchRequest.bind(this),void 0];for(M.unshift.apply(M,y),M.push.apply(M,E),R=M.length,C=Promise.resolve(u);w<R;)C=C.then(M[w++],M[w++]);return C}R=y.length;let _=u;for(w=0;w<R;){const M=y[w++],I=y[w++];try{_=M(_)}catch(N){I.call(this,N);break}}try{C=dispatchRequest.call(this,_)}catch(M){return Promise.reject(M)}for(w=0,R=E.length;w<R;)C=C.then(E[w++],E[w++]);return C}getUri(c){c=mergeConfig$1(this.defaults,c);const u=buildFullPath(c.baseURL,c.url,c.allowAbsoluteUrls);return buildURL(u,c.params,c.paramsSerializer)}};utils$2.forEach(["delete","get","head","options"],function(c){Axios$1.prototype[c]=function(u,d){return this.request(mergeConfig$1(d||{},{method:c,url:u,data:(d||{}).data}))}});utils$2.forEach(["post","put","patch"],function(c){function u(d){return function(m,g,y){return this.request(mergeConfig$1(y||{},{method:c,headers:d?{"Content-Type":"multipart/form-data"}:{},url:m,data:g}))}}Axios$1.prototype[c]=u(),Axios$1.prototype[c+"Form"]=u(!0)});let CancelToken$1=class Rf{constructor(c){if(typeof c!="function")throw new TypeError("executor must be a function.");let u;this.promise=new Promise(function(m){u=m});const d=this;this.promise.then(f=>{if(!d._listeners)return;let m=d._listeners.length;for(;m-- >0;)d._listeners[m](f);d._listeners=null}),this.promise.then=f=>{let m;const g=new Promise(y=>{d.subscribe(y),m=y}).then(f);return g.cancel=function(){d.unsubscribe(m)},g},c(function(m,g,y){d.reason||(d.reason=new CanceledError$1(m,g,y),u(d.reason))})}throwIfRequested(){if(this.reason)throw this.reason}subscribe(c){if(this.reason){c(this.reason);return}this._listeners?this._listeners.push(c):this._listeners=[c]}unsubscribe(c){if(!this._listeners)return;const u=this._listeners.indexOf(c);u!==-1&&this._listeners.splice(u,1)}toAbortSignal(){const c=new AbortController,u=d=>{c.abort(d)};return this.subscribe(u),c.signal.unsubscribe=()=>this.unsubscribe(u),c.signal}static source(){let c;return{token:new Rf(function(f){c=f}),cancel:c}}};function spread$1(a){return function(u){return a.apply(null,u)}}function isAxiosError$1(a){return utils$2.isObject(a)&&a.isAxiosError===!0}const HttpStatusCode$1={Continue:100,SwitchingProtocols:101,Processing:102,EarlyHints:103,Ok:200,Created:201,Accepted:202,NonAuthoritativeInformation:203,NoContent:204,ResetContent:205,PartialContent:206,MultiStatus:207,AlreadyReported:208,ImUsed:226,MultipleChoices:300,MovedPermanently:301,Found:302,SeeOther:303,NotModified:304,UseProxy:305,Unused:306,TemporaryRedirect:307,PermanentRedirect:308,BadRequest:400,Unauthorized:401,PaymentRequired:402,Forbidden:403,NotFound:404,MethodNotAllowed:405,NotAcceptable:406,ProxyAuthenticationRequired:407,RequestTimeout:408,Conflict:409,Gone:410,LengthRequired:411,PreconditionFailed:412,PayloadTooLarge:413,UriTooLong:414,UnsupportedMediaType:415,RangeNotSatisfiable:416,ExpectationFailed:417,ImATeapot:418,MisdirectedRequest:421,UnprocessableEntity:422,Locked:423,FailedDependency:424,TooEarly:425,UpgradeRequired:426,PreconditionRequired:428,TooManyRequests:429,RequestHeaderFieldsTooLarge:431,UnavailableForLegalReasons:451,InternalServerError:500,NotImplemented:501,BadGateway:502,ServiceUnavailable:503,GatewayTimeout:504,HttpVersionNotSupported:505,VariantAlsoNegotiates:506,InsufficientStorage:507,LoopDetected:508,NotExtended:510,NetworkAuthenticationRequired:511};Object.entries(HttpStatusCode$1).forEach(([a,c])=>{HttpStatusCode$1[c]=a});function createInstance(a){const c=new Axios$1(a),u=bind(Axios$1.prototype.request,c);return utils$2.extend(u,Axios$1.prototype,c,{allOwnKeys:!0}),utils$2.extend(u,c,null,{allOwnKeys:!0}),u.create=function(f){return createInstance(mergeConfig$1(a,f))},u}const axios=createInstance(defaults);axios.Axios=Axios$1;axios.CanceledError=CanceledError$1;axios.CancelToken=CancelToken$1;axios.isCancel=isCancel$1;axios.VERSION=VERSION$1;axios.toFormData=toFormData$1;axios.AxiosError=AxiosError$1;axios.Cancel=axios.CanceledError;axios.all=function(c){return Promise.all(c)};axios.spread=spread$1;axios.isAxiosError=isAxiosError$1;axios.mergeConfig=mergeConfig$1;axios.AxiosHeaders=AxiosHeaders$1;axios.formToJSON=a=>formDataToJSON(utils$2.isHTMLForm(a)?new FormData(a):a);axios.getAdapter=adapters.getAdapter;axios.HttpStatusCode=HttpStatusCode$1;axios.default=axios;const{Axios,AxiosError,CanceledError,isCancel,CancelToken,VERSION,all:all$2,Cancel,isAxiosError,spread,toFormData,AxiosHeaders,HttpStatusCode,formToJSON,getAdapter,mergeConfig}=axios;function formatProdErrorMessage$1(a){return`Minified Redux error #${a}; visit https://redux.js.org/Errors?code=${a} for the full message or use the non-minified dev environment for full errors. `}var $$observable=typeof Symbol=="function"&&Symbol.observable||"@@observable",symbol_observable_default=$$observable,randomString=()=>Math.random().toString(36).substring(7).split("").join("."),ActionTypes={INIT:`@@redux/INIT${randomString()}`,REPLACE:`@@redux/REPLACE${randomString()}`,PROBE_UNKNOWN_ACTION:()=>`@@redux/PROBE_UNKNOWN_ACTION${randomString()}`},actionTypes_default=ActionTypes;function isPlainObject$2(a){if(typeof a!="object"||a===null)return!1;let c=a;for(;Object.getPrototypeOf(c)!==null;)c=Object.getPrototypeOf(c);return Object.getPrototypeOf(a)===c||Object.getPrototypeOf(a)===null}function createStore(a,c,u){if(typeof a!="function")throw new Error(formatProdErrorMessage$1(2));if(typeof c=="function"&&typeof u=="function"||typeof u=="function"&&typeof arguments[3]=="function")throw new Error(formatProdErrorMessage$1(0));if(typeof c=="function"&&typeof u>"u"&&(u=c,c=void 0),typeof u<"u"){if(typeof u!="function")throw new Error(formatProdErrorMessage$1(1));return u(createStore)(a,c)}let d=a,f=c,m=new Map,g=m,y=0,b=!1;function E(){g===m&&(g=new Map,m.forEach((N,A)=>{g.set(A,N)}))}function C(){if(b)throw new Error(formatProdErrorMessage$1(3));return f}function w(N){if(typeof N!="function")throw new Error(formatProdErrorMessage$1(4));if(b)throw new Error(formatProdErrorMessage$1(5));let A=!0;E();const P=y++;return g.set(P,N),function(){if(A){if(b)throw new Error(formatProdErrorMessage$1(6));A=!1,E(),g.delete(P),m=null}}}function R(N){if(!isPlainObject$2(N))throw new Error(formatProdErrorMessage$1(7));if(typeof N.type>"u")throw new Error(formatProdErrorMessage$1(8));if(typeof N.type!="string")throw new Error(formatProdErrorMessage$1(17));if(b)throw new Error(formatProdErrorMessage$1(9));try{b=!0,f=d(f,N)}finally{b=!1}return(m=g).forEach(P=>{P()}),N}function _(N){if(typeof N!="function")throw new Error(formatProdErrorMessage$1(10));d=N,R({type:actionTypes_default.REPLACE})}function M(){const N=w;return{subscribe(A){if(typeof A!="object"||A===null)throw new Error(formatProdErrorMessage$1(11));function P(){const B=A;B.next&&B.next(C())}return P(),{unsubscribe:N(P)}},[symbol_observable_default](){return this}}}return R({type:actionTypes_default.INIT}),{dispatch:R,subscribe:w,getState:C,replaceReducer:_,[symbol_observable_default]:M}}function assertReducerShape(a){Object.keys(a).forEach(c=>{const u=a[c];if(typeof u(void 0,{type:actionTypes_default.INIT})>"u")throw new Error(formatProdErrorMessage$1(12));if(typeof u(void 0,{type:actionTypes_default.PROBE_UNKNOWN_ACTION()})>"u")throw new Error(formatProdErrorMessage$1(13))})}function combineReducers(a){const c=Object.keys(a),u={};for(let m=0;m<c.length;m++){const g=c[m];typeof a[g]=="function"&&(u[g]=a[g])}const d=Object.keys(u);let f;try{assertReducerShape(u)}catch(m){f=m}return function(g={},y){if(f)throw f;let b=!1;const E={};for(let C=0;C<d.length;C++){const w=d[C],R=u[w],_=g[w],M=R(_,y);if(typeof M>"u")throw y&&y.type,new Error(formatProdErrorMessage$1(14));E[w]=M,b=b||M!==_}return b=b||d.length!==Object.keys(g).length,b?E:g}}function compose(...a){return a.length===0?c=>c:a.length===1?a[0]:a.reduce((c,u)=>(...d)=>c(u(...d)))}function applyMiddleware(...a){return c=>(u,d)=>{const f=c(u,d);let m=()=>{throw new Error(formatProdErrorMessage$1(15))};const g={getState:f.getState,dispatch:(b,...E)=>m(b,...E)},y=a.map(b=>b(g));return m=compose(...y)(f.dispatch),{...f,dispatch:m}}}function isAction(a){return isPlainObject$2(a)&&"type"in a&&typeof a.type=="string"}var NOTHING=Symbol.for("immer-nothing"),DRAFTABLE=Symbol.for("immer-draftable"),DRAFT_STATE=Symbol.for("immer-state");function die(a,...c){throw new Error(`[Immer] minified error nr: ${a}. Full error at: https://bit.ly/3cXEKWf`)}var getPrototypeOf=Object.getPrototypeOf;function isDraft(a){return!!a&&!!a[DRAFT_STATE]}function isDraftable(a){var c;return a?isPlainObject$1(a)||Array.isArray(a)||!!a[DRAFTABLE]||!!((c=a.constructor)!=null&&c[DRAFTABLE])||isMap(a)||isSet(a):!1}var objectCtorString=Object.prototype.constructor.toString();function isPlainObject$1(a){if(!a||typeof a!="object")return!1;const c=getPrototypeOf(a);if(c===null)return!0;const u=Object.hasOwnProperty.call(c,"constructor")&&c.constructor;return u===Object?!0:typeof u=="function"&&Function.toString.call(u)===objectCtorString}function each(a,c){getArchtype(a)===0?Reflect.ownKeys(a).forEach(u=>{c(u,a[u],a)}):a.forEach((u,d)=>c(d,u,a))}function getArchtype(a){const c=a[DRAFT_STATE];return c?c.type_:Array.isArray(a)?1:isMap(a)?2:isSet(a)?3:0}function has(a,c){return getArchtype(a)===2?a.has(c):Object.prototype.hasOwnProperty.call(a,c)}function set(a,c,u){const d=getArchtype(a);d===2?a.set(c,u):d===3?a.add(u):a[c]=u}function is(a,c){return a===c?a!==0||1/a===1/c:a!==a&&c!==c}function isMap(a){return a instanceof Map}function isSet(a){return a instanceof Set}function latest(a){return a.copy_||a.base_}function shallowCopy(a,c){if(isMap(a))return new Map(a);if(isSet(a))return new Set(a);if(Array.isArray(a))return Array.prototype.slice.call(a);const u=isPlainObject$1(a);if(c===!0||c==="class_only"&&!u){const d=Object.getOwnPropertyDescriptors(a);delete d[DRAFT_STATE];let f=Reflect.ownKeys(d);for(let m=0;m<f.length;m++){const g=f[m],y=d[g];y.writable===!1&&(y.writable=!0,y.configurable=!0),(y.get||y.set)&&(d[g]={configurable:!0,writable:!0,enumerable:y.enumerable,value:a[g]})}return Object.create(getPrototypeOf(a),d)}else{const d=getPrototypeOf(a);if(d!==null&&u)return{...a};const f=Object.create(d);return Object.assign(f,a)}}function freeze(a,c=!1){return isFrozen(a)||isDraft(a)||!isDraftable(a)||(getArchtype(a)>1&&(a.set=a.add=a.clear=a.delete=dontMutateFrozenCollections),Object.freeze(a),c&&Object.entries(a).forEach(([u,d])=>freeze(d,!0))),a}function dontMutateFrozenCollections(){die(2)}function isFrozen(a){return Object.isFrozen(a)}var plugins={};function getPlugin(a){const c=plugins[a];return c||die(0,a),c}var currentScope;function getCurrentScope(){return currentScope}function createScope(a,c){return{drafts_:[],parent_:a,immer_:c,canAutoFreeze_:!0,unfinalizedDrafts_:0}}function usePatchesInScope(a,c){c&&(getPlugin("Patches"),a.patches_=[],a.inversePatches_=[],a.patchListener_=c)}function revokeScope(a){leaveScope(a),a.drafts_.forEach(revokeDraft),a.drafts_=null}function leaveScope(a){a===currentScope&&(currentScope=a.parent_)}function enterScope(a){return currentScope=createScope(currentScope,a)}function revokeDraft(a){const c=a[DRAFT_STATE];c.type_===0||c.type_===1?c.revoke_():c.revoked_=!0}function processResult(a,c){c.unfinalizedDrafts_=c.drafts_.length;const u=c.drafts_[0];return a!==void 0&&a!==u?(u[DRAFT_STATE].modified_&&(revokeScope(c),die(4)),isDraftable(a)&&(a=finalize(c,a),c.parent_||maybeFreeze(c,a)),c.patches_&&getPlugin("Patches").generateReplacementPatches_(u[DRAFT_STATE].base_,a,c.patches_,c.inversePatches_)):a=finalize(c,u,[]),revokeScope(c),c.patches_&&c.patchListener_(c.patches_,c.inversePatches_),a!==NOTHING?a:void 0}function finalize(a,c,u){if(isFrozen(c))return c;const d=c[DRAFT_STATE];if(!d)return each(c,(f,m)=>finalizeProperty(a,d,c,f,m,u)),c;if(d.scope_!==a)return c;if(!d.modified_)return maybeFreeze(a,d.base_,!0),d.base_;if(!d.finalized_){d.finalized_=!0,d.scope_.unfinalizedDrafts_--;const f=d.copy_;let m=f,g=!1;d.type_===3&&(m=new Set(f),f.clear(),g=!0),each(m,(y,b)=>finalizeProperty(a,d,f,y,b,u,g)),maybeFreeze(a,f,!1),u&&a.patches_&&getPlugin("Patches").generatePatches_(d,u,a.patches_,a.inversePatches_)}return d.copy_}function finalizeProperty(a,c,u,d,f,m,g){if(isDraft(f)){const y=m&&c&&c.type_!==3&&!has(c.assigned_,d)?m.concat(d):void 0,b=finalize(a,f,y);if(set(u,d,b),isDraft(b))a.canAutoFreeze_=!1;else return}else g&&u.add(f);if(isDraftable(f)&&!isFrozen(f)){if(!a.immer_.autoFreeze_&&a.unfinalizedDrafts_<1)return;finalize(a,f),(!c||!c.scope_.parent_)&&typeof d!="symbol"&&Object.prototype.propertyIsEnumerable.call(u,d)&&maybeFreeze(a,f)}}function maybeFreeze(a,c,u=!1){!a.parent_&&a.immer_.autoFreeze_&&a.canAutoFreeze_&&freeze(c,u)}function createProxyProxy(a,c){const u=Array.isArray(a),d={type_:u?1:0,scope_:c?c.scope_:getCurrentScope(),modified_:!1,finalized_:!1,assigned_:{},parent_:c,base_:a,draft_:null,copy_:null,revoke_:null,isManual_:!1};let f=d,m=objectTraps;u&&(f=[d],m=arrayTraps);const{revoke:g,proxy:y}=Proxy.revocable(f,m);return d.draft_=y,d.revoke_=g,y}var objectTraps={get(a,c){if(c===DRAFT_STATE)return a;const u=latest(a);if(!has(u,c))return readPropFromProto(a,u,c);const d=u[c];return a.finalized_||!isDraftable(d)?d:d===peek(a.base_,c)?(prepareCopy(a),a.copy_[c]=createProxy(d,a)):d},has(a,c){return c in latest(a)},ownKeys(a){return Reflect.ownKeys(latest(a))},set(a,c,u){const d=getDescriptorFromProto(latest(a),c);if(d!=null&&d.set)return d.set.call(a.draft_,u),!0;if(!a.modified_){const f=peek(latest(a),c),m=f==null?void 0:f[DRAFT_STATE];if(m&&m.base_===u)return a.copy_[c]=u,a.assigned_[c]=!1,!0;if(is(u,f)&&(u!==void 0||has(a.base_,c)))return!0;prepareCopy(a),markChanged(a)}return a.copy_[c]===u&&(u!==void 0||c in a.copy_)||Number.isNaN(u)&&Number.isNaN(a.copy_[c])||(a.copy_[c]=u,a.assigned_[c]=!0),!0},deleteProperty(a,c){return peek(a.base_,c)!==void 0||c in a.base_?(a.assigned_[c]=!1,prepareCopy(a),markChanged(a)):delete a.assigned_[c],a.copy_&&delete a.copy_[c],!0},getOwnPropertyDescriptor(a,c){const u=latest(a),d=Reflect.getOwnPropertyDescriptor(u,c);return d&&{writable:!0,configurable:a.type_!==1||c!=="length",enumerable:d.enumerable,value:u[c]}},defineProperty(){die(11)},getPrototypeOf(a){return getPrototypeOf(a.base_)},setPrototypeOf(){die(12)}},arrayTraps={};each(objectTraps,(a,c)=>{arrayTraps[a]=function(){return arguments[0]=arguments[0][0],c.apply(this,arguments)}});arrayTraps.deleteProperty=function(a,c){return arrayTraps.set.call(this,a,c,void 0)};arrayTraps.set=function(a,c,u){return objectTraps.set.call(this,a[0],c,u,a[0])};function peek(a,c){const u=a[DRAFT_STATE];return(u?latest(u):a)[c]}function readPropFromProto(a,c,u){var f;const d=getDescriptorFromProto(c,u);return d?"value"in d?d.value:(f=d.get)==null?void 0:f.call(a.draft_):void 0}function getDescriptorFromProto(a,c){if(!(c in a))return;let u=getPrototypeOf(a);for(;u;){const d=Object.getOwnPropertyDescriptor(u,c);if(d)return d;u=getPrototypeOf(u)}}function markChanged(a){a.modified_||(a.modified_=!0,a.parent_&&markChanged(a.parent_))}function prepareCopy(a){a.copy_||(a.copy_=shallowCopy(a.base_,a.scope_.immer_.useStrictShallowCopy_))}var Immer2=class{constructor(a){this.autoFreeze_=!0,this.useStrictShallowCopy_=!1,this.produce=(c,u,d)=>{if(typeof c=="function"&&typeof u!="function"){const m=u;u=c;const g=this;return function(b=m,...E){return g.produce(b,C=>u.call(this,C,...E))}}typeof u!="function"&&die(6),d!==void 0&&typeof d!="function"&&die(7);let f;if(isDraftable(c)){const m=enterScope(this),g=createProxy(c,void 0);let y=!0;try{f=u(g),y=!1}finally{y?revokeScope(m):leaveScope(m)}return usePatchesInScope(m,d),processResult(f,m)}else if(!c||typeof c!="object"){if(f=u(c),f===void 0&&(f=c),f===NOTHING&&(f=void 0),this.autoFreeze_&&freeze(f,!0),d){const m=[],g=[];getPlugin("Patches").generateReplacementPatches_(c,f,m,g),d(m,g)}return f}else die(1,c)},this.produceWithPatches=(c,u)=>{if(typeof c=="function")return(g,...y)=>this.produceWithPatches(g,b=>c(b,...y));let d,f;return[this.produce(c,u,(g,y)=>{d=g,f=y}),d,f]},typeof(a==null?void 0:a.autoFreeze)=="boolean"&&this.setAutoFreeze(a.autoFreeze),typeof(a==null?void 0:a.useStrictShallowCopy)=="boolean"&&this.setUseStrictShallowCopy(a.useStrictShallowCopy)}createDraft(a){isDraftable(a)||die(8),isDraft(a)&&(a=current(a));const c=enterScope(this),u=createProxy(a,void 0);return u[DRAFT_STATE].isManual_=!0,leaveScope(c),u}finishDraft(a,c){const u=a&&a[DRAFT_STATE];(!u||!u.isManual_)&&die(9);const{scope_:d}=u;return usePatchesInScope(d,c),processResult(void 0,d)}setAutoFreeze(a){this.autoFreeze_=a}setUseStrictShallowCopy(a){this.useStrictShallowCopy_=a}applyPatches(a,c){let u;for(u=c.length-1;u>=0;u--){const f=c[u];if(f.path.length===0&&f.op==="replace"){a=f.value;break}}u>-1&&(c=c.slice(u+1));const d=getPlugin("Patches").applyPatches_;return isDraft(a)?d(a,c):this.produce(a,f=>d(f,c))}};function createProxy(a,c){const u=isMap(a)?getPlugin("MapSet").proxyMap_(a,c):isSet(a)?getPlugin("MapSet").proxySet_(a,c):createProxyProxy(a,c);return(c?c.scope_:getCurrentScope()).drafts_.push(u),u}function current(a){return isDraft(a)||die(10,a),currentImpl(a)}function currentImpl(a){if(!isDraftable(a)||isFrozen(a))return a;const c=a[DRAFT_STATE];let u;if(c){if(!c.modified_)return c.base_;c.finalized_=!0,u=shallowCopy(a,c.scope_.immer_.useStrictShallowCopy_)}else u=shallowCopy(a,!0);return each(u,(d,f)=>{set(u,d,currentImpl(f))}),c&&(c.finalized_=!1),u}var immer=new Immer2,produce=immer.produce;immer.produceWithPatches.bind(immer);immer.setAutoFreeze.bind(immer);immer.setUseStrictShallowCopy.bind(immer);immer.applyPatches.bind(immer);immer.createDraft.bind(immer);immer.finishDraft.bind(immer);function createThunkMiddleware(a){return({dispatch:u,getState:d})=>f=>m=>typeof m=="function"?m(u,d,a):f(m)}var thunk=createThunkMiddleware(),withExtraArgument=createThunkMiddleware,composeWithDevTools=typeof window<"u"&&window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__?window.__REDUX_DEVTOOLS_EXTENSION_COMPOSE__:function(){if(arguments.length!==0)return typeof arguments[0]=="object"?compose:compose.apply(null,arguments)};function createAction(a,c){function u(...d){if(c){let f=c(...d);if(!f)throw new Error(formatProdErrorMessage(0));return{type:a,payload:f.payload,..."meta"in f&&{meta:f.meta},..."error"in f&&{error:f.error}}}return{type:a,payload:d[0]}}return u.toString=()=>`${a}`,u.type=a,u.match=d=>isAction(d)&&d.type===a,u}var Tuple=class ti extends Array{constructor(...c){super(...c),Object.setPrototypeOf(this,ti.prototype)}static get[Symbol.species](){return ti}concat(...c){return super.concat.apply(this,c)}prepend(...c){return c.length===1&&Array.isArray(c[0])?new ti(...c[0].concat(this)):new ti(...c.concat(this))}};function freezeDraftable(a){return isDraftable(a)?produce(a,()=>{}):a}function getOrInsertComputed(a,c,u){return a.has(c)?a.get(c):a.set(c,u(c)).get(c)}function isBoolean(a){return typeof a=="boolean"}var buildGetDefaultMiddleware=()=>function(c){const{thunk:u=!0,immutableCheck:d=!0,serializableCheck:f=!0,actionCreatorCheck:m=!0}=c??{};let g=new Tuple;return u&&(isBoolean(u)?g.push(thunk):g.push(withExtraArgument(u.extraArgument))),g},SHOULD_AUTOBATCH="RTK_autoBatch",createQueueWithTimer=a=>c=>{setTimeout(c,a)},autoBatchEnhancer=(a={type:"raf"})=>c=>(...u)=>{const d=c(...u);let f=!0,m=!1,g=!1;const y=new Set,b=a.type==="tick"?queueMicrotask:a.type==="raf"?typeof window<"u"&&window.requestAnimationFrame?window.requestAnimationFrame:createQueueWithTimer(10):a.type==="callback"?a.queueNotification:createQueueWithTimer(a.timeout),E=()=>{g=!1,m&&(m=!1,y.forEach(C=>C()))};return Object.assign({},d,{subscribe(C){const w=()=>f&&C(),R=d.subscribe(w);return y.add(C),()=>{R(),y.delete(C)}},dispatch(C){var w;try{return f=!((w=C==null?void 0:C.meta)!=null&&w[SHOULD_AUTOBATCH]),m=!f,m&&(g||(g=!0,b(E))),d.dispatch(C)}finally{f=!0}}})},buildGetDefaultEnhancers=a=>function(u){const{autoBatch:d=!0}=u??{};let f=new Tuple(a);return d&&f.push(autoBatchEnhancer(typeof d=="object"?d:void 0)),f};function configureStore(a){const c=buildGetDefaultMiddleware(),{reducer:u=void 0,middleware:d,devTools:f=!0,preloadedState:m=void 0,enhancers:g=void 0}=a||{};let y;if(typeof u=="function")y=u;else if(isPlainObject$2(u))y=combineReducers(u);else throw new Error(formatProdErrorMessage(1));let b;typeof d=="function"?b=d(c):b=c();let E=compose;f&&(E=composeWithDevTools({trace:!1,...typeof f=="object"&&f}));const C=applyMiddleware(...b),w=buildGetDefaultEnhancers(C);let R=typeof g=="function"?g(w):w();const _=E(...R);return createStore(y,m,_)}function executeReducerBuilderCallback(a){const c={},u=[];let d;const f={addCase(m,g){const y=typeof m=="string"?m:m.type;if(!y)throw new Error(formatProdErrorMessage(28));if(y in c)throw new Error(formatProdErrorMessage(29));return c[y]=g,f},addMatcher(m,g){return u.push({matcher:m,reducer:g}),f},addDefaultCase(m){return d=m,f}};return a(f),[c,u,d]}function isStateFunction(a){return typeof a=="function"}function createReducer(a,c){let[u,d,f]=executeReducerBuilderCallback(c),m;if(isStateFunction(a))m=()=>freezeDraftable(a());else{const y=freezeDraftable(a);m=()=>y}function g(y=m(),b){let E=[u[b.type],...d.filter(({matcher:C})=>C(b)).map(({reducer:C})=>C)];return E.filter(C=>!!C).length===0&&(E=[f]),E.reduce((C,w)=>{if(w)if(isDraft(C)){const _=w(C,b);return _===void 0?C:_}else{if(isDraftable(C))return produce(C,R=>w(R,b));{const R=w(C,b);if(R===void 0){if(C===null)return C;throw Error("A case reducer on a non-draftable value must not return undefined")}return R}}return C},y)}return g.getInitialState=m,g}var asyncThunkSymbol=Symbol.for("rtk-slice-createasyncthunk");function getType(a,c){return`${a}/${c}`}function buildCreateSlice({creators:a}={}){var u;const c=(u=a==null?void 0:a.asyncThunk)==null?void 0:u[asyncThunkSymbol];return function(f){const{name:m,reducerPath:g=m}=f;if(!m)throw new Error(formatProdErrorMessage(11));const y=(typeof f.reducers=="function"?f.reducers(buildReducerCreators()):f.reducers)||{},b=Object.keys(y),E={sliceCaseReducersByName:{},sliceCaseReducersByType:{},actionCreators:{},sliceMatchers:[]},C={addCase(B,j){const L=typeof B=="string"?B:B.type;if(!L)throw new Error(formatProdErrorMessage(12));if(L in E.sliceCaseReducersByType)throw new Error(formatProdErrorMessage(13));return E.sliceCaseReducersByType[L]=j,C},addMatcher(B,j){return E.sliceMatchers.push({matcher:B,reducer:j}),C},exposeAction(B,j){return E.actionCreators[B]=j,C},exposeCaseReducer(B,j){return E.sliceCaseReducersByName[B]=j,C}};b.forEach(B=>{const j=y[B],L={reducerName:B,type:getType(m,B),createNotation:typeof f.reducers=="function"};isAsyncThunkSliceReducerDefinition(j)?handleThunkCaseReducerDefinition(L,j,C,c):handleNormalReducerDefinition(L,j,C)});function w(){const[B={},j=[],L=void 0]=typeof f.extraReducers=="function"?executeReducerBuilderCallback(f.extraReducers):[f.extraReducers],U={...B,...E.sliceCaseReducersByType};return createReducer(f.initialState,q=>{for(let F in U)q.addCase(F,U[F]);for(let F of E.sliceMatchers)q.addMatcher(F.matcher,F.reducer);for(let F of j)q.addMatcher(F.matcher,F.reducer);L&&q.addDefaultCase(L)})}const R=B=>B,_=new Map,M=new WeakMap;let I;function N(B,j){return I||(I=w()),I(B,j)}function A(){return I||(I=w()),I.getInitialState()}function P(B,j=!1){function L(q){let F=q[B];return typeof F>"u"&&j&&(F=getOrInsertComputed(M,L,A)),F}function U(q=R){const F=getOrInsertComputed(_,j,()=>new WeakMap);return getOrInsertComputed(F,q,()=>{const K={};for(const[X,Q]of Object.entries(f.selectors??{}))K[X]=wrapSelector(Q,q,()=>getOrInsertComputed(M,q,A),j);return K})}return{reducerPath:B,getSelectors:U,get selectors(){return U(L)},selectSlice:L}}const z={name:m,reducer:N,actions:E.actionCreators,caseReducers:E.sliceCaseReducersByName,getInitialState:A,...P(g),injectInto(B,{reducerPath:j,...L}={}){const U=j??g;return B.inject({reducerPath:U,reducer:N},L),{...z,...P(U,!0)}}};return z}}function wrapSelector(a,c,u,d){function f(m,...g){let y=c(m);return typeof y>"u"&&d&&(y=u()),a(y,...g)}return f.unwrapped=a,f}var createSlice=buildCreateSlice();function buildReducerCreators(){function a(c,u){return{_reducerDefinitionType:"asyncThunk",payloadCreator:c,...u}}return a.withTypes=()=>a,{reducer(c){return Object.assign({[c.name](...u){return c(...u)}}[c.name],{_reducerDefinitionType:"reducer"})},preparedReducer(c,u){return{_reducerDefinitionType:"reducerWithPrepare",prepare:c,reducer:u}},asyncThunk:a}}function handleNormalReducerDefinition({type:a,reducerName:c,createNotation:u},d,f){let m,g;if("reducer"in d){if(u&&!isCaseReducerWithPrepareDefinition(d))throw new Error(formatProdErrorMessage(17));m=d.reducer,g=d.prepare}else m=d;f.addCase(a,m).exposeCaseReducer(c,m).exposeAction(c,g?createAction(a,g):createAction(a))}function isAsyncThunkSliceReducerDefinition(a){return a._reducerDefinitionType==="asyncThunk"}function isCaseReducerWithPrepareDefinition(a){return a._reducerDefinitionType==="reducerWithPrepare"}function handleThunkCaseReducerDefinition({type:a,reducerName:c},u,d,f){if(!f)throw new Error(formatProdErrorMessage(18));const{payloadCreator:m,fulfilled:g,pending:y,rejected:b,settled:E,options:C}=u,w=f(a,m,C);d.exposeAction(c,w),g&&d.addCase(w.fulfilled,g),y&&d.addCase(w.pending,y),b&&d.addCase(w.rejected,b),E&&d.addMatcher(w.settled,E),d.exposeCaseReducer(c,{fulfilled:g||noop,pending:y||noop,rejected:b||noop,settled:E||noop})}function noop(){}function formatProdErrorMessage(a){return`Minified Redux Toolkit error #${a}; visit https://redux-toolkit.js.org/Errors?code=${a} for the full message or use the non-minified dev environment for full errors. `}const localCurrenct=localStorage.getItem("currenct_project"),projectSlice=createSlice({name:"project",initialState:{currenct:localCurrenct?JSON.parse(localCurrenct):{name:"default project",projectKey:"default"}},reducers:{setCurrenct:(a,c)=>{a.currenct=c.payload,localStorage.setItem("currenct_project",JSON.stringify(c.payload))}}}),{setCurrenct}=projectSlice.actions,projectReducer=projectSlice.reducer,{Content,Sider}=Layout;[RefIcon$2,RefIcon$g,RefIcon$c].map((a,c)=>{const u=String(c+1);return{key:`sub${u}`,icon:React.createElement(a),label:`subnav ${u}`,children:Array.from({length:4}).map((d,f)=>{const m=c*4+f+1;return{key:m,label:`option${m}`}})}});const Test=()=>jsxRuntimeExports.jsx(Skeleton,{active:!0}),App$1=()=>{const a=useNavigate(),c=useLocation(),[u,d]=reactExports.useState([]),[f,m]=reactExports.useState([]),g=useDispatch(),{projectKey:y}=useSelector(_=>_.project.currenct);console.log(y);const b=_=>{console.log(_),a(_)},E=async()=>{const _=await axios.get("/list-project");m(_.data.map(M=>({label:`${M.project}`,value:M.project})))};reactExports.useEffect(()=>{E()},[]);const{token:{colorBgContainer:C,borderRadiusLG:w}}=theme.useToken(),R=[{key:"/",label:"项目介绍"},{key:"/sample",label:"检测样本"},{key:"/pipeline-card",label:"流程管道"},{key:"/analysis-result",label:"分析结果"},{key:"/literature",label:"文献资料"}];return jsxRuntimeExports.jsxs(Layout,{children:[jsxRuntimeExports.jsxs(Header$2,{style:{display:"flex",alignItems:"center",justifyContent:"space-between"},children:[jsxRuntimeExports.jsxs("div",{style:{display:"flex",alignItems:"center",flex:1,minWidth:0},children:[jsxRuntimeExports.jsx("div",{style:{color:"#fff",marginRight:"1rem",whiteSpace:"nowrap"},children:"BRAVE"}),jsxRuntimeExports.jsx(Menu,{theme:"dark",mode:"horizontal",defaultSelectedKeys:["1"],items:R,onSelect:_=>b(_.key),style:{flex:1,minWidth:0}})]}),jsxRuntimeExports.jsx("div",{style:{marginLeft:"auto",minWidth:100},children:jsxRuntimeExports.jsx(Select,{onChange:_=>{console.log(_),g(setCurrenct({name:_,projectKey:_}))},value:y,style:{width:100},placeholder:"选择项目",options:f})})]}),jsxRuntimeExports.jsx(Layout,{style:{padding:"24px 0",background:C,borderRadius:w},children:jsxRuntimeExports.jsx(Content,{style:{padding:"0 24px",minHeight:"100vh"},children:jsxRuntimeExports.jsx(reactExports.Suspense,{fallback:jsxRuntimeExports.jsx(Test,{}),children:jsxRuntimeExports.jsx(Outlet,{context:{project:y}})},c.key)})})]})},readJsonAPi=a=>axios.get(`/fast-api/read-json?path=${a}`),ResultList$1=reactExports.forwardRef(({title:a,form:c,appendSampleColumns:u=[],setResultTableList:d,cleanDom:f,analysisType:m,setRecord:g,setTableLoading:y,setTabletData:b,shouldTrigger:E,analysisMethod:C,columnsParamsALL:w,activeTabKey:R,setActiveTabKey:_,cardExtra:M,params:I},N)=>{reactExports.useImperativeHandle(N,()=>({reload:q}));const{project:A}=useOutletContext(),[P,z]=reactExports.useState([]),[B,j]=reactExports.useState(),[L,U]=reactExports.useState(!1),q=()=>{if(console.log(C),C&&Array.isArray(C)){const J=C.flatMap(W=>W.inputKey);X({analysisMethodValues:J})}else X({params:I})};reactExports.useEffect(()=>{_&&_(C[0].name),q()},[JSON.stringify(I)]);const F=J=>{z(B[J]),_(J)},K=()=>{const J=Object.fromEntries(C.map(G=>[G.name,G.inputKey])),W={};return Object.entries(J).forEach(([G,te])=>{te.forEach(ae=>{W[ae]=G})}),W},X=async({analysisMethodValues:J,params:W})=>{U(!0);let G=await axios.post("/fast-api/find-analyais-result-by-analysis-method",{project:A,analysis_method:J,...W});if(J){const te=K(),ae=G.data.reduce((V,ne)=>{const le=te[ne.analysis_method];V[le]||(V[le]=[]);const{sample_key:ee,id:ie,sample_group:ce,...ue}=ne;return V[le].push({label:ee,value:ie,sample_group:ce||"no_group",sample_key:ee,id:ie,...ue}),V},{});d&&d(ae),j(ae),z(R?ae[R]?ae[R]:[]:ae[C[0].name]?ae[C[0].name]:[])}else z(G.data);U(!1)},Q=async J=>{await axios.delete(`/analyais-result/delete-by-id/${J}`),staticMethods.success("删除成功!"),q()},Y=async J=>{y(!0);const W=await readJsonAPi(J);b(W.data),y(!1)};let Z=[];return m=="sample"?Z=[{title:"id",dataIndex:"id",key:"id",ellipsis:!0},{title:"分析名称",dataIndex:"analysis_name",key:"analysis_name",ellipsis:!0},{title:"分析id",dataIndex:"analysis_id",key:"analysis_id",ellipsis:!0},{title:"样本名称",dataIndex:"sample_name",key:"sample_name",ellipsis:!0},{title:"样本Key",dataIndex:"sample_key",key:"sample_key",ellipsis:!0},{title:"分析Key",dataIndex:"analysis_key",key:"analysis_key",ellipsis:!0},{title:"样本分组",dataIndex:"sample_group",key:"sample_group",ellipsis:!0},{title:"样本来源",dataIndex:"sample_source",key:"sample_source",ellipsis:!0},{title:"疾病",dataIndex:"host_disease",key:"host_disease",ellipsis:!0},{title:"样本分组名称",dataIndex:"sample_group_name",key:"sample_group_name",ellipsis:!0},{title:"软件",dataIndex:"software",key:"software",ellipsis:!0},{title:"project",dataIndex:"project",key:"project",ellipsis:!0},...u,{title:"操作",key:"action",fixed:"right",ellipsis:!0,width:200,render:(J,W)=>jsxRuntimeExports.jsx(Space,{size:"middle",children:jsxRuntimeExports.jsx(Popover,{content:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:W.analysis_name}),children:jsxRuntimeExports.jsx("a",{onClick:()=>{g(W),f&&f(void 0)},children:"查看"})})})}]:Z=[{title:"分析名称",dataIndex:"analysis_name",key:"analysis_name",ellipsis:!0},{title:"id",dataIndex:"id",key:"id",ellipsis:!0},{title:"分析方法",dataIndex:"analysis_method",key:"analysis_method",ellipsis:!0},{title:"输入软件",dataIndex:"software",key:"software",ellipsis:!0},{title:"project",dataIndex:"project",key:"project",ellipsis:!0},{title:"analysis_type",dataIndex:"analysis_type",key:"analysis_type",ellipsis:!0},{title:"创建时间",dataIndex:"create_date",key:"create_date",ellipsis:!0},{title:"操作",key:"action",fixed:"right",ellipsis:!0,width:200,render:(J,W)=>jsxRuntimeExports.jsxs(Space,{size:"middle",children:[jsxRuntimeExports.jsx(Popover,{content:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:W.content}),children:jsxRuntimeExports.jsx("a",{onClick:()=>{const G=JSON.parse(W.request_param);c&&(c.resetFields(),c.setFieldsValue(G),W!=null&&W.id&&c.setFieldValue("id",W==null?void 0:W.id)),Y(W.content),g&&g(W)},children:"查看"})}),jsxRuntimeExports.jsx(Popconfirm,{title:"确定删除吗?",onConfirm:async()=>{await Q(W.id)},children:jsxRuntimeExports.jsx("a",{children:"删除"})})]})}],jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Card,{title:a,extra:jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[M,jsxRuntimeExports.jsx(Button$1,{onClick:q,children:"刷新"})]}),tabList:C&&Array.isArray(C)&&C.length>1?C.map(J=>({key:J.name,label:J.label})):void 0,activeTabKey:R,onTabChange:F,children:jsxRuntimeExports.jsx(ForwardTable,{rowKey:J=>J.id,size:"small",pagination:{pageSize:10},loading:L,scroll:{x:"max-content",y:55*5},columns:w||Z,footer:()=>`一共${P&&Array.isArray(P)&&P.length}条记录`,dataSource:P})})})}),FormJsonComp=reactExports.memo(({formJson:a,dataMap:c})=>{const u={GroupSelect:{Component:BaseSelect,dataKey:"sample_group_list"},GroupCompareSelect:{Component:GroupCompareSelect},BaseSelect:{Component:BaseSelect},BaseInputNumber:{Component:BaseInputNumber},BaseInput:{Component:BaseInput},RankSelect:{Component:BaseSelect,dataKey:"rank",mode:void 0,initialValue:"SPECIES"},GroupFieldSelect:{Component:BaseSelect,dataKey:"group_field",mode:void 0,initialValue:"sample_group"},FilterFieldSelect:{Component:FilterSelect,dataKey:"sample_group_list",mode:void 0},GroupSelectSampleButton:{Component:GroupSelectSampleButton,dataKey:"sample_group_list"},MetaphlanCladeSelect:{Component:MetaphlanCladeSelect},SelectAll:{Component:SelectAll,dataKey:"sample_group_list"}},d=({type:f,dataMap:m,inputAnalysisMethod:g,dataKey:y,data:b,name:E,inputKey:C,...w})=>{const R=u[f],{first_data_key:_,...M}=m;if(!R)return jsxRuntimeExports.jsxs("div",{children:["未知类型 ",f]});const{Component:I,...N}=R;let A=[];return b?A=b:g?A=M[g]:y?y in M&&(A=M[y]):C?A=M[E]:_ in M&&(A=M[_]),jsxRuntimeExports.jsx(I,{...w,...N,data:A,name:E})};return jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:a.map((f,m)=>jsxRuntimeExports.jsx(d,{...f,dataMap:c},m))})},(a,c)=>(console.log(JSON.stringify(a)===JSON.stringify(c)),JSON.stringify(a)===JSON.stringify(c))),FilterSelect=({label:a,name:c,data:u,rules:d,field:f,...m})=>{const[g,y]=reactExports.useState(),b=Form$1.useFormInstance();return reactExports.useEffect(()=>{if(u&&f){const E=[...new Set(u.map(f))],C=E.map(w=>({label:w,value:w}));y(C),b.setFieldValue(c,E[0])}},[u]),jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{label:a,name:c,rules:d,children:jsxRuntimeExports.jsx(BasicSelect,{...m,options:g})})})},BasicSelect=({options:a,clear:c,value:u,onChange:d,...f})=>{const m=Form$1.useFormInstance(),g=y=>{d(y),c&&m.resetFields(c)};return jsxRuntimeExports.jsx(Select,{showSearch:!0,filterOption:(y,b)=>((b==null?void 0:b.label)??"").toLowerCase().includes(y.toLowerCase()),...f,options:a,value:u,onChange:g})},MetaphlanCladeSelect=({label:a,name:c,data:u,initialValue:d,rules:f,...m})=>{const[g,y]=reactExports.useState(),b=async()=>{let C=(await axios.get("/fast-api/get_metaphlan_clade")).data.map(w=>({label:`${w.taxon.replaceAll(" ","_")}_${w.clade}`,value:w.clade}));y(C)};return reactExports.useEffect(()=>{b()},[]),jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{initialValue:d,label:a,name:c,rules:f,children:jsxRuntimeExports.jsx(Select,{...m,options:g,showSearch:!0,filterOption:(E,C)=>((C==null?void 0:C.label)??"").toLowerCase().includes(E.toLowerCase())})})})},GroupCompareSelect=({label:a,name:c,data:u,initialValue:d,rules:f,...m})=>{const g=Form$1.useFormInstance(),y=Form$1.useWatch(["sites1","group"],g),b=Form$1.useWatch(["sites2","group"],g),[E,C]=reactExports.useState();return reactExports.useEffect(()=>{y&&b&&C([{label:"Prevalent in both sites",value:"Prevalent in both sites"},{label:`Prevalent in ${b.join("-")}`,value:`Prevalent in ${b.join("-")}`},{label:`Prevalent in ${y.join("-")}`,value:`Prevalent in ${y.join("-")}`},{label:"Not prevalent in either sites",value:"Not prevalent in either sites"}])},[y,b]),jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{initialValue:d,label:a,name:c,rules:f,children:jsxRuntimeExports.jsx(Select,{showSearch:!0,filterOption:(w,R)=>((R==null?void 0:R.label)??"").toLowerCase().includes(w.toLowerCase()),...m,options:E})})})},BaseInput=({label:a,name:c,data:u,initialValue:d,rules:f,...m})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{initialValue:d,label:a,name:c,rules:f,children:jsxRuntimeExports.jsx(TextArea,{...m})})}),BaseInputNumber=({label:a,name:c,data:u,initialValue:d,rules:f,...m})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{initialValue:d,label:a,name:c,rules:f,children:jsxRuntimeExports.jsx(TypedInputNumber,{...m})})}),BaseSelect=({label:a,name:c,data:u,initialValue:d,rules:f,...m})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{initialValue:d,label:a,name:c,rules:f,children:jsxRuntimeExports.jsx(BasicSelect,{...m,options:u})})}),GroupSelectSampleButton=({label:a,name:c,rules:u,data:d,filter:f,group:m,groupField:g})=>{const[y,b]=reactExports.useState(),[E,C]=reactExports.useState([]),w=Form$1.useFormInstance();let R=[];f&&(R=f.map(N=>N.name));const _=Form$1.useWatch(N=>{const A=Object.entries(N).filter(([P])=>R.includes(P));return Object.fromEntries(A)},w),M=Form$1.useWatch(m,w),I=(N,A)=>{const P=N.reduce((z,B)=>{const j=B[A];return z[j]||(z[j]=[]),z[j].push(B.value),z},{});b(P)};return reactExports.useEffect(()=>{f&&_&&(d=f.reduce((N,A)=>N.filter(P=>A.method(P)===_[A.name]),d),d=d.map(N=>{const{label:A,id:P,value:z,...B}=N;return{label:`${N.label}(${f[0].method(N)})`,value:N.value,...B}})),d&&g?I(d,g):d&&M&&I(d,M),C(d)},[d,M,_]),jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx(Form$1.Item,{label:a,name:[c,"sample"],rules:u,children:jsxRuntimeExports.jsx(GroupSelectSample,{sampleGrouped:y,sampleGroup:E,watch:[c,"group"]})}),jsxRuntimeExports.jsx(Form$1.Item,{label:a,name:[c,"group"],rules:u,children:jsxRuntimeExports.jsx(GroupSelectButton,{sampleGrouped:y})})]})},SelectAll=({label:a,name:c,data:u,initialValue:d,rules:f,...m})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{initialValue:d,label:a,name:c,rules:f,children:jsxRuntimeExports.jsx(SelectAllComp,{data:u,...m})})}),SelectAllComp=({data:a,value:c,onChange:u,mode:d,...f})=>{const[m,g]=reactExports.useState(c),y=b=>{console.log(b),u(b),g(b)};return jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx(Select,{...f,mode:d,value:m,onChange:y,allowClear:!0,options:a}),d=="multiple"&&jsxRuntimeExports.jsxs(Button$1,{onClick:()=>{const b=a.map(E=>E.value);g(b),u(b)},children:["选择全部",m&&jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:["(",m.length,")"]})]})]})},GroupSelectSample=({value:a,onChange:c,sampleGroup:u,watch:d,sampleGrouped:f})=>{const[m,g]=reactExports.useState(),y=Form$1.useFormInstance(),b=Form$1.useWatch(d,y);reactExports.useEffect(()=>{g(b)},[b]);const E=C=>{const w=Object.entries(f||{}).filter(([R])=>C.includes(R)).flatMap(([,R])=>R);c(w)};return reactExports.useEffect(()=>{m&&E(m)},[m]),jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx(Select,{showSearch:!0,filterOption:(C,w)=>((w==null?void 0:w.label)??"").toLowerCase().includes(C.toLowerCase()),mode:"multiple",value:a,onChange:c,options:u}),a&&jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:["一共选择",a.length,"个样本"]})]})},GroupSelectButton=({value:a,onChange:c,sampleGrouped:u})=>{const d=f=>{if((a||[]).includes(f)){const m=(a||[]).filter(g=>!g.includes(f));c(m)}else{const m=[...a||[],f];c(m)}};return jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:Object.entries(u||{}).map(([f,m])=>jsxRuntimeExports.jsx("span",{children:jsxRuntimeExports.jsxs(Button$1,{type:(a||[]).includes(f)?"primary":"dashed",onClick:()=>d(f),children:[f,"(",m.length,")"]})},f))})},parseAnalysisResultAPi=a=>axios.post(`/fast-api/parse-analysis-result/${a}`),ResultList=reactExports.forwardRef(({title:a,form:c,appendSampleColumns:u=[],setResultTableList:d,cleanDom:f,analysisType:m,setRecord:g,setTableLoading:y,setTabletData:b,shouldTrigger:E,analysisMethod:C,columnsParamsALL:w,project:R},_)=>{reactExports.useImperativeHandle(_,()=>({reload:B}));const[M,I]=staticMethods.useMessage(),[N,A]=reactExports.useState([]),[P,z]=reactExports.useState(!1),B=async()=>{z(!0);let U=await axios.get(`/fast-api/analysis?analysis_method=${C}&project=${R}`);d&&d(U.data),A(U.data),z(!1)},j=async U=>{await axios.delete(`/fast-api/analysis/${U}`),staticMethods.success("删除成功!"),B()};let L=[{title:"id",dataIndex:"id",key:"id",ellipsis:!0},{title:"project",dataIndex:"project",key:"project",ellipsis:!0},{title:"analysis_method",dataIndex:"analysis_method",key:"analysis_method",ellipsis:!0},{title:"analysis_name",dataIndex:"analysis_name",key:"analysis_name",ellipsis:!0},{title:"params_path",dataIndex:"params_path",key:"params_path",ellipsis:!0},{title:"pipeline_script",dataIndex:"pipeline_script",key:"pipeline_script",ellipsis:!0},{title:"work_dir",dataIndex:"work_dir",key:"work_dir",ellipsis:!0},{title:"output_dir",dataIndex:"output_dir",key:"output_dir",ellipsis:!0},{title:"操作",key:"action",fixed:"right",ellipsis:!0,width:200,render:(U,q)=>jsxRuntimeExports.jsxs(Space,{size:"middle",children:[jsxRuntimeExports.jsx(Popover,{content:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:q.analysis_name}),children:jsxRuntimeExports.jsx("a",{onClick:()=>{g(q)},children:"查看"})}),jsxRuntimeExports.jsx(Popconfirm,{title:"是否删除!",onConfirm:async()=>{await j(q.id)},children:jsxRuntimeExports.jsx("a",{children:"删除"})}),jsxRuntimeExports.jsx(Popconfirm,{title:"是否解析!",onConfirm:async()=>{var F,K;try{await parseAnalysisResultAPi(q.id),M.success("提交成功")}catch(X){console.log(X),M.error((K=(F=X==null?void 0:X.response)==null?void 0:F.data)==null?void 0:K.detail)}},children:jsxRuntimeExports.jsx("a",{children:"解析"})})]})}];return reactExports.useEffect(()=>{B()},[]),jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[I,jsxRuntimeExports.jsx(Card,{title:a,extra:jsxRuntimeExports.jsx(Button$1,{onClick:B,children:"刷新"}),children:jsxRuntimeExports.jsx(ForwardTable,{size:"small",pagination:!1,loading:P,scroll:{x:"max-content",y:55*5},columns:L,footer:()=>`一共${N.length}条记录`,dataSource:N})})]})});function ok$1(){}function unreachable(){}function parse$2(a){const c=[],u=String(a||"");let d=u.indexOf(","),f=0,m=!1;for(;!m;){d===-1&&(d=u.length,m=!0);const g=u.slice(f,d).trim();(g||!m)&&c.push(g),f=d+1,d=u.indexOf(",",f)}return c}function stringify$1(a,c){const u={};return(a[a.length-1]===""?[...a,""]:a).join((u.padRight?" ":"")+","+(u.padLeft===!1?"":" ")).trim()}const nameRe=/^[$_\p{ID_Start}][$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,nameReJsx=/^[$_\p{ID_Start}][-$_\u{200C}\u{200D}\p{ID_Continue}]*$/u,emptyOptions$5={};function name(a,c){return(emptyOptions$5.jsx?nameReJsx:nameRe).test(a)}const re=/[ \t\n\f\r]/g;function whitespace(a){return typeof a=="object"?a.type==="text"?empty$1(a.value):!1:empty$1(a)}function empty$1(a){return a.replace(re,"")===""}class Schema{constructor(c,u,d){this.normal=u,this.property=c,d&&(this.space=d)}}Schema.prototype.normal={};Schema.prototype.property={};Schema.prototype.space=void 0;function merge(a,c){const u={},d={};for(const f of a)Object.assign(u,f.property),Object.assign(d,f.normal);return new Schema(u,d,c)}function normalize$1(a){return a.toLowerCase()}class Info{constructor(c,u){this.attribute=u,this.property=c}}Info.prototype.attribute="";Info.prototype.booleanish=!1;Info.prototype.boolean=!1;Info.prototype.commaOrSpaceSeparated=!1;Info.prototype.commaSeparated=!1;Info.prototype.defined=!1;Info.prototype.mustUseProperty=!1;Info.prototype.number=!1;Info.prototype.overloadedBoolean=!1;Info.prototype.property="";Info.prototype.spaceSeparated=!1;Info.prototype.space=void 0;let powers=0;const boolean=increment(),booleanish=increment(),overloadedBoolean=increment(),number=increment(),spaceSeparated=increment(),commaSeparated=increment(),commaOrSpaceSeparated=increment();function increment(){return 2**++powers}const types=Object.freeze(Object.defineProperty({__proto__:null,boolean,booleanish,commaOrSpaceSeparated,commaSeparated,number,overloadedBoolean,spaceSeparated},Symbol.toStringTag,{value:"Module"})),checks=Object.keys(types);class DefinedInfo extends Info{constructor(c,u,d,f){let m=-1;if(super(c,u),mark(this,"space",f),typeof d=="number")for(;++m<checks.length;){const g=checks[m];mark(this,checks[m],(d&types[g])===types[g])}}}DefinedInfo.prototype.defined=!0;function mark(a,c,u){u&&(a[c]=u)}function create(a){const c={},u={};for(const[d,f]of Object.entries(a.properties)){const m=new DefinedInfo(d,a.transform(a.attributes||{},d),f,a.space);a.mustUseProperty&&a.mustUseProperty.includes(d)&&(m.mustUseProperty=!0),c[d]=m,u[normalize$1(d)]=d,u[normalize$1(m.attribute)]=d}return new Schema(c,u,a.space)}const aria=create({properties:{ariaActiveDescendant:null,ariaAtomic:booleanish,ariaAutoComplete:null,ariaBusy:booleanish,ariaChecked:booleanish,ariaColCount:number,ariaColIndex:number,ariaColSpan:number,ariaControls:spaceSeparated,ariaCurrent:null,ariaDescribedBy:spaceSeparated,ariaDetails:null,ariaDisabled:booleanish,ariaDropEffect:spaceSeparated,ariaErrorMessage:null,ariaExpanded:booleanish,ariaFlowTo:spaceSeparated,ariaGrabbed:booleanish,ariaHasPopup:null,ariaHidden:booleanish,ariaInvalid:null,ariaKeyShortcuts:null,ariaLabel:null,ariaLabelledBy:spaceSeparated,ariaLevel:number,ariaLive:null,ariaModal:booleanish,ariaMultiLine:booleanish,ariaMultiSelectable:booleanish,ariaOrientation:null,ariaOwns:spaceSeparated,ariaPlaceholder:null,ariaPosInSet:number,ariaPressed:booleanish,ariaReadOnly:booleanish,ariaRelevant:null,ariaRequired:booleanish,ariaRoleDescription:spaceSeparated,ariaRowCount:number,ariaRowIndex:number,ariaRowSpan:number,ariaSelected:booleanish,ariaSetSize:number,ariaSort:null,ariaValueMax:number,ariaValueMin:number,ariaValueNow:number,ariaValueText:null,role:null},transform(a,c){return c==="role"?c:"aria-"+c.slice(4).toLowerCase()}});function caseSensitiveTransform(a,c){return c in a?a[c]:c}function caseInsensitiveTransform(a,c){return caseSensitiveTransform(a,c.toLowerCase())}const html$3=create({attributes:{acceptcharset:"accept-charset",classname:"class",htmlfor:"for",httpequiv:"http-equiv"},mustUseProperty:["checked","multiple","muted","selected"],properties:{abbr:null,accept:commaSeparated,acceptCharset:spaceSeparated,accessKey:spaceSeparated,action:null,allow:null,allowFullScreen:boolean,allowPaymentRequest:boolean,allowUserMedia:boolean,alt:null,as:null,async:boolean,autoCapitalize:null,autoComplete:spaceSeparated,autoFocus:boolean,autoPlay:boolean,blocking:spaceSeparated,capture:null,charSet:null,checked:boolean,cite:null,className:spaceSeparated,cols:number,colSpan:null,content:null,contentEditable:booleanish,controls:boolean,controlsList:spaceSeparated,coords:number|commaSeparated,crossOrigin:null,data:null,dateTime:null,decoding:null,default:boolean,defer:boolean,dir:null,dirName:null,disabled:boolean,download:overloadedBoolean,draggable:booleanish,encType:null,enterKeyHint:null,fetchPriority:null,form:null,formAction:null,formEncType:null,formMethod:null,formNoValidate:boolean,formTarget:null,headers:spaceSeparated,height:number,hidden:overloadedBoolean,high:number,href:null,hrefLang:null,htmlFor:spaceSeparated,httpEquiv:spaceSeparated,id:null,imageSizes:null,imageSrcSet:null,inert:boolean,inputMode:null,integrity:null,is:null,isMap:boolean,itemId:null,itemProp:spaceSeparated,itemRef:spaceSeparated,itemScope:boolean,itemType:spaceSeparated,kind:null,label:null,lang:null,language:null,list:null,loading:null,loop:boolean,low:number,manifest:null,max:null,maxLength:number,media:null,method:null,min:null,minLength:number,multiple:boolean,muted:boolean,name:null,nonce:null,noModule:boolean,noValidate:boolean,onAbort:null,onAfterPrint:null,onAuxClick:null,onBeforeMatch:null,onBeforePrint:null,onBeforeToggle:null,onBeforeUnload:null,onBlur:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onContextLost:null,onContextMenu:null,onContextRestored:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnded:null,onError:null,onFocus:null,onFormData:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLanguageChange:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadEnd:null,onLoadStart:null,onMessage:null,onMessageError:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRejectionHandled:null,onReset:null,onResize:null,onScroll:null,onScrollEnd:null,onSecurityPolicyViolation:null,onSeeked:null,onSeeking:null,onSelect:null,onSlotChange:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnhandledRejection:null,onUnload:null,onVolumeChange:null,onWaiting:null,onWheel:null,open:boolean,optimum:number,pattern:null,ping:spaceSeparated,placeholder:null,playsInline:boolean,popover:null,popoverTarget:null,popoverTargetAction:null,poster:null,preload:null,readOnly:boolean,referrerPolicy:null,rel:spaceSeparated,required:boolean,reversed:boolean,rows:number,rowSpan:number,sandbox:spaceSeparated,scope:null,scoped:boolean,seamless:boolean,selected:boolean,shadowRootClonable:boolean,shadowRootDelegatesFocus:boolean,shadowRootMode:null,shape:null,size:number,sizes:null,slot:null,span:number,spellCheck:booleanish,src:null,srcDoc:null,srcLang:null,srcSet:null,start:number,step:null,style:null,tabIndex:number,target:null,title:null,translate:null,type:null,typeMustMatch:boolean,useMap:null,value:booleanish,width:number,wrap:null,writingSuggestions:null,align:null,aLink:null,archive:spaceSeparated,axis:null,background:null,bgColor:null,border:number,borderColor:null,bottomMargin:number,cellPadding:null,cellSpacing:null,char:null,charOff:null,classId:null,clear:null,code:null,codeBase:null,codeType:null,color:null,compact:boolean,declare:boolean,event:null,face:null,frame:null,frameBorder:null,hSpace:number,leftMargin:number,link:null,longDesc:null,lowSrc:null,marginHeight:number,marginWidth:number,noResize:boolean,noHref:boolean,noShade:boolean,noWrap:boolean,object:null,profile:null,prompt:null,rev:null,rightMargin:number,rules:null,scheme:null,scrolling:booleanish,standby:null,summary:null,text:null,topMargin:number,valueType:null,version:null,vAlign:null,vLink:null,vSpace:number,allowTransparency:null,autoCorrect:null,autoSave:null,disablePictureInPicture:boolean,disableRemotePlayback:boolean,prefix:null,property:null,results:number,security:null,unselectable:null},space:"html",transform:caseInsensitiveTransform}),svg$1=create({attributes:{accentHeight:"accent-height",alignmentBaseline:"alignment-baseline",arabicForm:"arabic-form",baselineShift:"baseline-shift",capHeight:"cap-height",className:"class",clipPath:"clip-path",clipRule:"clip-rule",colorInterpolation:"color-interpolation",colorInterpolationFilters:"color-interpolation-filters",colorProfile:"color-profile",colorRendering:"color-rendering",crossOrigin:"crossorigin",dataType:"datatype",dominantBaseline:"dominant-baseline",enableBackground:"enable-background",fillOpacity:"fill-opacity",fillRule:"fill-rule",floodColor:"flood-color",floodOpacity:"flood-opacity",fontFamily:"font-family",fontSize:"font-size",fontSizeAdjust:"font-size-adjust",fontStretch:"font-stretch",fontStyle:"font-style",fontVariant:"font-variant",fontWeight:"font-weight",glyphName:"glyph-name",glyphOrientationHorizontal:"glyph-orientation-horizontal",glyphOrientationVertical:"glyph-orientation-vertical",hrefLang:"hreflang",horizAdvX:"horiz-adv-x",horizOriginX:"horiz-origin-x",horizOriginY:"horiz-origin-y",imageRendering:"image-rendering",letterSpacing:"letter-spacing",lightingColor:"lighting-color",markerEnd:"marker-end",markerMid:"marker-mid",markerStart:"marker-start",navDown:"nav-down",navDownLeft:"nav-down-left",navDownRight:"nav-down-right",navLeft:"nav-left",navNext:"nav-next",navPrev:"nav-prev",navRight:"nav-right",navUp:"nav-up",navUpLeft:"nav-up-left",navUpRight:"nav-up-right",onAbort:"onabort",onActivate:"onactivate",onAfterPrint:"onafterprint",onBeforePrint:"onbeforeprint",onBegin:"onbegin",onCancel:"oncancel",onCanPlay:"oncanplay",onCanPlayThrough:"oncanplaythrough",onChange:"onchange",onClick:"onclick",onClose:"onclose",onCopy:"oncopy",onCueChange:"oncuechange",onCut:"oncut",onDblClick:"ondblclick",onDrag:"ondrag",onDragEnd:"ondragend",onDragEnter:"ondragenter",onDragExit:"ondragexit",onDragLeave:"ondragleave",onDragOver:"ondragover",onDragStart:"ondragstart",onDrop:"ondrop",onDurationChange:"ondurationchange",onEmptied:"onemptied",onEnd:"onend",onEnded:"onended",onError:"onerror",onFocus:"onfocus",onFocusIn:"onfocusin",onFocusOut:"onfocusout",onHashChange:"onhashchange",onInput:"oninput",onInvalid:"oninvalid",onKeyDown:"onkeydown",onKeyPress:"onkeypress",onKeyUp:"onkeyup",onLoad:"onload",onLoadedData:"onloadeddata",onLoadedMetadata:"onloadedmetadata",onLoadStart:"onloadstart",onMessage:"onmessage",onMouseDown:"onmousedown",onMouseEnter:"onmouseenter",onMouseLeave:"onmouseleave",onMouseMove:"onmousemove",onMouseOut:"onmouseout",onMouseOver:"onmouseover",onMouseUp:"onmouseup",onMouseWheel:"onmousewheel",onOffline:"onoffline",onOnline:"ononline",onPageHide:"onpagehide",onPageShow:"onpageshow",onPaste:"onpaste",onPause:"onpause",onPlay:"onplay",onPlaying:"onplaying",onPopState:"onpopstate",onProgress:"onprogress",onRateChange:"onratechange",onRepeat:"onrepeat",onReset:"onreset",onResize:"onresize",onScroll:"onscroll",onSeeked:"onseeked",onSeeking:"onseeking",onSelect:"onselect",onShow:"onshow",onStalled:"onstalled",onStorage:"onstorage",onSubmit:"onsubmit",onSuspend:"onsuspend",onTimeUpdate:"ontimeupdate",onToggle:"ontoggle",onUnload:"onunload",onVolumeChange:"onvolumechange",onWaiting:"onwaiting",onZoom:"onzoom",overlinePosition:"overline-position",overlineThickness:"overline-thickness",paintOrder:"paint-order",panose1:"panose-1",pointerEvents:"pointer-events",referrerPolicy:"referrerpolicy",renderingIntent:"rendering-intent",shapeRendering:"shape-rendering",stopColor:"stop-color",stopOpacity:"stop-opacity",strikethroughPosition:"strikethrough-position",strikethroughThickness:"strikethrough-thickness",strokeDashArray:"stroke-dasharray",strokeDashOffset:"stroke-dashoffset",strokeLineCap:"stroke-linecap",strokeLineJoin:"stroke-linejoin",strokeMiterLimit:"stroke-miterlimit",strokeOpacity:"stroke-opacity",strokeWidth:"stroke-width",tabIndex:"tabindex",textAnchor:"text-anchor",textDecoration:"text-decoration",textRendering:"text-rendering",transformOrigin:"transform-origin",typeOf:"typeof",underlinePosition:"underline-position",underlineThickness:"underline-thickness",unicodeBidi:"unicode-bidi",unicodeRange:"unicode-range",unitsPerEm:"units-per-em",vAlphabetic:"v-alphabetic",vHanging:"v-hanging",vIdeographic:"v-ideographic",vMathematical:"v-mathematical",vectorEffect:"vector-effect",vertAdvY:"vert-adv-y",vertOriginX:"vert-origin-x",vertOriginY:"vert-origin-y",wordSpacing:"word-spacing",writingMode:"writing-mode",xHeight:"x-height",playbackOrder:"playbackorder",timelineBegin:"timelinebegin"},properties:{about:commaOrSpaceSeparated,accentHeight:number,accumulate:null,additive:null,alignmentBaseline:null,alphabetic:number,amplitude:number,arabicForm:null,ascent:number,attributeName:null,attributeType:null,azimuth:number,bandwidth:null,baselineShift:null,baseFrequency:null,baseProfile:null,bbox:null,begin:null,bias:number,by:null,calcMode:null,capHeight:number,className:spaceSeparated,clip:null,clipPath:null,clipPathUnits:null,clipRule:null,color:null,colorInterpolation:null,colorInterpolationFilters:null,colorProfile:null,colorRendering:null,content:null,contentScriptType:null,contentStyleType:null,crossOrigin:null,cursor:null,cx:null,cy:null,d:null,dataType:null,defaultAction:null,descent:number,diffuseConstant:number,direction:null,display:null,dur:null,divisor:number,dominantBaseline:null,download:boolean,dx:null,dy:null,edgeMode:null,editable:null,elevation:number,enableBackground:null,end:null,event:null,exponent:number,externalResourcesRequired:null,fill:null,fillOpacity:number,fillRule:null,filter:null,filterRes:null,filterUnits:null,floodColor:null,floodOpacity:null,focusable:null,focusHighlight:null,fontFamily:null,fontSize:null,fontSizeAdjust:null,fontStretch:null,fontStyle:null,fontVariant:null,fontWeight:null,format:null,fr:null,from:null,fx:null,fy:null,g1:commaSeparated,g2:commaSeparated,glyphName:commaSeparated,glyphOrientationHorizontal:null,glyphOrientationVertical:null,glyphRef:null,gradientTransform:null,gradientUnits:null,handler:null,hanging:number,hatchContentUnits:null,hatchUnits:null,height:null,href:null,hrefLang:null,horizAdvX:number,horizOriginX:number,horizOriginY:number,id:null,ideographic:number,imageRendering:null,initialVisibility:null,in:null,in2:null,intercept:number,k:number,k1:number,k2:number,k3:number,k4:number,kernelMatrix:commaOrSpaceSeparated,kernelUnitLength:null,keyPoints:null,keySplines:null,keyTimes:null,kerning:null,lang:null,lengthAdjust:null,letterSpacing:null,lightingColor:null,limitingConeAngle:number,local:null,markerEnd:null,markerMid:null,markerStart:null,markerHeight:null,markerUnits:null,markerWidth:null,mask:null,maskContentUnits:null,maskUnits:null,mathematical:null,max:null,media:null,mediaCharacterEncoding:null,mediaContentEncodings:null,mediaSize:number,mediaTime:null,method:null,min:null,mode:null,name:null,navDown:null,navDownLeft:null,navDownRight:null,navLeft:null,navNext:null,navPrev:null,navRight:null,navUp:null,navUpLeft:null,navUpRight:null,numOctaves:null,observer:null,offset:null,onAbort:null,onActivate:null,onAfterPrint:null,onBeforePrint:null,onBegin:null,onCancel:null,onCanPlay:null,onCanPlayThrough:null,onChange:null,onClick:null,onClose:null,onCopy:null,onCueChange:null,onCut:null,onDblClick:null,onDrag:null,onDragEnd:null,onDragEnter:null,onDragExit:null,onDragLeave:null,onDragOver:null,onDragStart:null,onDrop:null,onDurationChange:null,onEmptied:null,onEnd:null,onEnded:null,onError:null,onFocus:null,onFocusIn:null,onFocusOut:null,onHashChange:null,onInput:null,onInvalid:null,onKeyDown:null,onKeyPress:null,onKeyUp:null,onLoad:null,onLoadedData:null,onLoadedMetadata:null,onLoadStart:null,onMessage:null,onMouseDown:null,onMouseEnter:null,onMouseLeave:null,onMouseMove:null,onMouseOut:null,onMouseOver:null,onMouseUp:null,onMouseWheel:null,onOffline:null,onOnline:null,onPageHide:null,onPageShow:null,onPaste:null,onPause:null,onPlay:null,onPlaying:null,onPopState:null,onProgress:null,onRateChange:null,onRepeat:null,onReset:null,onResize:null,onScroll:null,onSeeked:null,onSeeking:null,onSelect:null,onShow:null,onStalled:null,onStorage:null,onSubmit:null,onSuspend:null,onTimeUpdate:null,onToggle:null,onUnload:null,onVolumeChange:null,onWaiting:null,onZoom:null,opacity:null,operator:null,order:null,orient:null,orientation:null,origin:null,overflow:null,overlay:null,overlinePosition:number,overlineThickness:number,paintOrder:null,panose1:null,path:null,pathLength:number,patternContentUnits:null,patternTransform:null,patternUnits:null,phase:null,ping:spaceSeparated,pitch:null,playbackOrder:null,pointerEvents:null,points:null,pointsAtX:number,pointsAtY:number,pointsAtZ:number,preserveAlpha:null,preserveAspectRatio:null,primitiveUnits:null,propagate:null,property:commaOrSpaceSeparated,r:null,radius:null,referrerPolicy:null,refX:null,refY:null,rel:commaOrSpaceSeparated,rev:commaOrSpaceSeparated,renderingIntent:null,repeatCount:null,repeatDur:null,requiredExtensions:commaOrSpaceSeparated,requiredFeatures:commaOrSpaceSeparated,requiredFonts:commaOrSpaceSeparated,requiredFormats:commaOrSpaceSeparated,resource:null,restart:null,result:null,rotate:null,rx:null,ry:null,scale:null,seed:null,shapeRendering:null,side:null,slope:null,snapshotTime:null,specularConstant:number,specularExponent:number,spreadMethod:null,spacing:null,startOffset:null,stdDeviation:null,stemh:null,stemv:null,stitchTiles:null,stopColor:null,stopOpacity:null,strikethroughPosition:number,strikethroughThickness:number,string:null,stroke:null,strokeDashArray:commaOrSpaceSeparated,strokeDashOffset:null,strokeLineCap:null,strokeLineJoin:null,strokeMiterLimit:number,strokeOpacity:number,strokeWidth:null,style:null,surfaceScale:number,syncBehavior:null,syncBehaviorDefault:null,syncMaster:null,syncTolerance:null,syncToleranceDefault:null,systemLanguage:commaOrSpaceSeparated,tabIndex:number,tableValues:null,target:null,targetX:number,targetY:number,textAnchor:null,textDecoration:null,textRendering:null,textLength:null,timelineBegin:null,title:null,transformBehavior:null,type:null,typeOf:commaOrSpaceSeparated,to:null,transform:null,transformOrigin:null,u1:null,u2:null,underlinePosition:number,underlineThickness:number,unicode:null,unicodeBidi:null,unicodeRange:null,unitsPerEm:number,values:null,vAlphabetic:number,vMathematical:number,vectorEffect:null,vHanging:number,vIdeographic:number,version:null,vertAdvY:number,vertOriginX:number,vertOriginY:number,viewBox:null,viewTarget:null,visibility:null,width:null,widths:null,wordSpacing:null,writingMode:null,x:null,x1:null,x2:null,xChannelSelector:null,xHeight:number,y:null,y1:null,y2:null,yChannelSelector:null,z:null,zoomAndPan:null},space:"svg",transform:caseSensitiveTransform}),xlink=create({properties:{xLinkActuate:null,xLinkArcRole:null,xLinkHref:null,xLinkRole:null,xLinkShow:null,xLinkTitle:null,xLinkType:null},space:"xlink",transform(a,c){return"xlink:"+c.slice(5).toLowerCase()}}),xmlns=create({attributes:{xmlnsxlink:"xmlns:xlink"},properties:{xmlnsXLink:null,xmlns:null},space:"xmlns",transform:caseInsensitiveTransform}),xml=create({properties:{xmlBase:null,xmlLang:null,xmlSpace:null},space:"xml",transform(a,c){return"xml:"+c.slice(3).toLowerCase()}}),hastToReact={classId:"classID",dataType:"datatype",itemId:"itemID",strokeDashArray:"strokeDasharray",strokeDashOffset:"strokeDashoffset",strokeLineCap:"strokeLinecap",strokeLineJoin:"strokeLinejoin",strokeMiterLimit:"strokeMiterlimit",typeOf:"typeof",xLinkActuate:"xlinkActuate",xLinkArcRole:"xlinkArcrole",xLinkHref:"xlinkHref",xLinkRole:"xlinkRole",xLinkShow:"xlinkShow",xLinkTitle:"xlinkTitle",xLinkType:"xlinkType",xmlnsXLink:"xmlnsXlink"},cap$1=/[A-Z]/g,dash=/-[a-z]/g,valid=/^data[-\w.:]+$/i;function find(a,c){const u=normalize$1(c);let d=c,f=Info;if(u in a.normal)return a.property[a.normal[u]];if(u.length>4&&u.slice(0,4)==="data"&&valid.test(c)){if(c.charAt(4)==="-"){const m=c.slice(5).replace(dash,camelcase);d="data"+m.charAt(0).toUpperCase()+m.slice(1)}else{const m=c.slice(4);if(!dash.test(m)){let g=m.replace(cap$1,kebab);g.charAt(0)!=="-"&&(g="-"+g),c="data"+g}}f=DefinedInfo}return new f(d,c)}function kebab(a){return"-"+a.toLowerCase()}function camelcase(a){return a.charAt(1).toUpperCase()}const html$2=merge([aria,html$3,xlink,xmlns,xml],"html"),svg=merge([aria,svg$1,xlink,xmlns,xml],"svg");function parse$1(a){const c=String(a||"").trim();return c?c.split(/[ \t\n\r\f]+/g):[]}function stringify(a){return a.join(" ").trim()}var cjs$1={},inlineStyleParser,hasRequiredInlineStyleParser;function requireInlineStyleParser(){if(hasRequiredInlineStyleParser)return inlineStyleParser;hasRequiredInlineStyleParser=1;var a=/\/\*[^*]*\*+([^/*][^*]*\*+)*\//g,c=/\n/g,u=/^\s*/,d=/^(\*?[-#/*\\\w]+(\[[0-9a-z_-]+\])?)\s*/,f=/^:\s*/,m=/^((?:'(?:\\'|.)*?'|"(?:\\"|.)*?"|\([^)]*?\)|[^};])+)/,g=/^[;\s]*/,y=/^\s+|\s+$/g,b=`
`,E="/",C="*",w="",R="comment",_="declaration";inlineStyleParser=function(I,N){if(typeof I!="string")throw new TypeError("First argument must be a string");if(!I)return[];N=N||{};var A=1,P=1;function z(Y){var Z=Y.match(c);Z&&(A+=Z.length);var J=Y.lastIndexOf(b);P=~J?Y.length-J:P+Y.length}function B(){var Y={line:A,column:P};return function(Z){return Z.position=new j(Y),q(),Z}}function j(Y){this.start=Y,this.end={line:A,column:P},this.source=N.source}j.prototype.content=I;function L(Y){var Z=new Error(N.source+":"+A+":"+P+": "+Y);if(Z.reason=Y,Z.filename=N.source,Z.line=A,Z.column=P,Z.source=I,!N.silent)throw Z}function U(Y){var Z=Y.exec(I);if(Z){var J=Z[0];return z(J),I=I.slice(J.length),Z}}function q(){U(u)}function F(Y){var Z;for(Y=Y||[];Z=K();)Z!==!1&&Y.push(Z);return Y}function K(){var Y=B();if(!(E!=I.charAt(0)||C!=I.charAt(1))){for(var Z=2;w!=I.charAt(Z)&&(C!=I.charAt(Z)||E!=I.charAt(Z+1));)++Z;if(Z+=2,w===I.charAt(Z-1))return L("End of comment missing");var J=I.slice(2,Z-2);return P+=2,z(J),I=I.slice(Z),P+=2,Y({type:R,comment:J})}}function X(){var Y=B(),Z=U(d);if(Z){if(K(),!U(f))return L("property missing ':'");var J=U(m),W=Y({type:_,property:M(Z[0].replace(a,w)),value:J?M(J[0].replace(a,w)):w});return U(g),W}}function Q(){var Y=[];F(Y);for(var Z;Z=X();)Z!==!1&&(Y.push(Z),F(Y));return Y}return q(),Q()};function M(I){return I?I.replace(y,w):w}return inlineStyleParser}var hasRequiredCjs$1;function requireCjs$1(){if(hasRequiredCjs$1)return cjs$1;hasRequiredCjs$1=1;var a=cjs$1&&cjs$1.__importDefault||function(d){return d&&d.__esModule?d:{default:d}};Object.defineProperty(cjs$1,"__esModule",{value:!0}),cjs$1.default=u;var c=a(requireInlineStyleParser());function u(d,f){var m=null;if(!d||typeof d!="string")return m;var g=(0,c.default)(d),y=typeof f=="function";return g.forEach(function(b){if(b.type==="declaration"){var E=b.property,C=b.value;y?f(E,C,b):C&&(m=m||{},m[E]=C)}}),m}return cjs$1}var utilities={},hasRequiredUtilities;function requireUtilities(){if(hasRequiredUtilities)return utilities;hasRequiredUtilities=1,Object.defineProperty(utilities,"__esModule",{value:!0}),utilities.camelCase=void 0;var a=/^--[a-zA-Z0-9_-]+$/,c=/-([a-z])/g,u=/^[^-]+$/,d=/^-(webkit|moz|ms|o|khtml)-/,f=/^-(ms)-/,m=function(E){return!E||u.test(E)||a.test(E)},g=function(E,C){return C.toUpperCase()},y=function(E,C){return"".concat(C,"-")},b=function(E,C){return C===void 0&&(C={}),m(E)?E:(E=E.toLowerCase(),C.reactCompat?E=E.replace(f,y):E=E.replace(d,y),E.replace(c,g))};return utilities.camelCase=b,utilities}var cjs,hasRequiredCjs;function requireCjs(){if(hasRequiredCjs)return cjs;hasRequiredCjs=1;var a=cjs&&cjs.__importDefault||function(f){return f&&f.__esModule?f:{default:f}},c=a(requireCjs$1()),u=requireUtilities();function d(f,m){var g={};return!f||typeof f!="string"||(0,c.default)(f,function(y,b){y&&b&&(g[(0,u.camelCase)(y,m)]=b)}),g}return d.default=d,cjs=d,cjs}var cjsExports=requireCjs();const styleToJs=getDefaultExportFromCjs(cjsExports),pointEnd=point$2("end"),pointStart=point$2("start");function point$2(a){return c;function c(u){const d=u&&u.position&&u.position[a]||{};if(typeof d.line=="number"&&d.line>0&&typeof d.column=="number"&&d.column>0)return{line:d.line,column:d.column,offset:typeof d.offset=="number"&&d.offset>-1?d.offset:void 0}}}function position$1(a){const c=pointStart(a),u=pointEnd(a);if(c&&u)return{start:c,end:u}}function stringifyPosition(a){return!a||typeof a!="object"?"":"position"in a||"type"in a?position(a.position):"start"in a||"end"in a?position(a):"line"in a||"column"in a?point$1(a):""}function point$1(a){return index(a&&a.line)+":"+index(a&&a.column)}function position(a){return point$1(a&&a.start)+"-"+point$1(a&&a.end)}function index(a){return a&&typeof a=="number"?a:1}class VFileMessage extends Error{constructor(c,u,d){super(),typeof u=="string"&&(d=u,u=void 0);let f="",m={},g=!1;if(u&&("line"in u&&"column"in u?m={place:u}:"start"in u&&"end"in u?m={place:u}:"type"in u?m={ancestors:[u],place:u.position}:m={...u}),typeof c=="string"?f=c:!m.cause&&c&&(g=!0,f=c.message,m.cause=c),!m.ruleId&&!m.source&&typeof d=="string"){const b=d.indexOf(":");b===-1?m.ruleId=d:(m.source=d.slice(0,b),m.ruleId=d.slice(b+1))}if(!m.place&&m.ancestors&&m.ancestors){const b=m.ancestors[m.ancestors.length-1];b&&(m.place=b.position)}const y=m.place&&"start"in m.place?m.place.start:m.place;this.ancestors=m.ancestors||void 0,this.cause=m.cause||void 0,this.column=y?y.column:void 0,this.fatal=void 0,this.file,this.message=f,this.line=y?y.line:void 0,this.name=stringifyPosition(m.place)||"1:1",this.place=m.place||void 0,this.reason=this.message,this.ruleId=m.ruleId||void 0,this.source=m.source||void 0,this.stack=g&&m.cause&&typeof m.cause.stack=="string"?m.cause.stack:"",this.actual,this.expected,this.note,this.url}}VFileMessage.prototype.file="";VFileMessage.prototype.name="";VFileMessage.prototype.reason="";VFileMessage.prototype.message="";VFileMessage.prototype.stack="";VFileMessage.prototype.column=void 0;VFileMessage.prototype.line=void 0;VFileMessage.prototype.ancestors=void 0;VFileMessage.prototype.cause=void 0;VFileMessage.prototype.fatal=void 0;VFileMessage.prototype.place=void 0;VFileMessage.prototype.ruleId=void 0;VFileMessage.prototype.source=void 0;const own$3={}.hasOwnProperty,emptyMap=new Map,cap=/[A-Z]/g,tableElements=new Set(["table","tbody","thead","tfoot","tr"]),tableCellElement=new Set(["td","th"]),docs="https://github.com/syntax-tree/hast-util-to-jsx-runtime";function toJsxRuntime(a,c){if(!c||c.Fragment===void 0)throw new TypeError("Expected `Fragment` in options");const u=c.filePath||void 0;let d;if(c.development){if(typeof c.jsxDEV!="function")throw new TypeError("Expected `jsxDEV` in options when `development: true`");d=developmentCreate(u,c.jsxDEV)}else{if(typeof c.jsx!="function")throw new TypeError("Expected `jsx` in production options");if(typeof c.jsxs!="function")throw new TypeError("Expected `jsxs` in production options");d=productionCreate(u,c.jsx,c.jsxs)}const f={Fragment:c.Fragment,ancestors:[],components:c.components||{},create:d,elementAttributeNameCase:c.elementAttributeNameCase||"react",evaluater:c.createEvaluater?c.createEvaluater():void 0,filePath:u,ignoreInvalidStyle:c.ignoreInvalidStyle||!1,passKeys:c.passKeys!==!1,passNode:c.passNode||!1,schema:c.space==="svg"?svg:html$2,stylePropertyNameCase:c.stylePropertyNameCase||"dom",tableCellAlignToStyle:c.tableCellAlignToStyle!==!1},m=one$2(f,a,void 0);return m&&typeof m!="string"?m:f.create(a,f.Fragment,{children:m||void 0},void 0)}function one$2(a,c,u){if(c.type==="element")return element$3(a,c,u);if(c.type==="mdxFlowExpression"||c.type==="mdxTextExpression")return mdxExpression(a,c);if(c.type==="mdxJsxFlowElement"||c.type==="mdxJsxTextElement")return mdxJsxElement(a,c,u);if(c.type==="mdxjsEsm")return mdxEsm(a,c);if(c.type==="root")return root$3(a,c,u);if(c.type==="text")return text$8(a,c)}function element$3(a,c,u){const d=a.schema;let f=d;c.tagName.toLowerCase()==="svg"&&d.space==="html"&&(f=svg,a.schema=f),a.ancestors.push(c);const m=findComponentFromName(a,c.tagName,!1),g=createElementProps(a,c);let y=createChildren(a,c);return tableElements.has(c.tagName)&&(y=y.filter(function(b){return typeof b=="string"?!whitespace(b):!0})),addNode(a,g,m,c),addChildren(g,y),a.ancestors.pop(),a.schema=d,a.create(c,m,g,u)}function mdxExpression(a,c){if(c.data&&c.data.estree&&a.evaluater){const d=c.data.estree.body[0];return d.type,a.evaluater.evaluateExpression(d.expression)}crashEstree(a,c.position)}function mdxEsm(a,c){if(c.data&&c.data.estree&&a.evaluater)return a.evaluater.evaluateProgram(c.data.estree);crashEstree(a,c.position)}function mdxJsxElement(a,c,u){const d=a.schema;let f=d;c.name==="svg"&&d.space==="html"&&(f=svg,a.schema=f),a.ancestors.push(c);const m=c.name===null?a.Fragment:findComponentFromName(a,c.name,!0),g=createJsxElementProps(a,c),y=createChildren(a,c);return addNode(a,g,m,c),addChildren(g,y),a.ancestors.pop(),a.schema=d,a.create(c,m,g,u)}function root$3(a,c,u){const d={};return addChildren(d,createChildren(a,c)),a.create(c,a.Fragment,d,u)}function text$8(a,c){return c.value}function addNode(a,c,u,d){typeof u!="string"&&u!==a.Fragment&&a.passNode&&(c.node=d)}function addChildren(a,c){if(c.length>0){const u=c.length>1?c:c[0];u&&(a.children=u)}}function productionCreate(a,c,u){return d;function d(f,m,g,y){const E=Array.isArray(g.children)?u:c;return y?E(m,g,y):E(m,g)}}function developmentCreate(a,c){return u;function u(d,f,m,g){const y=Array.isArray(m.children),b=pointStart(d);return c(f,m,g,y,{columnNumber:b?b.column-1:void 0,fileName:a,lineNumber:b?b.line:void 0},void 0)}}function createElementProps(a,c){const u={};let d,f;for(f in c.properties)if(f!=="children"&&own$3.call(c.properties,f)){const m=createProperty(a,f,c.properties[f]);if(m){const[g,y]=m;a.tableCellAlignToStyle&&g==="align"&&typeof y=="string"&&tableCellElement.has(c.tagName)?d=y:u[g]=y}}if(d){const m=u.style||(u.style={});m[a.stylePropertyNameCase==="css"?"text-align":"textAlign"]=d}return u}function createJsxElementProps(a,c){const u={};for(const d of c.attributes)if(d.type==="mdxJsxExpressionAttribute")if(d.data&&d.data.estree&&a.evaluater){const m=d.data.estree.body[0];m.type;const g=m.expression;g.type;const y=g.properties[0];y.type,Object.assign(u,a.evaluater.evaluateExpression(y.argument))}else crashEstree(a,c.position);else{const f=d.name;let m;if(d.value&&typeof d.value=="object")if(d.value.data&&d.value.data.estree&&a.evaluater){const y=d.value.data.estree.body[0];y.type,m=a.evaluater.evaluateExpression(y.expression)}else crashEstree(a,c.position);else m=d.value===null?!0:d.value;u[f]=m}return u}function createChildren(a,c){const u=[];let d=-1;const f=a.passKeys?new Map:emptyMap;for(;++d<c.children.length;){const m=c.children[d];let g;if(a.passKeys){const b=m.type==="element"?m.tagName:m.type==="mdxJsxFlowElement"||m.type==="mdxJsxTextElement"?m.name:void 0;if(b){const E=f.get(b)||0;g=b+"-"+E,f.set(b,E+1)}}const y=one$2(a,m,g);y!==void 0&&u.push(y)}return u}function createProperty(a,c,u){const d=find(a.schema,c);if(!(u==null||typeof u=="number"&&Number.isNaN(u))){if(Array.isArray(u)&&(u=d.commaSeparated?stringify$1(u):stringify(u)),d.property==="style"){let f=typeof u=="object"?u:parseStyle(a,String(u));return a.stylePropertyNameCase==="css"&&(f=transformStylesToCssCasing(f)),["style",f]}return[a.elementAttributeNameCase==="react"&&d.space?hastToReact[d.property]||d.property:d.attribute,u]}}function parseStyle(a,c){try{return styleToJs(c,{reactCompat:!0})}catch(u){if(a.ignoreInvalidStyle)return{};const d=u,f=new VFileMessage("Cannot parse `style` attribute",{ancestors:a.ancestors,cause:d,ruleId:"style",source:"hast-util-to-jsx-runtime"});throw f.file=a.filePath||void 0,f.url=docs+"#cannot-parse-style-attribute",f}}function findComponentFromName(a,c,u){let d;if(!u)d={type:"Literal",value:c};else if(c.includes(".")){const f=c.split(".");let m=-1,g;for(;++m<f.length;){const y=name(f[m])?{type:"Identifier",name:f[m]}:{type:"Literal",value:f[m]};g=g?{type:"MemberExpression",object:g,property:y,computed:!!(m&&y.type==="Literal"),optional:!1}:y}d=g}else d=name(c)&&!/^[a-z]/.test(c)?{type:"Identifier",name:c}:{type:"Literal",value:c};if(d.type==="Literal"){const f=d.value;return own$3.call(a.components,f)?a.components[f]:f}if(a.evaluater)return a.evaluater.evaluateExpression(d);crashEstree(a)}function crashEstree(a,c){const u=new VFileMessage("Cannot handle MDX estrees without `createEvaluater`",{ancestors:a.ancestors,place:c,ruleId:"mdx-estree",source:"hast-util-to-jsx-runtime"});throw u.file=a.filePath||void 0,u.url=docs+"#cannot-handle-mdx-estrees-without-createevaluater",u}function transformStylesToCssCasing(a){const c={};let u;for(u in a)own$3.call(a,u)&&(c[transformStyleToCssCasing(u)]=a[u]);return c}function transformStyleToCssCasing(a){let c=a.replace(cap,toDash);return c.slice(0,3)==="ms-"&&(c="-"+c),c}function toDash(a){return"-"+a.toLowerCase()}const urlAttributes={action:["form"],cite:["blockquote","del","ins","q"],data:["object"],formAction:["button","input"],href:["a","area","base","link"],icon:["menuitem"],itemId:null,manifest:["html"],ping:["a","area"],poster:["video"],src:["audio","embed","iframe","img","input","script","source","track","video"]},emptyOptions$4={};function toString$1(a,c){const u=emptyOptions$4,d=typeof u.includeImageAlt=="boolean"?u.includeImageAlt:!0,f=typeof u.includeHtml=="boolean"?u.includeHtml:!0;return one$1(a,d,f)}function one$1(a,c,u){if(node(a)){if("value"in a)return a.type==="html"&&!u?"":a.value;if(c&&"alt"in a&&a.alt)return a.alt;if("children"in a)return all$1(a.children,c,u)}return Array.isArray(a)?all$1(a,c,u):""}function all$1(a,c,u){const d=[];let f=-1;for(;++f<a.length;)d[f]=one$1(a[f],c,u);return d.join("")}function node(a){return!!(a&&typeof a=="object")}const element$2=document.createElement("i");function decodeNamedCharacterReference(a){const c="&"+a+";";element$2.innerHTML=c;const u=element$2.textContent;return u.charCodeAt(u.length-1)===59&&a!=="semi"||u===c?!1:u}function splice(a,c,u,d){const f=a.length;let m=0,g;if(c<0?c=-c>f?0:f+c:c=c>f?f:c,u=u>0?u:0,d.length<1e4)g=Array.from(d),g.unshift(c,u),a.splice(...g);else for(u&&a.splice(c,u);m<d.length;)g=d.slice(m,m+1e4),g.unshift(c,0),a.splice(...g),m+=1e4,c+=1e4}function push(a,c){return a.length>0?(splice(a,a.length,0,c),a):c}const hasOwnProperty={}.hasOwnProperty;function combineExtensions(a){const c={};let u=-1;for(;++u<a.length;)syntaxExtension(c,a[u]);return c}function syntaxExtension(a,c){let u;for(u in c){const f=(hasOwnProperty.call(a,u)?a[u]:void 0)||(a[u]={}),m=c[u];let g;if(m)for(g in m){hasOwnProperty.call(f,g)||(f[g]=[]);const y=m[g];constructs(f[g],Array.isArray(y)?y:y?[y]:[])}}}function constructs(a,c){let u=-1;const d=[];for(;++u<c.length;)(c[u].add==="after"?a:d).push(c[u]);splice(a,0,0,d)}function decodeNumericCharacterReference(a,c){const u=Number.parseInt(a,c);return u<9||u===11||u>13&&u<32||u>126&&u<160||u>55295&&u<57344||u>64975&&u<65008||(u&65535)===65535||(u&65535)===65534||u>1114111?"�":String.fromCodePoint(u)}function normalizeIdentifier(a){return a.replace(/[\t\n\r ]+/g," ").replace(/^ | $/g,"").toLowerCase().toUpperCase()}const asciiAlpha=regexCheck(/[A-Za-z]/),asciiAlphanumeric=regexCheck(/[\dA-Za-z]/),asciiAtext=regexCheck(/[#-'*+\--9=?A-Z^-~]/);function asciiControl(a){return a!==null&&(a<32||a===127)}const asciiDigit=regexCheck(/\d/),asciiHexDigit=regexCheck(/[\dA-Fa-f]/),asciiPunctuation=regexCheck(/[!-/:-@[-`{-~]/);function markdownLineEnding(a){return a!==null&&a<-2}function markdownLineEndingOrSpace(a){return a!==null&&(a<0||a===32)}function markdownSpace(a){return a===-2||a===-1||a===32}const unicodePunctuation=regexCheck(new RegExp("\\p{P}|\\p{S}","u")),unicodeWhitespace=regexCheck(/\s/);function regexCheck(a){return c;function c(u){return u!==null&&u>-1&&a.test(String.fromCharCode(u))}}function normalizeUri(a){const c=[];let u=-1,d=0,f=0;for(;++u<a.length;){const m=a.charCodeAt(u);let g="";if(m===37&&asciiAlphanumeric(a.charCodeAt(u+1))&&asciiAlphanumeric(a.charCodeAt(u+2)))f=2;else if(m<128)/[!#$&-;=?-Z_a-z~]/.test(String.fromCharCode(m))||(g=String.fromCharCode(m));else if(m>55295&&m<57344){const y=a.charCodeAt(u+1);m<56320&&y>56319&&y<57344?(g=String.fromCharCode(m,y),f=1):g="�"}else g=String.fromCharCode(m);g&&(c.push(a.slice(d,u),encodeURIComponent(g)),d=u+f+1,g=""),f&&(u+=f,f=0)}return c.join("")+a.slice(d)}function factorySpace(a,c,u,d){const f=d?d-1:Number.POSITIVE_INFINITY;let m=0;return g;function g(b){return markdownSpace(b)?(a.enter(u),y(b)):c(b)}function y(b){return markdownSpace(b)&&m++<f?(a.consume(b),y):(a.exit(u),c(b))}}const content$1={tokenize:initializeContent};function initializeContent(a){const c=a.attempt(this.parser.constructs.contentInitial,d,f);let u;return c;function d(y){if(y===null){a.consume(y);return}return a.enter("lineEnding"),a.consume(y),a.exit("lineEnding"),factorySpace(a,c,"linePrefix")}function f(y){return a.enter("paragraph"),m(y)}function m(y){const b=a.enter("chunkText",{contentType:"text",previous:u});return u&&(u.next=b),u=b,g(y)}function g(y){if(y===null){a.exit("chunkText"),a.exit("paragraph"),a.consume(y);return}return markdownLineEnding(y)?(a.consume(y),a.exit("chunkText"),m):(a.consume(y),g)}}const document$2={tokenize:initializeDocument},containerConstruct={tokenize:tokenizeContainer};function initializeDocument(a){const c=this,u=[];let d=0,f,m,g;return y;function y(z){if(d<u.length){const B=u[d];return c.containerState=B[1],a.attempt(B[0].continuation,b,E)(z)}return E(z)}function b(z){if(d++,c.containerState._closeFlow){c.containerState._closeFlow=void 0,f&&P();const B=c.events.length;let j=B,L;for(;j--;)if(c.events[j][0]==="exit"&&c.events[j][1].type==="chunkFlow"){L=c.events[j][1].end;break}A(d);let U=B;for(;U<c.events.length;)c.events[U][1].end={...L},U++;return splice(c.events,j+1,0,c.events.slice(B)),c.events.length=U,E(z)}return y(z)}function E(z){if(d===u.length){if(!f)return R(z);if(f.currentConstruct&&f.currentConstruct.concrete)return M(z);c.interrupt=!!(f.currentConstruct&&!f._gfmTableDynamicInterruptHack)}return c.containerState={},a.check(containerConstruct,C,w)(z)}function C(z){return f&&P(),A(d),R(z)}function w(z){return c.parser.lazy[c.now().line]=d!==u.length,g=c.now().offset,M(z)}function R(z){return c.containerState={},a.attempt(containerConstruct,_,M)(z)}function _(z){return d++,u.push([c.currentConstruct,c.containerState]),R(z)}function M(z){if(z===null){f&&P(),A(0),a.consume(z);return}return f=f||c.parser.flow(c.now()),a.enter("chunkFlow",{_tokenizer:f,contentType:"flow",previous:m}),I(z)}function I(z){if(z===null){N(a.exit("chunkFlow"),!0),A(0),a.consume(z);return}return markdownLineEnding(z)?(a.consume(z),N(a.exit("chunkFlow")),d=0,c.interrupt=void 0,y):(a.consume(z),I)}function N(z,B){const j=c.sliceStream(z);if(B&&j.push(null),z.previous=m,m&&(m.next=z),m=z,f.defineSkip(z.start),f.write(j),c.parser.lazy[z.start.line]){let L=f.events.length;for(;L--;)if(f.events[L][1].start.offset<g&&(!f.events[L][1].end||f.events[L][1].end.offset>g))return;const U=c.events.length;let q=U,F,K;for(;q--;)if(c.events[q][0]==="exit"&&c.events[q][1].type==="chunkFlow"){if(F){K=c.events[q][1].end;break}F=!0}for(A(d),L=U;L<c.events.length;)c.events[L][1].end={...K},L++;splice(c.events,q+1,0,c.events.slice(U)),c.events.length=L}}function A(z){let B=u.length;for(;B-- >z;){const j=u[B];c.containerState=j[1],j[0].exit.call(c,a)}u.length=z}function P(){f.write([null]),m=void 0,f=void 0,c.containerState._closeFlow=void 0}}function tokenizeContainer(a,c,u){return factorySpace(a,a.attempt(this.parser.constructs.document,c,u),"linePrefix",this.parser.constructs.disable.null.includes("codeIndented")?void 0:4)}function classifyCharacter(a){if(a===null||markdownLineEndingOrSpace(a)||unicodeWhitespace(a))return 1;if(unicodePunctuation(a))return 2}function resolveAll(a,c,u){const d=[];let f=-1;for(;++f<a.length;){const m=a[f].resolveAll;m&&!d.includes(m)&&(c=m(c,u),d.push(m))}return c}const attention={name:"attention",resolveAll:resolveAllAttention,tokenize:tokenizeAttention};function resolveAllAttention(a,c){let u=-1,d,f,m,g,y,b,E,C;for(;++u<a.length;)if(a[u][0]==="enter"&&a[u][1].type==="attentionSequence"&&a[u][1]._close){for(d=u;d--;)if(a[d][0]==="exit"&&a[d][1].type==="attentionSequence"&&a[d][1]._open&&c.sliceSerialize(a[d][1]).charCodeAt(0)===c.sliceSerialize(a[u][1]).charCodeAt(0)){if((a[d][1]._close||a[u][1]._open)&&(a[u][1].end.offset-a[u][1].start.offset)%3&&!((a[d][1].end.offset-a[d][1].start.offset+a[u][1].end.offset-a[u][1].start.offset)%3))continue;b=a[d][1].end.offset-a[d][1].start.offset>1&&a[u][1].end.offset-a[u][1].start.offset>1?2:1;const w={...a[d][1].end},R={...a[u][1].start};movePoint(w,-b),movePoint(R,b),g={type:b>1?"strongSequence":"emphasisSequence",start:w,end:{...a[d][1].end}},y={type:b>1?"strongSequence":"emphasisSequence",start:{...a[u][1].start},end:R},m={type:b>1?"strongText":"emphasisText",start:{...a[d][1].end},end:{...a[u][1].start}},f={type:b>1?"strong":"emphasis",start:{...g.start},end:{...y.end}},a[d][1].end={...g.start},a[u][1].start={...y.end},E=[],a[d][1].end.offset-a[d][1].start.offset&&(E=push(E,[["enter",a[d][1],c],["exit",a[d][1],c]])),E=push(E,[["enter",f,c],["enter",g,c],["exit",g,c],["enter",m,c]]),E=push(E,resolveAll(c.parser.constructs.insideSpan.null,a.slice(d+1,u),c)),E=push(E,[["exit",m,c],["enter",y,c],["exit",y,c],["exit",f,c]]),a[u][1].end.offset-a[u][1].start.offset?(C=2,E=push(E,[["enter",a[u][1],c],["exit",a[u][1],c]])):C=0,splice(a,d-1,u-d+3,E),u=d+E.length-C-2;break}}for(u=-1;++u<a.length;)a[u][1].type==="attentionSequence"&&(a[u][1].type="data");return a}function tokenizeAttention(a,c){const u=this.parser.constructs.attentionMarkers.null,d=this.previous,f=classifyCharacter(d);let m;return g;function g(b){return m=b,a.enter("attentionSequence"),y(b)}function y(b){if(b===m)return a.consume(b),y;const E=a.exit("attentionSequence"),C=classifyCharacter(b),w=!C||C===2&&f||u.includes(b),R=!f||f===2&&C||u.includes(d);return E._open=!!(m===42?w:w&&(f||!R)),E._close=!!(m===42?R:R&&(C||!w)),c(b)}}function movePoint(a,c){a.column+=c,a.offset+=c,a._bufferIndex+=c}const autolink={name:"autolink",tokenize:tokenizeAutolink};function tokenizeAutolink(a,c,u){let d=0;return f;function f(_){return a.enter("autolink"),a.enter("autolinkMarker"),a.consume(_),a.exit("autolinkMarker"),a.enter("autolinkProtocol"),m}function m(_){return asciiAlpha(_)?(a.consume(_),g):_===64?u(_):E(_)}function g(_){return _===43||_===45||_===46||asciiAlphanumeric(_)?(d=1,y(_)):E(_)}function y(_){return _===58?(a.consume(_),d=0,b):(_===43||_===45||_===46||asciiAlphanumeric(_))&&d++<32?(a.consume(_),y):(d=0,E(_))}function b(_){return _===62?(a.exit("autolinkProtocol"),a.enter("autolinkMarker"),a.consume(_),a.exit("autolinkMarker"),a.exit("autolink"),c):_===null||_===32||_===60||asciiControl(_)?u(_):(a.consume(_),b)}function E(_){return _===64?(a.consume(_),C):asciiAtext(_)?(a.consume(_),E):u(_)}function C(_){return asciiAlphanumeric(_)?w(_):u(_)}function w(_){return _===46?(a.consume(_),d=0,C):_===62?(a.exit("autolinkProtocol").type="autolinkEmail",a.enter("autolinkMarker"),a.consume(_),a.exit("autolinkMarker"),a.exit("autolink"),c):R(_)}function R(_){if((_===45||asciiAlphanumeric(_))&&d++<63){const M=_===45?R:w;return a.consume(_),M}return u(_)}}const blankLine={partial:!0,tokenize:tokenizeBlankLine};function tokenizeBlankLine(a,c,u){return d;function d(m){return markdownSpace(m)?factorySpace(a,f,"linePrefix")(m):f(m)}function f(m){return m===null||markdownLineEnding(m)?c(m):u(m)}}const blockQuote={continuation:{tokenize:tokenizeBlockQuoteContinuation},exit:exit$1,name:"blockQuote",tokenize:tokenizeBlockQuoteStart};function tokenizeBlockQuoteStart(a,c,u){const d=this;return f;function f(g){if(g===62){const y=d.containerState;return y.open||(a.enter("blockQuote",{_container:!0}),y.open=!0),a.enter("blockQuotePrefix"),a.enter("blockQuoteMarker"),a.consume(g),a.exit("blockQuoteMarker"),m}return u(g)}function m(g){return markdownSpace(g)?(a.enter("blockQuotePrefixWhitespace"),a.consume(g),a.exit("blockQuotePrefixWhitespace"),a.exit("blockQuotePrefix"),c):(a.exit("blockQuotePrefix"),c(g))}}function tokenizeBlockQuoteContinuation(a,c,u){const d=this;return f;function f(g){return markdownSpace(g)?factorySpace(a,m,"linePrefix",d.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(g):m(g)}function m(g){return a.attempt(blockQuote,c,u)(g)}}function exit$1(a){a.exit("blockQuote")}const characterEscape={name:"characterEscape",tokenize:tokenizeCharacterEscape};function tokenizeCharacterEscape(a,c,u){return d;function d(m){return a.enter("characterEscape"),a.enter("escapeMarker"),a.consume(m),a.exit("escapeMarker"),f}function f(m){return asciiPunctuation(m)?(a.enter("characterEscapeValue"),a.consume(m),a.exit("characterEscapeValue"),a.exit("characterEscape"),c):u(m)}}const characterReference={name:"characterReference",tokenize:tokenizeCharacterReference};function tokenizeCharacterReference(a,c,u){const d=this;let f=0,m,g;return y;function y(w){return a.enter("characterReference"),a.enter("characterReferenceMarker"),a.consume(w),a.exit("characterReferenceMarker"),b}function b(w){return w===35?(a.enter("characterReferenceMarkerNumeric"),a.consume(w),a.exit("characterReferenceMarkerNumeric"),E):(a.enter("characterReferenceValue"),m=31,g=asciiAlphanumeric,C(w))}function E(w){return w===88||w===120?(a.enter("characterReferenceMarkerHexadecimal"),a.consume(w),a.exit("characterReferenceMarkerHexadecimal"),a.enter("characterReferenceValue"),m=6,g=asciiHexDigit,C):(a.enter("characterReferenceValue"),m=7,g=asciiDigit,C(w))}function C(w){if(w===59&&f){const R=a.exit("characterReferenceValue");return g===asciiAlphanumeric&&!decodeNamedCharacterReference(d.sliceSerialize(R))?u(w):(a.enter("characterReferenceMarker"),a.consume(w),a.exit("characterReferenceMarker"),a.exit("characterReference"),c)}return g(w)&&f++<m?(a.consume(w),C):u(w)}}const nonLazyContinuation$1={partial:!0,tokenize:tokenizeNonLazyContinuation$1},codeFenced={concrete:!0,name:"codeFenced",tokenize:tokenizeCodeFenced};function tokenizeCodeFenced(a,c,u){const d=this,f={partial:!0,tokenize:j};let m=0,g=0,y;return b;function b(L){return E(L)}function E(L){const U=d.events[d.events.length-1];return m=U&&U[1].type==="linePrefix"?U[2].sliceSerialize(U[1],!0).length:0,y=L,a.enter("codeFenced"),a.enter("codeFencedFence"),a.enter("codeFencedFenceSequence"),C(L)}function C(L){return L===y?(g++,a.consume(L),C):g<3?u(L):(a.exit("codeFencedFenceSequence"),markdownSpace(L)?factorySpace(a,w,"whitespace")(L):w(L))}function w(L){return L===null||markdownLineEnding(L)?(a.exit("codeFencedFence"),d.interrupt?c(L):a.check(nonLazyContinuation$1,I,B)(L)):(a.enter("codeFencedFenceInfo"),a.enter("chunkString",{contentType:"string"}),R(L))}function R(L){return L===null||markdownLineEnding(L)?(a.exit("chunkString"),a.exit("codeFencedFenceInfo"),w(L)):markdownSpace(L)?(a.exit("chunkString"),a.exit("codeFencedFenceInfo"),factorySpace(a,_,"whitespace")(L)):L===96&&L===y?u(L):(a.consume(L),R)}function _(L){return L===null||markdownLineEnding(L)?w(L):(a.enter("codeFencedFenceMeta"),a.enter("chunkString",{contentType:"string"}),M(L))}function M(L){return L===null||markdownLineEnding(L)?(a.exit("chunkString"),a.exit("codeFencedFenceMeta"),w(L)):L===96&&L===y?u(L):(a.consume(L),M)}function I(L){return a.attempt(f,B,N)(L)}function N(L){return a.enter("lineEnding"),a.consume(L),a.exit("lineEnding"),A}function A(L){return m>0&&markdownSpace(L)?factorySpace(a,P,"linePrefix",m+1)(L):P(L)}function P(L){return L===null||markdownLineEnding(L)?a.check(nonLazyContinuation$1,I,B)(L):(a.enter("codeFlowValue"),z(L))}function z(L){return L===null||markdownLineEnding(L)?(a.exit("codeFlowValue"),P(L)):(a.consume(L),z)}function B(L){return a.exit("codeFenced"),c(L)}function j(L,U,q){let F=0;return K;function K(J){return L.enter("lineEnding"),L.consume(J),L.exit("lineEnding"),X}function X(J){return L.enter("codeFencedFence"),markdownSpace(J)?factorySpace(L,Q,"linePrefix",d.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(J):Q(J)}function Q(J){return J===y?(L.enter("codeFencedFenceSequence"),Y(J)):q(J)}function Y(J){return J===y?(F++,L.consume(J),Y):F>=g?(L.exit("codeFencedFenceSequence"),markdownSpace(J)?factorySpace(L,Z,"whitespace")(J):Z(J)):q(J)}function Z(J){return J===null||markdownLineEnding(J)?(L.exit("codeFencedFence"),U(J)):q(J)}}}function tokenizeNonLazyContinuation$1(a,c,u){const d=this;return f;function f(g){return g===null?u(g):(a.enter("lineEnding"),a.consume(g),a.exit("lineEnding"),m)}function m(g){return d.parser.lazy[d.now().line]?u(g):c(g)}}const codeIndented={name:"codeIndented",tokenize:tokenizeCodeIndented},furtherStart={partial:!0,tokenize:tokenizeFurtherStart};function tokenizeCodeIndented(a,c,u){const d=this;return f;function f(E){return a.enter("codeIndented"),factorySpace(a,m,"linePrefix",5)(E)}function m(E){const C=d.events[d.events.length-1];return C&&C[1].type==="linePrefix"&&C[2].sliceSerialize(C[1],!0).length>=4?g(E):u(E)}function g(E){return E===null?b(E):markdownLineEnding(E)?a.attempt(furtherStart,g,b)(E):(a.enter("codeFlowValue"),y(E))}function y(E){return E===null||markdownLineEnding(E)?(a.exit("codeFlowValue"),g(E)):(a.consume(E),y)}function b(E){return a.exit("codeIndented"),c(E)}}function tokenizeFurtherStart(a,c,u){const d=this;return f;function f(g){return d.parser.lazy[d.now().line]?u(g):markdownLineEnding(g)?(a.enter("lineEnding"),a.consume(g),a.exit("lineEnding"),f):factorySpace(a,m,"linePrefix",5)(g)}function m(g){const y=d.events[d.events.length-1];return y&&y[1].type==="linePrefix"&&y[2].sliceSerialize(y[1],!0).length>=4?c(g):markdownLineEnding(g)?f(g):u(g)}}const codeText={name:"codeText",previous:previous$2,resolve:resolveCodeText,tokenize:tokenizeCodeText};function resolveCodeText(a){let c=a.length-4,u=3,d,f;if((a[u][1].type==="lineEnding"||a[u][1].type==="space")&&(a[c][1].type==="lineEnding"||a[c][1].type==="space")){for(d=u;++d<c;)if(a[d][1].type==="codeTextData"){a[u][1].type="codeTextPadding",a[c][1].type="codeTextPadding",u+=2,c-=2;break}}for(d=u-1,c++;++d<=c;)f===void 0?d!==c&&a[d][1].type!=="lineEnding"&&(f=d):(d===c||a[d][1].type==="lineEnding")&&(a[f][1].type="codeTextData",d!==f+2&&(a[f][1].end=a[d-1][1].end,a.splice(f+2,d-f-2),c-=d-f-2,d=f+2),f=void 0);return a}function previous$2(a){return a!==96||this.events[this.events.length-1][1].type==="characterEscape"}function tokenizeCodeText(a,c,u){let d=0,f,m;return g;function g(w){return a.enter("codeText"),a.enter("codeTextSequence"),y(w)}function y(w){return w===96?(a.consume(w),d++,y):(a.exit("codeTextSequence"),b(w))}function b(w){return w===null?u(w):w===32?(a.enter("space"),a.consume(w),a.exit("space"),b):w===96?(m=a.enter("codeTextSequence"),f=0,C(w)):markdownLineEnding(w)?(a.enter("lineEnding"),a.consume(w),a.exit("lineEnding"),b):(a.enter("codeTextData"),E(w))}function E(w){return w===null||w===32||w===96||markdownLineEnding(w)?(a.exit("codeTextData"),b(w)):(a.consume(w),E)}function C(w){return w===96?(a.consume(w),f++,C):f===d?(a.exit("codeTextSequence"),a.exit("codeText"),c(w)):(m.type="codeTextData",E(w))}}class SpliceBuffer{constructor(c){this.left=c?[...c]:[],this.right=[]}get(c){if(c<0||c>=this.left.length+this.right.length)throw new RangeError("Cannot access index `"+c+"` in a splice buffer of size `"+(this.left.length+this.right.length)+"`");return c<this.left.length?this.left[c]:this.right[this.right.length-c+this.left.length-1]}get length(){return this.left.length+this.right.length}shift(){return this.setCursor(0),this.right.pop()}slice(c,u){const d=u??Number.POSITIVE_INFINITY;return d<this.left.length?this.left.slice(c,d):c>this.left.length?this.right.slice(this.right.length-d+this.left.length,this.right.length-c+this.left.length).reverse():this.left.slice(c).concat(this.right.slice(this.right.length-d+this.left.length).reverse())}splice(c,u,d){const f=u||0;this.setCursor(Math.trunc(c));const m=this.right.splice(this.right.length-f,Number.POSITIVE_INFINITY);return d&&chunkedPush(this.left,d),m.reverse()}pop(){return this.setCursor(Number.POSITIVE_INFINITY),this.left.pop()}push(c){this.setCursor(Number.POSITIVE_INFINITY),this.left.push(c)}pushMany(c){this.setCursor(Number.POSITIVE_INFINITY),chunkedPush(this.left,c)}unshift(c){this.setCursor(0),this.right.push(c)}unshiftMany(c){this.setCursor(0),chunkedPush(this.right,c.reverse())}setCursor(c){if(!(c===this.left.length||c>this.left.length&&this.right.length===0||c<0&&this.left.length===0))if(c<this.left.length){const u=this.left.splice(c,Number.POSITIVE_INFINITY);chunkedPush(this.right,u.reverse())}else{const u=this.right.splice(this.left.length+this.right.length-c,Number.POSITIVE_INFINITY);chunkedPush(this.left,u.reverse())}}}function chunkedPush(a,c){let u=0;if(c.length<1e4)a.push(...c);else for(;u<c.length;)a.push(...c.slice(u,u+1e4)),u+=1e4}function subtokenize(a){const c={};let u=-1,d,f,m,g,y,b,E;const C=new SpliceBuffer(a);for(;++u<C.length;){for(;u in c;)u=c[u];if(d=C.get(u),u&&d[1].type==="chunkFlow"&&C.get(u-1)[1].type==="listItemPrefix"&&(b=d[1]._tokenizer.events,m=0,m<b.length&&b[m][1].type==="lineEndingBlank"&&(m+=2),m<b.length&&b[m][1].type==="content"))for(;++m<b.length&&b[m][1].type!=="content";)b[m][1].type==="chunkText"&&(b[m][1]._isInFirstContentOfListItem=!0,m++);if(d[0]==="enter")d[1].contentType&&(Object.assign(c,subcontent(C,u)),u=c[u],E=!0);else if(d[1]._container){for(m=u,f=void 0;m--;)if(g=C.get(m),g[1].type==="lineEnding"||g[1].type==="lineEndingBlank")g[0]==="enter"&&(f&&(C.get(f)[1].type="lineEndingBlank"),g[1].type="lineEnding",f=m);else if(!(g[1].type==="linePrefix"||g[1].type==="listItemIndent"))break;f&&(d[1].end={...C.get(f)[1].start},y=C.slice(f,u),y.unshift(d),C.splice(f,u-f+1,y))}}return splice(a,0,Number.POSITIVE_INFINITY,C.slice(0)),!E}function subcontent(a,c){const u=a.get(c)[1],d=a.get(c)[2];let f=c-1;const m=[];let g=u._tokenizer;g||(g=d.parser[u.contentType](u.start),u._contentTypeTextTrailing&&(g._contentTypeTextTrailing=!0));const y=g.events,b=[],E={};let C,w,R=-1,_=u,M=0,I=0;const N=[I];for(;_;){for(;a.get(++f)[1]!==_;);m.push(f),_._tokenizer||(C=d.sliceStream(_),_.next||C.push(null),w&&g.defineSkip(_.start),_._isInFirstContentOfListItem&&(g._gfmTasklistFirstContentOfListItem=!0),g.write(C),_._isInFirstContentOfListItem&&(g._gfmTasklistFirstContentOfListItem=void 0)),w=_,_=_.next}for(_=u;++R<y.length;)y[R][0]==="exit"&&y[R-1][0]==="enter"&&y[R][1].type===y[R-1][1].type&&y[R][1].start.line!==y[R][1].end.line&&(I=R+1,N.push(I),_._tokenizer=void 0,_.previous=void 0,_=_.next);for(g.events=[],_?(_._tokenizer=void 0,_.previous=void 0):N.pop(),R=N.length;R--;){const A=y.slice(N[R],N[R+1]),P=m.pop();b.push([P,P+A.length-1]),a.splice(P,2,A)}for(b.reverse(),R=-1;++R<b.length;)E[M+b[R][0]]=M+b[R][1],M+=b[R][1]-b[R][0]-1;return E}const content={resolve:resolveContent,tokenize:tokenizeContent},continuationConstruct={partial:!0,tokenize:tokenizeContinuation};function resolveContent(a){return subtokenize(a),a}function tokenizeContent(a,c){let u;return d;function d(y){return a.enter("content"),u=a.enter("chunkContent",{contentType:"content"}),f(y)}function f(y){return y===null?m(y):markdownLineEnding(y)?a.check(continuationConstruct,g,m)(y):(a.consume(y),f)}function m(y){return a.exit("chunkContent"),a.exit("content"),c(y)}function g(y){return a.consume(y),a.exit("chunkContent"),u.next=a.enter("chunkContent",{contentType:"content",previous:u}),u=u.next,f}}function tokenizeContinuation(a,c,u){const d=this;return f;function f(g){return a.exit("chunkContent"),a.enter("lineEnding"),a.consume(g),a.exit("lineEnding"),factorySpace(a,m,"linePrefix")}function m(g){if(g===null||markdownLineEnding(g))return u(g);const y=d.events[d.events.length-1];return!d.parser.constructs.disable.null.includes("codeIndented")&&y&&y[1].type==="linePrefix"&&y[2].sliceSerialize(y[1],!0).length>=4?c(g):a.interrupt(d.parser.constructs.flow,u,c)(g)}}function factoryDestination(a,c,u,d,f,m,g,y,b){const E=b||Number.POSITIVE_INFINITY;let C=0;return w;function w(A){return A===60?(a.enter(d),a.enter(f),a.enter(m),a.consume(A),a.exit(m),R):A===null||A===32||A===41||asciiControl(A)?u(A):(a.enter(d),a.enter(g),a.enter(y),a.enter("chunkString",{contentType:"string"}),I(A))}function R(A){return A===62?(a.enter(m),a.consume(A),a.exit(m),a.exit(f),a.exit(d),c):(a.enter(y),a.enter("chunkString",{contentType:"string"}),_(A))}function _(A){return A===62?(a.exit("chunkString"),a.exit(y),R(A)):A===null||A===60||markdownLineEnding(A)?u(A):(a.consume(A),A===92?M:_)}function M(A){return A===60||A===62||A===92?(a.consume(A),_):_(A)}function I(A){return!C&&(A===null||A===41||markdownLineEndingOrSpace(A))?(a.exit("chunkString"),a.exit(y),a.exit(g),a.exit(d),c(A)):C<E&&A===40?(a.consume(A),C++,I):A===41?(a.consume(A),C--,I):A===null||A===32||A===40||asciiControl(A)?u(A):(a.consume(A),A===92?N:I)}function N(A){return A===40||A===41||A===92?(a.consume(A),I):I(A)}}function factoryLabel(a,c,u,d,f,m){const g=this;let y=0,b;return E;function E(_){return a.enter(d),a.enter(f),a.consume(_),a.exit(f),a.enter(m),C}function C(_){return y>999||_===null||_===91||_===93&&!b||_===94&&!y&&"_hiddenFootnoteSupport"in g.parser.constructs?u(_):_===93?(a.exit(m),a.enter(f),a.consume(_),a.exit(f),a.exit(d),c):markdownLineEnding(_)?(a.enter("lineEnding"),a.consume(_),a.exit("lineEnding"),C):(a.enter("chunkString",{contentType:"string"}),w(_))}function w(_){return _===null||_===91||_===93||markdownLineEnding(_)||y++>999?(a.exit("chunkString"),C(_)):(a.consume(_),b||(b=!markdownSpace(_)),_===92?R:w)}function R(_){return _===91||_===92||_===93?(a.consume(_),y++,w):w(_)}}function factoryTitle(a,c,u,d,f,m){let g;return y;function y(R){return R===34||R===39||R===40?(a.enter(d),a.enter(f),a.consume(R),a.exit(f),g=R===40?41:R,b):u(R)}function b(R){return R===g?(a.enter(f),a.consume(R),a.exit(f),a.exit(d),c):(a.enter(m),E(R))}function E(R){return R===g?(a.exit(m),b(g)):R===null?u(R):markdownLineEnding(R)?(a.enter("lineEnding"),a.consume(R),a.exit("lineEnding"),factorySpace(a,E,"linePrefix")):(a.enter("chunkString",{contentType:"string"}),C(R))}function C(R){return R===g||R===null||markdownLineEnding(R)?(a.exit("chunkString"),E(R)):(a.consume(R),R===92?w:C)}function w(R){return R===g||R===92?(a.consume(R),C):C(R)}}function factoryWhitespace(a,c){let u;return d;function d(f){return markdownLineEnding(f)?(a.enter("lineEnding"),a.consume(f),a.exit("lineEnding"),u=!0,d):markdownSpace(f)?factorySpace(a,d,u?"linePrefix":"lineSuffix")(f):c(f)}}const definition$1={name:"definition",tokenize:tokenizeDefinition},titleBefore={partial:!0,tokenize:tokenizeTitleBefore};function tokenizeDefinition(a,c,u){const d=this;let f;return m;function m(_){return a.enter("definition"),g(_)}function g(_){return factoryLabel.call(d,a,y,u,"definitionLabel","definitionLabelMarker","definitionLabelString")(_)}function y(_){return f=normalizeIdentifier(d.sliceSerialize(d.events[d.events.length-1][1]).slice(1,-1)),_===58?(a.enter("definitionMarker"),a.consume(_),a.exit("definitionMarker"),b):u(_)}function b(_){return markdownLineEndingOrSpace(_)?factoryWhitespace(a,E)(_):E(_)}function E(_){return factoryDestination(a,C,u,"definitionDestination","definitionDestinationLiteral","definitionDestinationLiteralMarker","definitionDestinationRaw","definitionDestinationString")(_)}function C(_){return a.attempt(titleBefore,w,w)(_)}function w(_){return markdownSpace(_)?factorySpace(a,R,"whitespace")(_):R(_)}function R(_){return _===null||markdownLineEnding(_)?(a.exit("definition"),d.parser.defined.push(f),c(_)):u(_)}}function tokenizeTitleBefore(a,c,u){return d;function d(y){return markdownLineEndingOrSpace(y)?factoryWhitespace(a,f)(y):u(y)}function f(y){return factoryTitle(a,m,u,"definitionTitle","definitionTitleMarker","definitionTitleString")(y)}function m(y){return markdownSpace(y)?factorySpace(a,g,"whitespace")(y):g(y)}function g(y){return y===null||markdownLineEnding(y)?c(y):u(y)}}const hardBreakEscape={name:"hardBreakEscape",tokenize:tokenizeHardBreakEscape};function tokenizeHardBreakEscape(a,c,u){return d;function d(m){return a.enter("hardBreakEscape"),a.consume(m),f}function f(m){return markdownLineEnding(m)?(a.exit("hardBreakEscape"),c(m)):u(m)}}const headingAtx={name:"headingAtx",resolve:resolveHeadingAtx,tokenize:tokenizeHeadingAtx};function resolveHeadingAtx(a,c){let u=a.length-2,d=3,f,m;return a[d][1].type==="whitespace"&&(d+=2),u-2>d&&a[u][1].type==="whitespace"&&(u-=2),a[u][1].type==="atxHeadingSequence"&&(d===u-1||u-4>d&&a[u-2][1].type==="whitespace")&&(u-=d+1===u?2:4),u>d&&(f={type:"atxHeadingText",start:a[d][1].start,end:a[u][1].end},m={type:"chunkText",start:a[d][1].start,end:a[u][1].end,contentType:"text"},splice(a,d,u-d+1,[["enter",f,c],["enter",m,c],["exit",m,c],["exit",f,c]])),a}function tokenizeHeadingAtx(a,c,u){let d=0;return f;function f(C){return a.enter("atxHeading"),m(C)}function m(C){return a.enter("atxHeadingSequence"),g(C)}function g(C){return C===35&&d++<6?(a.consume(C),g):C===null||markdownLineEndingOrSpace(C)?(a.exit("atxHeadingSequence"),y(C)):u(C)}function y(C){return C===35?(a.enter("atxHeadingSequence"),b(C)):C===null||markdownLineEnding(C)?(a.exit("atxHeading"),c(C)):markdownSpace(C)?factorySpace(a,y,"whitespace")(C):(a.enter("atxHeadingText"),E(C))}function b(C){return C===35?(a.consume(C),b):(a.exit("atxHeadingSequence"),y(C))}function E(C){return C===null||C===35||markdownLineEndingOrSpace(C)?(a.exit("atxHeadingText"),y(C)):(a.consume(C),E)}}const htmlBlockNames=["address","article","aside","base","basefont","blockquote","body","caption","center","col","colgroup","dd","details","dialog","dir","div","dl","dt","fieldset","figcaption","figure","footer","form","frame","frameset","h1","h2","h3","h4","h5","h6","head","header","hr","html","iframe","legend","li","link","main","menu","menuitem","nav","noframes","ol","optgroup","option","p","param","search","section","summary","table","tbody","td","tfoot","th","thead","title","tr","track","ul"],htmlRawNames=["pre","script","style","textarea"],htmlFlow={concrete:!0,name:"htmlFlow",resolveTo:resolveToHtmlFlow,tokenize:tokenizeHtmlFlow},blankLineBefore={partial:!0,tokenize:tokenizeBlankLineBefore},nonLazyContinuationStart={partial:!0,tokenize:tokenizeNonLazyContinuationStart};function resolveToHtmlFlow(a){let c=a.length;for(;c--&&!(a[c][0]==="enter"&&a[c][1].type==="htmlFlow"););return c>1&&a[c-2][1].type==="linePrefix"&&(a[c][1].start=a[c-2][1].start,a[c+1][1].start=a[c-2][1].start,a.splice(c-2,2)),a}function tokenizeHtmlFlow(a,c,u){const d=this;let f,m,g,y,b;return E;function E(ee){return C(ee)}function C(ee){return a.enter("htmlFlow"),a.enter("htmlFlowData"),a.consume(ee),w}function w(ee){return ee===33?(a.consume(ee),R):ee===47?(a.consume(ee),m=!0,I):ee===63?(a.consume(ee),f=3,d.interrupt?c:V):asciiAlpha(ee)?(a.consume(ee),g=String.fromCharCode(ee),N):u(ee)}function R(ee){return ee===45?(a.consume(ee),f=2,_):ee===91?(a.consume(ee),f=5,y=0,M):asciiAlpha(ee)?(a.consume(ee),f=4,d.interrupt?c:V):u(ee)}function _(ee){return ee===45?(a.consume(ee),d.interrupt?c:V):u(ee)}function M(ee){const ie="CDATA[";return ee===ie.charCodeAt(y++)?(a.consume(ee),y===ie.length?d.interrupt?c:Q:M):u(ee)}function I(ee){return asciiAlpha(ee)?(a.consume(ee),g=String.fromCharCode(ee),N):u(ee)}function N(ee){if(ee===null||ee===47||ee===62||markdownLineEndingOrSpace(ee)){const ie=ee===47,ce=g.toLowerCase();return!ie&&!m&&htmlRawNames.includes(ce)?(f=1,d.interrupt?c(ee):Q(ee)):htmlBlockNames.includes(g.toLowerCase())?(f=6,ie?(a.consume(ee),A):d.interrupt?c(ee):Q(ee)):(f=7,d.interrupt&&!d.parser.lazy[d.now().line]?u(ee):m?P(ee):z(ee))}return ee===45||asciiAlphanumeric(ee)?(a.consume(ee),g+=String.fromCharCode(ee),N):u(ee)}function A(ee){return ee===62?(a.consume(ee),d.interrupt?c:Q):u(ee)}function P(ee){return markdownSpace(ee)?(a.consume(ee),P):K(ee)}function z(ee){return ee===47?(a.consume(ee),K):ee===58||ee===95||asciiAlpha(ee)?(a.consume(ee),B):markdownSpace(ee)?(a.consume(ee),z):K(ee)}function B(ee){return ee===45||ee===46||ee===58||ee===95||asciiAlphanumeric(ee)?(a.consume(ee),B):j(ee)}function j(ee){return ee===61?(a.consume(ee),L):markdownSpace(ee)?(a.consume(ee),j):z(ee)}function L(ee){return ee===null||ee===60||ee===61||ee===62||ee===96?u(ee):ee===34||ee===39?(a.consume(ee),b=ee,U):markdownSpace(ee)?(a.consume(ee),L):q(ee)}function U(ee){return ee===b?(a.consume(ee),b=null,F):ee===null||markdownLineEnding(ee)?u(ee):(a.consume(ee),U)}function q(ee){return ee===null||ee===34||ee===39||ee===47||ee===60||ee===61||ee===62||ee===96||markdownLineEndingOrSpace(ee)?j(ee):(a.consume(ee),q)}function F(ee){return ee===47||ee===62||markdownSpace(ee)?z(ee):u(ee)}function K(ee){return ee===62?(a.consume(ee),X):u(ee)}function X(ee){return ee===null||markdownLineEnding(ee)?Q(ee):markdownSpace(ee)?(a.consume(ee),X):u(ee)}function Q(ee){return ee===45&&f===2?(a.consume(ee),W):ee===60&&f===1?(a.consume(ee),G):ee===62&&f===4?(a.consume(ee),ne):ee===63&&f===3?(a.consume(ee),V):ee===93&&f===5?(a.consume(ee),ae):markdownLineEnding(ee)&&(f===6||f===7)?(a.exit("htmlFlowData"),a.check(blankLineBefore,le,Y)(ee)):ee===null||markdownLineEnding(ee)?(a.exit("htmlFlowData"),Y(ee)):(a.consume(ee),Q)}function Y(ee){return a.check(nonLazyContinuationStart,Z,le)(ee)}function Z(ee){return a.enter("lineEnding"),a.consume(ee),a.exit("lineEnding"),J}function J(ee){return ee===null||markdownLineEnding(ee)?Y(ee):(a.enter("htmlFlowData"),Q(ee))}function W(ee){return ee===45?(a.consume(ee),V):Q(ee)}function G(ee){return ee===47?(a.consume(ee),g="",te):Q(ee)}function te(ee){if(ee===62){const ie=g.toLowerCase();return htmlRawNames.includes(ie)?(a.consume(ee),ne):Q(ee)}return asciiAlpha(ee)&&g.length<8?(a.consume(ee),g+=String.fromCharCode(ee),te):Q(ee)}function ae(ee){return ee===93?(a.consume(ee),V):Q(ee)}function V(ee){return ee===62?(a.consume(ee),ne):ee===45&&f===2?(a.consume(ee),V):Q(ee)}function ne(ee){return ee===null||markdownLineEnding(ee)?(a.exit("htmlFlowData"),le(ee)):(a.consume(ee),ne)}function le(ee){return a.exit("htmlFlow"),c(ee)}}function tokenizeNonLazyContinuationStart(a,c,u){const d=this;return f;function f(g){return markdownLineEnding(g)?(a.enter("lineEnding"),a.consume(g),a.exit("lineEnding"),m):u(g)}function m(g){return d.parser.lazy[d.now().line]?u(g):c(g)}}function tokenizeBlankLineBefore(a,c,u){return d;function d(f){return a.enter("lineEnding"),a.consume(f),a.exit("lineEnding"),a.attempt(blankLine,c,u)}}const htmlText={name:"htmlText",tokenize:tokenizeHtmlText};function tokenizeHtmlText(a,c,u){const d=this;let f,m,g;return y;function y(V){return a.enter("htmlText"),a.enter("htmlTextData"),a.consume(V),b}function b(V){return V===33?(a.consume(V),E):V===47?(a.consume(V),j):V===63?(a.consume(V),z):asciiAlpha(V)?(a.consume(V),q):u(V)}function E(V){return V===45?(a.consume(V),C):V===91?(a.consume(V),m=0,M):asciiAlpha(V)?(a.consume(V),P):u(V)}function C(V){return V===45?(a.consume(V),_):u(V)}function w(V){return V===null?u(V):V===45?(a.consume(V),R):markdownLineEnding(V)?(g=w,G(V)):(a.consume(V),w)}function R(V){return V===45?(a.consume(V),_):w(V)}function _(V){return V===62?W(V):V===45?R(V):w(V)}function M(V){const ne="CDATA[";return V===ne.charCodeAt(m++)?(a.consume(V),m===ne.length?I:M):u(V)}function I(V){return V===null?u(V):V===93?(a.consume(V),N):markdownLineEnding(V)?(g=I,G(V)):(a.consume(V),I)}function N(V){return V===93?(a.consume(V),A):I(V)}function A(V){return V===62?W(V):V===93?(a.consume(V),A):I(V)}function P(V){return V===null||V===62?W(V):markdownLineEnding(V)?(g=P,G(V)):(a.consume(V),P)}function z(V){return V===null?u(V):V===63?(a.consume(V),B):markdownLineEnding(V)?(g=z,G(V)):(a.consume(V),z)}function B(V){return V===62?W(V):z(V)}function j(V){return asciiAlpha(V)?(a.consume(V),L):u(V)}function L(V){return V===45||asciiAlphanumeric(V)?(a.consume(V),L):U(V)}function U(V){return markdownLineEnding(V)?(g=U,G(V)):markdownSpace(V)?(a.consume(V),U):W(V)}function q(V){return V===45||asciiAlphanumeric(V)?(a.consume(V),q):V===47||V===62||markdownLineEndingOrSpace(V)?F(V):u(V)}function F(V){return V===47?(a.consume(V),W):V===58||V===95||asciiAlpha(V)?(a.consume(V),K):markdownLineEnding(V)?(g=F,G(V)):markdownSpace(V)?(a.consume(V),F):W(V)}function K(V){return V===45||V===46||V===58||V===95||asciiAlphanumeric(V)?(a.consume(V),K):X(V)}function X(V){return V===61?(a.consume(V),Q):markdownLineEnding(V)?(g=X,G(V)):markdownSpace(V)?(a.consume(V),X):F(V)}function Q(V){return V===null||V===60||V===61||V===62||V===96?u(V):V===34||V===39?(a.consume(V),f=V,Y):markdownLineEnding(V)?(g=Q,G(V)):markdownSpace(V)?(a.consume(V),Q):(a.consume(V),Z)}function Y(V){return V===f?(a.consume(V),f=void 0,J):V===null?u(V):markdownLineEnding(V)?(g=Y,G(V)):(a.consume(V),Y)}function Z(V){return V===null||V===34||V===39||V===60||V===61||V===96?u(V):V===47||V===62||markdownLineEndingOrSpace(V)?F(V):(a.consume(V),Z)}function J(V){return V===47||V===62||markdownLineEndingOrSpace(V)?F(V):u(V)}function W(V){return V===62?(a.consume(V),a.exit("htmlTextData"),a.exit("htmlText"),c):u(V)}function G(V){return a.exit("htmlTextData"),a.enter("lineEnding"),a.consume(V),a.exit("lineEnding"),te}function te(V){return markdownSpace(V)?factorySpace(a,ae,"linePrefix",d.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(V):ae(V)}function ae(V){return a.enter("htmlTextData"),g(V)}}const labelEnd={name:"labelEnd",resolveAll:resolveAllLabelEnd,resolveTo:resolveToLabelEnd,tokenize:tokenizeLabelEnd},resourceConstruct={tokenize:tokenizeResource},referenceFullConstruct={tokenize:tokenizeReferenceFull},referenceCollapsedConstruct={tokenize:tokenizeReferenceCollapsed};function resolveAllLabelEnd(a){let c=-1;const u=[];for(;++c<a.length;){const d=a[c][1];if(u.push(a[c]),d.type==="labelImage"||d.type==="labelLink"||d.type==="labelEnd"){const f=d.type==="labelImage"?4:2;d.type="data",c+=f}}return a.length!==u.length&&splice(a,0,a.length,u),a}function resolveToLabelEnd(a,c){let u=a.length,d=0,f,m,g,y;for(;u--;)if(f=a[u][1],m){if(f.type==="link"||f.type==="labelLink"&&f._inactive)break;a[u][0]==="enter"&&f.type==="labelLink"&&(f._inactive=!0)}else if(g){if(a[u][0]==="enter"&&(f.type==="labelImage"||f.type==="labelLink")&&!f._balanced&&(m=u,f.type!=="labelLink")){d=2;break}}else f.type==="labelEnd"&&(g=u);const b={type:a[m][1].type==="labelLink"?"link":"image",start:{...a[m][1].start},end:{...a[a.length-1][1].end}},E={type:"label",start:{...a[m][1].start},end:{...a[g][1].end}},C={type:"labelText",start:{...a[m+d+2][1].end},end:{...a[g-2][1].start}};return y=[["enter",b,c],["enter",E,c]],y=push(y,a.slice(m+1,m+d+3)),y=push(y,[["enter",C,c]]),y=push(y,resolveAll(c.parser.constructs.insideSpan.null,a.slice(m+d+4,g-3),c)),y=push(y,[["exit",C,c],a[g-2],a[g-1],["exit",E,c]]),y=push(y,a.slice(g+1)),y=push(y,[["exit",b,c]]),splice(a,m,a.length,y),a}function tokenizeLabelEnd(a,c,u){const d=this;let f=d.events.length,m,g;for(;f--;)if((d.events[f][1].type==="labelImage"||d.events[f][1].type==="labelLink")&&!d.events[f][1]._balanced){m=d.events[f][1];break}return y;function y(R){return m?m._inactive?w(R):(g=d.parser.defined.includes(normalizeIdentifier(d.sliceSerialize({start:m.end,end:d.now()}))),a.enter("labelEnd"),a.enter("labelMarker"),a.consume(R),a.exit("labelMarker"),a.exit("labelEnd"),b):u(R)}function b(R){return R===40?a.attempt(resourceConstruct,C,g?C:w)(R):R===91?a.attempt(referenceFullConstruct,C,g?E:w)(R):g?C(R):w(R)}function E(R){return a.attempt(referenceCollapsedConstruct,C,w)(R)}function C(R){return c(R)}function w(R){return m._balanced=!0,u(R)}}function tokenizeResource(a,c,u){return d;function d(w){return a.enter("resource"),a.enter("resourceMarker"),a.consume(w),a.exit("resourceMarker"),f}function f(w){return markdownLineEndingOrSpace(w)?factoryWhitespace(a,m)(w):m(w)}function m(w){return w===41?C(w):factoryDestination(a,g,y,"resourceDestination","resourceDestinationLiteral","resourceDestinationLiteralMarker","resourceDestinationRaw","resourceDestinationString",32)(w)}function g(w){return markdownLineEndingOrSpace(w)?factoryWhitespace(a,b)(w):C(w)}function y(w){return u(w)}function b(w){return w===34||w===39||w===40?factoryTitle(a,E,u,"resourceTitle","resourceTitleMarker","resourceTitleString")(w):C(w)}function E(w){return markdownLineEndingOrSpace(w)?factoryWhitespace(a,C)(w):C(w)}function C(w){return w===41?(a.enter("resourceMarker"),a.consume(w),a.exit("resourceMarker"),a.exit("resource"),c):u(w)}}function tokenizeReferenceFull(a,c,u){const d=this;return f;function f(y){return factoryLabel.call(d,a,m,g,"reference","referenceMarker","referenceString")(y)}function m(y){return d.parser.defined.includes(normalizeIdentifier(d.sliceSerialize(d.events[d.events.length-1][1]).slice(1,-1)))?c(y):u(y)}function g(y){return u(y)}}function tokenizeReferenceCollapsed(a,c,u){return d;function d(m){return a.enter("reference"),a.enter("referenceMarker"),a.consume(m),a.exit("referenceMarker"),f}function f(m){return m===93?(a.enter("referenceMarker"),a.consume(m),a.exit("referenceMarker"),a.exit("reference"),c):u(m)}}const labelStartImage={name:"labelStartImage",resolveAll:labelEnd.resolveAll,tokenize:tokenizeLabelStartImage};function tokenizeLabelStartImage(a,c,u){const d=this;return f;function f(y){return a.enter("labelImage"),a.enter("labelImageMarker"),a.consume(y),a.exit("labelImageMarker"),m}function m(y){return y===91?(a.enter("labelMarker"),a.consume(y),a.exit("labelMarker"),a.exit("labelImage"),g):u(y)}function g(y){return y===94&&"_hiddenFootnoteSupport"in d.parser.constructs?u(y):c(y)}}const labelStartLink={name:"labelStartLink",resolveAll:labelEnd.resolveAll,tokenize:tokenizeLabelStartLink};function tokenizeLabelStartLink(a,c,u){const d=this;return f;function f(g){return a.enter("labelLink"),a.enter("labelMarker"),a.consume(g),a.exit("labelMarker"),a.exit("labelLink"),m}function m(g){return g===94&&"_hiddenFootnoteSupport"in d.parser.constructs?u(g):c(g)}}const lineEnding={name:"lineEnding",tokenize:tokenizeLineEnding};function tokenizeLineEnding(a,c){return u;function u(d){return a.enter("lineEnding"),a.consume(d),a.exit("lineEnding"),factorySpace(a,c,"linePrefix")}}const thematicBreak$2={name:"thematicBreak",tokenize:tokenizeThematicBreak};function tokenizeThematicBreak(a,c,u){let d=0,f;return m;function m(E){return a.enter("thematicBreak"),g(E)}function g(E){return f=E,y(E)}function y(E){return E===f?(a.enter("thematicBreakSequence"),b(E)):d>=3&&(E===null||markdownLineEnding(E))?(a.exit("thematicBreak"),c(E)):u(E)}function b(E){return E===f?(a.consume(E),d++,b):(a.exit("thematicBreakSequence"),markdownSpace(E)?factorySpace(a,y,"whitespace")(E):y(E))}}const list$2={continuation:{tokenize:tokenizeListContinuation},exit:tokenizeListEnd,name:"list",tokenize:tokenizeListStart},listItemPrefixWhitespaceConstruct={partial:!0,tokenize:tokenizeListItemPrefixWhitespace},indentConstruct={partial:!0,tokenize:tokenizeIndent$1};function tokenizeListStart(a,c,u){const d=this,f=d.events[d.events.length-1];let m=f&&f[1].type==="linePrefix"?f[2].sliceSerialize(f[1],!0).length:0,g=0;return y;function y(_){const M=d.containerState.type||(_===42||_===43||_===45?"listUnordered":"listOrdered");if(M==="listUnordered"?!d.containerState.marker||_===d.containerState.marker:asciiDigit(_)){if(d.containerState.type||(d.containerState.type=M,a.enter(M,{_container:!0})),M==="listUnordered")return a.enter("listItemPrefix"),_===42||_===45?a.check(thematicBreak$2,u,E)(_):E(_);if(!d.interrupt||_===49)return a.enter("listItemPrefix"),a.enter("listItemValue"),b(_)}return u(_)}function b(_){return asciiDigit(_)&&++g<10?(a.consume(_),b):(!d.interrupt||g<2)&&(d.containerState.marker?_===d.containerState.marker:_===41||_===46)?(a.exit("listItemValue"),E(_)):u(_)}function E(_){return a.enter("listItemMarker"),a.consume(_),a.exit("listItemMarker"),d.containerState.marker=d.containerState.marker||_,a.check(blankLine,d.interrupt?u:C,a.attempt(listItemPrefixWhitespaceConstruct,R,w))}function C(_){return d.containerState.initialBlankLine=!0,m++,R(_)}function w(_){return markdownSpace(_)?(a.enter("listItemPrefixWhitespace"),a.consume(_),a.exit("listItemPrefixWhitespace"),R):u(_)}function R(_){return d.containerState.size=m+d.sliceSerialize(a.exit("listItemPrefix"),!0).length,c(_)}}function tokenizeListContinuation(a,c,u){const d=this;return d.containerState._closeFlow=void 0,a.check(blankLine,f,m);function f(y){return d.containerState.furtherBlankLines=d.containerState.furtherBlankLines||d.containerState.initialBlankLine,factorySpace(a,c,"listItemIndent",d.containerState.size+1)(y)}function m(y){return d.containerState.furtherBlankLines||!markdownSpace(y)?(d.containerState.furtherBlankLines=void 0,d.containerState.initialBlankLine=void 0,g(y)):(d.containerState.furtherBlankLines=void 0,d.containerState.initialBlankLine=void 0,a.attempt(indentConstruct,c,g)(y))}function g(y){return d.containerState._closeFlow=!0,d.interrupt=void 0,factorySpace(a,a.attempt(list$2,c,u),"linePrefix",d.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(y)}}function tokenizeIndent$1(a,c,u){const d=this;return factorySpace(a,f,"listItemIndent",d.containerState.size+1);function f(m){const g=d.events[d.events.length-1];return g&&g[1].type==="listItemIndent"&&g[2].sliceSerialize(g[1],!0).length===d.containerState.size?c(m):u(m)}}function tokenizeListEnd(a){a.exit(this.containerState.type)}function tokenizeListItemPrefixWhitespace(a,c,u){const d=this;return factorySpace(a,f,"listItemPrefixWhitespace",d.parser.constructs.disable.null.includes("codeIndented")?void 0:5);function f(m){const g=d.events[d.events.length-1];return!markdownSpace(m)&&g&&g[1].type==="listItemPrefixWhitespace"?c(m):u(m)}}const setextUnderline={name:"setextUnderline",resolveTo:resolveToSetextUnderline,tokenize:tokenizeSetextUnderline};function resolveToSetextUnderline(a,c){let u=a.length,d,f,m;for(;u--;)if(a[u][0]==="enter"){if(a[u][1].type==="content"){d=u;break}a[u][1].type==="paragraph"&&(f=u)}else a[u][1].type==="content"&&a.splice(u,1),!m&&a[u][1].type==="definition"&&(m=u);const g={type:"setextHeading",start:{...a[d][1].start},end:{...a[a.length-1][1].end}};return a[f][1].type="setextHeadingText",m?(a.splice(f,0,["enter",g,c]),a.splice(m+1,0,["exit",a[d][1],c]),a[d][1].end={...a[m][1].end}):a[d][1]=g,a.push(["exit",g,c]),a}function tokenizeSetextUnderline(a,c,u){const d=this;let f;return m;function m(E){let C=d.events.length,w;for(;C--;)if(d.events[C][1].type!=="lineEnding"&&d.events[C][1].type!=="linePrefix"&&d.events[C][1].type!=="content"){w=d.events[C][1].type==="paragraph";break}return!d.parser.lazy[d.now().line]&&(d.interrupt||w)?(a.enter("setextHeadingLine"),f=E,g(E)):u(E)}function g(E){return a.enter("setextHeadingLineSequence"),y(E)}function y(E){return E===f?(a.consume(E),y):(a.exit("setextHeadingLineSequence"),markdownSpace(E)?factorySpace(a,b,"lineSuffix")(E):b(E))}function b(E){return E===null||markdownLineEnding(E)?(a.exit("setextHeadingLine"),c(E)):u(E)}}const flow$1={tokenize:initializeFlow};function initializeFlow(a){const c=this,u=a.attempt(blankLine,d,a.attempt(this.parser.constructs.flowInitial,f,factorySpace(a,a.attempt(this.parser.constructs.flow,f,a.attempt(content,f)),"linePrefix")));return u;function d(m){if(m===null){a.consume(m);return}return a.enter("lineEndingBlank"),a.consume(m),a.exit("lineEndingBlank"),c.currentConstruct=void 0,u}function f(m){if(m===null){a.consume(m);return}return a.enter("lineEnding"),a.consume(m),a.exit("lineEnding"),c.currentConstruct=void 0,u}}const resolver={resolveAll:createResolver()},string$1=initializeFactory("string"),text$7=initializeFactory("text");function initializeFactory(a){return{resolveAll:createResolver(a==="text"?resolveAllLineSuffixes:void 0),tokenize:c};function c(u){const d=this,f=this.parser.constructs[a],m=u.attempt(f,g,y);return g;function g(C){return E(C)?m(C):y(C)}function y(C){if(C===null){u.consume(C);return}return u.enter("data"),u.consume(C),b}function b(C){return E(C)?(u.exit("data"),m(C)):(u.consume(C),b)}function E(C){if(C===null)return!0;const w=f[C];let R=-1;if(w)for(;++R<w.length;){const _=w[R];if(!_.previous||_.previous.call(d,d.previous))return!0}return!1}}}function createResolver(a){return c;function c(u,d){let f=-1,m;for(;++f<=u.length;)m===void 0?u[f]&&u[f][1].type==="data"&&(m=f,f++):(!u[f]||u[f][1].type!=="data")&&(f!==m+2&&(u[m][1].end=u[f-1][1].end,u.splice(m+2,f-m-2),f=m+2),m=void 0);return a?a(u,d):u}}function resolveAllLineSuffixes(a,c){let u=0;for(;++u<=a.length;)if((u===a.length||a[u][1].type==="lineEnding")&&a[u-1][1].type==="data"){const d=a[u-1][1],f=c.sliceStream(d);let m=f.length,g=-1,y=0,b;for(;m--;){const E=f[m];if(typeof E=="string"){for(g=E.length;E.charCodeAt(g-1)===32;)y++,g--;if(g)break;g=-1}else if(E===-2)b=!0,y++;else if(E!==-1){m++;break}}if(c._contentTypeTextTrailing&&u===a.length&&(y=0),y){const E={type:u===a.length||b||y<2?"lineSuffix":"hardBreakTrailing",start:{_bufferIndex:m?g:d.start._bufferIndex+g,_index:d.start._index+m,line:d.end.line,column:d.end.column-y,offset:d.end.offset-y},end:{...d.end}};d.end={...E.start},d.start.offset===d.end.offset?Object.assign(d,E):(a.splice(u,0,["enter",E,c],["exit",E,c]),u+=2)}u++}return a}const document$1={42:list$2,43:list$2,45:list$2,48:list$2,49:list$2,50:list$2,51:list$2,52:list$2,53:list$2,54:list$2,55:list$2,56:list$2,57:list$2,62:blockQuote},contentInitial={91:definition$1},flowInitial={[-2]:codeIndented,[-1]:codeIndented,32:codeIndented},flow={35:headingAtx,42:thematicBreak$2,45:[setextUnderline,thematicBreak$2],60:htmlFlow,61:setextUnderline,95:thematicBreak$2,96:codeFenced,126:codeFenced},string={38:characterReference,92:characterEscape},text$6={[-5]:lineEnding,[-4]:lineEnding,[-3]:lineEnding,33:labelStartImage,38:characterReference,42:attention,60:[autolink,htmlText],91:labelStartLink,92:[hardBreakEscape,characterEscape],93:labelEnd,95:attention,96:codeText},insideSpan={null:[attention,resolver]},attentionMarkers={null:[42,95]},disable={null:[]},defaultConstructs=Object.freeze(Object.defineProperty({__proto__:null,attentionMarkers,contentInitial,disable,document:document$1,flow,flowInitial,insideSpan,string,text:text$6},Symbol.toStringTag,{value:"Module"}));function createTokenizer(a,c,u){let d={_bufferIndex:-1,_index:0,line:u&&u.line||1,column:u&&u.column||1,offset:u&&u.offset||0};const f={},m=[];let g=[],y=[];const b={attempt:U(j),check:U(L),consume:P,enter:z,exit:B,interrupt:U(L,{interrupt:!0})},E={code:null,containerState:{},defineSkip:I,events:[],now:M,parser:a,previous:null,sliceSerialize:R,sliceStream:_,write:w};let C=c.tokenize.call(E,b);return c.resolveAll&&m.push(c),E;function w(X){return g=push(g,X),N(),g[g.length-1]!==null?[]:(q(c,0),E.events=resolveAll(m,E.events,E),E.events)}function R(X,Q){return serializeChunks(_(X),Q)}function _(X){return sliceChunks(g,X)}function M(){const{_bufferIndex:X,_index:Q,line:Y,column:Z,offset:J}=d;return{_bufferIndex:X,_index:Q,line:Y,column:Z,offset:J}}function I(X){f[X.line]=X.column,K()}function N(){let X;for(;d._index<g.length;){const Q=g[d._index];if(typeof Q=="string")for(X=d._index,d._bufferIndex<0&&(d._bufferIndex=0);d._index===X&&d._bufferIndex<Q.length;)A(Q.charCodeAt(d._bufferIndex));else A(Q)}}function A(X){C=C(X)}function P(X){markdownLineEnding(X)?(d.line++,d.column=1,d.offset+=X===-3?2:1,K()):X!==-1&&(d.column++,d.offset++),d._bufferIndex<0?d._index++:(d._bufferIndex++,d._bufferIndex===g[d._index].length&&(d._bufferIndex=-1,d._index++)),E.previous=X}function z(X,Q){const Y=Q||{};return Y.type=X,Y.start=M(),E.events.push(["enter",Y,E]),y.push(Y),Y}function B(X){const Q=y.pop();return Q.end=M(),E.events.push(["exit",Q,E]),Q}function j(X,Q){q(X,Q.from)}function L(X,Q){Q.restore()}function U(X,Q){return Y;function Y(Z,J,W){let G,te,ae,V;return Array.isArray(Z)?le(Z):"tokenize"in Z?le([Z]):ne(Z);function ne(ue){return me;function me(de){const ge=de!==null&&ue[de],Ce=de!==null&&ue.null,ve=[...Array.isArray(ge)?ge:ge?[ge]:[],...Array.isArray(Ce)?Ce:Ce?[Ce]:[]];return le(ve)(de)}}function le(ue){return G=ue,te=0,ue.length===0?W:ee(ue[te])}function ee(ue){return me;function me(de){return V=F(),ae=ue,ue.partial||(E.currentConstruct=ue),ue.name&&E.parser.constructs.disable.null.includes(ue.name)?ce():ue.tokenize.call(Q?Object.assign(Object.create(E),Q):E,b,ie,ce)(de)}}function ie(ue){return X(ae,V),J}function ce(ue){return V.restore(),++te<G.length?ee(G[te]):W}}}function q(X,Q){X.resolveAll&&!m.includes(X)&&m.push(X),X.resolve&&splice(E.events,Q,E.events.length-Q,X.resolve(E.events.slice(Q),E)),X.resolveTo&&(E.events=X.resolveTo(E.events,E))}function F(){const X=M(),Q=E.previous,Y=E.currentConstruct,Z=E.events.length,J=Array.from(y);return{from:Z,restore:W};function W(){d=X,E.previous=Q,E.currentConstruct=Y,E.events.length=Z,y=J,K()}}function K(){d.line in f&&d.column<2&&(d.column=f[d.line],d.offset+=f[d.line]-1)}}function sliceChunks(a,c){const u=c.start._index,d=c.start._bufferIndex,f=c.end._index,m=c.end._bufferIndex;let g;if(u===f)g=[a[u].slice(d,m)];else{if(g=a.slice(u,f),d>-1){const y=g[0];typeof y=="string"?g[0]=y.slice(d):g.shift()}m>0&&g.push(a[f].slice(0,m))}return g}function serializeChunks(a,c){let u=-1;const d=[];let f;for(;++u<a.length;){const m=a[u];let g;if(typeof m=="string")g=m;else switch(m){case-5:{g="\r";break}case-4:{g=`
`;break}case-3:{g=`\r
`;break}case-2:{g=c?" ":"	";break}case-1:{if(!c&&f)continue;g=" ";break}default:g=String.fromCharCode(m)}f=m===-2,d.push(g)}return d.join("")}function parse(a){const d={constructs:combineExtensions([defaultConstructs,...(a||{}).extensions||[]]),content:f(content$1),defined:[],document:f(document$2),flow:f(flow$1),lazy:{},string:f(string$1),text:f(text$7)};return d;function f(m){return g;function g(y){return createTokenizer(d,m,y)}}}function postprocess(a){for(;!subtokenize(a););return a}const search$1=/[\0\t\n\r]/g;function preprocess(){let a=1,c="",u=!0,d;return f;function f(m,g,y){const b=[];let E,C,w,R,_;for(m=c+(typeof m=="string"?m.toString():new TextDecoder(g||void 0).decode(m)),w=0,c="",u&&(m.charCodeAt(0)===65279&&w++,u=void 0);w<m.length;){if(search$1.lastIndex=w,E=search$1.exec(m),R=E&&E.index!==void 0?E.index:m.length,_=m.charCodeAt(R),!E){c=m.slice(w);break}if(_===10&&w===R&&d)b.push(-3),d=void 0;else switch(d&&(b.push(-5),d=void 0),w<R&&(b.push(m.slice(w,R)),a+=R-w),_){case 0:{b.push(65533),a++;break}case 9:{for(C=Math.ceil(a/4)*4,b.push(-2);a++<C;)b.push(-1);break}case 10:{b.push(-4),a=1;break}default:d=!0,a=1}w=R+1}return y&&(d&&b.push(-5),c&&b.push(c),b.push(null)),b}}const characterEscapeOrReference=/\\([!-/:-@[-`{-~])|&(#(?:\d{1,7}|x[\da-f]{1,6})|[\da-z]{1,31});/gi;function decodeString(a){return a.replace(characterEscapeOrReference,decode)}function decode(a,c,u){if(c)return c;if(u.charCodeAt(0)===35){const f=u.charCodeAt(1),m=f===120||f===88;return decodeNumericCharacterReference(u.slice(m?2:1),m?16:10)}return decodeNamedCharacterReference(u)||a}const own$2={}.hasOwnProperty;function fromMarkdown(a,c,u){return typeof c!="string"&&(u=c,c=void 0),compiler(u)(postprocess(parse(u).document().write(preprocess()(a,c,!0))))}function compiler(a){const c={transforms:[],canContainEols:["emphasis","fragment","heading","paragraph","strong"],enter:{autolink:m(De),autolinkProtocol:F,autolinkEmail:F,atxHeading:m(ye),blockQuote:m(Ce),characterEscape:F,characterReference:F,codeFenced:m(ve),codeFencedFenceInfo:g,codeFencedFenceMeta:g,codeIndented:m(ve,g),codeText:m(fe,g),codeTextData:F,data:F,codeFlowValue:F,definition:m(pe),definitionDestinationString:g,definitionLabelString:g,definitionTitleString:g,emphasis:m(xe),hardBreakEscape:m(he),hardBreakTrailing:m(he),htmlFlow:m(we,g),htmlFlowData:F,htmlText:m(we,g),htmlTextData:F,image:m(Re),label:g,link:m(De),listItem:m(Ee),listItemValue:R,listOrdered:m(Ae,w),listUnordered:m(Ae),paragraph:m(Ne),reference:ee,referenceString:g,resourceDestinationString:g,resourceTitleString:g,setextHeading:m(ye),strong:m(_e),thematicBreak:m(Ke)},exit:{atxHeading:b(),atxHeadingSequence:j,autolink:b(),autolinkEmail:ge,autolinkProtocol:de,blockQuote:b(),characterEscapeValue:K,characterReferenceMarkerHexadecimal:ce,characterReferenceMarkerNumeric:ce,characterReferenceValue:ue,characterReference:me,codeFenced:b(N),codeFencedFence:I,codeFencedFenceInfo:_,codeFencedFenceMeta:M,codeFlowValue:K,codeIndented:b(A),codeText:b(J),codeTextData:K,data:K,definition:b(),definitionDestinationString:B,definitionLabelString:P,definitionTitleString:z,emphasis:b(),hardBreakEscape:b(Q),hardBreakTrailing:b(Q),htmlFlow:b(Y),htmlFlowData:K,htmlText:b(Z),htmlTextData:K,image:b(G),label:ae,labelText:te,lineEnding:X,link:b(W),listItem:b(),listOrdered:b(),listUnordered:b(),paragraph:b(),referenceString:ie,resourceDestinationString:V,resourceTitleString:ne,resource:le,setextHeading:b(q),setextHeadingLineSequence:U,setextHeadingText:L,strong:b(),thematicBreak:b()}};configure(c,(a||{}).mdastExtensions||[]);const u={};return d;function d(be){let Te={type:"root",children:[]};const Le={stack:[Te],tokenStack:[],config:c,enter:y,exit:E,buffer:g,resume:C,data:u},Oe=[];let Be=-1;for(;++Be<be.length;)if(be[Be][1].type==="listOrdered"||be[Be][1].type==="listUnordered")if(be[Be][0]==="enter")Oe.push(Be);else{const Ve=Oe.pop();Be=f(be,Ve,Be)}for(Be=-1;++Be<be.length;){const Ve=c[be[Be][0]];own$2.call(Ve,be[Be][1].type)&&Ve[be[Be][1].type].call(Object.assign({sliceSerialize:be[Be][2].sliceSerialize},Le),be[Be][1])}if(Le.tokenStack.length>0){const Ve=Le.tokenStack[Le.tokenStack.length-1];(Ve[1]||defaultOnError).call(Le,void 0,Ve[0])}for(Te.position={start:point(be.length>0?be[0][1].start:{line:1,column:1,offset:0}),end:point(be.length>0?be[be.length-2][1].end:{line:1,column:1,offset:0})},Be=-1;++Be<c.transforms.length;)Te=c.transforms[Be](Te)||Te;return Te}function f(be,Te,Le){let Oe=Te-1,Be=-1,Ve=!1,Pe,Ge,qe,Ue;for(;++Oe<=Le;){const je=be[Oe];switch(je[1].type){case"listUnordered":case"listOrdered":case"blockQuote":{je[0]==="enter"?Be++:Be--,Ue=void 0;break}case"lineEndingBlank":{je[0]==="enter"&&(Pe&&!Ue&&!Be&&!qe&&(qe=Oe),Ue=void 0);break}case"linePrefix":case"listItemValue":case"listItemMarker":case"listItemPrefix":case"listItemPrefixWhitespace":break;default:Ue=void 0}if(!Be&&je[0]==="enter"&&je[1].type==="listItemPrefix"||Be===-1&&je[0]==="exit"&&(je[1].type==="listUnordered"||je[1].type==="listOrdered")){if(Pe){let We=Oe;for(Ge=void 0;We--;){const ut=be[We];if(ut[1].type==="lineEnding"||ut[1].type==="lineEndingBlank"){if(ut[0]==="exit")continue;Ge&&(be[Ge][1].type="lineEndingBlank",Ve=!0),ut[1].type="lineEnding",Ge=We}else if(!(ut[1].type==="linePrefix"||ut[1].type==="blockQuotePrefix"||ut[1].type==="blockQuotePrefixWhitespace"||ut[1].type==="blockQuoteMarker"||ut[1].type==="listItemIndent"))break}qe&&(!Ge||qe<Ge)&&(Pe._spread=!0),Pe.end=Object.assign({},Ge?be[Ge][1].start:je[1].end),be.splice(Ge||Oe,0,["exit",Pe,je[2]]),Oe++,Le++}if(je[1].type==="listItemPrefix"){const We={type:"listItem",_spread:!1,start:Object.assign({},je[1].start),end:void 0};Pe=We,be.splice(Oe,0,["enter",We,je[2]]),Oe++,Le++,qe=void 0,Ue=!0}}}return be[Te][1]._spread=Ve,Le}function m(be,Te){return Le;function Le(Oe){y.call(this,be(Oe),Oe),Te&&Te.call(this,Oe)}}function g(){this.stack.push({type:"fragment",children:[]})}function y(be,Te,Le){this.stack[this.stack.length-1].children.push(be),this.stack.push(be),this.tokenStack.push([Te,Le||void 0]),be.position={start:point(Te.start),end:void 0}}function b(be){return Te;function Te(Le){be&&be.call(this,Le),E.call(this,Le)}}function E(be,Te){const Le=this.stack.pop(),Oe=this.tokenStack.pop();if(Oe)Oe[0].type!==be.type&&(Te?Te.call(this,be,Oe[0]):(Oe[1]||defaultOnError).call(this,be,Oe[0]));else throw new Error("Cannot close `"+be.type+"` ("+stringifyPosition({start:be.start,end:be.end})+"): it’s not open");Le.position.end=point(be.end)}function C(){return toString$1(this.stack.pop())}function w(){this.data.expectingFirstListItemValue=!0}function R(be){if(this.data.expectingFirstListItemValue){const Te=this.stack[this.stack.length-2];Te.start=Number.parseInt(this.sliceSerialize(be),10),this.data.expectingFirstListItemValue=void 0}}function _(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.lang=be}function M(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.meta=be}function I(){this.data.flowCodeInside||(this.buffer(),this.data.flowCodeInside=!0)}function N(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.value=be.replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),this.data.flowCodeInside=void 0}function A(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.value=be.replace(/(\r?\n|\r)$/g,"")}function P(be){const Te=this.resume(),Le=this.stack[this.stack.length-1];Le.label=Te,Le.identifier=normalizeIdentifier(this.sliceSerialize(be)).toLowerCase()}function z(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.title=be}function B(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.url=be}function j(be){const Te=this.stack[this.stack.length-1];if(!Te.depth){const Le=this.sliceSerialize(be).length;Te.depth=Le}}function L(){this.data.setextHeadingSlurpLineEnding=!0}function U(be){const Te=this.stack[this.stack.length-1];Te.depth=this.sliceSerialize(be).codePointAt(0)===61?1:2}function q(){this.data.setextHeadingSlurpLineEnding=void 0}function F(be){const Le=this.stack[this.stack.length-1].children;let Oe=Le[Le.length-1];(!Oe||Oe.type!=="text")&&(Oe=ke(),Oe.position={start:point(be.start),end:void 0},Le.push(Oe)),this.stack.push(Oe)}function K(be){const Te=this.stack.pop();Te.value+=this.sliceSerialize(be),Te.position.end=point(be.end)}function X(be){const Te=this.stack[this.stack.length-1];if(this.data.atHardBreak){const Le=Te.children[Te.children.length-1];Le.position.end=point(be.end),this.data.atHardBreak=void 0;return}!this.data.setextHeadingSlurpLineEnding&&c.canContainEols.includes(Te.type)&&(F.call(this,be),K.call(this,be))}function Q(){this.data.atHardBreak=!0}function Y(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.value=be}function Z(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.value=be}function J(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.value=be}function W(){const be=this.stack[this.stack.length-1];if(this.data.inReference){const Te=this.data.referenceType||"shortcut";be.type+="Reference",be.referenceType=Te,delete be.url,delete be.title}else delete be.identifier,delete be.label;this.data.referenceType=void 0}function G(){const be=this.stack[this.stack.length-1];if(this.data.inReference){const Te=this.data.referenceType||"shortcut";be.type+="Reference",be.referenceType=Te,delete be.url,delete be.title}else delete be.identifier,delete be.label;this.data.referenceType=void 0}function te(be){const Te=this.sliceSerialize(be),Le=this.stack[this.stack.length-2];Le.label=decodeString(Te),Le.identifier=normalizeIdentifier(Te).toLowerCase()}function ae(){const be=this.stack[this.stack.length-1],Te=this.resume(),Le=this.stack[this.stack.length-1];if(this.data.inReference=!0,Le.type==="link"){const Oe=be.children;Le.children=Oe}else Le.alt=Te}function V(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.url=be}function ne(){const be=this.resume(),Te=this.stack[this.stack.length-1];Te.title=be}function le(){this.data.inReference=void 0}function ee(){this.data.referenceType="collapsed"}function ie(be){const Te=this.resume(),Le=this.stack[this.stack.length-1];Le.label=Te,Le.identifier=normalizeIdentifier(this.sliceSerialize(be)).toLowerCase(),this.data.referenceType="full"}function ce(be){this.data.characterReferenceType=be.type}function ue(be){const Te=this.sliceSerialize(be),Le=this.data.characterReferenceType;let Oe;Le?(Oe=decodeNumericCharacterReference(Te,Le==="characterReferenceMarkerNumeric"?10:16),this.data.characterReferenceType=void 0):Oe=decodeNamedCharacterReference(Te);const Be=this.stack[this.stack.length-1];Be.value+=Oe}function me(be){const Te=this.stack.pop();Te.position.end=point(be.end)}function de(be){K.call(this,be);const Te=this.stack[this.stack.length-1];Te.url=this.sliceSerialize(be)}function ge(be){K.call(this,be);const Te=this.stack[this.stack.length-1];Te.url="mailto:"+this.sliceSerialize(be)}function Ce(){return{type:"blockquote",children:[]}}function ve(){return{type:"code",lang:null,meta:null,value:""}}function fe(){return{type:"inlineCode",value:""}}function pe(){return{type:"definition",identifier:"",label:null,title:null,url:""}}function xe(){return{type:"emphasis",children:[]}}function ye(){return{type:"heading",depth:0,children:[]}}function he(){return{type:"break"}}function we(){return{type:"html",value:""}}function Re(){return{type:"image",title:null,url:"",alt:null}}function De(){return{type:"link",title:null,url:"",children:[]}}function Ae(be){return{type:"list",ordered:be.type==="listOrdered",start:null,spread:be._spread,children:[]}}function Ee(be){return{type:"listItem",spread:be._spread,checked:null,children:[]}}function Ne(){return{type:"paragraph",children:[]}}function _e(){return{type:"strong",children:[]}}function ke(){return{type:"text",value:""}}function Ke(){return{type:"thematicBreak"}}}function point(a){return{line:a.line,column:a.column,offset:a.offset}}function configure(a,c){let u=-1;for(;++u<c.length;){const d=c[u];Array.isArray(d)?configure(a,d):extension(a,d)}}function extension(a,c){let u;for(u in c)if(own$2.call(c,u))switch(u){case"canContainEols":{const d=c[u];d&&a[u].push(...d);break}case"transforms":{const d=c[u];d&&a[u].push(...d);break}case"enter":case"exit":{const d=c[u];d&&Object.assign(a[u],d);break}}}function defaultOnError(a,c){throw a?new Error("Cannot close `"+a.type+"` ("+stringifyPosition({start:a.start,end:a.end})+"): a different token (`"+c.type+"`, "+stringifyPosition({start:c.start,end:c.end})+") is open"):new Error("Cannot close document, a token (`"+c.type+"`, "+stringifyPosition({start:c.start,end:c.end})+") is still open")}function remarkParse(a){const c=this;c.parser=u;function u(d){return fromMarkdown(d,{...c.data("settings"),...a,extensions:c.data("micromarkExtensions")||[],mdastExtensions:c.data("fromMarkdownExtensions")||[]})}}function blockquote$1(a,c){const u={type:"element",tagName:"blockquote",properties:{},children:a.wrap(a.all(c),!0)};return a.patch(c,u),a.applyData(c,u)}function hardBreak$1(a,c){const u={type:"element",tagName:"br",properties:{},children:[]};return a.patch(c,u),[a.applyData(c,u),{type:"text",value:`
`}]}function code$2(a,c){const u=c.value?c.value+`
`:"",d={};c.lang&&(d.className=["language-"+c.lang]);let f={type:"element",tagName:"code",properties:d,children:[{type:"text",value:u}]};return c.meta&&(f.data={meta:c.meta}),a.patch(c,f),f=a.applyData(c,f),f={type:"element",tagName:"pre",properties:{},children:[f]},a.patch(c,f),f}function strikethrough(a,c){const u={type:"element",tagName:"del",properties:{},children:a.all(c)};return a.patch(c,u),a.applyData(c,u)}function emphasis$1(a,c){const u={type:"element",tagName:"em",properties:{},children:a.all(c)};return a.patch(c,u),a.applyData(c,u)}function footnoteReference$1(a,c){const u=typeof a.options.clobberPrefix=="string"?a.options.clobberPrefix:"user-content-",d=String(c.identifier).toUpperCase(),f=normalizeUri(d.toLowerCase()),m=a.footnoteOrder.indexOf(d);let g,y=a.footnoteCounts.get(d);y===void 0?(y=0,a.footnoteOrder.push(d),g=a.footnoteOrder.length):g=m+1,y+=1,a.footnoteCounts.set(d,y);const b={type:"element",tagName:"a",properties:{href:"#"+u+"fn-"+f,id:u+"fnref-"+f+(y>1?"-"+y:""),dataFootnoteRef:!0,ariaDescribedBy:["footnote-label"]},children:[{type:"text",value:String(g)}]};a.patch(c,b);const E={type:"element",tagName:"sup",properties:{},children:[b]};return a.patch(c,E),a.applyData(c,E)}function heading$1(a,c){const u={type:"element",tagName:"h"+c.depth,properties:{},children:a.all(c)};return a.patch(c,u),a.applyData(c,u)}function html$1(a,c){if(a.options.allowDangerousHtml){const u={type:"raw",value:c.value};return a.patch(c,u),a.applyData(c,u)}}function revert(a,c){const u=c.referenceType;let d="]";if(u==="collapsed"?d+="[]":u==="full"&&(d+="["+(c.label||c.identifier)+"]"),c.type==="imageReference")return[{type:"text",value:"!["+c.alt+d}];const f=a.all(c),m=f[0];m&&m.type==="text"?m.value="["+m.value:f.unshift({type:"text",value:"["});const g=f[f.length-1];return g&&g.type==="text"?g.value+=d:f.push({type:"text",value:d}),f}function imageReference$1(a,c){const u=String(c.identifier).toUpperCase(),d=a.definitionById.get(u);if(!d)return revert(a,c);const f={src:normalizeUri(d.url||""),alt:c.alt};d.title!==null&&d.title!==void 0&&(f.title=d.title);const m={type:"element",tagName:"img",properties:f,children:[]};return a.patch(c,m),a.applyData(c,m)}function image$1(a,c){const u={src:normalizeUri(c.url)};c.alt!==null&&c.alt!==void 0&&(u.alt=c.alt),c.title!==null&&c.title!==void 0&&(u.title=c.title);const d={type:"element",tagName:"img",properties:u,children:[]};return a.patch(c,d),a.applyData(c,d)}function inlineCode$1(a,c){const u={type:"text",value:c.value.replace(/\r?\n|\r/g," ")};a.patch(c,u);const d={type:"element",tagName:"code",properties:{},children:[u]};return a.patch(c,d),a.applyData(c,d)}function linkReference$1(a,c){const u=String(c.identifier).toUpperCase(),d=a.definitionById.get(u);if(!d)return revert(a,c);const f={href:normalizeUri(d.url||"")};d.title!==null&&d.title!==void 0&&(f.title=d.title);const m={type:"element",tagName:"a",properties:f,children:a.all(c)};return a.patch(c,m),a.applyData(c,m)}function link$1(a,c){const u={href:normalizeUri(c.url)};c.title!==null&&c.title!==void 0&&(u.title=c.title);const d={type:"element",tagName:"a",properties:u,children:a.all(c)};return a.patch(c,d),a.applyData(c,d)}function listItem$1(a,c,u){const d=a.all(c),f=u?listLoose(u):listItemLoose(c),m={},g=[];if(typeof c.checked=="boolean"){const C=d[0];let w;C&&C.type==="element"&&C.tagName==="p"?w=C:(w={type:"element",tagName:"p",properties:{},children:[]},d.unshift(w)),w.children.length>0&&w.children.unshift({type:"text",value:" "}),w.children.unshift({type:"element",tagName:"input",properties:{type:"checkbox",checked:c.checked,disabled:!0},children:[]}),m.className=["task-list-item"]}let y=-1;for(;++y<d.length;){const C=d[y];(f||y!==0||C.type!=="element"||C.tagName!=="p")&&g.push({type:"text",value:`
`}),C.type==="element"&&C.tagName==="p"&&!f?g.push(...C.children):g.push(C)}const b=d[d.length-1];b&&(f||b.type!=="element"||b.tagName!=="p")&&g.push({type:"text",value:`
`});const E={type:"element",tagName:"li",properties:m,children:g};return a.patch(c,E),a.applyData(c,E)}function listLoose(a){let c=!1;if(a.type==="list"){c=a.spread||!1;const u=a.children;let d=-1;for(;!c&&++d<u.length;)c=listItemLoose(u[d])}return c}function listItemLoose(a){const c=a.spread;return c??a.children.length>1}function list$1(a,c){const u={},d=a.all(c);let f=-1;for(typeof c.start=="number"&&c.start!==1&&(u.start=c.start);++f<d.length;){const g=d[f];if(g.type==="element"&&g.tagName==="li"&&g.properties&&Array.isArray(g.properties.className)&&g.properties.className.includes("task-list-item")){u.className=["contains-task-list"];break}}const m={type:"element",tagName:c.ordered?"ol":"ul",properties:u,children:a.wrap(d,!0)};return a.patch(c,m),a.applyData(c,m)}function paragraph$1(a,c){const u={type:"element",tagName:"p",properties:{},children:a.all(c)};return a.patch(c,u),a.applyData(c,u)}function root$2(a,c){const u={type:"root",children:a.wrap(a.all(c))};return a.patch(c,u),a.applyData(c,u)}function strong$1(a,c){const u={type:"element",tagName:"strong",properties:{},children:a.all(c)};return a.patch(c,u),a.applyData(c,u)}function table(a,c){const u=a.all(c),d=u.shift(),f=[];if(d){const g={type:"element",tagName:"thead",properties:{},children:a.wrap([d],!0)};a.patch(c.children[0],g),f.push(g)}if(u.length>0){const g={type:"element",tagName:"tbody",properties:{},children:a.wrap(u,!0)},y=pointStart(c.children[1]),b=pointEnd(c.children[c.children.length-1]);y&&b&&(g.position={start:y,end:b}),f.push(g)}const m={type:"element",tagName:"table",properties:{},children:a.wrap(f,!0)};return a.patch(c,m),a.applyData(c,m)}function tableRow(a,c,u){const d=u?u.children:void 0,m=(d?d.indexOf(c):1)===0?"th":"td",g=u&&u.type==="table"?u.align:void 0,y=g?g.length:c.children.length;let b=-1;const E=[];for(;++b<y;){const w=c.children[b],R={},_=g?g[b]:void 0;_&&(R.align=_);let M={type:"element",tagName:m,properties:R,children:[]};w&&(M.children=a.all(w),a.patch(w,M),M=a.applyData(w,M)),E.push(M)}const C={type:"element",tagName:"tr",properties:{},children:a.wrap(E,!0)};return a.patch(c,C),a.applyData(c,C)}function tableCell(a,c){const u={type:"element",tagName:"td",properties:{},children:a.all(c)};return a.patch(c,u),a.applyData(c,u)}const tab=9,space=32;function trimLines(a){const c=String(a),u=/\r?\n|\r/g;let d=u.exec(c),f=0;const m=[];for(;d;)m.push(trimLine(c.slice(f,d.index),f>0,!0),d[0]),f=d.index+d[0].length,d=u.exec(c);return m.push(trimLine(c.slice(f),f>0,!1)),m.join("")}function trimLine(a,c,u){let d=0,f=a.length;if(c){let m=a.codePointAt(d);for(;m===tab||m===space;)d++,m=a.codePointAt(d)}if(u){let m=a.codePointAt(f-1);for(;m===tab||m===space;)f--,m=a.codePointAt(f-1)}return f>d?a.slice(d,f):""}function text$5(a,c){const u={type:"text",value:trimLines(String(c.value))};return a.patch(c,u),a.applyData(c,u)}function thematicBreak$1(a,c){const u={type:"element",tagName:"hr",properties:{},children:[]};return a.patch(c,u),a.applyData(c,u)}const handlers={blockquote:blockquote$1,break:hardBreak$1,code:code$2,delete:strikethrough,emphasis:emphasis$1,footnoteReference:footnoteReference$1,heading:heading$1,html:html$1,imageReference:imageReference$1,image:image$1,inlineCode:inlineCode$1,linkReference:linkReference$1,link:link$1,listItem:listItem$1,list:list$1,paragraph:paragraph$1,root:root$2,strong:strong$1,table,tableCell,tableRow,text:text$5,thematicBreak:thematicBreak$1,toml:ignore,yaml:ignore,definition:ignore,footnoteDefinition:ignore};function ignore(){}const VOID=-1,PRIMITIVE=0,ARRAY=1,OBJECT=2,DATE=3,REGEXP=4,MAP=5,SET=6,ERROR=7,BIGINT=8,env=typeof self=="object"?self:globalThis,deserializer=(a,c)=>{const u=(f,m)=>(a.set(m,f),f),d=f=>{if(a.has(f))return a.get(f);const[m,g]=c[f];switch(m){case PRIMITIVE:case VOID:return u(g,f);case ARRAY:{const y=u([],f);for(const b of g)y.push(d(b));return y}case OBJECT:{const y=u({},f);for(const[b,E]of g)y[d(b)]=d(E);return y}case DATE:return u(new Date(g),f);case REGEXP:{const{source:y,flags:b}=g;return u(new RegExp(y,b),f)}case MAP:{const y=u(new Map,f);for(const[b,E]of g)y.set(d(b),d(E));return y}case SET:{const y=u(new Set,f);for(const b of g)y.add(d(b));return y}case ERROR:{const{name:y,message:b}=g;return u(new env[y](b),f)}case BIGINT:return u(BigInt(g),f);case"BigInt":return u(Object(BigInt(g)),f);case"ArrayBuffer":return u(new Uint8Array(g).buffer,g);case"DataView":{const{buffer:y}=new Uint8Array(g);return u(new DataView(y),g)}}return u(new env[m](g),f)};return d},deserialize=a=>deserializer(new Map,a)(0),EMPTY="",{toString}={},{keys}=Object,typeOf=a=>{const c=typeof a;if(c!=="object"||!a)return[PRIMITIVE,c];const u=toString.call(a).slice(8,-1);switch(u){case"Array":return[ARRAY,EMPTY];case"Object":return[OBJECT,EMPTY];case"Date":return[DATE,EMPTY];case"RegExp":return[REGEXP,EMPTY];case"Map":return[MAP,EMPTY];case"Set":return[SET,EMPTY];case"DataView":return[ARRAY,u]}return u.includes("Array")?[ARRAY,u]:u.includes("Error")?[ERROR,u]:[OBJECT,u]},shouldSkip=([a,c])=>a===PRIMITIVE&&(c==="function"||c==="symbol"),serializer=(a,c,u,d)=>{const f=(g,y)=>{const b=d.push(g)-1;return u.set(y,b),b},m=g=>{if(u.has(g))return u.get(g);let[y,b]=typeOf(g);switch(y){case PRIMITIVE:{let C=g;switch(b){case"bigint":y=BIGINT,C=g.toString();break;case"function":case"symbol":if(a)throw new TypeError("unable to serialize "+b);C=null;break;case"undefined":return f([VOID],g)}return f([y,C],g)}case ARRAY:{if(b){let R=g;return b==="DataView"?R=new Uint8Array(g.buffer):b==="ArrayBuffer"&&(R=new Uint8Array(g)),f([b,[...R]],g)}const C=[],w=f([y,C],g);for(const R of g)C.push(m(R));return w}case OBJECT:{if(b)switch(b){case"BigInt":return f([b,g.toString()],g);case"Boolean":case"Number":case"String":return f([b,g.valueOf()],g)}if(c&&"toJSON"in g)return m(g.toJSON());const C=[],w=f([y,C],g);for(const R of keys(g))(a||!shouldSkip(typeOf(g[R])))&&C.push([m(R),m(g[R])]);return w}case DATE:return f([y,g.toISOString()],g);case REGEXP:{const{source:C,flags:w}=g;return f([y,{source:C,flags:w}],g)}case MAP:{const C=[],w=f([y,C],g);for(const[R,_]of g)(a||!(shouldSkip(typeOf(R))||shouldSkip(typeOf(_))))&&C.push([m(R),m(_)]);return w}case SET:{const C=[],w=f([y,C],g);for(const R of g)(a||!shouldSkip(typeOf(R)))&&C.push(m(R));return w}}const{message:E}=g;return f([y,{name:b,message:E}],g)};return m},serialize$1=(a,{json:c,lossy:u}={})=>{const d=[];return serializer(!(c||u),!!c,new Map,d)(a),d},structuredClone$1=typeof structuredClone=="function"?(a,c)=>c&&("json"in c||"lossy"in c)?deserialize(serialize$1(a,c)):structuredClone(a):(a,c)=>deserialize(serialize$1(a,c));function defaultFootnoteBackContent(a,c){const u=[{type:"text",value:"↩"}];return c>1&&u.push({type:"element",tagName:"sup",properties:{},children:[{type:"text",value:String(c)}]}),u}function defaultFootnoteBackLabel(a,c){return"Back to reference "+(a+1)+(c>1?"-"+c:"")}function footer(a){const c=typeof a.options.clobberPrefix=="string"?a.options.clobberPrefix:"user-content-",u=a.options.footnoteBackContent||defaultFootnoteBackContent,d=a.options.footnoteBackLabel||defaultFootnoteBackLabel,f=a.options.footnoteLabel||"Footnotes",m=a.options.footnoteLabelTagName||"h2",g=a.options.footnoteLabelProperties||{className:["sr-only"]},y=[];let b=-1;for(;++b<a.footnoteOrder.length;){const E=a.footnoteById.get(a.footnoteOrder[b]);if(!E)continue;const C=a.all(E),w=String(E.identifier).toUpperCase(),R=normalizeUri(w.toLowerCase());let _=0;const M=[],I=a.footnoteCounts.get(w);for(;I!==void 0&&++_<=I;){M.length>0&&M.push({type:"text",value:" "});let P=typeof u=="string"?u:u(b,_);typeof P=="string"&&(P={type:"text",value:P}),M.push({type:"element",tagName:"a",properties:{href:"#"+c+"fnref-"+R+(_>1?"-"+_:""),dataFootnoteBackref:"",ariaLabel:typeof d=="string"?d:d(b,_),className:["data-footnote-backref"]},children:Array.isArray(P)?P:[P]})}const N=C[C.length-1];if(N&&N.type==="element"&&N.tagName==="p"){const P=N.children[N.children.length-1];P&&P.type==="text"?P.value+=" ":N.children.push({type:"text",value:" "}),N.children.push(...M)}else C.push(...M);const A={type:"element",tagName:"li",properties:{id:c+"fn-"+R},children:a.wrap(C,!0)};a.patch(E,A),y.push(A)}if(y.length!==0)return{type:"element",tagName:"section",properties:{dataFootnotes:!0,className:["footnotes"]},children:[{type:"element",tagName:m,properties:{...structuredClone$1(g),id:"footnote-label"},children:[{type:"text",value:f}]},{type:"text",value:`
`},{type:"element",tagName:"ol",properties:{},children:a.wrap(y,!0)},{type:"text",value:`
`}]}}const convert=function(a){if(a==null)return ok;if(typeof a=="function")return castFactory$1(a);if(typeof a=="object")return Array.isArray(a)?anyFactory$1(a):propsFactory(a);if(typeof a=="string")return typeFactory(a);throw new Error("Expected function, string, or object as test")};function anyFactory$1(a){const c=[];let u=-1;for(;++u<a.length;)c[u]=convert(a[u]);return castFactory$1(d);function d(...f){let m=-1;for(;++m<c.length;)if(c[m].apply(this,f))return!0;return!1}}function propsFactory(a){const c=a;return castFactory$1(u);function u(d){const f=d;let m;for(m in a)if(f[m]!==c[m])return!1;return!0}}function typeFactory(a){return castFactory$1(c);function c(u){return u&&u.type===a}}function castFactory$1(a){return c;function c(u,d,f){return!!(looksLikeANode(u)&&a.call(this,u,typeof d=="number"?d:void 0,f||void 0))}}function ok(){return!0}function looksLikeANode(a){return a!==null&&typeof a=="object"&&"type"in a}function color(a){return a}const empty=[],CONTINUE=!0,EXIT=!1,SKIP="skip";function visitParents(a,c,u,d){let f;typeof c=="function"&&typeof u!="function"?(d=u,u=c):f=c;const m=convert(f),g=d?-1:1;y(a,void 0,[])();function y(b,E,C){const w=b&&typeof b=="object"?b:{};if(typeof w.type=="string"){const _=typeof w.tagName=="string"?w.tagName:typeof w.name=="string"?w.name:void 0;Object.defineProperty(R,"name",{value:"node ("+(b.type+(_?"<"+_+">":""))+")"})}return R;function R(){let _=empty,M,I,N;if((!c||m(b,E,C[C.length-1]||void 0))&&(_=toResult(u(b,C)),_[0]===EXIT))return _;if("children"in b&&b.children){const A=b;if(A.children&&_[0]!==SKIP)for(I=(d?A.children.length:-1)+g,N=C.concat(A);I>-1&&I<A.children.length;){const P=A.children[I];if(M=y(P,I,N)(),M[0]===EXIT)return M;I=typeof M[1]=="number"?M[1]:I+g}}return _}}}function toResult(a){return Array.isArray(a)?a:typeof a=="number"?[CONTINUE,a]:a==null?empty:[a]}function visit(a,c,u,d){let f,m,g;typeof c=="function"?(m=void 0,g=c,f=u):(m=c,g=u,f=d),visitParents(a,m,y,f);function y(b,E){const C=E[E.length-1],w=C?C.children.indexOf(b):void 0;return g(b,w,C)}}const own$1={}.hasOwnProperty,emptyOptions$3={};function createState(a,c){const u=c||emptyOptions$3,d=new Map,f=new Map,m=new Map,g={...handlers,...u.handlers},y={all:E,applyData,definitionById:d,footnoteById:f,footnoteCounts:m,footnoteOrder:[],handlers:g,one:b,options:u,patch,wrap:wrap$1};return visit(a,function(C){if(C.type==="definition"||C.type==="footnoteDefinition"){const w=C.type==="definition"?d:f,R=String(C.identifier).toUpperCase();w.has(R)||w.set(R,C)}}),y;function b(C,w){const R=C.type,_=y.handlers[R];if(own$1.call(y.handlers,R)&&_)return _(y,C,w);if(y.options.passThrough&&y.options.passThrough.includes(R)){if("children"in C){const{children:I,...N}=C,A=structuredClone$1(N);return A.children=y.all(C),A}return structuredClone$1(C)}return(y.options.unknownHandler||defaultUnknownHandler)(y,C,w)}function E(C){const w=[];if("children"in C){const R=C.children;let _=-1;for(;++_<R.length;){const M=y.one(R[_],C);if(M){if(_&&R[_-1].type==="break"&&(!Array.isArray(M)&&M.type==="text"&&(M.value=trimMarkdownSpaceStart(M.value)),!Array.isArray(M)&&M.type==="element")){const I=M.children[0];I&&I.type==="text"&&(I.value=trimMarkdownSpaceStart(I.value))}Array.isArray(M)?w.push(...M):w.push(M)}}}return w}}function patch(a,c){a.position&&(c.position=position$1(a))}function applyData(a,c){let u=c;if(a&&a.data){const d=a.data.hName,f=a.data.hChildren,m=a.data.hProperties;if(typeof d=="string")if(u.type==="element")u.tagName=d;else{const g="children"in u?u.children:[u];u={type:"element",tagName:d,properties:{},children:g}}u.type==="element"&&m&&Object.assign(u.properties,structuredClone$1(m)),"children"in u&&u.children&&f!==null&&f!==void 0&&(u.children=f)}return u}function defaultUnknownHandler(a,c){const u=c.data||{},d="value"in c&&!(own$1.call(u,"hProperties")||own$1.call(u,"hChildren"))?{type:"text",value:c.value}:{type:"element",tagName:"div",properties:{},children:a.all(c)};return a.patch(c,d),a.applyData(c,d)}function wrap$1(a,c){const u=[];let d=-1;for(c&&u.push({type:"text",value:`
`});++d<a.length;)d&&u.push({type:"text",value:`
`}),u.push(a[d]);return c&&a.length>0&&u.push({type:"text",value:`
`}),u}function trimMarkdownSpaceStart(a){let c=0,u=a.charCodeAt(c);for(;u===9||u===32;)c++,u=a.charCodeAt(c);return a.slice(c)}function toHast(a,c){const u=createState(a,c),d=u.one(a,void 0),f=footer(u),m=Array.isArray(d)?{type:"root",children:d}:d||{type:"root",children:[]};return f&&m.children.push({type:"text",value:`
`},f),m}function remarkRehype(a,c){return a&&"run"in a?async function(u,d){const f=toHast(u,{file:d,...c});await a.run(f,d)}:function(u,d){return toHast(u,{file:d,...a||c})}}function bail(a){if(a)throw a}var extend$1,hasRequiredExtend;function requireExtend(){if(hasRequiredExtend)return extend$1;hasRequiredExtend=1;var a=Object.prototype.hasOwnProperty,c=Object.prototype.toString,u=Object.defineProperty,d=Object.getOwnPropertyDescriptor,f=function(E){return typeof Array.isArray=="function"?Array.isArray(E):c.call(E)==="[object Array]"},m=function(E){if(!E||c.call(E)!=="[object Object]")return!1;var C=a.call(E,"constructor"),w=E.constructor&&E.constructor.prototype&&a.call(E.constructor.prototype,"isPrototypeOf");if(E.constructor&&!C&&!w)return!1;var R;for(R in E);return typeof R>"u"||a.call(E,R)},g=function(E,C){u&&C.name==="__proto__"?u(E,C.name,{enumerable:!0,configurable:!0,value:C.newValue,writable:!0}):E[C.name]=C.newValue},y=function(E,C){if(C==="__proto__")if(a.call(E,C)){if(d)return d(E,C).value}else return;return E[C]};return extend$1=function b(){var E,C,w,R,_,M,I=arguments[0],N=1,A=arguments.length,P=!1;for(typeof I=="boolean"&&(P=I,I=arguments[1]||{},N=2),(I==null||typeof I!="object"&&typeof I!="function")&&(I={});N<A;++N)if(E=arguments[N],E!=null)for(C in E)w=y(I,C),R=y(E,C),I!==R&&(P&&R&&(m(R)||(_=f(R)))?(_?(_=!1,M=w&&f(w)?w:[]):M=w&&m(w)?w:{},g(I,{name:C,newValue:b(P,M,R)})):typeof R<"u"&&g(I,{name:C,newValue:R}));return I},extend$1}var extendExports=requireExtend();const extend=getDefaultExportFromCjs(extendExports);function isPlainObject(a){if(typeof a!="object"||a===null)return!1;const c=Object.getPrototypeOf(a);return(c===null||c===Object.prototype||Object.getPrototypeOf(c)===null)&&!(Symbol.toStringTag in a)&&!(Symbol.iterator in a)}function trough(){const a=[],c={run:u,use:d};return c;function u(...f){let m=-1;const g=f.pop();if(typeof g!="function")throw new TypeError("Expected function as last argument, not "+g);y(null,...f);function y(b,...E){const C=a[++m];let w=-1;if(b){g(b);return}for(;++w<f.length;)(E[w]===null||E[w]===void 0)&&(E[w]=f[w]);f=E,C?wrap(C,y)(...E):g(null,...E)}}function d(f){if(typeof f!="function")throw new TypeError("Expected `middelware` to be a function, not "+f);return a.push(f),c}}function wrap(a,c){let u;return d;function d(...g){const y=a.length>g.length;let b;y&&g.push(f);try{b=a.apply(this,g)}catch(E){const C=E;if(y&&u)throw C;return f(C)}y||(b&&b.then&&typeof b.then=="function"?b.then(m,f):b instanceof Error?f(b):m(b))}function f(g,...y){u||(u=!0,c(g,...y))}function m(g){f(null,g)}}const minpath={basename,dirname,extname,join,sep:"/"};function basename(a,c){if(c!==void 0&&typeof c!="string")throw new TypeError('"ext" argument must be a string');assertPath$1(a);let u=0,d=-1,f=a.length,m;if(c===void 0||c.length===0||c.length>a.length){for(;f--;)if(a.codePointAt(f)===47){if(m){u=f+1;break}}else d<0&&(m=!0,d=f+1);return d<0?"":a.slice(u,d)}if(c===a)return"";let g=-1,y=c.length-1;for(;f--;)if(a.codePointAt(f)===47){if(m){u=f+1;break}}else g<0&&(m=!0,g=f+1),y>-1&&(a.codePointAt(f)===c.codePointAt(y--)?y<0&&(d=f):(y=-1,d=g));return u===d?d=g:d<0&&(d=a.length),a.slice(u,d)}function dirname(a){if(assertPath$1(a),a.length===0)return".";let c=-1,u=a.length,d;for(;--u;)if(a.codePointAt(u)===47){if(d){c=u;break}}else d||(d=!0);return c<0?a.codePointAt(0)===47?"/":".":c===1&&a.codePointAt(0)===47?"//":a.slice(0,c)}function extname(a){assertPath$1(a);let c=a.length,u=-1,d=0,f=-1,m=0,g;for(;c--;){const y=a.codePointAt(c);if(y===47){if(g){d=c+1;break}continue}u<0&&(g=!0,u=c+1),y===46?f<0?f=c:m!==1&&(m=1):f>-1&&(m=-1)}return f<0||u<0||m===0||m===1&&f===u-1&&f===d+1?"":a.slice(f,u)}function join(...a){let c=-1,u;for(;++c<a.length;)assertPath$1(a[c]),a[c]&&(u=u===void 0?a[c]:u+"/"+a[c]);return u===void 0?".":normalize(u)}function normalize(a){assertPath$1(a);const c=a.codePointAt(0)===47;let u=normalizeString(a,!c);return u.length===0&&!c&&(u="."),u.length>0&&a.codePointAt(a.length-1)===47&&(u+="/"),c?"/"+u:u}function normalizeString(a,c){let u="",d=0,f=-1,m=0,g=-1,y,b;for(;++g<=a.length;){if(g<a.length)y=a.codePointAt(g);else{if(y===47)break;y=47}if(y===47){if(!(f===g-1||m===1))if(f!==g-1&&m===2){if(u.length<2||d!==2||u.codePointAt(u.length-1)!==46||u.codePointAt(u.length-2)!==46){if(u.length>2){if(b=u.lastIndexOf("/"),b!==u.length-1){b<0?(u="",d=0):(u=u.slice(0,b),d=u.length-1-u.lastIndexOf("/")),f=g,m=0;continue}}else if(u.length>0){u="",d=0,f=g,m=0;continue}}c&&(u=u.length>0?u+"/..":"..",d=2)}else u.length>0?u+="/"+a.slice(f+1,g):u=a.slice(f+1,g),d=g-f-1;f=g,m=0}else y===46&&m>-1?m++:m=-1}return u}function assertPath$1(a){if(typeof a!="string")throw new TypeError("Path must be a string. Received "+JSON.stringify(a))}const minproc={cwd};function cwd(){return"/"}function isUrl(a){return!!(a!==null&&typeof a=="object"&&"href"in a&&a.href&&"protocol"in a&&a.protocol&&a.auth===void 0)}function urlToPath(a){if(typeof a=="string")a=new URL(a);else if(!isUrl(a)){const c=new TypeError('The "path" argument must be of type string or an instance of URL. Received `'+a+"`");throw c.code="ERR_INVALID_ARG_TYPE",c}if(a.protocol!=="file:"){const c=new TypeError("The URL must be of scheme file");throw c.code="ERR_INVALID_URL_SCHEME",c}return getPathFromURLPosix(a)}function getPathFromURLPosix(a){if(a.hostname!==""){const d=new TypeError('File URL host must be "localhost" or empty on darwin');throw d.code="ERR_INVALID_FILE_URL_HOST",d}const c=a.pathname;let u=-1;for(;++u<c.length;)if(c.codePointAt(u)===37&&c.codePointAt(u+1)===50){const d=c.codePointAt(u+2);if(d===70||d===102){const f=new TypeError("File URL path must not include encoded / characters");throw f.code="ERR_INVALID_FILE_URL_PATH",f}}return decodeURIComponent(c)}const order=["history","path","basename","stem","extname","dirname"];class VFile{constructor(c){let u;c?isUrl(c)?u={path:c}:typeof c=="string"||isUint8Array$1(c)?u={value:c}:u=c:u={},this.cwd="cwd"in u?"":minproc.cwd(),this.data={},this.history=[],this.messages=[],this.value,this.map,this.result,this.stored;let d=-1;for(;++d<order.length;){const m=order[d];m in u&&u[m]!==void 0&&u[m]!==null&&(this[m]=m==="history"?[...u[m]]:u[m])}let f;for(f in u)order.includes(f)||(this[f]=u[f])}get basename(){return typeof this.path=="string"?minpath.basename(this.path):void 0}set basename(c){assertNonEmpty(c,"basename"),assertPart(c,"basename"),this.path=minpath.join(this.dirname||"",c)}get dirname(){return typeof this.path=="string"?minpath.dirname(this.path):void 0}set dirname(c){assertPath(this.basename,"dirname"),this.path=minpath.join(c||"",this.basename)}get extname(){return typeof this.path=="string"?minpath.extname(this.path):void 0}set extname(c){if(assertPart(c,"extname"),assertPath(this.dirname,"extname"),c){if(c.codePointAt(0)!==46)throw new Error("`extname` must start with `.`");if(c.includes(".",1))throw new Error("`extname` cannot contain multiple dots")}this.path=minpath.join(this.dirname,this.stem+(c||""))}get path(){return this.history[this.history.length-1]}set path(c){isUrl(c)&&(c=urlToPath(c)),assertNonEmpty(c,"path"),this.path!==c&&this.history.push(c)}get stem(){return typeof this.path=="string"?minpath.basename(this.path,this.extname):void 0}set stem(c){assertNonEmpty(c,"stem"),assertPart(c,"stem"),this.path=minpath.join(this.dirname||"",c+(this.extname||""))}fail(c,u,d){const f=this.message(c,u,d);throw f.fatal=!0,f}info(c,u,d){const f=this.message(c,u,d);return f.fatal=void 0,f}message(c,u,d){const f=new VFileMessage(c,u,d);return this.path&&(f.name=this.path+":"+f.name,f.file=this.path),f.fatal=!1,this.messages.push(f),f}toString(c){return this.value===void 0?"":typeof this.value=="string"?this.value:new TextDecoder(c||void 0).decode(this.value)}}function assertPart(a,c){if(a&&a.includes(minpath.sep))throw new Error("`"+c+"` cannot be a path: did not expect `"+minpath.sep+"`")}function assertNonEmpty(a,c){if(!a)throw new Error("`"+c+"` cannot be empty")}function assertPath(a,c){if(!a)throw new Error("Setting `"+c+"` requires `path` to be set too")}function isUint8Array$1(a){return!!(a&&typeof a=="object"&&"byteLength"in a&&"byteOffset"in a)}const CallableInstance=function(a){const d=this.constructor.prototype,f=d[a],m=function(){return f.apply(m,arguments)};return Object.setPrototypeOf(m,d),m},own={}.hasOwnProperty;class Processor extends CallableInstance{constructor(){super("copy"),this.Compiler=void 0,this.Parser=void 0,this.attachers=[],this.compiler=void 0,this.freezeIndex=-1,this.frozen=void 0,this.namespace={},this.parser=void 0,this.transformers=trough()}copy(){const c=new Processor;let u=-1;for(;++u<this.attachers.length;){const d=this.attachers[u];c.use(...d)}return c.data(extend(!0,{},this.namespace)),c}data(c,u){return typeof c=="string"?arguments.length===2?(assertUnfrozen("data",this.frozen),this.namespace[c]=u,this):own.call(this.namespace,c)&&this.namespace[c]||void 0:c?(assertUnfrozen("data",this.frozen),this.namespace=c,this):this.namespace}freeze(){if(this.frozen)return this;const c=this;for(;++this.freezeIndex<this.attachers.length;){const[u,...d]=this.attachers[this.freezeIndex];if(d[0]===!1)continue;d[0]===!0&&(d[0]=void 0);const f=u.call(c,...d);typeof f=="function"&&this.transformers.use(f)}return this.frozen=!0,this.freezeIndex=Number.POSITIVE_INFINITY,this}parse(c){this.freeze();const u=vfile(c),d=this.parser||this.Parser;return assertParser("parse",d),d(String(u),u)}process(c,u){const d=this;return this.freeze(),assertParser("process",this.parser||this.Parser),assertCompiler("process",this.compiler||this.Compiler),u?f(void 0,u):new Promise(f);function f(m,g){const y=vfile(c),b=d.parse(y);d.run(b,y,function(C,w,R){if(C||!w||!R)return E(C);const _=w,M=d.stringify(_,R);looksLikeAValue(M)?R.value=M:R.result=M,E(C,R)});function E(C,w){C||!w?g(C):m?m(w):u(void 0,w)}}}processSync(c){let u=!1,d;return this.freeze(),assertParser("processSync",this.parser||this.Parser),assertCompiler("processSync",this.compiler||this.Compiler),this.process(c,f),assertDone("processSync","process",u),d;function f(m,g){u=!0,bail(m),d=g}}run(c,u,d){assertNode(c),this.freeze();const f=this.transformers;return!d&&typeof u=="function"&&(d=u,u=void 0),d?m(void 0,d):new Promise(m);function m(g,y){const b=vfile(u);f.run(c,b,E);function E(C,w,R){const _=w||c;C?y(C):g?g(_):d(void 0,_,R)}}}runSync(c,u){let d=!1,f;return this.run(c,u,m),assertDone("runSync","run",d),f;function m(g,y){bail(g),f=y,d=!0}}stringify(c,u){this.freeze();const d=vfile(u),f=this.compiler||this.Compiler;return assertCompiler("stringify",f),assertNode(c),f(c,d)}use(c,...u){const d=this.attachers,f=this.namespace;if(assertUnfrozen("use",this.frozen),c!=null)if(typeof c=="function")b(c,u);else if(typeof c=="object")Array.isArray(c)?y(c):g(c);else throw new TypeError("Expected usable value, not `"+c+"`");return this;function m(E){if(typeof E=="function")b(E,[]);else if(typeof E=="object")if(Array.isArray(E)){const[C,...w]=E;b(C,w)}else g(E);else throw new TypeError("Expected usable value, not `"+E+"`")}function g(E){if(!("plugins"in E)&&!("settings"in E))throw new Error("Expected usable value but received an empty preset, which is probably a mistake: presets typically come with `plugins` and sometimes with `settings`, but this has neither");y(E.plugins),E.settings&&(f.settings=extend(!0,f.settings,E.settings))}function y(E){let C=-1;if(E!=null)if(Array.isArray(E))for(;++C<E.length;){const w=E[C];m(w)}else throw new TypeError("Expected a list of plugins, not `"+E+"`")}function b(E,C){let w=-1,R=-1;for(;++w<d.length;)if(d[w][0]===E){R=w;break}if(R===-1)d.push([E,...C]);else if(C.length>0){let[_,...M]=C;const I=d[R][1];isPlainObject(I)&&isPlainObject(_)&&(_=extend(!0,I,_)),d[R]=[E,_,...M]}}}}const unified=new Processor().freeze();function assertParser(a,c){if(typeof c!="function")throw new TypeError("Cannot `"+a+"` without `parser`")}function assertCompiler(a,c){if(typeof c!="function")throw new TypeError("Cannot `"+a+"` without `compiler`")}function assertUnfrozen(a,c){if(c)throw new Error("Cannot call `"+a+"` on a frozen processor.\nCreate a new processor first, by calling it: use `processor()` instead of `processor`.")}function assertNode(a){if(!isPlainObject(a)||typeof a.type!="string")throw new TypeError("Expected node, got `"+a+"`")}function assertDone(a,c,u){if(!u)throw new Error("`"+a+"` finished async. Use `"+c+"` instead")}function vfile(a){return looksLikeAVFile(a)?a:new VFile(a)}function looksLikeAVFile(a){return!!(a&&typeof a=="object"&&"message"in a&&"messages"in a)}function looksLikeAValue(a){return typeof a=="string"||isUint8Array(a)}function isUint8Array(a){return!!(a&&typeof a=="object"&&"byteLength"in a&&"byteOffset"in a)}const changelog="https://github.com/remarkjs/react-markdown/blob/main/changelog.md",emptyPlugins=[],emptyRemarkRehypeOptions={allowDangerousHtml:!0},safeProtocol=/^(https?|ircs?|mailto|xmpp)$/i,deprecations=[{from:"astPlugins",id:"remove-buggy-html-in-markdown-parser"},{from:"allowDangerousHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"allowNode",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowElement"},{from:"allowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"allowedElements"},{from:"className",id:"remove-classname"},{from:"disallowedTypes",id:"replace-allownode-allowedtypes-and-disallowedtypes",to:"disallowedElements"},{from:"escapeHtml",id:"remove-buggy-html-in-markdown-parser"},{from:"includeElementIndex",id:"#remove-includeelementindex"},{from:"includeNodeIndex",id:"change-includenodeindex-to-includeelementindex"},{from:"linkTarget",id:"remove-linktarget"},{from:"plugins",id:"change-plugins-to-remarkplugins",to:"remarkPlugins"},{from:"rawSourcePos",id:"#remove-rawsourcepos"},{from:"renderers",id:"change-renderers-to-components",to:"components"},{from:"source",id:"change-source-to-children",to:"children"},{from:"sourcePos",id:"#remove-sourcepos"},{from:"transformImageUri",id:"#add-urltransform",to:"urlTransform"},{from:"transformLinkUri",id:"#add-urltransform",to:"urlTransform"}];function Markdown$1(a){const c=createProcessor(a),u=createFile(a);return post(c.runSync(c.parse(u),u),a)}function createProcessor(a){const c=a.rehypePlugins||emptyPlugins,u=a.remarkPlugins||emptyPlugins,d=a.remarkRehypeOptions?{...a.remarkRehypeOptions,...emptyRemarkRehypeOptions}:emptyRemarkRehypeOptions;return unified().use(remarkParse).use(u).use(remarkRehype,d).use(c)}function createFile(a){const c=a.children||"",u=new VFile;return typeof c=="string"&&(u.value=c),u}function post(a,c){const u=c.allowedElements,d=c.allowElement,f=c.components,m=c.disallowedElements,g=c.skipHtml,y=c.unwrapDisallowed,b=c.urlTransform||defaultUrlTransform;for(const C of deprecations)Object.hasOwn(c,C.from)&&(""+C.from+(C.to?"use `"+C.to+"` instead":"remove it")+changelog+C.id,void 0);return visit(a,E),toJsxRuntime(a,{Fragment:jsxRuntimeExports.Fragment,components:f,ignoreInvalidStyle:!0,jsx:jsxRuntimeExports.jsx,jsxs:jsxRuntimeExports.jsxs,passKeys:!0,passNode:!0});function E(C,w,R){if(C.type==="raw"&&R&&typeof w=="number")return g?R.children.splice(w,1):R.children[w]={type:"text",value:C.value},w;if(C.type==="element"){let _;for(_ in urlAttributes)if(Object.hasOwn(urlAttributes,_)&&Object.hasOwn(C.properties,_)){const M=C.properties[_],I=urlAttributes[_];(I===null||I.includes(C.tagName))&&(C.properties[_]=b(String(M||""),_,C))}}if(C.type==="element"){let _=u?!u.includes(C.tagName):m?m.includes(C.tagName):!1;if(!_&&d&&typeof w=="number"&&(_=!d(C,w,R)),_&&R&&typeof w=="number")return y&&C.children?R.children.splice(w,1,...C.children):R.children.splice(w,1),w}}}function defaultUrlTransform(a){const c=a.indexOf(":"),u=a.indexOf("?"),d=a.indexOf("#"),f=a.indexOf("/");return c===-1||f!==-1&&c>f||u!==-1&&c>u||d!==-1&&c>d||safeProtocol.test(a.slice(0,c))?a:""}function ccount(a,c){const u=String(a);if(typeof c!="string")throw new TypeError("Expected character");let d=0,f=u.indexOf(c);for(;f!==-1;)d++,f=u.indexOf(c,f+c.length);return d}function escapeStringRegexp(a){if(typeof a!="string")throw new TypeError("Expected a string");return a.replace(/[|\\{}()[\]^$+*?.]/g,"\\$&").replace(/-/g,"\\x2d")}function findAndReplace(a,c,u){const f=convert((u||{}).ignore||[]),m=toPairs(c);let g=-1;for(;++g<m.length;)visitParents(a,"text",y);function y(E,C){let w=-1,R;for(;++w<C.length;){const _=C[w],M=R?R.children:void 0;if(f(_,M?M.indexOf(_):void 0,R))return;R=_}if(R)return b(E,C)}function b(E,C){const w=C[C.length-1],R=m[g][0],_=m[g][1];let M=0;const N=w.children.indexOf(E);let A=!1,P=[];R.lastIndex=0;let z=R.exec(E.value);for(;z;){const B=z.index,j={index:z.index,input:z.input,stack:[...C,E]};let L=_(...z,j);if(typeof L=="string"&&(L=L.length>0?{type:"text",value:L}:void 0),L===!1?R.lastIndex=B+1:(M!==B&&P.push({type:"text",value:E.value.slice(M,B)}),Array.isArray(L)?P.push(...L):L&&P.push(L),M=B+z[0].length,A=!0),!R.global)break;z=R.exec(E.value)}return A?(M<E.value.length&&P.push({type:"text",value:E.value.slice(M)}),w.children.splice(N,1,...P)):P=[E],N+P.length}}function toPairs(a){const c=[];if(!Array.isArray(a))throw new TypeError("Expected find and replace tuple or list of tuples");const u=!a[0]||Array.isArray(a[0])?a:[a];let d=-1;for(;++d<u.length;){const f=u[d];c.push([toExpression(f[0]),toFunction(f[1])])}return c}function toExpression(a){return typeof a=="string"?new RegExp(escapeStringRegexp(a),"g"):a}function toFunction(a){return typeof a=="function"?a:function(){return a}}const inConstruct="phrasing",notInConstruct=["autolink","link","image","label"];function gfmAutolinkLiteralFromMarkdown(){return{transforms:[transformGfmAutolinkLiterals],enter:{literalAutolink:enterLiteralAutolink,literalAutolinkEmail:enterLiteralAutolinkValue,literalAutolinkHttp:enterLiteralAutolinkValue,literalAutolinkWww:enterLiteralAutolinkValue},exit:{literalAutolink:exitLiteralAutolink,literalAutolinkEmail:exitLiteralAutolinkEmail,literalAutolinkHttp:exitLiteralAutolinkHttp,literalAutolinkWww:exitLiteralAutolinkWww}}}function gfmAutolinkLiteralToMarkdown(){return{unsafe:[{character:"@",before:"[+\\-.\\w]",after:"[\\-.\\w]",inConstruct,notInConstruct},{character:".",before:"[Ww]",after:"[\\-.\\w]",inConstruct,notInConstruct},{character:":",before:"[ps]",after:"\\/",inConstruct,notInConstruct}]}}function enterLiteralAutolink(a){this.enter({type:"link",title:null,url:"",children:[]},a)}function enterLiteralAutolinkValue(a){this.config.enter.autolinkProtocol.call(this,a)}function exitLiteralAutolinkHttp(a){this.config.exit.autolinkProtocol.call(this,a)}function exitLiteralAutolinkWww(a){this.config.exit.data.call(this,a);const c=this.stack[this.stack.length-1];c.type,c.url="http://"+this.sliceSerialize(a)}function exitLiteralAutolinkEmail(a){this.config.exit.autolinkEmail.call(this,a)}function exitLiteralAutolink(a){this.exit(a)}function transformGfmAutolinkLiterals(a){findAndReplace(a,[[/(https?:\/\/|www(?=\.))([-.\w]+)([^ \t\r\n]*)/gi,findUrl],[new RegExp("(?<=^|\\s|\\p{P}|\\p{S})([-.\\w+]+)@([-\\w]+(?:\\.[-\\w]+)+)","gu"),findEmail]],{ignore:["link","linkReference"]})}function findUrl(a,c,u,d,f){let m="";if(!previous$1(f)||(/^w/i.test(c)&&(u=c+u,c="",m="http://"),!isCorrectDomain(u)))return!1;const g=splitUrl(u+d);if(!g[0])return!1;const y={type:"link",title:null,url:m+c+g[0],children:[{type:"text",value:c+g[0]}]};return g[1]?[y,{type:"text",value:g[1]}]:y}function findEmail(a,c,u,d){return!previous$1(d,!0)||/[-\d_]$/.test(u)?!1:{type:"link",title:null,url:"mailto:"+c+"@"+u,children:[{type:"text",value:c+"@"+u}]}}function isCorrectDomain(a){const c=a.split(".");return!(c.length<2||c[c.length-1]&&(/_/.test(c[c.length-1])||!/[a-zA-Z\d]/.test(c[c.length-1]))||c[c.length-2]&&(/_/.test(c[c.length-2])||!/[a-zA-Z\d]/.test(c[c.length-2])))}function splitUrl(a){const c=/[!"&'),.:;<>?\]}]+$/.exec(a);if(!c)return[a,void 0];a=a.slice(0,c.index);let u=c[0],d=u.indexOf(")");const f=ccount(a,"(");let m=ccount(a,")");for(;d!==-1&&f>m;)a+=u.slice(0,d+1),u=u.slice(d+1),d=u.indexOf(")"),m++;return[a,u]}function previous$1(a,c){const u=a.input.charCodeAt(a.index-1);return(a.index===0||unicodeWhitespace(u)||unicodePunctuation(u))&&(!c||u!==47)}footnoteReference.peek=footnoteReferencePeek;function enterFootnoteCallString(){this.buffer()}function enterFootnoteCall(a){this.enter({type:"footnoteReference",identifier:"",label:""},a)}function enterFootnoteDefinitionLabelString(){this.buffer()}function enterFootnoteDefinition(a){this.enter({type:"footnoteDefinition",identifier:"",label:"",children:[]},a)}function exitFootnoteCallString(a){const c=this.resume(),u=this.stack[this.stack.length-1];u.type,u.identifier=normalizeIdentifier(this.sliceSerialize(a)).toLowerCase(),u.label=c}function exitFootnoteCall(a){this.exit(a)}function exitFootnoteDefinitionLabelString(a){const c=this.resume(),u=this.stack[this.stack.length-1];u.type,u.identifier=normalizeIdentifier(this.sliceSerialize(a)).toLowerCase(),u.label=c}function exitFootnoteDefinition(a){this.exit(a)}function footnoteReferencePeek(){return"["}function footnoteReference(a,c,u,d){const f=u.createTracker(d);let m=f.move("[^");const g=u.enter("footnoteReference"),y=u.enter("reference");return m+=f.move(u.safe(u.associationId(a),{after:"]",before:m})),y(),g(),m+=f.move("]"),m}function gfmFootnoteFromMarkdown(){return{enter:{gfmFootnoteCallString:enterFootnoteCallString,gfmFootnoteCall:enterFootnoteCall,gfmFootnoteDefinitionLabelString:enterFootnoteDefinitionLabelString,gfmFootnoteDefinition:enterFootnoteDefinition},exit:{gfmFootnoteCallString:exitFootnoteCallString,gfmFootnoteCall:exitFootnoteCall,gfmFootnoteDefinitionLabelString:exitFootnoteDefinitionLabelString,gfmFootnoteDefinition:exitFootnoteDefinition}}}function gfmFootnoteToMarkdown(a){let c=!1;return a&&a.firstLineBlank&&(c=!0),{handlers:{footnoteDefinition:u,footnoteReference},unsafe:[{character:"[",inConstruct:["label","phrasing","reference"]}]};function u(d,f,m,g){const y=m.createTracker(g);let b=y.move("[^");const E=m.enter("footnoteDefinition"),C=m.enter("label");return b+=y.move(m.safe(m.associationId(d),{before:b,after:"]"})),C(),b+=y.move("]:"),d.children&&d.children.length>0&&(y.shift(4),b+=y.move((c?`
`:" ")+m.indentLines(m.containerFlow(d,y.current()),c?mapAll:mapExceptFirst))),E(),b}}function mapExceptFirst(a,c,u){return c===0?a:mapAll(a,c,u)}function mapAll(a,c,u){return(u?"":"    ")+a}const constructsWithoutStrikethrough=["autolink","destinationLiteral","destinationRaw","reference","titleQuote","titleApostrophe"];handleDelete.peek=peekDelete;function gfmStrikethroughFromMarkdown(){return{canContainEols:["delete"],enter:{strikethrough:enterStrikethrough},exit:{strikethrough:exitStrikethrough}}}function gfmStrikethroughToMarkdown(){return{unsafe:[{character:"~",inConstruct:"phrasing",notInConstruct:constructsWithoutStrikethrough}],handlers:{delete:handleDelete}}}function enterStrikethrough(a){this.enter({type:"delete",children:[]},a)}function exitStrikethrough(a){this.exit(a)}function handleDelete(a,c,u,d){const f=u.createTracker(d),m=u.enter("strikethrough");let g=f.move("~~");return g+=u.containerPhrasing(a,{...f.current(),before:g,after:"~"}),g+=f.move("~~"),m(),g}function peekDelete(){return"~"}function defaultStringLength(a){return a.length}function markdownTable(a,c){const u=c||{},d=(u.align||[]).concat(),f=u.stringLength||defaultStringLength,m=[],g=[],y=[],b=[];let E=0,C=-1;for(;++C<a.length;){const I=[],N=[];let A=-1;for(a[C].length>E&&(E=a[C].length);++A<a[C].length;){const P=serialize(a[C][A]);if(u.alignDelimiters!==!1){const z=f(P);N[A]=z,(b[A]===void 0||z>b[A])&&(b[A]=z)}I.push(P)}g[C]=I,y[C]=N}let w=-1;if(typeof d=="object"&&"length"in d)for(;++w<E;)m[w]=toAlignment(d[w]);else{const I=toAlignment(d);for(;++w<E;)m[w]=I}w=-1;const R=[],_=[];for(;++w<E;){const I=m[w];let N="",A="";I===99?(N=":",A=":"):I===108?N=":":I===114&&(A=":");let P=u.alignDelimiters===!1?1:Math.max(1,b[w]-N.length-A.length);const z=N+"-".repeat(P)+A;u.alignDelimiters!==!1&&(P=N.length+P+A.length,P>b[w]&&(b[w]=P),_[w]=P),R[w]=z}g.splice(1,0,R),y.splice(1,0,_),C=-1;const M=[];for(;++C<g.length;){const I=g[C],N=y[C];w=-1;const A=[];for(;++w<E;){const P=I[w]||"";let z="",B="";if(u.alignDelimiters!==!1){const j=b[w]-(N[w]||0),L=m[w];L===114?z=" ".repeat(j):L===99?j%2?(z=" ".repeat(j/2+.5),B=" ".repeat(j/2-.5)):(z=" ".repeat(j/2),B=z):B=" ".repeat(j)}u.delimiterStart!==!1&&!w&&A.push("|"),u.padding!==!1&&!(u.alignDelimiters===!1&&P==="")&&(u.delimiterStart!==!1||w)&&A.push(" "),u.alignDelimiters!==!1&&A.push(z),A.push(P),u.alignDelimiters!==!1&&A.push(B),u.padding!==!1&&A.push(" "),(u.delimiterEnd!==!1||w!==E-1)&&A.push("|")}M.push(u.delimiterEnd===!1?A.join("").replace(/ +$/,""):A.join(""))}return M.join(`
`)}function serialize(a){return a==null?"":String(a)}function toAlignment(a){const c=typeof a=="string"?a.codePointAt(0):0;return c===67||c===99?99:c===76||c===108?108:c===82||c===114?114:0}function blockquote(a,c,u,d){const f=u.enter("blockquote"),m=u.createTracker(d);m.move("> "),m.shift(2);const g=u.indentLines(u.containerFlow(a,m.current()),map$1);return f(),g}function map$1(a,c,u){return">"+(u?"":" ")+a}function patternInScope(a,c){return listInScope(a,c.inConstruct,!0)&&!listInScope(a,c.notInConstruct,!1)}function listInScope(a,c,u){if(typeof c=="string"&&(c=[c]),!c||c.length===0)return u;let d=-1;for(;++d<c.length;)if(a.includes(c[d]))return!0;return!1}function hardBreak(a,c,u,d){let f=-1;for(;++f<u.unsafe.length;)if(u.unsafe[f].character===`
`&&patternInScope(u.stack,u.unsafe[f]))return/[ \t]/.test(d.before)?"":" ";return`\\
`}function longestStreak(a,c){const u=String(a);let d=u.indexOf(c),f=d,m=0,g=0;if(typeof c!="string")throw new TypeError("Expected substring");for(;d!==-1;)d===f?++m>g&&(g=m):m=1,f=d+c.length,d=u.indexOf(c,f);return g}function formatCodeAsIndented(a,c){return!!(c.options.fences===!1&&a.value&&!a.lang&&/[^ \r\n]/.test(a.value)&&!/^[\t ]*(?:[\r\n]|$)|(?:^|[\r\n])[\t ]*$/.test(a.value))}function checkFence(a){const c=a.options.fence||"`";if(c!=="`"&&c!=="~")throw new Error("Cannot serialize code with `"+c+"` for `options.fence`, expected `` ` `` or `~`");return c}function code$1(a,c,u,d){const f=checkFence(u),m=a.value||"",g=f==="`"?"GraveAccent":"Tilde";if(formatCodeAsIndented(a,u)){const w=u.enter("codeIndented"),R=u.indentLines(m,map);return w(),R}const y=u.createTracker(d),b=f.repeat(Math.max(longestStreak(m,f)+1,3)),E=u.enter("codeFenced");let C=y.move(b);if(a.lang){const w=u.enter(`codeFencedLang${g}`);C+=y.move(u.safe(a.lang,{before:C,after:" ",encode:["`"],...y.current()})),w()}if(a.lang&&a.meta){const w=u.enter(`codeFencedMeta${g}`);C+=y.move(" "),C+=y.move(u.safe(a.meta,{before:C,after:`
`,encode:["`"],...y.current()})),w()}return C+=y.move(`
`),m&&(C+=y.move(m+`
`)),C+=y.move(b),E(),C}function map(a,c,u){return(u?"":"    ")+a}function checkQuote(a){const c=a.options.quote||'"';if(c!=='"'&&c!=="'")throw new Error("Cannot serialize title with `"+c+"` for `options.quote`, expected `\"`, or `'`");return c}function definition(a,c,u,d){const f=checkQuote(u),m=f==='"'?"Quote":"Apostrophe",g=u.enter("definition");let y=u.enter("label");const b=u.createTracker(d);let E=b.move("[");return E+=b.move(u.safe(u.associationId(a),{before:E,after:"]",...b.current()})),E+=b.move("]: "),y(),!a.url||/[\0- \u007F]/.test(a.url)?(y=u.enter("destinationLiteral"),E+=b.move("<"),E+=b.move(u.safe(a.url,{before:E,after:">",...b.current()})),E+=b.move(">")):(y=u.enter("destinationRaw"),E+=b.move(u.safe(a.url,{before:E,after:a.title?" ":`
`,...b.current()}))),y(),a.title&&(y=u.enter(`title${m}`),E+=b.move(" "+f),E+=b.move(u.safe(a.title,{before:E,after:f,...b.current()})),E+=b.move(f),y()),g(),E}function checkEmphasis(a){const c=a.options.emphasis||"*";if(c!=="*"&&c!=="_")throw new Error("Cannot serialize emphasis with `"+c+"` for `options.emphasis`, expected `*`, or `_`");return c}function encodeCharacterReference(a){return"&#x"+a.toString(16).toUpperCase()+";"}function encodeInfo(a,c,u){const d=classifyCharacter(a),f=classifyCharacter(c);return d===void 0?f===void 0?u==="_"?{inside:!0,outside:!0}:{inside:!1,outside:!1}:f===1?{inside:!0,outside:!0}:{inside:!1,outside:!0}:d===1?f===void 0?{inside:!1,outside:!1}:f===1?{inside:!0,outside:!0}:{inside:!1,outside:!1}:f===void 0?{inside:!1,outside:!1}:f===1?{inside:!0,outside:!1}:{inside:!1,outside:!1}}emphasis.peek=emphasisPeek;function emphasis(a,c,u,d){const f=checkEmphasis(u),m=u.enter("emphasis"),g=u.createTracker(d),y=g.move(f);let b=g.move(u.containerPhrasing(a,{after:f,before:y,...g.current()}));const E=b.charCodeAt(0),C=encodeInfo(d.before.charCodeAt(d.before.length-1),E,f);C.inside&&(b=encodeCharacterReference(E)+b.slice(1));const w=b.charCodeAt(b.length-1),R=encodeInfo(d.after.charCodeAt(0),w,f);R.inside&&(b=b.slice(0,-1)+encodeCharacterReference(w));const _=g.move(f);return m(),u.attentionEncodeSurroundingInfo={after:R.outside,before:C.outside},y+b+_}function emphasisPeek(a,c,u){return u.options.emphasis||"*"}function formatHeadingAsSetext(a,c){let u=!1;return visit(a,function(d){if("value"in d&&/\r?\n|\r/.test(d.value)||d.type==="break")return u=!0,EXIT}),!!((!a.depth||a.depth<3)&&toString$1(a)&&(c.options.setext||u))}function heading(a,c,u,d){const f=Math.max(Math.min(6,a.depth||1),1),m=u.createTracker(d);if(formatHeadingAsSetext(a,u)){const C=u.enter("headingSetext"),w=u.enter("phrasing"),R=u.containerPhrasing(a,{...m.current(),before:`
`,after:`
`});return w(),C(),R+`
`+(f===1?"=":"-").repeat(R.length-(Math.max(R.lastIndexOf("\r"),R.lastIndexOf(`
`))+1))}const g="#".repeat(f),y=u.enter("headingAtx"),b=u.enter("phrasing");m.move(g+" ");let E=u.containerPhrasing(a,{before:"# ",after:`
`,...m.current()});return/^[\t ]/.test(E)&&(E=encodeCharacterReference(E.charCodeAt(0))+E.slice(1)),E=E?g+" "+E:g,u.options.closeAtx&&(E+=" "+g),b(),y(),E}html.peek=htmlPeek;function html(a){return a.value||""}function htmlPeek(){return"<"}image.peek=imagePeek;function image(a,c,u,d){const f=checkQuote(u),m=f==='"'?"Quote":"Apostrophe",g=u.enter("image");let y=u.enter("label");const b=u.createTracker(d);let E=b.move("![");return E+=b.move(u.safe(a.alt,{before:E,after:"]",...b.current()})),E+=b.move("]("),y(),!a.url&&a.title||/[\0- \u007F]/.test(a.url)?(y=u.enter("destinationLiteral"),E+=b.move("<"),E+=b.move(u.safe(a.url,{before:E,after:">",...b.current()})),E+=b.move(">")):(y=u.enter("destinationRaw"),E+=b.move(u.safe(a.url,{before:E,after:a.title?" ":")",...b.current()}))),y(),a.title&&(y=u.enter(`title${m}`),E+=b.move(" "+f),E+=b.move(u.safe(a.title,{before:E,after:f,...b.current()})),E+=b.move(f),y()),E+=b.move(")"),g(),E}function imagePeek(){return"!"}imageReference.peek=imageReferencePeek;function imageReference(a,c,u,d){const f=a.referenceType,m=u.enter("imageReference");let g=u.enter("label");const y=u.createTracker(d);let b=y.move("![");const E=u.safe(a.alt,{before:b,after:"]",...y.current()});b+=y.move(E+"]["),g();const C=u.stack;u.stack=[],g=u.enter("reference");const w=u.safe(u.associationId(a),{before:b,after:"]",...y.current()});return g(),u.stack=C,m(),f==="full"||!E||E!==w?b+=y.move(w+"]"):f==="shortcut"?b=b.slice(0,-1):b+=y.move("]"),b}function imageReferencePeek(){return"!"}inlineCode.peek=inlineCodePeek;function inlineCode(a,c,u){let d=a.value||"",f="`",m=-1;for(;new RegExp("(^|[^`])"+f+"([^`]|$)").test(d);)f+="`";for(/[^ \r\n]/.test(d)&&(/^[ \r\n]/.test(d)&&/[ \r\n]$/.test(d)||/^`|`$/.test(d))&&(d=" "+d+" ");++m<u.unsafe.length;){const g=u.unsafe[m],y=u.compilePattern(g);let b;if(g.atBreak)for(;b=y.exec(d);){let E=b.index;d.charCodeAt(E)===10&&d.charCodeAt(E-1)===13&&E--,d=d.slice(0,E)+" "+d.slice(b.index+1)}}return f+d+f}function inlineCodePeek(){return"`"}function formatLinkAsAutolink(a,c){const u=toString$1(a);return!!(!c.options.resourceLink&&a.url&&!a.title&&a.children&&a.children.length===1&&a.children[0].type==="text"&&(u===a.url||"mailto:"+u===a.url)&&/^[a-z][a-z+.-]+:/i.test(a.url)&&!/[\0- <>\u007F]/.test(a.url))}link.peek=linkPeek;function link(a,c,u,d){const f=checkQuote(u),m=f==='"'?"Quote":"Apostrophe",g=u.createTracker(d);let y,b;if(formatLinkAsAutolink(a,u)){const C=u.stack;u.stack=[],y=u.enter("autolink");let w=g.move("<");return w+=g.move(u.containerPhrasing(a,{before:w,after:">",...g.current()})),w+=g.move(">"),y(),u.stack=C,w}y=u.enter("link"),b=u.enter("label");let E=g.move("[");return E+=g.move(u.containerPhrasing(a,{before:E,after:"](",...g.current()})),E+=g.move("]("),b(),!a.url&&a.title||/[\0- \u007F]/.test(a.url)?(b=u.enter("destinationLiteral"),E+=g.move("<"),E+=g.move(u.safe(a.url,{before:E,after:">",...g.current()})),E+=g.move(">")):(b=u.enter("destinationRaw"),E+=g.move(u.safe(a.url,{before:E,after:a.title?" ":")",...g.current()}))),b(),a.title&&(b=u.enter(`title${m}`),E+=g.move(" "+f),E+=g.move(u.safe(a.title,{before:E,after:f,...g.current()})),E+=g.move(f),b()),E+=g.move(")"),y(),E}function linkPeek(a,c,u){return formatLinkAsAutolink(a,u)?"<":"["}linkReference.peek=linkReferencePeek;function linkReference(a,c,u,d){const f=a.referenceType,m=u.enter("linkReference");let g=u.enter("label");const y=u.createTracker(d);let b=y.move("[");const E=u.containerPhrasing(a,{before:b,after:"]",...y.current()});b+=y.move(E+"]["),g();const C=u.stack;u.stack=[],g=u.enter("reference");const w=u.safe(u.associationId(a),{before:b,after:"]",...y.current()});return g(),u.stack=C,m(),f==="full"||!E||E!==w?b+=y.move(w+"]"):f==="shortcut"?b=b.slice(0,-1):b+=y.move("]"),b}function linkReferencePeek(){return"["}function checkBullet(a){const c=a.options.bullet||"*";if(c!=="*"&&c!=="+"&&c!=="-")throw new Error("Cannot serialize items with `"+c+"` for `options.bullet`, expected `*`, `+`, or `-`");return c}function checkBulletOther(a){const c=checkBullet(a),u=a.options.bulletOther;if(!u)return c==="*"?"-":"*";if(u!=="*"&&u!=="+"&&u!=="-")throw new Error("Cannot serialize items with `"+u+"` for `options.bulletOther`, expected `*`, `+`, or `-`");if(u===c)throw new Error("Expected `bullet` (`"+c+"`) and `bulletOther` (`"+u+"`) to be different");return u}function checkBulletOrdered(a){const c=a.options.bulletOrdered||".";if(c!=="."&&c!==")")throw new Error("Cannot serialize items with `"+c+"` for `options.bulletOrdered`, expected `.` or `)`");return c}function checkRule(a){const c=a.options.rule||"*";if(c!=="*"&&c!=="-"&&c!=="_")throw new Error("Cannot serialize rules with `"+c+"` for `options.rule`, expected `*`, `-`, or `_`");return c}function list(a,c,u,d){const f=u.enter("list"),m=u.bulletCurrent;let g=a.ordered?checkBulletOrdered(u):checkBullet(u);const y=a.ordered?g==="."?")":".":checkBulletOther(u);let b=c&&u.bulletLastUsed?g===u.bulletLastUsed:!1;if(!a.ordered){const C=a.children?a.children[0]:void 0;if((g==="*"||g==="-")&&C&&(!C.children||!C.children[0])&&u.stack[u.stack.length-1]==="list"&&u.stack[u.stack.length-2]==="listItem"&&u.stack[u.stack.length-3]==="list"&&u.stack[u.stack.length-4]==="listItem"&&u.indexStack[u.indexStack.length-1]===0&&u.indexStack[u.indexStack.length-2]===0&&u.indexStack[u.indexStack.length-3]===0&&(b=!0),checkRule(u)===g&&C){let w=-1;for(;++w<a.children.length;){const R=a.children[w];if(R&&R.type==="listItem"&&R.children&&R.children[0]&&R.children[0].type==="thematicBreak"){b=!0;break}}}}b&&(g=y),u.bulletCurrent=g;const E=u.containerFlow(a,d);return u.bulletLastUsed=g,u.bulletCurrent=m,f(),E}function checkListItemIndent(a){const c=a.options.listItemIndent||"one";if(c!=="tab"&&c!=="one"&&c!=="mixed")throw new Error("Cannot serialize items with `"+c+"` for `options.listItemIndent`, expected `tab`, `one`, or `mixed`");return c}function listItem(a,c,u,d){const f=checkListItemIndent(u);let m=u.bulletCurrent||checkBullet(u);c&&c.type==="list"&&c.ordered&&(m=(typeof c.start=="number"&&c.start>-1?c.start:1)+(u.options.incrementListMarker===!1?0:c.children.indexOf(a))+m);let g=m.length+1;(f==="tab"||f==="mixed"&&(c&&c.type==="list"&&c.spread||a.spread))&&(g=Math.ceil(g/4)*4);const y=u.createTracker(d);y.move(m+" ".repeat(g-m.length)),y.shift(g);const b=u.enter("listItem"),E=u.indentLines(u.containerFlow(a,y.current()),C);return b(),E;function C(w,R,_){return R?(_?"":" ".repeat(g))+w:(_?m:m+" ".repeat(g-m.length))+w}}function paragraph(a,c,u,d){const f=u.enter("paragraph"),m=u.enter("phrasing"),g=u.containerPhrasing(a,d);return m(),f(),g}const phrasing=convert(["break","delete","emphasis","footnote","footnoteReference","image","imageReference","inlineCode","inlineMath","link","linkReference","mdxJsxTextElement","mdxTextExpression","strong","text","textDirective"]);function root$1(a,c,u,d){return(a.children.some(function(g){return phrasing(g)})?u.containerPhrasing:u.containerFlow).call(u,a,d)}function checkStrong(a){const c=a.options.strong||"*";if(c!=="*"&&c!=="_")throw new Error("Cannot serialize strong with `"+c+"` for `options.strong`, expected `*`, or `_`");return c}strong.peek=strongPeek;function strong(a,c,u,d){const f=checkStrong(u),m=u.enter("strong"),g=u.createTracker(d),y=g.move(f+f);let b=g.move(u.containerPhrasing(a,{after:f,before:y,...g.current()}));const E=b.charCodeAt(0),C=encodeInfo(d.before.charCodeAt(d.before.length-1),E,f);C.inside&&(b=encodeCharacterReference(E)+b.slice(1));const w=b.charCodeAt(b.length-1),R=encodeInfo(d.after.charCodeAt(0),w,f);R.inside&&(b=b.slice(0,-1)+encodeCharacterReference(w));const _=g.move(f+f);return m(),u.attentionEncodeSurroundingInfo={after:R.outside,before:C.outside},y+b+_}function strongPeek(a,c,u){return u.options.strong||"*"}function text$4(a,c,u,d){return u.safe(a.value,d)}function checkRuleRepetition(a){const c=a.options.ruleRepetition||3;if(c<3)throw new Error("Cannot serialize rules with repetition `"+c+"` for `options.ruleRepetition`, expected `3` or more");return c}function thematicBreak(a,c,u){const d=(checkRule(u)+(u.options.ruleSpaces?" ":"")).repeat(checkRuleRepetition(u));return u.options.ruleSpaces?d.slice(0,-1):d}const handle={blockquote,break:hardBreak,code:code$1,definition,emphasis,hardBreak,heading,html,image,imageReference,inlineCode,link,linkReference,list,listItem,paragraph,root:root$1,strong,text:text$4,thematicBreak};function gfmTableFromMarkdown(){return{enter:{table:enterTable,tableData:enterCell,tableHeader:enterCell,tableRow:enterRow},exit:{codeText:exitCodeText,table:exitTable,tableData:exit,tableHeader:exit,tableRow:exit}}}function enterTable(a){const c=a._align;this.enter({type:"table",align:c.map(function(u){return u==="none"?null:u}),children:[]},a),this.data.inTable=!0}function exitTable(a){this.exit(a),this.data.inTable=void 0}function enterRow(a){this.enter({type:"tableRow",children:[]},a)}function exit(a){this.exit(a)}function enterCell(a){this.enter({type:"tableCell",children:[]},a)}function exitCodeText(a){let c=this.resume();this.data.inTable&&(c=c.replace(/\\([\\|])/g,replace));const u=this.stack[this.stack.length-1];u.type,u.value=c,this.exit(a)}function replace(a,c){return c==="|"?c:a}function gfmTableToMarkdown(a){const c=a||{},u=c.tableCellPadding,d=c.tablePipeAlign,f=c.stringLength,m=u?" ":"|";return{unsafe:[{character:"\r",inConstruct:"tableCell"},{character:`
`,inConstruct:"tableCell"},{atBreak:!0,character:"|",after:"[	 :-]"},{character:"|",inConstruct:"tableCell"},{atBreak:!0,character:":",after:"-"},{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{inlineCode:R,table:g,tableCell:b,tableRow:y}};function g(_,M,I,N){return E(C(_,I,N),_.align)}function y(_,M,I,N){const A=w(_,I,N),P=E([A]);return P.slice(0,P.indexOf(`
`))}function b(_,M,I,N){const A=I.enter("tableCell"),P=I.enter("phrasing"),z=I.containerPhrasing(_,{...N,before:m,after:m});return P(),A(),z}function E(_,M){return markdownTable(_,{align:M,alignDelimiters:d,padding:u,stringLength:f})}function C(_,M,I){const N=_.children;let A=-1;const P=[],z=M.enter("table");for(;++A<N.length;)P[A]=w(N[A],M,I);return z(),P}function w(_,M,I){const N=_.children;let A=-1;const P=[],z=M.enter("tableRow");for(;++A<N.length;)P[A]=b(N[A],_,M,I);return z(),P}function R(_,M,I){let N=handle.inlineCode(_,M,I);return I.stack.includes("tableCell")&&(N=N.replace(/\|/g,"\\$&")),N}}function gfmTaskListItemFromMarkdown(){return{exit:{taskListCheckValueChecked:exitCheck,taskListCheckValueUnchecked:exitCheck,paragraph:exitParagraphWithTaskListItem}}}function gfmTaskListItemToMarkdown(){return{unsafe:[{atBreak:!0,character:"-",after:"[:|-]"}],handlers:{listItem:listItemWithTaskListItem}}}function exitCheck(a){const c=this.stack[this.stack.length-2];c.type,c.checked=a.type==="taskListCheckValueChecked"}function exitParagraphWithTaskListItem(a){const c=this.stack[this.stack.length-2];if(c&&c.type==="listItem"&&typeof c.checked=="boolean"){const u=this.stack[this.stack.length-1];u.type;const d=u.children[0];if(d&&d.type==="text"){const f=c.children;let m=-1,g;for(;++m<f.length;){const y=f[m];if(y.type==="paragraph"){g=y;break}}g===u&&(d.value=d.value.slice(1),d.value.length===0?u.children.shift():u.position&&d.position&&typeof d.position.start.offset=="number"&&(d.position.start.column++,d.position.start.offset++,u.position.start=Object.assign({},d.position.start)))}}this.exit(a)}function listItemWithTaskListItem(a,c,u,d){const f=a.children[0],m=typeof a.checked=="boolean"&&f&&f.type==="paragraph",g="["+(a.checked?"x":" ")+"] ",y=u.createTracker(d);m&&y.move(g);let b=handle.listItem(a,c,u,{...d,...y.current()});return m&&(b=b.replace(/^(?:[*+-]|\d+\.)([\r\n]| {1,3})/,E)),b;function E(C){return C+g}}function gfmFromMarkdown(){return[gfmAutolinkLiteralFromMarkdown(),gfmFootnoteFromMarkdown(),gfmStrikethroughFromMarkdown(),gfmTableFromMarkdown(),gfmTaskListItemFromMarkdown()]}function gfmToMarkdown(a){return{extensions:[gfmAutolinkLiteralToMarkdown(),gfmFootnoteToMarkdown(a),gfmStrikethroughToMarkdown(),gfmTableToMarkdown(a),gfmTaskListItemToMarkdown()]}}const wwwPrefix={tokenize:tokenizeWwwPrefix,partial:!0},domain={tokenize:tokenizeDomain,partial:!0},path$1={tokenize:tokenizePath,partial:!0},trail={tokenize:tokenizeTrail,partial:!0},emailDomainDotTrail={tokenize:tokenizeEmailDomainDotTrail,partial:!0},wwwAutolink={name:"wwwAutolink",tokenize:tokenizeWwwAutolink,previous:previousWww},protocolAutolink={name:"protocolAutolink",tokenize:tokenizeProtocolAutolink,previous:previousProtocol},emailAutolink={name:"emailAutolink",tokenize:tokenizeEmailAutolink,previous:previousEmail},text$3={};function gfmAutolinkLiteral(){return{text:text$3}}let code=48;for(;code<123;)text$3[code]=emailAutolink,code++,code===58?code=65:code===91&&(code=97);text$3[43]=emailAutolink;text$3[45]=emailAutolink;text$3[46]=emailAutolink;text$3[95]=emailAutolink;text$3[72]=[emailAutolink,protocolAutolink];text$3[104]=[emailAutolink,protocolAutolink];text$3[87]=[emailAutolink,wwwAutolink];text$3[119]=[emailAutolink,wwwAutolink];function tokenizeEmailAutolink(a,c,u){const d=this;let f,m;return g;function g(w){return!gfmAtext(w)||!previousEmail.call(d,d.previous)||previousUnbalanced(d.events)?u(w):(a.enter("literalAutolink"),a.enter("literalAutolinkEmail"),y(w))}function y(w){return gfmAtext(w)?(a.consume(w),y):w===64?(a.consume(w),b):u(w)}function b(w){return w===46?a.check(emailDomainDotTrail,C,E)(w):w===45||w===95||asciiAlphanumeric(w)?(m=!0,a.consume(w),b):C(w)}function E(w){return a.consume(w),f=!0,b}function C(w){return m&&f&&asciiAlpha(d.previous)?(a.exit("literalAutolinkEmail"),a.exit("literalAutolink"),c(w)):u(w)}}function tokenizeWwwAutolink(a,c,u){const d=this;return f;function f(g){return g!==87&&g!==119||!previousWww.call(d,d.previous)||previousUnbalanced(d.events)?u(g):(a.enter("literalAutolink"),a.enter("literalAutolinkWww"),a.check(wwwPrefix,a.attempt(domain,a.attempt(path$1,m),u),u)(g))}function m(g){return a.exit("literalAutolinkWww"),a.exit("literalAutolink"),c(g)}}function tokenizeProtocolAutolink(a,c,u){const d=this;let f="",m=!1;return g;function g(w){return(w===72||w===104)&&previousProtocol.call(d,d.previous)&&!previousUnbalanced(d.events)?(a.enter("literalAutolink"),a.enter("literalAutolinkHttp"),f+=String.fromCodePoint(w),a.consume(w),y):u(w)}function y(w){if(asciiAlpha(w)&&f.length<5)return f+=String.fromCodePoint(w),a.consume(w),y;if(w===58){const R=f.toLowerCase();if(R==="http"||R==="https")return a.consume(w),b}return u(w)}function b(w){return w===47?(a.consume(w),m?E:(m=!0,b)):u(w)}function E(w){return w===null||asciiControl(w)||markdownLineEndingOrSpace(w)||unicodeWhitespace(w)||unicodePunctuation(w)?u(w):a.attempt(domain,a.attempt(path$1,C),u)(w)}function C(w){return a.exit("literalAutolinkHttp"),a.exit("literalAutolink"),c(w)}}function tokenizeWwwPrefix(a,c,u){let d=0;return f;function f(g){return(g===87||g===119)&&d<3?(d++,a.consume(g),f):g===46&&d===3?(a.consume(g),m):u(g)}function m(g){return g===null?u(g):c(g)}}function tokenizeDomain(a,c,u){let d,f,m;return g;function g(E){return E===46||E===95?a.check(trail,b,y)(E):E===null||markdownLineEndingOrSpace(E)||unicodeWhitespace(E)||E!==45&&unicodePunctuation(E)?b(E):(m=!0,a.consume(E),g)}function y(E){return E===95?d=!0:(f=d,d=void 0),a.consume(E),g}function b(E){return f||d||!m?u(E):c(E)}}function tokenizePath(a,c){let u=0,d=0;return f;function f(g){return g===40?(u++,a.consume(g),f):g===41&&d<u?m(g):g===33||g===34||g===38||g===39||g===41||g===42||g===44||g===46||g===58||g===59||g===60||g===63||g===93||g===95||g===126?a.check(trail,c,m)(g):g===null||markdownLineEndingOrSpace(g)||unicodeWhitespace(g)?c(g):(a.consume(g),f)}function m(g){return g===41&&d++,a.consume(g),f}}function tokenizeTrail(a,c,u){return d;function d(y){return y===33||y===34||y===39||y===41||y===42||y===44||y===46||y===58||y===59||y===63||y===95||y===126?(a.consume(y),d):y===38?(a.consume(y),m):y===93?(a.consume(y),f):y===60||y===null||markdownLineEndingOrSpace(y)||unicodeWhitespace(y)?c(y):u(y)}function f(y){return y===null||y===40||y===91||markdownLineEndingOrSpace(y)||unicodeWhitespace(y)?c(y):d(y)}function m(y){return asciiAlpha(y)?g(y):u(y)}function g(y){return y===59?(a.consume(y),d):asciiAlpha(y)?(a.consume(y),g):u(y)}}function tokenizeEmailDomainDotTrail(a,c,u){return d;function d(m){return a.consume(m),f}function f(m){return asciiAlphanumeric(m)?u(m):c(m)}}function previousWww(a){return a===null||a===40||a===42||a===95||a===91||a===93||a===126||markdownLineEndingOrSpace(a)}function previousProtocol(a){return!asciiAlpha(a)}function previousEmail(a){return!(a===47||gfmAtext(a))}function gfmAtext(a){return a===43||a===45||a===46||a===95||asciiAlphanumeric(a)}function previousUnbalanced(a){let c=a.length,u=!1;for(;c--;){const d=a[c][1];if((d.type==="labelLink"||d.type==="labelImage")&&!d._balanced){u=!0;break}if(d._gfmAutolinkLiteralWalkedInto){u=!1;break}}return a.length>0&&!u&&(a[a.length-1][1]._gfmAutolinkLiteralWalkedInto=!0),u}const indent={tokenize:tokenizeIndent,partial:!0};function gfmFootnote(){return{document:{91:{name:"gfmFootnoteDefinition",tokenize:tokenizeDefinitionStart,continuation:{tokenize:tokenizeDefinitionContinuation},exit:gfmFootnoteDefinitionEnd}},text:{91:{name:"gfmFootnoteCall",tokenize:tokenizeGfmFootnoteCall},93:{name:"gfmPotentialFootnoteCall",add:"after",tokenize:tokenizePotentialGfmFootnoteCall,resolveTo:resolveToPotentialGfmFootnoteCall}}}}function tokenizePotentialGfmFootnoteCall(a,c,u){const d=this;let f=d.events.length;const m=d.parser.gfmFootnotes||(d.parser.gfmFootnotes=[]);let g;for(;f--;){const b=d.events[f][1];if(b.type==="labelImage"){g=b;break}if(b.type==="gfmFootnoteCall"||b.type==="labelLink"||b.type==="label"||b.type==="image"||b.type==="link")break}return y;function y(b){if(!g||!g._balanced)return u(b);const E=normalizeIdentifier(d.sliceSerialize({start:g.end,end:d.now()}));return E.codePointAt(0)!==94||!m.includes(E.slice(1))?u(b):(a.enter("gfmFootnoteCallLabelMarker"),a.consume(b),a.exit("gfmFootnoteCallLabelMarker"),c(b))}}function resolveToPotentialGfmFootnoteCall(a,c){let u=a.length;for(;u--;)if(a[u][1].type==="labelImage"&&a[u][0]==="enter"){a[u][1];break}a[u+1][1].type="data",a[u+3][1].type="gfmFootnoteCallLabelMarker";const d={type:"gfmFootnoteCall",start:Object.assign({},a[u+3][1].start),end:Object.assign({},a[a.length-1][1].end)},f={type:"gfmFootnoteCallMarker",start:Object.assign({},a[u+3][1].end),end:Object.assign({},a[u+3][1].end)};f.end.column++,f.end.offset++,f.end._bufferIndex++;const m={type:"gfmFootnoteCallString",start:Object.assign({},f.end),end:Object.assign({},a[a.length-1][1].start)},g={type:"chunkString",contentType:"string",start:Object.assign({},m.start),end:Object.assign({},m.end)},y=[a[u+1],a[u+2],["enter",d,c],a[u+3],a[u+4],["enter",f,c],["exit",f,c],["enter",m,c],["enter",g,c],["exit",g,c],["exit",m,c],a[a.length-2],a[a.length-1],["exit",d,c]];return a.splice(u,a.length-u+1,...y),a}function tokenizeGfmFootnoteCall(a,c,u){const d=this,f=d.parser.gfmFootnotes||(d.parser.gfmFootnotes=[]);let m=0,g;return y;function y(w){return a.enter("gfmFootnoteCall"),a.enter("gfmFootnoteCallLabelMarker"),a.consume(w),a.exit("gfmFootnoteCallLabelMarker"),b}function b(w){return w!==94?u(w):(a.enter("gfmFootnoteCallMarker"),a.consume(w),a.exit("gfmFootnoteCallMarker"),a.enter("gfmFootnoteCallString"),a.enter("chunkString").contentType="string",E)}function E(w){if(m>999||w===93&&!g||w===null||w===91||markdownLineEndingOrSpace(w))return u(w);if(w===93){a.exit("chunkString");const R=a.exit("gfmFootnoteCallString");return f.includes(normalizeIdentifier(d.sliceSerialize(R)))?(a.enter("gfmFootnoteCallLabelMarker"),a.consume(w),a.exit("gfmFootnoteCallLabelMarker"),a.exit("gfmFootnoteCall"),c):u(w)}return markdownLineEndingOrSpace(w)||(g=!0),m++,a.consume(w),w===92?C:E}function C(w){return w===91||w===92||w===93?(a.consume(w),m++,E):E(w)}}function tokenizeDefinitionStart(a,c,u){const d=this,f=d.parser.gfmFootnotes||(d.parser.gfmFootnotes=[]);let m,g=0,y;return b;function b(M){return a.enter("gfmFootnoteDefinition")._container=!0,a.enter("gfmFootnoteDefinitionLabel"),a.enter("gfmFootnoteDefinitionLabelMarker"),a.consume(M),a.exit("gfmFootnoteDefinitionLabelMarker"),E}function E(M){return M===94?(a.enter("gfmFootnoteDefinitionMarker"),a.consume(M),a.exit("gfmFootnoteDefinitionMarker"),a.enter("gfmFootnoteDefinitionLabelString"),a.enter("chunkString").contentType="string",C):u(M)}function C(M){if(g>999||M===93&&!y||M===null||M===91||markdownLineEndingOrSpace(M))return u(M);if(M===93){a.exit("chunkString");const I=a.exit("gfmFootnoteDefinitionLabelString");return m=normalizeIdentifier(d.sliceSerialize(I)),a.enter("gfmFootnoteDefinitionLabelMarker"),a.consume(M),a.exit("gfmFootnoteDefinitionLabelMarker"),a.exit("gfmFootnoteDefinitionLabel"),R}return markdownLineEndingOrSpace(M)||(y=!0),g++,a.consume(M),M===92?w:C}function w(M){return M===91||M===92||M===93?(a.consume(M),g++,C):C(M)}function R(M){return M===58?(a.enter("definitionMarker"),a.consume(M),a.exit("definitionMarker"),f.includes(m)||f.push(m),factorySpace(a,_,"gfmFootnoteDefinitionWhitespace")):u(M)}function _(M){return c(M)}}function tokenizeDefinitionContinuation(a,c,u){return a.check(blankLine,c,a.attempt(indent,c,u))}function gfmFootnoteDefinitionEnd(a){a.exit("gfmFootnoteDefinition")}function tokenizeIndent(a,c,u){const d=this;return factorySpace(a,f,"gfmFootnoteDefinitionIndent",5);function f(m){const g=d.events[d.events.length-1];return g&&g[1].type==="gfmFootnoteDefinitionIndent"&&g[2].sliceSerialize(g[1],!0).length===4?c(m):u(m)}}function gfmStrikethrough(a){let u=(a||{}).singleTilde;const d={name:"strikethrough",tokenize:m,resolveAll:f};return u==null&&(u=!0),{text:{126:d},insideSpan:{null:[d]},attentionMarkers:{null:[126]}};function f(g,y){let b=-1;for(;++b<g.length;)if(g[b][0]==="enter"&&g[b][1].type==="strikethroughSequenceTemporary"&&g[b][1]._close){let E=b;for(;E--;)if(g[E][0]==="exit"&&g[E][1].type==="strikethroughSequenceTemporary"&&g[E][1]._open&&g[b][1].end.offset-g[b][1].start.offset===g[E][1].end.offset-g[E][1].start.offset){g[b][1].type="strikethroughSequence",g[E][1].type="strikethroughSequence";const C={type:"strikethrough",start:Object.assign({},g[E][1].start),end:Object.assign({},g[b][1].end)},w={type:"strikethroughText",start:Object.assign({},g[E][1].end),end:Object.assign({},g[b][1].start)},R=[["enter",C,y],["enter",g[E][1],y],["exit",g[E][1],y],["enter",w,y]],_=y.parser.constructs.insideSpan.null;_&&splice(R,R.length,0,resolveAll(_,g.slice(E+1,b),y)),splice(R,R.length,0,[["exit",w,y],["enter",g[b][1],y],["exit",g[b][1],y],["exit",C,y]]),splice(g,E-1,b-E+3,R),b=E+R.length-2;break}}for(b=-1;++b<g.length;)g[b][1].type==="strikethroughSequenceTemporary"&&(g[b][1].type="data");return g}function m(g,y,b){const E=this.previous,C=this.events;let w=0;return R;function R(M){return E===126&&C[C.length-1][1].type!=="characterEscape"?b(M):(g.enter("strikethroughSequenceTemporary"),_(M))}function _(M){const I=classifyCharacter(E);if(M===126)return w>1?b(M):(g.consume(M),w++,_);if(w<2&&!u)return b(M);const N=g.exit("strikethroughSequenceTemporary"),A=classifyCharacter(M);return N._open=!A||A===2&&!!I,N._close=!I||I===2&&!!A,y(M)}}}class EditMap{constructor(){this.map=[]}add(c,u,d){addImplementation(this,c,u,d)}consume(c){if(this.map.sort(function(m,g){return m[0]-g[0]}),this.map.length===0)return;let u=this.map.length;const d=[];for(;u>0;)u-=1,d.push(c.slice(this.map[u][0]+this.map[u][1]),this.map[u][2]),c.length=this.map[u][0];d.push(c.slice()),c.length=0;let f=d.pop();for(;f;){for(const m of f)c.push(m);f=d.pop()}this.map.length=0}}function addImplementation(a,c,u,d){let f=0;if(!(u===0&&d.length===0)){for(;f<a.map.length;){if(a.map[f][0]===c){a.map[f][1]+=u,a.map[f][2].push(...d);return}f+=1}a.map.push([c,u,d])}}function gfmTableAlign(a,c){let u=!1;const d=[];for(;c<a.length;){const f=a[c];if(u){if(f[0]==="enter")f[1].type==="tableContent"&&d.push(a[c+1][1].type==="tableDelimiterMarker"?"left":"none");else if(f[1].type==="tableContent"){if(a[c-1][1].type==="tableDelimiterMarker"){const m=d.length-1;d[m]=d[m]==="left"?"center":"right"}}else if(f[1].type==="tableDelimiterRow")break}else f[0]==="enter"&&f[1].type==="tableDelimiterRow"&&(u=!0);c+=1}return d}function gfmTable(){return{flow:{null:{name:"table",tokenize:tokenizeTable,resolveAll:resolveTable}}}}function tokenizeTable(a,c,u){const d=this;let f=0,m=0,g;return y;function y(K){let X=d.events.length-1;for(;X>-1;){const Z=d.events[X][1].type;if(Z==="lineEnding"||Z==="linePrefix")X--;else break}const Q=X>-1?d.events[X][1].type:null,Y=Q==="tableHead"||Q==="tableRow"?L:b;return Y===L&&d.parser.lazy[d.now().line]?u(K):Y(K)}function b(K){return a.enter("tableHead"),a.enter("tableRow"),E(K)}function E(K){return K===124||(g=!0,m+=1),C(K)}function C(K){return K===null?u(K):markdownLineEnding(K)?m>1?(m=0,d.interrupt=!0,a.exit("tableRow"),a.enter("lineEnding"),a.consume(K),a.exit("lineEnding"),_):u(K):markdownSpace(K)?factorySpace(a,C,"whitespace")(K):(m+=1,g&&(g=!1,f+=1),K===124?(a.enter("tableCellDivider"),a.consume(K),a.exit("tableCellDivider"),g=!0,C):(a.enter("data"),w(K)))}function w(K){return K===null||K===124||markdownLineEndingOrSpace(K)?(a.exit("data"),C(K)):(a.consume(K),K===92?R:w)}function R(K){return K===92||K===124?(a.consume(K),w):w(K)}function _(K){return d.interrupt=!1,d.parser.lazy[d.now().line]?u(K):(a.enter("tableDelimiterRow"),g=!1,markdownSpace(K)?factorySpace(a,M,"linePrefix",d.parser.constructs.disable.null.includes("codeIndented")?void 0:4)(K):M(K))}function M(K){return K===45||K===58?N(K):K===124?(g=!0,a.enter("tableCellDivider"),a.consume(K),a.exit("tableCellDivider"),I):j(K)}function I(K){return markdownSpace(K)?factorySpace(a,N,"whitespace")(K):N(K)}function N(K){return K===58?(m+=1,g=!0,a.enter("tableDelimiterMarker"),a.consume(K),a.exit("tableDelimiterMarker"),A):K===45?(m+=1,A(K)):K===null||markdownLineEnding(K)?B(K):j(K)}function A(K){return K===45?(a.enter("tableDelimiterFiller"),P(K)):j(K)}function P(K){return K===45?(a.consume(K),P):K===58?(g=!0,a.exit("tableDelimiterFiller"),a.enter("tableDelimiterMarker"),a.consume(K),a.exit("tableDelimiterMarker"),z):(a.exit("tableDelimiterFiller"),z(K))}function z(K){return markdownSpace(K)?factorySpace(a,B,"whitespace")(K):B(K)}function B(K){return K===124?M(K):K===null||markdownLineEnding(K)?!g||f!==m?j(K):(a.exit("tableDelimiterRow"),a.exit("tableHead"),c(K)):j(K)}function j(K){return u(K)}function L(K){return a.enter("tableRow"),U(K)}function U(K){return K===124?(a.enter("tableCellDivider"),a.consume(K),a.exit("tableCellDivider"),U):K===null||markdownLineEnding(K)?(a.exit("tableRow"),c(K)):markdownSpace(K)?factorySpace(a,U,"whitespace")(K):(a.enter("data"),q(K))}function q(K){return K===null||K===124||markdownLineEndingOrSpace(K)?(a.exit("data"),U(K)):(a.consume(K),K===92?F:q)}function F(K){return K===92||K===124?(a.consume(K),q):q(K)}}function resolveTable(a,c){let u=-1,d=!0,f=0,m=[0,0,0,0],g=[0,0,0,0],y=!1,b=0,E,C,w;const R=new EditMap;for(;++u<a.length;){const _=a[u],M=_[1];_[0]==="enter"?M.type==="tableHead"?(y=!1,b!==0&&(flushTableEnd(R,c,b,E,C),C=void 0,b=0),E={type:"table",start:Object.assign({},M.start),end:Object.assign({},M.end)},R.add(u,0,[["enter",E,c]])):M.type==="tableRow"||M.type==="tableDelimiterRow"?(d=!0,w=void 0,m=[0,0,0,0],g=[0,u+1,0,0],y&&(y=!1,C={type:"tableBody",start:Object.assign({},M.start),end:Object.assign({},M.end)},R.add(u,0,[["enter",C,c]])),f=M.type==="tableDelimiterRow"?2:C?3:1):f&&(M.type==="data"||M.type==="tableDelimiterMarker"||M.type==="tableDelimiterFiller")?(d=!1,g[2]===0&&(m[1]!==0&&(g[0]=g[1],w=flushCell(R,c,m,f,void 0,w),m=[0,0,0,0]),g[2]=u)):M.type==="tableCellDivider"&&(d?d=!1:(m[1]!==0&&(g[0]=g[1],w=flushCell(R,c,m,f,void 0,w)),m=g,g=[m[1],u,0,0])):M.type==="tableHead"?(y=!0,b=u):M.type==="tableRow"||M.type==="tableDelimiterRow"?(b=u,m[1]!==0?(g[0]=g[1],w=flushCell(R,c,m,f,u,w)):g[1]!==0&&(w=flushCell(R,c,g,f,u,w)),f=0):f&&(M.type==="data"||M.type==="tableDelimiterMarker"||M.type==="tableDelimiterFiller")&&(g[3]=u)}for(b!==0&&flushTableEnd(R,c,b,E,C),R.consume(c.events),u=-1;++u<c.events.length;){const _=c.events[u];_[0]==="enter"&&_[1].type==="table"&&(_[1]._align=gfmTableAlign(c.events,u))}return a}function flushCell(a,c,u,d,f,m){const g=d===1?"tableHeader":d===2?"tableDelimiter":"tableData",y="tableContent";u[0]!==0&&(m.end=Object.assign({},getPoint(c.events,u[0])),a.add(u[0],0,[["exit",m,c]]));const b=getPoint(c.events,u[1]);if(m={type:g,start:Object.assign({},b),end:Object.assign({},b)},a.add(u[1],0,[["enter",m,c]]),u[2]!==0){const E=getPoint(c.events,u[2]),C=getPoint(c.events,u[3]),w={type:y,start:Object.assign({},E),end:Object.assign({},C)};if(a.add(u[2],0,[["enter",w,c]]),d!==2){const R=c.events[u[2]],_=c.events[u[3]];if(R[1].end=Object.assign({},_[1].end),R[1].type="chunkText",R[1].contentType="text",u[3]>u[2]+1){const M=u[2]+1,I=u[3]-u[2]-1;a.add(M,I,[])}}a.add(u[3]+1,0,[["exit",w,c]])}return f!==void 0&&(m.end=Object.assign({},getPoint(c.events,f)),a.add(f,0,[["exit",m,c]]),m=void 0),m}function flushTableEnd(a,c,u,d,f){const m=[],g=getPoint(c.events,u);f&&(f.end=Object.assign({},g),m.push(["exit",f,c])),d.end=Object.assign({},g),m.push(["exit",d,c]),a.add(u+1,0,m)}function getPoint(a,c){const u=a[c],d=u[0]==="enter"?"start":"end";return u[1][d]}const tasklistCheck={name:"tasklistCheck",tokenize:tokenizeTasklistCheck};function gfmTaskListItem(){return{text:{91:tasklistCheck}}}function tokenizeTasklistCheck(a,c,u){const d=this;return f;function f(b){return d.previous!==null||!d._gfmTasklistFirstContentOfListItem?u(b):(a.enter("taskListCheck"),a.enter("taskListCheckMarker"),a.consume(b),a.exit("taskListCheckMarker"),m)}function m(b){return markdownLineEndingOrSpace(b)?(a.enter("taskListCheckValueUnchecked"),a.consume(b),a.exit("taskListCheckValueUnchecked"),g):b===88||b===120?(a.enter("taskListCheckValueChecked"),a.consume(b),a.exit("taskListCheckValueChecked"),g):u(b)}function g(b){return b===93?(a.enter("taskListCheckMarker"),a.consume(b),a.exit("taskListCheckMarker"),a.exit("taskListCheck"),y):u(b)}function y(b){return markdownLineEnding(b)?c(b):markdownSpace(b)?a.check({tokenize:spaceThenNonSpace},c,u)(b):u(b)}}function spaceThenNonSpace(a,c,u){return factorySpace(a,d,"whitespace");function d(f){return f===null?u(f):c(f)}}function gfm(a){return combineExtensions([gfmAutolinkLiteral(),gfmFootnote(),gfmStrikethrough(a),gfmTable(),gfmTaskListItem()])}const emptyOptions$2={};function remarkGfm(a){const c=this,u=a||emptyOptions$2,d=c.data(),f=d.micromarkExtensions||(d.micromarkExtensions=[]),m=d.fromMarkdownExtensions||(d.fromMarkdownExtensions=[]),g=d.toMarkdownExtensions||(d.toMarkdownExtensions=[]);f.push(gfm(u)),m.push(gfmFromMarkdown()),g.push(gfmToMarkdown(u))}function mathFromMarkdown(){return{enter:{mathFlow:a,mathFlowFenceMeta:c,mathText:m},exit:{mathFlow:f,mathFlowFence:d,mathFlowFenceMeta:u,mathFlowValue:y,mathText:g,mathTextData:y}};function a(b){const E={type:"element",tagName:"code",properties:{className:["language-math","math-display"]},children:[]};this.enter({type:"math",meta:null,value:"",data:{hName:"pre",hChildren:[E]}},b)}function c(){this.buffer()}function u(){const b=this.resume(),E=this.stack[this.stack.length-1];E.type,E.meta=b}function d(){this.data.mathFlowInside||(this.buffer(),this.data.mathFlowInside=!0)}function f(b){const E=this.resume().replace(/^(\r?\n|\r)|(\r?\n|\r)$/g,""),C=this.stack[this.stack.length-1];C.type,this.exit(b),C.value=E;const w=C.data.hChildren[0];w.type,w.tagName,w.children.push({type:"text",value:E}),this.data.mathFlowInside=void 0}function m(b){this.enter({type:"inlineMath",value:"",data:{hName:"code",hProperties:{className:["language-math","math-inline"]},hChildren:[]}},b),this.buffer()}function g(b){const E=this.resume(),C=this.stack[this.stack.length-1];C.type,this.exit(b),C.value=E,C.data.hChildren.push({type:"text",value:E})}function y(b){this.config.enter.data.call(this,b),this.config.exit.data.call(this,b)}}function mathToMarkdown(a){let c=(a||{}).singleDollarTextMath;return c==null&&(c=!0),d.peek=f,{unsafe:[{character:"\r",inConstruct:"mathFlowMeta"},{character:`
`,inConstruct:"mathFlowMeta"},{character:"$",after:c?void 0:"\\$",inConstruct:"phrasing"},{character:"$",inConstruct:"mathFlowMeta"},{atBreak:!0,character:"$",after:"\\$"}],handlers:{math:u,inlineMath:d}};function u(m,g,y,b){const E=m.value||"",C=y.createTracker(b),w="$".repeat(Math.max(longestStreak(E,"$")+1,2)),R=y.enter("mathFlow");let _=C.move(w);if(m.meta){const M=y.enter("mathFlowMeta");_+=C.move(y.safe(m.meta,{after:`
`,before:_,encode:["$"],...C.current()})),M()}return _+=C.move(`
`),E&&(_+=C.move(E+`
`)),_+=C.move(w),R(),_}function d(m,g,y){let b=m.value||"",E=1;for(c||E++;new RegExp("(^|[^$])"+"\\$".repeat(E)+"([^$]|$)").test(b);)E++;const C="$".repeat(E);/[^ \r\n]/.test(b)&&(/^[ \r\n]/.test(b)&&/[ \r\n]$/.test(b)||/^\$|\$$/.test(b))&&(b=" "+b+" ");let w=-1;for(;++w<y.unsafe.length;){const R=y.unsafe[w];if(!R.atBreak)continue;const _=y.compilePattern(R);let M;for(;M=_.exec(b);){let I=M.index;b.codePointAt(I)===10&&b.codePointAt(I-1)===13&&I--,b=b.slice(0,I)+" "+b.slice(M.index+1)}}return C+b+C}function f(){return"$"}}const mathFlow={tokenize:tokenizeMathFenced,concrete:!0,name:"mathFlow"},nonLazyContinuation={tokenize:tokenizeNonLazyContinuation,partial:!0};function tokenizeMathFenced(a,c,u){const d=this,f=d.events[d.events.length-1],m=f&&f[1].type==="linePrefix"?f[2].sliceSerialize(f[1],!0).length:0;let g=0;return y;function y(P){return a.enter("mathFlow"),a.enter("mathFlowFence"),a.enter("mathFlowFenceSequence"),b(P)}function b(P){return P===36?(a.consume(P),g++,b):g<2?u(P):(a.exit("mathFlowFenceSequence"),factorySpace(a,E,"whitespace")(P))}function E(P){return P===null||markdownLineEnding(P)?w(P):(a.enter("mathFlowFenceMeta"),a.enter("chunkString",{contentType:"string"}),C(P))}function C(P){return P===null||markdownLineEnding(P)?(a.exit("chunkString"),a.exit("mathFlowFenceMeta"),w(P)):P===36?u(P):(a.consume(P),C)}function w(P){return a.exit("mathFlowFence"),d.interrupt?c(P):a.attempt(nonLazyContinuation,R,N)(P)}function R(P){return a.attempt({tokenize:A,partial:!0},N,_)(P)}function _(P){return(m?factorySpace(a,M,"linePrefix",m+1):M)(P)}function M(P){return P===null?N(P):markdownLineEnding(P)?a.attempt(nonLazyContinuation,R,N)(P):(a.enter("mathFlowValue"),I(P))}function I(P){return P===null||markdownLineEnding(P)?(a.exit("mathFlowValue"),M(P)):(a.consume(P),I)}function N(P){return a.exit("mathFlow"),c(P)}function A(P,z,B){let j=0;return factorySpace(P,L,"linePrefix",d.parser.constructs.disable.null.includes("codeIndented")?void 0:4);function L(F){return P.enter("mathFlowFence"),P.enter("mathFlowFenceSequence"),U(F)}function U(F){return F===36?(j++,P.consume(F),U):j<g?B(F):(P.exit("mathFlowFenceSequence"),factorySpace(P,q,"whitespace")(F))}function q(F){return F===null||markdownLineEnding(F)?(P.exit("mathFlowFence"),z(F)):B(F)}}}function tokenizeNonLazyContinuation(a,c,u){const d=this;return f;function f(g){return g===null?c(g):(a.enter("lineEnding"),a.consume(g),a.exit("lineEnding"),m)}function m(g){return d.parser.lazy[d.now().line]?u(g):c(g)}}function mathText(a){let u=(a||{}).singleDollarTextMath;return u==null&&(u=!0),{tokenize:d,resolve:resolveMathText,previous,name:"mathText"};function d(f,m,g){let y=0,b,E;return C;function C(I){return f.enter("mathText"),f.enter("mathTextSequence"),w(I)}function w(I){return I===36?(f.consume(I),y++,w):y<2&&!u?g(I):(f.exit("mathTextSequence"),R(I))}function R(I){return I===null?g(I):I===36?(E=f.enter("mathTextSequence"),b=0,M(I)):I===32?(f.enter("space"),f.consume(I),f.exit("space"),R):markdownLineEnding(I)?(f.enter("lineEnding"),f.consume(I),f.exit("lineEnding"),R):(f.enter("mathTextData"),_(I))}function _(I){return I===null||I===32||I===36||markdownLineEnding(I)?(f.exit("mathTextData"),R(I)):(f.consume(I),_)}function M(I){return I===36?(f.consume(I),b++,M):b===y?(f.exit("mathTextSequence"),f.exit("mathText"),m(I)):(E.type="mathTextData",_(I))}}}function resolveMathText(a){let c=a.length-4,u=3,d,f;if((a[u][1].type==="lineEnding"||a[u][1].type==="space")&&(a[c][1].type==="lineEnding"||a[c][1].type==="space")){for(d=u;++d<c;)if(a[d][1].type==="mathTextData"){a[c][1].type="mathTextPadding",a[u][1].type="mathTextPadding",u+=2,c-=2;break}}for(d=u-1,c++;++d<=c;)f===void 0?d!==c&&a[d][1].type!=="lineEnding"&&(f=d):(d===c||a[d][1].type==="lineEnding")&&(a[f][1].type="mathTextData",d!==f+2&&(a[f][1].end=a[d-1][1].end,a.splice(f+2,d-f-2),c-=d-f-2,d=f+2),f=void 0);return a}function previous(a){return a!==36||this.events[this.events.length-1][1].type==="characterEscape"}function math$1(a){return{flow:{36:mathFlow},text:{36:mathText(a)}}}class SourceLocation{constructor(c,u,d){this.lexer=void 0,this.start=void 0,this.end=void 0,this.lexer=c,this.start=u,this.end=d}static range(c,u){return u?!c||!c.loc||!u.loc||c.loc.lexer!==u.loc.lexer?null:new SourceLocation(c.loc.lexer,c.loc.start,u.loc.end):c&&c.loc}}class Token{constructor(c,u){this.text=void 0,this.loc=void 0,this.noexpand=void 0,this.treatAsRelax=void 0,this.text=c,this.loc=u}range(c,u){return new Token(u,SourceLocation.range(this,c))}}class ParseError{constructor(c,u){this.name=void 0,this.position=void 0,this.length=void 0,this.rawMessage=void 0;var d="KaTeX parse error: "+c,f,m,g=u&&u.loc;if(g&&g.start<=g.end){var y=g.lexer.input;f=g.start,m=g.end,f===y.length?d+=" at end of input: ":d+=" at position "+(f+1)+": ";var b=y.slice(f,m).replace(/[^]/g,"$&̲"),E;f>15?E="…"+y.slice(f-15,f):E=y.slice(0,f);var C;m+15<y.length?C=y.slice(m,m+15)+"…":C=y.slice(m),d+=E+b+C}var w=new Error(d);return w.name="ParseError",w.__proto__=ParseError.prototype,w.position=f,f!=null&&m!=null&&(w.length=m-f),w.rawMessage=c,w}}ParseError.prototype.__proto__=Error.prototype;var contains=function(c,u){return c.indexOf(u)!==-1},deflt=function(c,u){return c===void 0?u:c},uppercase=/([A-Z])/g,hyphenate=function(c){return c.replace(uppercase,"-$1").toLowerCase()},ESCAPE_LOOKUP={"&":"&amp;",">":"&gt;","<":"&lt;",'"':"&quot;","'":"&#x27;"},ESCAPE_REGEX=/[&><"']/g;function escape(a){return String(a).replace(ESCAPE_REGEX,c=>ESCAPE_LOOKUP[c])}var getBaseElem=function a(c){return c.type==="ordgroup"||c.type==="color"?c.body.length===1?a(c.body[0]):c:c.type==="font"?a(c.body):c},isCharacterBox=function(c){var u=getBaseElem(c);return u.type==="mathord"||u.type==="textord"||u.type==="atom"},assert=function(c){if(!c)throw new Error("Expected non-null, but got "+String(c));return c},protocolFromUrl=function(c){var u=/^[\x00-\x20]*([^\\/#?]*?)(:|&#0*58|&#x0*3a|&colon)/i.exec(c);return u?u[2]!==":"||!/^[a-zA-Z][a-zA-Z0-9+\-.]*$/.test(u[1])?null:u[1].toLowerCase():"_relative"},utils={contains,deflt,escape,hyphenate,getBaseElem,isCharacterBox,protocolFromUrl},SETTINGS_SCHEMA={displayMode:{type:"boolean",description:"Render math in display mode, which puts the math in display style (so \\int and \\sum are large, for example), and centers the math on the page on its own line.",cli:"-d, --display-mode"},output:{type:{enum:["htmlAndMathml","html","mathml"]},description:"Determines the markup language of the output.",cli:"-F, --format <type>"},leqno:{type:"boolean",description:"Render display math in leqno style (left-justified tags)."},fleqn:{type:"boolean",description:"Render display math flush left."},throwOnError:{type:"boolean",default:!0,cli:"-t, --no-throw-on-error",cliDescription:"Render errors (in the color given by --error-color) instead of throwing a ParseError exception when encountering an error."},errorColor:{type:"string",default:"#cc0000",cli:"-c, --error-color <color>",cliDescription:"A color string given in the format 'rgb' or 'rrggbb' (no #). This option determines the color of errors rendered by the -t option.",cliProcessor:a=>"#"+a},macros:{type:"object",cli:"-m, --macro <def>",cliDescription:"Define custom macro of the form '\\foo:expansion' (use multiple -m arguments for multiple macros).",cliDefault:[],cliProcessor:(a,c)=>(c.push(a),c)},minRuleThickness:{type:"number",description:"Specifies a minimum thickness, in ems, for fraction lines, `\\sqrt` top lines, `{array}` vertical lines, `\\hline`, `\\hdashline`, `\\underline`, `\\overline`, and the borders of `\\fbox`, `\\boxed`, and `\\fcolorbox`.",processor:a=>Math.max(0,a),cli:"--min-rule-thickness <size>",cliProcessor:parseFloat},colorIsTextColor:{type:"boolean",description:"Makes \\color behave like LaTeX's 2-argument \\textcolor, instead of LaTeX's one-argument \\color mode change.",cli:"-b, --color-is-text-color"},strict:{type:[{enum:["warn","ignore","error"]},"boolean","function"],description:"Turn on strict / LaTeX faithfulness mode, which throws an error if the input uses features that are not supported by LaTeX.",cli:"-S, --strict",cliDefault:!1},trust:{type:["boolean","function"],description:"Trust the input, enabling all HTML features such as \\url.",cli:"-T, --trust"},maxSize:{type:"number",default:1/0,description:"If non-zero, all user-specified sizes, e.g. in \\rule{500em}{500em}, will be capped to maxSize ems. Otherwise, elements and spaces can be arbitrarily large",processor:a=>Math.max(0,a),cli:"-s, --max-size <n>",cliProcessor:parseInt},maxExpand:{type:"number",default:1e3,description:"Limit the number of macro expansions to the specified number, to prevent e.g. infinite macro loops. If set to Infinity, the macro expander will try to fully expand as in LaTeX.",processor:a=>Math.max(0,a),cli:"-e, --max-expand <n>",cliProcessor:a=>a==="Infinity"?1/0:parseInt(a)},globalGroup:{type:"boolean",cli:!1}};function getDefaultValue(a){if(a.default)return a.default;var c=a.type,u=Array.isArray(c)?c[0]:c;if(typeof u!="string")return u.enum[0];switch(u){case"boolean":return!1;case"string":return"";case"number":return 0;case"object":return{}}}class Settings{constructor(c){this.displayMode=void 0,this.output=void 0,this.leqno=void 0,this.fleqn=void 0,this.throwOnError=void 0,this.errorColor=void 0,this.macros=void 0,this.minRuleThickness=void 0,this.colorIsTextColor=void 0,this.strict=void 0,this.trust=void 0,this.maxSize=void 0,this.maxExpand=void 0,this.globalGroup=void 0,c=c||{};for(var u in SETTINGS_SCHEMA)if(SETTINGS_SCHEMA.hasOwnProperty(u)){var d=SETTINGS_SCHEMA[u];this[u]=c[u]!==void 0?d.processor?d.processor(c[u]):c[u]:getDefaultValue(d)}}reportNonstrict(c,u,d){var f=this.strict;if(typeof f=="function"&&(f=f(c,u,d)),!(!f||f==="ignore")){if(f===!0||f==="error")throw new ParseError("LaTeX-incompatible input and strict mode is set to 'error': "+(u+" ["+c+"]"),d);f==="warn"?typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(u+" ["+c+"]")):typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+f+"': "+u+" ["+c+"]"))}}useStrictBehavior(c,u,d){var f=this.strict;if(typeof f=="function")try{f=f(c,u,d)}catch{f="error"}return!f||f==="ignore"?!1:f===!0||f==="error"?!0:f==="warn"?(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to 'warn': "+(u+" ["+c+"]")),!1):(typeof console<"u"&&console.warn("LaTeX-incompatible input and strict mode is set to "+("unrecognized '"+f+"': "+u+" ["+c+"]")),!1)}isTrusted(c){if(c.url&&!c.protocol){var u=utils.protocolFromUrl(c.url);if(u==null)return!1;c.protocol=u}var d=typeof this.trust=="function"?this.trust(c):this.trust;return!!d}}class Style{constructor(c,u,d){this.id=void 0,this.size=void 0,this.cramped=void 0,this.id=c,this.size=u,this.cramped=d}sup(){return styles[sup[this.id]]}sub(){return styles[sub[this.id]]}fracNum(){return styles[fracNum[this.id]]}fracDen(){return styles[fracDen[this.id]]}cramp(){return styles[cramp[this.id]]}text(){return styles[text$1[this.id]]}isTight(){return this.size>=2}}var D=0,Dc=1,T=2,Tc=3,S=4,Sc=5,SS=6,SSc=7,styles=[new Style(D,0,!1),new Style(Dc,0,!0),new Style(T,1,!1),new Style(Tc,1,!0),new Style(S,2,!1),new Style(Sc,2,!0),new Style(SS,3,!1),new Style(SSc,3,!0)],sup=[S,Sc,S,Sc,SS,SSc,SS,SSc],sub=[Sc,Sc,Sc,Sc,SSc,SSc,SSc,SSc],fracNum=[T,Tc,S,Sc,SS,SSc,SS,SSc],fracDen=[Tc,Tc,Sc,Sc,SSc,SSc,SSc,SSc],cramp=[Dc,Dc,Tc,Tc,Sc,Sc,SSc,SSc],text$1=[D,Dc,T,Tc,T,Tc,T,Tc],Style$1={DISPLAY:styles[D],TEXT:styles[T],SCRIPT:styles[S],SCRIPTSCRIPT:styles[SS]},scriptData=[{name:"latin",blocks:[[256,591],[768,879]]},{name:"cyrillic",blocks:[[1024,1279]]},{name:"armenian",blocks:[[1328,1423]]},{name:"brahmic",blocks:[[2304,4255]]},{name:"georgian",blocks:[[4256,4351]]},{name:"cjk",blocks:[[12288,12543],[19968,40879],[65280,65376]]},{name:"hangul",blocks:[[44032,55215]]}];function scriptFromCodepoint(a){for(var c=0;c<scriptData.length;c++)for(var u=scriptData[c],d=0;d<u.blocks.length;d++){var f=u.blocks[d];if(a>=f[0]&&a<=f[1])return u.name}return null}var allBlocks=[];scriptData.forEach(a=>a.blocks.forEach(c=>allBlocks.push(...c)));function supportedCodepoint(a){for(var c=0;c<allBlocks.length;c+=2)if(a>=allBlocks[c]&&a<=allBlocks[c+1])return!0;return!1}var hLinePad=80,sqrtMain=function(c,u){return"M95,"+(622+c+u)+`
c-2.7,0,-7.17,-2.7,-13.5,-8c-5.8,-5.3,-9.5,-10,-9.5,-14
c0,-2,0.3,-3.3,1,-4c1.3,-2.7,23.83,-20.7,67.5,-54
c44.2,-33.3,65.8,-50.3,66.5,-51c1.3,-1.3,3,-2,5,-2c4.7,0,8.7,3.3,12,10
s173,378,173,378c0.7,0,35.3,-71,104,-213c68.7,-142,137.5,-285,206.5,-429
c69,-144,104.5,-217.7,106.5,-221
l`+c/2.075+" -"+c+`
c5.3,-9.3,12,-14,20,-14
H400000v`+(40+c)+`H845.2724
s-225.272,467,-225.272,467s-235,486,-235,486c-2.7,4.7,-9,7,-19,7
c-6,0,-10,-1,-12,-3s-194,-422,-194,-422s-65,47,-65,47z
M`+(834+c)+" "+u+"h400000v"+(40+c)+"h-400000z"},sqrtSize1=function(c,u){return"M263,"+(601+c+u)+`c0.7,0,18,39.7,52,119
c34,79.3,68.167,158.7,102.5,238c34.3,79.3,51.8,119.3,52.5,120
c340,-704.7,510.7,-1060.3,512,-1067
l`+c/2.084+" -"+c+`
c4.7,-7.3,11,-11,19,-11
H40000v`+(40+c)+`H1012.3
s-271.3,567,-271.3,567c-38.7,80.7,-84,175,-136,283c-52,108,-89.167,185.3,-111.5,232
c-22.3,46.7,-33.8,70.3,-34.5,71c-4.7,4.7,-12.3,7,-23,7s-12,-1,-12,-1
s-109,-253,-109,-253c-72.7,-168,-109.3,-252,-110,-252c-10.7,8,-22,16.7,-34,26
c-22,17.3,-33.3,26,-34,26s-26,-26,-26,-26s76,-59,76,-59s76,-60,76,-60z
M`+(1001+c)+" "+u+"h400000v"+(40+c)+"h-400000z"},sqrtSize2=function(c,u){return"M983 "+(10+c+u)+`
l`+c/3.13+" -"+c+`
c4,-6.7,10,-10,18,-10 H400000v`+(40+c)+`
H1013.1s-83.4,268,-264.1,840c-180.7,572,-277,876.3,-289,913c-4.7,4.7,-12.7,7,-24,7
s-12,0,-12,0c-1.3,-3.3,-3.7,-11.7,-7,-25c-35.3,-125.3,-106.7,-373.3,-214,-744
c-10,12,-21,25,-33,39s-32,39,-32,39c-6,-5.3,-15,-14,-27,-26s25,-30,25,-30
c26.7,-32.7,52,-63,76,-91s52,-60,52,-60s208,722,208,722
c56,-175.3,126.3,-397.3,211,-666c84.7,-268.7,153.8,-488.2,207.5,-658.5
c53.7,-170.3,84.5,-266.8,92.5,-289.5z
M`+(1001+c)+" "+u+"h400000v"+(40+c)+"h-400000z"},sqrtSize3=function(c,u){return"M424,"+(2398+c+u)+`
c-1.3,-0.7,-38.5,-172,-111.5,-514c-73,-342,-109.8,-513.3,-110.5,-514
c0,-2,-10.7,14.3,-32,49c-4.7,7.3,-9.8,15.7,-15.5,25c-5.7,9.3,-9.8,16,-12.5,20
s-5,7,-5,7c-4,-3.3,-8.3,-7.7,-13,-13s-13,-13,-13,-13s76,-122,76,-122s77,-121,77,-121
s209,968,209,968c0,-2,84.7,-361.7,254,-1079c169.3,-717.3,254.7,-1077.7,256,-1081
l`+c/4.223+" -"+c+`c4,-6.7,10,-10,18,-10 H400000
v`+(40+c)+`H1014.6
s-87.3,378.7,-272.6,1166c-185.3,787.3,-279.3,1182.3,-282,1185
c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2z M`+(1001+c)+" "+u+`
h400000v`+(40+c)+"h-400000z"},sqrtSize4=function(c,u){return"M473,"+(2713+c+u)+`
c339.3,-1799.3,509.3,-2700,510,-2702 l`+c/5.298+" -"+c+`
c3.3,-7.3,9.3,-11,18,-11 H400000v`+(40+c)+`H1017.7
s-90.5,478,-276.2,1466c-185.7,988,-279.5,1483,-281.5,1485c-2,6,-10,9,-24,9
c-8,0,-12,-0.7,-12,-2c0,-1.3,-5.3,-32,-16,-92c-50.7,-293.3,-119.7,-693.3,-207,-1200
c0,-1.3,-5.3,8.7,-16,30c-10.7,21.3,-21.3,42.7,-32,64s-16,33,-16,33s-26,-26,-26,-26
s76,-153,76,-153s77,-151,77,-151c0.7,0.7,35.7,202,105,604c67.3,400.7,102,602.7,104,
606zM`+(1001+c)+" "+u+"h400000v"+(40+c)+"H1017.7z"},phasePath=function(c){var u=c/2;return"M400000 "+c+" H0 L"+u+" 0 l65 45 L145 "+(c-80)+" H400000z"},sqrtTall=function(c,u,d){var f=d-54-u-c;return"M702 "+(c+u)+"H400000"+(40+c)+`
H742v`+f+`l-4 4-4 4c-.667.7 -2 1.5-4 2.5s-4.167 1.833-6.5 2.5-5.5 1-9.5 1
h-12l-28-84c-16.667-52-96.667 -294.333-240-727l-212 -643 -85 170
c-4-3.333-8.333-7.667-13 -13l-13-13l77-155 77-156c66 199.333 139 419.667
219 661 l218 661zM702 `+u+"H400000v"+(40+c)+"H742z"},sqrtPath=function(c,u,d){u=1e3*u;var f="";switch(c){case"sqrtMain":f=sqrtMain(u,hLinePad);break;case"sqrtSize1":f=sqrtSize1(u,hLinePad);break;case"sqrtSize2":f=sqrtSize2(u,hLinePad);break;case"sqrtSize3":f=sqrtSize3(u,hLinePad);break;case"sqrtSize4":f=sqrtSize4(u,hLinePad);break;case"sqrtTall":f=sqrtTall(u,hLinePad,d)}return f},innerPath=function(c,u){switch(c){case"⎜":return"M291 0 H417 V"+u+" H291z M291 0 H417 V"+u+" H291z";case"∣":return"M145 0 H188 V"+u+" H145z M145 0 H188 V"+u+" H145z";case"∥":return"M145 0 H188 V"+u+" H145z M145 0 H188 V"+u+" H145z"+("M367 0 H410 V"+u+" H367z M367 0 H410 V"+u+" H367z");case"⎟":return"M457 0 H583 V"+u+" H457z M457 0 H583 V"+u+" H457z";case"⎢":return"M319 0 H403 V"+u+" H319z M319 0 H403 V"+u+" H319z";case"⎥":return"M263 0 H347 V"+u+" H263z M263 0 H347 V"+u+" H263z";case"⎪":return"M384 0 H504 V"+u+" H384z M384 0 H504 V"+u+" H384z";case"⏐":return"M312 0 H355 V"+u+" H312z M312 0 H355 V"+u+" H312z";case"‖":return"M257 0 H300 V"+u+" H257z M257 0 H300 V"+u+" H257z"+("M478 0 H521 V"+u+" H478z M478 0 H521 V"+u+" H478z");default:return""}},path={doubleleftarrow:`M262 157
l10-10c34-36 62.7-77 86-123 3.3-8 5-13.3 5-16 0-5.3-6.7-8-20-8-7.3
 0-12.2.5-14.5 1.5-2.3 1-4.8 4.5-7.5 10.5-49.3 97.3-121.7 169.3-217 216-28
 14-57.3 25-88 33-6.7 2-11 3.8-13 5.5-2 1.7-3 4.2-3 7.5s1 5.8 3 7.5
c2 1.7 6.3 3.5 13 5.5 68 17.3 128.2 47.8 180.5 91.5 52.3 43.7 93.8 96.2 124.5
 157.5 9.3 8 15.3 12.3 18 13h6c12-.7 18-4 18-10 0-2-1.7-7-5-15-23.3-46-52-87
-86-123l-10-10h399738v-40H218c328 0 0 0 0 0l-10-8c-26.7-20-65.7-43-117-69 2.7
-2 6-3.7 10-5 36.7-16 72.3-37.3 107-64l10-8h399782v-40z
m8 0v40h399730v-40zm0 194v40h399730v-40z`,doublerightarrow:`M399738 392l
-10 10c-34 36-62.7 77-86 123-3.3 8-5 13.3-5 16 0 5.3 6.7 8 20 8 7.3 0 12.2-.5
 14.5-1.5 2.3-1 4.8-4.5 7.5-10.5 49.3-97.3 121.7-169.3 217-216 28-14 57.3-25 88
-33 6.7-2 11-3.8 13-5.5 2-1.7 3-4.2 3-7.5s-1-5.8-3-7.5c-2-1.7-6.3-3.5-13-5.5-68
-17.3-128.2-47.8-180.5-91.5-52.3-43.7-93.8-96.2-124.5-157.5-9.3-8-15.3-12.3-18
-13h-6c-12 .7-18 4-18 10 0 2 1.7 7 5 15 23.3 46 52 87 86 123l10 10H0v40h399782
c-328 0 0 0 0 0l10 8c26.7 20 65.7 43 117 69-2.7 2-6 3.7-10 5-36.7 16-72.3 37.3
-107 64l-10 8H0v40zM0 157v40h399730v-40zm0 194v40h399730v-40z`,leftarrow:`M400000 241H110l3-3c68.7-52.7 113.7-120
 135-202 4-14.7 6-23 6-25 0-7.3-7-11-21-11-8 0-13.2.8-15.5 2.5-2.3 1.7-4.2 5.8
-5.5 12.5-1.3 4.7-2.7 10.3-4 17-12 48.7-34.8 92-68.5 130S65.3 228.3 18 247
c-10 4-16 7.7-18 11 0 8.7 6 14.3 18 17 47.3 18.7 87.8 47 121.5 85S196 441.3 208
 490c.7 2 1.3 5 2 9s1.2 6.7 1.5 8c.3 1.3 1 3.3 2 6s2.2 4.5 3.5 5.5c1.3 1 3.3
 1.8 6 2.5s6 1 10 1c14 0 21-3.7 21-11 0-2-2-10.3-6-25-20-79.3-65-146.7-135-202
 l-3-3h399890zM100 241v40h399900v-40z`,leftbrace:`M6 548l-6-6v-35l6-11c56-104 135.3-181.3 238-232 57.3-28.7 117
-45 179-50h399577v120H403c-43.3 7-81 15-113 26-100.7 33-179.7 91-237 174-2.7
 5-6 9-10 13-.7 1-7.3 1-20 1H6z`,leftbraceunder:`M0 6l6-6h17c12.688 0 19.313.3 20 1 4 4 7.313 8.3 10 13
 35.313 51.3 80.813 93.8 136.5 127.5 55.688 33.7 117.188 55.8 184.5 66.5.688
 0 2 .3 4 1 18.688 2.7 76 4.3 172 5h399450v120H429l-6-1c-124.688-8-235-61.7
-331-161C60.687 138.7 32.312 99.3 7 54L0 41V6z`,leftgroup:`M400000 80
H435C64 80 168.3 229.4 21 260c-5.9 1.2-18 0-18 0-2 0-3-1-3-3v-38C76 61 257 0
 435 0h399565z`,leftgroupunder:`M400000 262
H435C64 262 168.3 112.6 21 82c-5.9-1.2-18 0-18 0-2 0-3 1-3 3v38c76 158 257 219
 435 219h399565z`,leftharpoon:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3
-3.3 10.2-9.5 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5
-18.3 3-21-1.3-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7
-196 228-6.7 4.7-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40z`,leftharpoonplus:`M0 267c.7 5.3 3 10 7 14h399993v-40H93c3.3-3.3 10.2-9.5
 20.5-18.5s17.8-15.8 22.5-20.5c50.7-52 88-110.3 112-175 4-11.3 5-18.3 3-21-1.3
-4-7.3-6-18-6-8 0-13 .7-15 2s-4.7 6.7-8 16c-42 98.7-107.3 174.7-196 228-6.7 4.7
-10.7 8-12 10-1.3 2-2 5.7-2 11zm100-26v40h399900v-40zM0 435v40h400000v-40z
m0 0v40h400000v-40z`,leftharpoondown:`M7 241c-4 4-6.333 8.667-7 14 0 5.333.667 9 2 11s5.333
 5.333 12 10c90.667 54 156 130 196 228 3.333 10.667 6.333 16.333 9 17 2 .667 5
 1 9 1h5c10.667 0 16.667-2 18-6 2-2.667 1-9.667-3-21-32-87.333-82.667-157.667
-152-211l-3-3h399907v-40zM93 281 H400000 v-40L7 241z`,leftharpoondownplus:`M7 435c-4 4-6.3 8.7-7 14 0 5.3.7 9 2 11s5.3 5.3 12
 10c90.7 54 156 130 196 228 3.3 10.7 6.3 16.3 9 17 2 .7 5 1 9 1h5c10.7 0 16.7
-2 18-6 2-2.7 1-9.7-3-21-32-87.3-82.7-157.7-152-211l-3-3h399907v-40H7zm93 0
v40h399900v-40zM0 241v40h399900v-40zm0 0v40h399900v-40z`,lefthook:`M400000 281 H103s-33-11.2-61-33.5S0 197.3 0 164s14.2-61.2 42.5
-83.5C70.8 58.2 104 47 142 47 c16.7 0 25 6.7 25 20 0 12-8.7 18.7-26 20-40 3.3
-68.7 15.7-86 37-10 12-15 25.3-15 40 0 22.7 9.8 40.7 29.5 54 19.7 13.3 43.5 21
 71.5 23h399859zM103 281v-40h399897v40z`,leftlinesegment:`M40 281 V428 H0 V94 H40 V241 H400000 v40z
M40 281 V428 H0 V94 H40 V241 H400000 v40z`,leftmapsto:`M40 281 V448H0V74H40V241H400000v40z
M40 281 V448H0V74H40V241H400000v40z`,leftToFrom:`M0 147h400000v40H0zm0 214c68 40 115.7 95.7 143 167h22c15.3 0 23
-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69-70-101l-7-8h399905v-40H95l7-8
c28.7-32 52-65.7 70-101 10.7-23.3 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 265.3
 68 321 0 361zm0-174v-40h399900v40zm100 154v40h399900v-40z`,longequal:`M0 50 h400000 v40H0z m0 194h40000v40H0z
M0 50 h400000 v40H0z m0 194h40000v40H0z`,midbrace:`M200428 334
c-100.7-8.3-195.3-44-280-108-55.3-42-101.7-93-139-153l-9-14c-2.7 4-5.7 8.7-9 14
-53.3 86.7-123.7 153-211 199-66.7 36-137.3 56.3-212 62H0V214h199568c178.3-11.7
 311.7-78.3 403-201 6-8 9.7-12 11-12 .7-.7 6.7-1 18-1s17.3.3 18 1c1.3 0 5 4 11
 12 44.7 59.3 101.3 106.3 170 141s145.3 54.3 229 60h199572v120z`,midbraceunder:`M199572 214
c100.7 8.3 195.3 44 280 108 55.3 42 101.7 93 139 153l9 14c2.7-4 5.7-8.7 9-14
 53.3-86.7 123.7-153 211-199 66.7-36 137.3-56.3 212-62h199568v120H200432c-178.3
 11.7-311.7 78.3-403 201-6 8-9.7 12-11 12-.7.7-6.7 1-18 1s-17.3-.3-18-1c-1.3 0
-5-4-11-12-44.7-59.3-101.3-106.3-170-141s-145.3-54.3-229-60H0V214z`,oiintSize1:`M512.6 71.6c272.6 0 320.3 106.8 320.3 178.2 0 70.8-47.7 177.6
-320.3 177.6S193.1 320.6 193.1 249.8c0-71.4 46.9-178.2 319.5-178.2z
m368.1 178.2c0-86.4-60.9-215.4-368.1-215.4-306.4 0-367.3 129-367.3 215.4 0 85.8
60.9 214.8 367.3 214.8 307.2 0 368.1-129 368.1-214.8z`,oiintSize2:`M757.8 100.1c384.7 0 451.1 137.6 451.1 230 0 91.3-66.4 228.8
-451.1 228.8-386.3 0-452.7-137.5-452.7-228.8 0-92.4 66.4-230 452.7-230z
m502.4 230c0-111.2-82.4-277.2-502.4-277.2s-504 166-504 277.2
c0 110 84 276 504 276s502.4-166 502.4-276z`,oiiintSize1:`M681.4 71.6c408.9 0 480.5 106.8 480.5 178.2 0 70.8-71.6 177.6
-480.5 177.6S202.1 320.6 202.1 249.8c0-71.4 70.5-178.2 479.3-178.2z
m525.8 178.2c0-86.4-86.8-215.4-525.7-215.4-437.9 0-524.7 129-524.7 215.4 0
85.8 86.8 214.8 524.7 214.8 438.9 0 525.7-129 525.7-214.8z`,oiiintSize2:`M1021.2 53c603.6 0 707.8 165.8 707.8 277.2 0 110-104.2 275.8
-707.8 275.8-606 0-710.2-165.8-710.2-275.8C311 218.8 415.2 53 1021.2 53z
m770.4 277.1c0-131.2-126.4-327.6-770.5-327.6S248.4 198.9 248.4 330.1
c0 130 128.8 326.4 772.7 326.4s770.5-196.4 770.5-326.4z`,rightarrow:`M0 241v40h399891c-47.3 35.3-84 78-110 128
-16.7 32-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20
 11 8 0 13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7
 39-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85
-40.5-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
 151.7 139 205zm0 0v40h399900v-40z`,rightbrace:`M400000 542l
-6 6h-17c-12.7 0-19.3-.3-20-1-4-4-7.3-8.3-10-13-35.3-51.3-80.8-93.8-136.5-127.5
s-117.2-55.8-184.5-66.5c-.7 0-2-.3-4-1-18.7-2.7-76-4.3-172-5H0V214h399571l6 1
c124.7 8 235 61.7 331 161 31.3 33.3 59.7 72.7 85 118l7 13v35z`,rightbraceunder:`M399994 0l6 6v35l-6 11c-56 104-135.3 181.3-238 232-57.3
 28.7-117 45-179 50H-300V214h399897c43.3-7 81-15 113-26 100.7-33 179.7-91 237
-174 2.7-5 6-9 10-13 .7-1 7.3-1 20-1h17z`,rightgroup:`M0 80h399565c371 0 266.7 149.4 414 180 5.9 1.2 18 0 18 0 2 0
 3-1 3-3v-38c-76-158-257-219-435-219H0z`,rightgroupunder:`M0 262h399565c371 0 266.7-149.4 414-180 5.9-1.2 18 0 18
 0 2 0 3 1 3 3v38c-76 158-257 219-435 219H0z`,rightharpoon:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3
-3.7-15.3-11-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2
-10.7 0-16.7 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58
 69.2 92 94.5zm0 0v40h399900v-40z`,rightharpoonplus:`M0 241v40h399993c4.7-4.7 7-9.3 7-14 0-9.3-3.7-15.3-11
-18-92.7-56.7-159-133.7-199-231-3.3-9.3-6-14.7-8-16-2-1.3-7-2-15-2-10.7 0-16.7
 2-18 6-2 2.7-1 9.7 3 21 15.3 42 36.7 81.8 64 119.5 27.3 37.7 58 69.2 92 94.5z
m0 0v40h399900v-40z m100 194v40h399900v-40zm0 0v40h399900v-40z`,rightharpoondown:`M399747 511c0 7.3 6.7 11 20 11 8 0 13-.8 15-2.5s4.7-6.8
 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3 8.5-5.8 9.5
-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3-64.7 57-92 95
-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 241v40h399900v-40z`,rightharpoondownplus:`M399747 705c0 7.3 6.7 11 20 11 8 0 13-.8
 15-2.5s4.7-6.8 8-15.5c40-94 99.3-166.3 178-217 13.3-8 20.3-12.3 21-13 5.3-3.3
 8.5-5.8 9.5-7.5 1-1.7 1.5-5.2 1.5-10.5s-2.3-10.3-7-15H0v40h399908c-34 25.3
-64.7 57-92 95-27.3 38-48.7 77.7-64 119-3.3 8.7-5 14-5 16zM0 435v40h399900v-40z
m0-194v40h400000v-40zm0 0v40h400000v-40z`,righthook:`M399859 241c-764 0 0 0 0 0 40-3.3 68.7-15.7 86-37 10-12 15-25.3
 15-40 0-22.7-9.8-40.7-29.5-54-19.7-13.3-43.5-21-71.5-23-17.3-1.3-26-8-26-20 0
-13.3 8.7-20 26-20 38 0 71 11.2 99 33.5 0 0 7 5.6 21 16.7 14 11.2 21 33.5 21
 66.8s-14 61.2-42 83.5c-28 22.3-61 33.5-99 33.5L0 241z M0 281v-40h399859v40z`,rightlinesegment:`M399960 241 V94 h40 V428 h-40 V281 H0 v-40z
M399960 241 V94 h40 V428 h-40 V281 H0 v-40z`,rightToFrom:`M400000 167c-70.7-42-118-97.7-142-167h-23c-15.3 0-23 .3-23
 1 0 1.3 5.3 13.7 16 37 18 35.3 41.3 69 70 101l7 8H0v40h399905l-7 8c-28.7 32
-52 65.7-70 101-10.7 23.3-16 35.7-16 37 0 .7 7.7 1 23 1h23c24-69.3 71.3-125 142
-167z M100 147v40h399900v-40zM0 341v40h399900v-40z`,twoheadleftarrow:`M0 167c68 40
 115.7 95.7 143 167h22c15.3 0 23-.3 23-1 0-1.3-5.3-13.7-16-37-18-35.3-41.3-69
-70-101l-7-8h125l9 7c50.7 39.3 85 86 103 140h46c0-4.7-6.3-18.7-19-42-18-35.3
-40-67.3-66-96l-9-9h399716v-40H284l9-9c26-28.7 48-60.7 66-96 12.7-23.333 19
-37.333 19-42h-46c-18 54-52.3 100.7-103 140l-9 7H95l7-8c28.7-32 52-65.7 70-101
 10.7-23.333 16-35.7 16-37 0-.7-7.7-1-23-1h-22C115.7 71.3 68 127 0 167z`,twoheadrightarrow:`M400000 167
c-68-40-115.7-95.7-143-167h-22c-15.3 0-23 .3-23 1 0 1.3 5.3 13.7 16 37 18 35.3
 41.3 69 70 101l7 8h-125l-9-7c-50.7-39.3-85-86-103-140h-46c0 4.7 6.3 18.7 19 42
 18 35.3 40 67.3 66 96l9 9H0v40h399716l-9 9c-26 28.7-48 60.7-66 96-12.7 23.333
-19 37.333-19 42h46c18-54 52.3-100.7 103-140l9-7h125l-7 8c-28.7 32-52 65.7-70
 101-10.7 23.333-16 35.7-16 37 0 .7 7.7 1 23 1h22c27.3-71.3 75-127 143-167z`,tilde1:`M200 55.538c-77 0-168 73.953-177 73.953-3 0-7
-2.175-9-5.437L2 97c-1-2-2-4-2-6 0-4 2-7 5-9l20-12C116 12 171 0 207 0c86 0
 114 68 191 68 78 0 168-68 177-68 4 0 7 2 9 5l12 19c1 2.175 2 4.35 2 6.525 0
 4.35-2 7.613-5 9.788l-19 13.05c-92 63.077-116.937 75.308-183 76.128
-68.267.847-113-73.952-191-73.952z`,tilde2:`M344 55.266c-142 0-300.638 81.316-311.5 86.418
-8.01 3.762-22.5 10.91-23.5 5.562L1 120c-1-2-1-3-1-4 0-5 3-9 8-10l18.4-9C160.9
 31.9 283 0 358 0c148 0 188 122 331 122s314-97 326-97c4 0 8 2 10 7l7 21.114
c1 2.14 1 3.21 1 4.28 0 5.347-3 9.626-7 10.696l-22.3 12.622C852.6 158.372 751
 181.476 676 181.476c-149 0-189-126.21-332-126.21z`,tilde3:`M786 59C457 59 32 175.242 13 175.242c-6 0-10-3.457
-11-10.37L.15 138c-1-7 3-12 10-13l19.2-6.4C378.4 40.7 634.3 0 804.3 0c337 0
 411.8 157 746.8 157 328 0 754-112 773-112 5 0 10 3 11 9l1 14.075c1 8.066-.697
 16.595-6.697 17.492l-21.052 7.31c-367.9 98.146-609.15 122.696-778.15 122.696
 -338 0-409-156.573-744-156.573z`,tilde4:`M786 58C457 58 32 177.487 13 177.487c-6 0-10-3.345
-11-10.035L.15 143c-1-7 3-12 10-13l22-6.7C381.2 35 637.15 0 807.15 0c337 0 409
 177 744 177 328 0 754-127 773-127 5 0 10 3 11 9l1 14.794c1 7.805-3 13.38-9
 14.495l-20.7 5.574c-366.85 99.79-607.3 139.372-776.3 139.372-338 0-409
 -175.236-744-175.236z`,vec:`M377 20c0-5.333 1.833-10 5.5-14S391 0 397 0c4.667 0 8.667 1.667 12 5
3.333 2.667 6.667 9 10 19 6.667 24.667 20.333 43.667 41 57 7.333 4.667 11
10.667 11 18 0 6-1 10-3 12s-6.667 5-14 9c-28.667 14.667-53.667 35.667-75 63
-1.333 1.333-3.167 3.5-5.5 6.5s-4 4.833-5 5.5c-1 .667-2.5 1.333-4.5 2s-4.333 1
-7 1c-4.667 0-9.167-1.833-13.5-5.5S337 184 337 178c0-12.667 15.667-32.333 47-59
H213l-171-1c-8.667-6-13-12.333-13-19 0-4.667 4.333-11.333 13-20h359
c-16-25.333-24-45-24-59z`,widehat1:`M529 0h5l519 115c5 1 9 5 9 10 0 1-1 2-1 3l-4 22
c-1 5-5 9-11 9h-2L532 67 19 159h-2c-5 0-9-4-11-9l-5-22c-1-6 2-12 8-13z`,widehat2:`M1181 0h2l1171 176c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 220h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat3:`M1181 0h2l1171 236c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 280h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widehat4:`M1181 0h2l1171 296c6 0 10 5 10 11l-2 23c-1 6-5 10
-11 10h-1L1182 67 15 340h-1c-6 0-10-4-11-10l-2-23c-1-6 4-11 10-11z`,widecheck1:`M529,159h5l519,-115c5,-1,9,-5,9,-10c0,-1,-1,-2,-1,-3l-4,-22c-1,
-5,-5,-9,-11,-9h-2l-512,92l-513,-92h-2c-5,0,-9,4,-11,9l-5,22c-1,6,2,12,8,13z`,widecheck2:`M1181,220h2l1171,-176c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,153l-1167,-153h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck3:`M1181,280h2l1171,-236c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,213l-1167,-213h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,widecheck4:`M1181,340h2l1171,-296c6,0,10,-5,10,-11l-2,-23c-1,-6,-5,-10,
-11,-10h-1l-1168,273l-1167,-273h-1c-6,0,-10,4,-11,10l-2,23c-1,6,4,11,10,11z`,baraboveleftarrow:`M400000 620h-399890l3 -3c68.7 -52.7 113.7 -120 135 -202
c4 -14.7 6 -23 6 -25c0 -7.3 -7 -11 -21 -11c-8 0 -13.2 0.8 -15.5 2.5
c-2.3 1.7 -4.2 5.8 -5.5 12.5c-1.3 4.7 -2.7 10.3 -4 17c-12 48.7 -34.8 92 -68.5 130
s-74.2 66.3 -121.5 85c-10 4 -16 7.7 -18 11c0 8.7 6 14.3 18 17c47.3 18.7 87.8 47
121.5 85s56.5 81.3 68.5 130c0.7 2 1.3 5 2 9s1.2 6.7 1.5 8c0.3 1.3 1 3.3 2 6
s2.2 4.5 3.5 5.5c1.3 1 3.3 1.8 6 2.5s6 1 10 1c14 0 21 -3.7 21 -11
c0 -2 -2 -10.3 -6 -25c-20 -79.3 -65 -146.7 -135 -202l-3 -3h399890z
M100 620v40h399900v-40z M0 241v40h399900v-40zM0 241v40h399900v-40z`,rightarrowabovebar:`M0 241v40h399891c-47.3 35.3-84 78-110 128-16.7 32
-27.7 63.7-33 95 0 1.3-.2 2.7-.5 4-.3 1.3-.5 2.3-.5 3 0 7.3 6.7 11 20 11 8 0
13.2-.8 15.5-2.5 2.3-1.7 4.2-5.5 5.5-11.5 2-13.3 5.7-27 11-41 14.7-44.7 39
-84.5 73-119.5s73.7-60.2 119-75.5c6-2 9-5.7 9-11s-3-9-9-11c-45.3-15.3-85-40.5
-119-75.5s-58.3-74.8-73-119.5c-4.7-14-8.3-27.3-11-40-1.3-6.7-3.2-10.8-5.5
-12.5-2.3-1.7-7.5-2.5-15.5-2.5-14 0-21 3.7-21 11 0 2 2 10.3 6 25 20.7 83.3 67
151.7 139 205zm96 379h399894v40H0zm0 0h399904v40H0z`,baraboveshortleftharpoon:`M507,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17
c2,0.7,5,1,9,1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21
c-32,-87.3,-82.7,-157.7,-152,-211c0,0,-3,-3,-3,-3l399351,0l0,-40
c-398570,0,-399437,0,-399437,0z M593 435 v40 H399500 v-40z
M0 281 v-40 H399908 v40z M0 281 v-40 H399908 v40z`,rightharpoonaboveshortbar:`M0,241 l0,40c399126,0,399993,0,399993,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M0 241 v40 H399908 v-40z M0 475 v-40 H399500 v40z M0 475 v-40 H399500 v40z`,shortbaraboveleftharpoon:`M7,435c-4,4,-6.3,8.7,-7,14c0,5.3,0.7,9,2,11
c1.3,2,5.3,5.3,12,10c90.7,54,156,130,196,228c3.3,10.7,6.3,16.3,9,17c2,0.7,5,1,9,
1c0,0,5,0,5,0c10.7,0,16.7,-2,18,-6c2,-2.7,1,-9.7,-3,-21c-32,-87.3,-82.7,-157.7,
-152,-211c0,0,-3,-3,-3,-3l399907,0l0,-40c-399126,0,-399993,0,-399993,0z
M93 435 v40 H400000 v-40z M500 241 v40 H400000 v-40z M500 241 v40 H400000 v-40z`,shortrightharpoonabovebar:`M53,241l0,40c398570,0,399437,0,399437,0
c4.7,-4.7,7,-9.3,7,-14c0,-9.3,-3.7,-15.3,-11,-18c-92.7,-56.7,-159,-133.7,-199,
-231c-3.3,-9.3,-6,-14.7,-8,-16c-2,-1.3,-7,-2,-15,-2c-10.7,0,-16.7,2,-18,6
c-2,2.7,-1,9.7,3,21c15.3,42,36.7,81.8,64,119.5c27.3,37.7,58,69.2,92,94.5z
M500 241 v40 H399408 v-40z M500 435 v40 H400000 v-40z`},tallDelim=function(c,u){switch(c){case"lbrack":return"M403 1759 V84 H666 V0 H319 V1759 v"+u+` v1759 h347 v-84
H403z M403 1759 V0 H319 V1759 v`+u+" v1759 h84z";case"rbrack":return"M347 1759 V0 H0 V84 H263 V1759 v"+u+` v1759 H0 v84 H347z
M347 1759 V0 H263 V1759 v`+u+" v1759 h84z";case"vert":return"M145 15 v585 v"+u+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-u+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+u+" v585 h43z";case"doublevert":return"M145 15 v585 v"+u+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-u+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M188 15 H145 v585 v`+u+` v585 h43z
M367 15 v585 v`+u+` v585 c2.667,10,9.667,15,21,15
c10,0,16.667,-5,20,-15 v-585 v`+-u+` v-585 c-2.667,-10,-9.667,-15,-21,-15
c-10,0,-16.667,5,-20,15z M410 15 H367 v585 v`+u+" v585 h43z";case"lfloor":return"M319 602 V0 H403 V602 v"+u+` v1715 h263 v84 H319z
MM319 602 V0 H403 V602 v`+u+" v1715 H319z";case"rfloor":return"M319 602 V0 H403 V602 v"+u+` v1799 H0 v-84 H319z
MM319 602 V0 H403 V602 v`+u+" v1715 H319z";case"lceil":return"M403 1759 V84 H666 V0 H319 V1759 v"+u+` v602 h84z
M403 1759 V0 H319 V1759 v`+u+" v602 h84z";case"rceil":return"M347 1759 V0 H0 V84 H263 V1759 v"+u+` v602 h84z
M347 1759 V0 h-84 V1759 v`+u+" v602 h84z";case"lparen":return`M863,9c0,-2,-2,-5,-6,-9c0,0,-17,0,-17,0c-12.7,0,-19.3,0.3,-20,1
c-5.3,5.3,-10.3,11,-15,17c-242.7,294.7,-395.3,682,-458,1162c-21.3,163.3,-33.3,349,
-36,557 l0,`+(u+84)+`c0.2,6,0,26,0,60c2,159.3,10,310.7,24,454c53.3,528,210,
949.7,470,1265c4.7,6,9.7,11.7,15,17c0.7,0.7,7,1,19,1c0,0,18,0,18,0c4,-4,6,-7,6,-9
c0,-2.7,-3.3,-8.7,-10,-18c-135.3,-192.7,-235.5,-414.3,-300.5,-665c-65,-250.7,-102.5,
-544.7,-112.5,-882c-2,-104,-3,-167,-3,-189
l0,-`+(u+92)+`c0,-162.7,5.7,-314,17,-454c20.7,-272,63.7,-513,129,-723c65.3,
-210,155.3,-396.3,270,-559c6.7,-9.3,10,-15.3,10,-18z`;case"rparen":return`M76,0c-16.7,0,-25,3,-25,9c0,2,2,6.3,6,13c21.3,28.7,42.3,60.3,
63,95c96.7,156.7,172.8,332.5,228.5,527.5c55.7,195,92.8,416.5,111.5,664.5
c11.3,139.3,17,290.7,17,454c0,28,1.7,43,3.3,45l0,`+(u+9)+`
c-3,4,-3.3,16.7,-3.3,38c0,162,-5.7,313.7,-17,455c-18.7,248,-55.8,469.3,-111.5,664
c-55.7,194.7,-131.8,370.3,-228.5,527c-20.7,34.7,-41.7,66.3,-63,95c-2,3.3,-4,7,-6,11
c0,7.3,5.7,11,17,11c0,0,11,0,11,0c9.3,0,14.3,-0.3,15,-1c5.3,-5.3,10.3,-11,15,-17
c242.7,-294.7,395.3,-681.7,458,-1161c21.3,-164.7,33.3,-350.7,36,-558
l0,-`+(u+144)+`c-2,-159.3,-10,-310.7,-24,-454c-53.3,-528,-210,-949.7,
-470,-1265c-4.7,-6,-9.7,-11.7,-15,-17c-0.7,-0.7,-6.7,-1,-18,-1z`;default:throw new Error("Unknown stretchy delimiter.")}};class DocumentFragment{constructor(c){this.children=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.children=c,this.classes=[],this.height=0,this.depth=0,this.maxFontSize=0,this.style={}}hasClass(c){return utils.contains(this.classes,c)}toNode(){for(var c=document.createDocumentFragment(),u=0;u<this.children.length;u++)c.appendChild(this.children[u].toNode());return c}toMarkup(){for(var c="",u=0;u<this.children.length;u++)c+=this.children[u].toMarkup();return c}toText(){var c=u=>u.toText();return this.children.map(c).join("")}}var fontMetricsData={"AMS-Regular":{32:[0,0,0,0,.25],65:[0,.68889,0,0,.72222],66:[0,.68889,0,0,.66667],67:[0,.68889,0,0,.72222],68:[0,.68889,0,0,.72222],69:[0,.68889,0,0,.66667],70:[0,.68889,0,0,.61111],71:[0,.68889,0,0,.77778],72:[0,.68889,0,0,.77778],73:[0,.68889,0,0,.38889],74:[.16667,.68889,0,0,.5],75:[0,.68889,0,0,.77778],76:[0,.68889,0,0,.66667],77:[0,.68889,0,0,.94445],78:[0,.68889,0,0,.72222],79:[.16667,.68889,0,0,.77778],80:[0,.68889,0,0,.61111],81:[.16667,.68889,0,0,.77778],82:[0,.68889,0,0,.72222],83:[0,.68889,0,0,.55556],84:[0,.68889,0,0,.66667],85:[0,.68889,0,0,.72222],86:[0,.68889,0,0,.72222],87:[0,.68889,0,0,1],88:[0,.68889,0,0,.72222],89:[0,.68889,0,0,.72222],90:[0,.68889,0,0,.66667],107:[0,.68889,0,0,.55556],160:[0,0,0,0,.25],165:[0,.675,.025,0,.75],174:[.15559,.69224,0,0,.94666],240:[0,.68889,0,0,.55556],295:[0,.68889,0,0,.54028],710:[0,.825,0,0,2.33334],732:[0,.9,0,0,2.33334],770:[0,.825,0,0,2.33334],771:[0,.9,0,0,2.33334],989:[.08167,.58167,0,0,.77778],1008:[0,.43056,.04028,0,.66667],8245:[0,.54986,0,0,.275],8463:[0,.68889,0,0,.54028],8487:[0,.68889,0,0,.72222],8498:[0,.68889,0,0,.55556],8502:[0,.68889,0,0,.66667],8503:[0,.68889,0,0,.44445],8504:[0,.68889,0,0,.66667],8513:[0,.68889,0,0,.63889],8592:[-.03598,.46402,0,0,.5],8594:[-.03598,.46402,0,0,.5],8602:[-.13313,.36687,0,0,1],8603:[-.13313,.36687,0,0,1],8606:[.01354,.52239,0,0,1],8608:[.01354,.52239,0,0,1],8610:[.01354,.52239,0,0,1.11111],8611:[.01354,.52239,0,0,1.11111],8619:[0,.54986,0,0,1],8620:[0,.54986,0,0,1],8621:[-.13313,.37788,0,0,1.38889],8622:[-.13313,.36687,0,0,1],8624:[0,.69224,0,0,.5],8625:[0,.69224,0,0,.5],8630:[0,.43056,0,0,1],8631:[0,.43056,0,0,1],8634:[.08198,.58198,0,0,.77778],8635:[.08198,.58198,0,0,.77778],8638:[.19444,.69224,0,0,.41667],8639:[.19444,.69224,0,0,.41667],8642:[.19444,.69224,0,0,.41667],8643:[.19444,.69224,0,0,.41667],8644:[.1808,.675,0,0,1],8646:[.1808,.675,0,0,1],8647:[.1808,.675,0,0,1],8648:[.19444,.69224,0,0,.83334],8649:[.1808,.675,0,0,1],8650:[.19444,.69224,0,0,.83334],8651:[.01354,.52239,0,0,1],8652:[.01354,.52239,0,0,1],8653:[-.13313,.36687,0,0,1],8654:[-.13313,.36687,0,0,1],8655:[-.13313,.36687,0,0,1],8666:[.13667,.63667,0,0,1],8667:[.13667,.63667,0,0,1],8669:[-.13313,.37788,0,0,1],8672:[-.064,.437,0,0,1.334],8674:[-.064,.437,0,0,1.334],8705:[0,.825,0,0,.5],8708:[0,.68889,0,0,.55556],8709:[.08167,.58167,0,0,.77778],8717:[0,.43056,0,0,.42917],8722:[-.03598,.46402,0,0,.5],8724:[.08198,.69224,0,0,.77778],8726:[.08167,.58167,0,0,.77778],8733:[0,.69224,0,0,.77778],8736:[0,.69224,0,0,.72222],8737:[0,.69224,0,0,.72222],8738:[.03517,.52239,0,0,.72222],8739:[.08167,.58167,0,0,.22222],8740:[.25142,.74111,0,0,.27778],8741:[.08167,.58167,0,0,.38889],8742:[.25142,.74111,0,0,.5],8756:[0,.69224,0,0,.66667],8757:[0,.69224,0,0,.66667],8764:[-.13313,.36687,0,0,.77778],8765:[-.13313,.37788,0,0,.77778],8769:[-.13313,.36687,0,0,.77778],8770:[-.03625,.46375,0,0,.77778],8774:[.30274,.79383,0,0,.77778],8776:[-.01688,.48312,0,0,.77778],8778:[.08167,.58167,0,0,.77778],8782:[.06062,.54986,0,0,.77778],8783:[.06062,.54986,0,0,.77778],8785:[.08198,.58198,0,0,.77778],8786:[.08198,.58198,0,0,.77778],8787:[.08198,.58198,0,0,.77778],8790:[0,.69224,0,0,.77778],8791:[.22958,.72958,0,0,.77778],8796:[.08198,.91667,0,0,.77778],8806:[.25583,.75583,0,0,.77778],8807:[.25583,.75583,0,0,.77778],8808:[.25142,.75726,0,0,.77778],8809:[.25142,.75726,0,0,.77778],8812:[.25583,.75583,0,0,.5],8814:[.20576,.70576,0,0,.77778],8815:[.20576,.70576,0,0,.77778],8816:[.30274,.79383,0,0,.77778],8817:[.30274,.79383,0,0,.77778],8818:[.22958,.72958,0,0,.77778],8819:[.22958,.72958,0,0,.77778],8822:[.1808,.675,0,0,.77778],8823:[.1808,.675,0,0,.77778],8828:[.13667,.63667,0,0,.77778],8829:[.13667,.63667,0,0,.77778],8830:[.22958,.72958,0,0,.77778],8831:[.22958,.72958,0,0,.77778],8832:[.20576,.70576,0,0,.77778],8833:[.20576,.70576,0,0,.77778],8840:[.30274,.79383,0,0,.77778],8841:[.30274,.79383,0,0,.77778],8842:[.13597,.63597,0,0,.77778],8843:[.13597,.63597,0,0,.77778],8847:[.03517,.54986,0,0,.77778],8848:[.03517,.54986,0,0,.77778],8858:[.08198,.58198,0,0,.77778],8859:[.08198,.58198,0,0,.77778],8861:[.08198,.58198,0,0,.77778],8862:[0,.675,0,0,.77778],8863:[0,.675,0,0,.77778],8864:[0,.675,0,0,.77778],8865:[0,.675,0,0,.77778],8872:[0,.69224,0,0,.61111],8873:[0,.69224,0,0,.72222],8874:[0,.69224,0,0,.88889],8876:[0,.68889,0,0,.61111],8877:[0,.68889,0,0,.61111],8878:[0,.68889,0,0,.72222],8879:[0,.68889,0,0,.72222],8882:[.03517,.54986,0,0,.77778],8883:[.03517,.54986,0,0,.77778],8884:[.13667,.63667,0,0,.77778],8885:[.13667,.63667,0,0,.77778],8888:[0,.54986,0,0,1.11111],8890:[.19444,.43056,0,0,.55556],8891:[.19444,.69224,0,0,.61111],8892:[.19444,.69224,0,0,.61111],8901:[0,.54986,0,0,.27778],8903:[.08167,.58167,0,0,.77778],8905:[.08167,.58167,0,0,.77778],8906:[.08167,.58167,0,0,.77778],8907:[0,.69224,0,0,.77778],8908:[0,.69224,0,0,.77778],8909:[-.03598,.46402,0,0,.77778],8910:[0,.54986,0,0,.76042],8911:[0,.54986,0,0,.76042],8912:[.03517,.54986,0,0,.77778],8913:[.03517,.54986,0,0,.77778],8914:[0,.54986,0,0,.66667],8915:[0,.54986,0,0,.66667],8916:[0,.69224,0,0,.66667],8918:[.0391,.5391,0,0,.77778],8919:[.0391,.5391,0,0,.77778],8920:[.03517,.54986,0,0,1.33334],8921:[.03517,.54986,0,0,1.33334],8922:[.38569,.88569,0,0,.77778],8923:[.38569,.88569,0,0,.77778],8926:[.13667,.63667,0,0,.77778],8927:[.13667,.63667,0,0,.77778],8928:[.30274,.79383,0,0,.77778],8929:[.30274,.79383,0,0,.77778],8934:[.23222,.74111,0,0,.77778],8935:[.23222,.74111,0,0,.77778],8936:[.23222,.74111,0,0,.77778],8937:[.23222,.74111,0,0,.77778],8938:[.20576,.70576,0,0,.77778],8939:[.20576,.70576,0,0,.77778],8940:[.30274,.79383,0,0,.77778],8941:[.30274,.79383,0,0,.77778],8994:[.19444,.69224,0,0,.77778],8995:[.19444,.69224,0,0,.77778],9416:[.15559,.69224,0,0,.90222],9484:[0,.69224,0,0,.5],9488:[0,.69224,0,0,.5],9492:[0,.37788,0,0,.5],9496:[0,.37788,0,0,.5],9585:[.19444,.68889,0,0,.88889],9586:[.19444,.74111,0,0,.88889],9632:[0,.675,0,0,.77778],9633:[0,.675,0,0,.77778],9650:[0,.54986,0,0,.72222],9651:[0,.54986,0,0,.72222],9654:[.03517,.54986,0,0,.77778],9660:[0,.54986,0,0,.72222],9661:[0,.54986,0,0,.72222],9664:[.03517,.54986,0,0,.77778],9674:[.11111,.69224,0,0,.66667],9733:[.19444,.69224,0,0,.94445],10003:[0,.69224,0,0,.83334],10016:[0,.69224,0,0,.83334],10731:[.11111,.69224,0,0,.66667],10846:[.19444,.75583,0,0,.61111],10877:[.13667,.63667,0,0,.77778],10878:[.13667,.63667,0,0,.77778],10885:[.25583,.75583,0,0,.77778],10886:[.25583,.75583,0,0,.77778],10887:[.13597,.63597,0,0,.77778],10888:[.13597,.63597,0,0,.77778],10889:[.26167,.75726,0,0,.77778],10890:[.26167,.75726,0,0,.77778],10891:[.48256,.98256,0,0,.77778],10892:[.48256,.98256,0,0,.77778],10901:[.13667,.63667,0,0,.77778],10902:[.13667,.63667,0,0,.77778],10933:[.25142,.75726,0,0,.77778],10934:[.25142,.75726,0,0,.77778],10935:[.26167,.75726,0,0,.77778],10936:[.26167,.75726,0,0,.77778],10937:[.26167,.75726,0,0,.77778],10938:[.26167,.75726,0,0,.77778],10949:[.25583,.75583,0,0,.77778],10950:[.25583,.75583,0,0,.77778],10955:[.28481,.79383,0,0,.77778],10956:[.28481,.79383,0,0,.77778],57350:[.08167,.58167,0,0,.22222],57351:[.08167,.58167,0,0,.38889],57352:[.08167,.58167,0,0,.77778],57353:[0,.43056,.04028,0,.66667],57356:[.25142,.75726,0,0,.77778],57357:[.25142,.75726,0,0,.77778],57358:[.41951,.91951,0,0,.77778],57359:[.30274,.79383,0,0,.77778],57360:[.30274,.79383,0,0,.77778],57361:[.41951,.91951,0,0,.77778],57366:[.25142,.75726,0,0,.77778],57367:[.25142,.75726,0,0,.77778],57368:[.25142,.75726,0,0,.77778],57369:[.25142,.75726,0,0,.77778],57370:[.13597,.63597,0,0,.77778],57371:[.13597,.63597,0,0,.77778]},"Caligraphic-Regular":{32:[0,0,0,0,.25],65:[0,.68333,0,.19445,.79847],66:[0,.68333,.03041,.13889,.65681],67:[0,.68333,.05834,.13889,.52653],68:[0,.68333,.02778,.08334,.77139],69:[0,.68333,.08944,.11111,.52778],70:[0,.68333,.09931,.11111,.71875],71:[.09722,.68333,.0593,.11111,.59487],72:[0,.68333,.00965,.11111,.84452],73:[0,.68333,.07382,0,.54452],74:[.09722,.68333,.18472,.16667,.67778],75:[0,.68333,.01445,.05556,.76195],76:[0,.68333,0,.13889,.68972],77:[0,.68333,0,.13889,1.2009],78:[0,.68333,.14736,.08334,.82049],79:[0,.68333,.02778,.11111,.79611],80:[0,.68333,.08222,.08334,.69556],81:[.09722,.68333,0,.11111,.81667],82:[0,.68333,0,.08334,.8475],83:[0,.68333,.075,.13889,.60556],84:[0,.68333,.25417,0,.54464],85:[0,.68333,.09931,.08334,.62583],86:[0,.68333,.08222,0,.61278],87:[0,.68333,.08222,.08334,.98778],88:[0,.68333,.14643,.13889,.7133],89:[.09722,.68333,.08222,.08334,.66834],90:[0,.68333,.07944,.13889,.72473],160:[0,0,0,0,.25]},"Fraktur-Regular":{32:[0,0,0,0,.25],33:[0,.69141,0,0,.29574],34:[0,.69141,0,0,.21471],38:[0,.69141,0,0,.73786],39:[0,.69141,0,0,.21201],40:[.24982,.74947,0,0,.38865],41:[.24982,.74947,0,0,.38865],42:[0,.62119,0,0,.27764],43:[.08319,.58283,0,0,.75623],44:[0,.10803,0,0,.27764],45:[.08319,.58283,0,0,.75623],46:[0,.10803,0,0,.27764],47:[.24982,.74947,0,0,.50181],48:[0,.47534,0,0,.50181],49:[0,.47534,0,0,.50181],50:[0,.47534,0,0,.50181],51:[.18906,.47534,0,0,.50181],52:[.18906,.47534,0,0,.50181],53:[.18906,.47534,0,0,.50181],54:[0,.69141,0,0,.50181],55:[.18906,.47534,0,0,.50181],56:[0,.69141,0,0,.50181],57:[.18906,.47534,0,0,.50181],58:[0,.47534,0,0,.21606],59:[.12604,.47534,0,0,.21606],61:[-.13099,.36866,0,0,.75623],63:[0,.69141,0,0,.36245],65:[0,.69141,0,0,.7176],66:[0,.69141,0,0,.88397],67:[0,.69141,0,0,.61254],68:[0,.69141,0,0,.83158],69:[0,.69141,0,0,.66278],70:[.12604,.69141,0,0,.61119],71:[0,.69141,0,0,.78539],72:[.06302,.69141,0,0,.7203],73:[0,.69141,0,0,.55448],74:[.12604,.69141,0,0,.55231],75:[0,.69141,0,0,.66845],76:[0,.69141,0,0,.66602],77:[0,.69141,0,0,1.04953],78:[0,.69141,0,0,.83212],79:[0,.69141,0,0,.82699],80:[.18906,.69141,0,0,.82753],81:[.03781,.69141,0,0,.82699],82:[0,.69141,0,0,.82807],83:[0,.69141,0,0,.82861],84:[0,.69141,0,0,.66899],85:[0,.69141,0,0,.64576],86:[0,.69141,0,0,.83131],87:[0,.69141,0,0,1.04602],88:[0,.69141,0,0,.71922],89:[.18906,.69141,0,0,.83293],90:[.12604,.69141,0,0,.60201],91:[.24982,.74947,0,0,.27764],93:[.24982,.74947,0,0,.27764],94:[0,.69141,0,0,.49965],97:[0,.47534,0,0,.50046],98:[0,.69141,0,0,.51315],99:[0,.47534,0,0,.38946],100:[0,.62119,0,0,.49857],101:[0,.47534,0,0,.40053],102:[.18906,.69141,0,0,.32626],103:[.18906,.47534,0,0,.5037],104:[.18906,.69141,0,0,.52126],105:[0,.69141,0,0,.27899],106:[0,.69141,0,0,.28088],107:[0,.69141,0,0,.38946],108:[0,.69141,0,0,.27953],109:[0,.47534,0,0,.76676],110:[0,.47534,0,0,.52666],111:[0,.47534,0,0,.48885],112:[.18906,.52396,0,0,.50046],113:[.18906,.47534,0,0,.48912],114:[0,.47534,0,0,.38919],115:[0,.47534,0,0,.44266],116:[0,.62119,0,0,.33301],117:[0,.47534,0,0,.5172],118:[0,.52396,0,0,.5118],119:[0,.52396,0,0,.77351],120:[.18906,.47534,0,0,.38865],121:[.18906,.47534,0,0,.49884],122:[.18906,.47534,0,0,.39054],160:[0,0,0,0,.25],8216:[0,.69141,0,0,.21471],8217:[0,.69141,0,0,.21471],58112:[0,.62119,0,0,.49749],58113:[0,.62119,0,0,.4983],58114:[.18906,.69141,0,0,.33328],58115:[.18906,.69141,0,0,.32923],58116:[.18906,.47534,0,0,.50343],58117:[0,.69141,0,0,.33301],58118:[0,.62119,0,0,.33409],58119:[0,.47534,0,0,.50073]},"Main-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.35],34:[0,.69444,0,0,.60278],35:[.19444,.69444,0,0,.95833],36:[.05556,.75,0,0,.575],37:[.05556,.75,0,0,.95833],38:[0,.69444,0,0,.89444],39:[0,.69444,0,0,.31944],40:[.25,.75,0,0,.44722],41:[.25,.75,0,0,.44722],42:[0,.75,0,0,.575],43:[.13333,.63333,0,0,.89444],44:[.19444,.15556,0,0,.31944],45:[0,.44444,0,0,.38333],46:[0,.15556,0,0,.31944],47:[.25,.75,0,0,.575],48:[0,.64444,0,0,.575],49:[0,.64444,0,0,.575],50:[0,.64444,0,0,.575],51:[0,.64444,0,0,.575],52:[0,.64444,0,0,.575],53:[0,.64444,0,0,.575],54:[0,.64444,0,0,.575],55:[0,.64444,0,0,.575],56:[0,.64444,0,0,.575],57:[0,.64444,0,0,.575],58:[0,.44444,0,0,.31944],59:[.19444,.44444,0,0,.31944],60:[.08556,.58556,0,0,.89444],61:[-.10889,.39111,0,0,.89444],62:[.08556,.58556,0,0,.89444],63:[0,.69444,0,0,.54305],64:[0,.69444,0,0,.89444],65:[0,.68611,0,0,.86944],66:[0,.68611,0,0,.81805],67:[0,.68611,0,0,.83055],68:[0,.68611,0,0,.88194],69:[0,.68611,0,0,.75555],70:[0,.68611,0,0,.72361],71:[0,.68611,0,0,.90416],72:[0,.68611,0,0,.9],73:[0,.68611,0,0,.43611],74:[0,.68611,0,0,.59444],75:[0,.68611,0,0,.90138],76:[0,.68611,0,0,.69166],77:[0,.68611,0,0,1.09166],78:[0,.68611,0,0,.9],79:[0,.68611,0,0,.86388],80:[0,.68611,0,0,.78611],81:[.19444,.68611,0,0,.86388],82:[0,.68611,0,0,.8625],83:[0,.68611,0,0,.63889],84:[0,.68611,0,0,.8],85:[0,.68611,0,0,.88472],86:[0,.68611,.01597,0,.86944],87:[0,.68611,.01597,0,1.18888],88:[0,.68611,0,0,.86944],89:[0,.68611,.02875,0,.86944],90:[0,.68611,0,0,.70277],91:[.25,.75,0,0,.31944],92:[.25,.75,0,0,.575],93:[.25,.75,0,0,.31944],94:[0,.69444,0,0,.575],95:[.31,.13444,.03194,0,.575],97:[0,.44444,0,0,.55902],98:[0,.69444,0,0,.63889],99:[0,.44444,0,0,.51111],100:[0,.69444,0,0,.63889],101:[0,.44444,0,0,.52708],102:[0,.69444,.10903,0,.35139],103:[.19444,.44444,.01597,0,.575],104:[0,.69444,0,0,.63889],105:[0,.69444,0,0,.31944],106:[.19444,.69444,0,0,.35139],107:[0,.69444,0,0,.60694],108:[0,.69444,0,0,.31944],109:[0,.44444,0,0,.95833],110:[0,.44444,0,0,.63889],111:[0,.44444,0,0,.575],112:[.19444,.44444,0,0,.63889],113:[.19444,.44444,0,0,.60694],114:[0,.44444,0,0,.47361],115:[0,.44444,0,0,.45361],116:[0,.63492,0,0,.44722],117:[0,.44444,0,0,.63889],118:[0,.44444,.01597,0,.60694],119:[0,.44444,.01597,0,.83055],120:[0,.44444,0,0,.60694],121:[.19444,.44444,.01597,0,.60694],122:[0,.44444,0,0,.51111],123:[.25,.75,0,0,.575],124:[.25,.75,0,0,.31944],125:[.25,.75,0,0,.575],126:[.35,.34444,0,0,.575],160:[0,0,0,0,.25],163:[0,.69444,0,0,.86853],168:[0,.69444,0,0,.575],172:[0,.44444,0,0,.76666],176:[0,.69444,0,0,.86944],177:[.13333,.63333,0,0,.89444],184:[.17014,0,0,0,.51111],198:[0,.68611,0,0,1.04166],215:[.13333,.63333,0,0,.89444],216:[.04861,.73472,0,0,.89444],223:[0,.69444,0,0,.59722],230:[0,.44444,0,0,.83055],247:[.13333,.63333,0,0,.89444],248:[.09722,.54167,0,0,.575],305:[0,.44444,0,0,.31944],338:[0,.68611,0,0,1.16944],339:[0,.44444,0,0,.89444],567:[.19444,.44444,0,0,.35139],710:[0,.69444,0,0,.575],711:[0,.63194,0,0,.575],713:[0,.59611,0,0,.575],714:[0,.69444,0,0,.575],715:[0,.69444,0,0,.575],728:[0,.69444,0,0,.575],729:[0,.69444,0,0,.31944],730:[0,.69444,0,0,.86944],732:[0,.69444,0,0,.575],733:[0,.69444,0,0,.575],915:[0,.68611,0,0,.69166],916:[0,.68611,0,0,.95833],920:[0,.68611,0,0,.89444],923:[0,.68611,0,0,.80555],926:[0,.68611,0,0,.76666],928:[0,.68611,0,0,.9],931:[0,.68611,0,0,.83055],933:[0,.68611,0,0,.89444],934:[0,.68611,0,0,.83055],936:[0,.68611,0,0,.89444],937:[0,.68611,0,0,.83055],8211:[0,.44444,.03194,0,.575],8212:[0,.44444,.03194,0,1.14999],8216:[0,.69444,0,0,.31944],8217:[0,.69444,0,0,.31944],8220:[0,.69444,0,0,.60278],8221:[0,.69444,0,0,.60278],8224:[.19444,.69444,0,0,.51111],8225:[.19444,.69444,0,0,.51111],8242:[0,.55556,0,0,.34444],8407:[0,.72444,.15486,0,.575],8463:[0,.69444,0,0,.66759],8465:[0,.69444,0,0,.83055],8467:[0,.69444,0,0,.47361],8472:[.19444,.44444,0,0,.74027],8476:[0,.69444,0,0,.83055],8501:[0,.69444,0,0,.70277],8592:[-.10889,.39111,0,0,1.14999],8593:[.19444,.69444,0,0,.575],8594:[-.10889,.39111,0,0,1.14999],8595:[.19444,.69444,0,0,.575],8596:[-.10889,.39111,0,0,1.14999],8597:[.25,.75,0,0,.575],8598:[.19444,.69444,0,0,1.14999],8599:[.19444,.69444,0,0,1.14999],8600:[.19444,.69444,0,0,1.14999],8601:[.19444,.69444,0,0,1.14999],8636:[-.10889,.39111,0,0,1.14999],8637:[-.10889,.39111,0,0,1.14999],8640:[-.10889,.39111,0,0,1.14999],8641:[-.10889,.39111,0,0,1.14999],8656:[-.10889,.39111,0,0,1.14999],8657:[.19444,.69444,0,0,.70277],8658:[-.10889,.39111,0,0,1.14999],8659:[.19444,.69444,0,0,.70277],8660:[-.10889,.39111,0,0,1.14999],8661:[.25,.75,0,0,.70277],8704:[0,.69444,0,0,.63889],8706:[0,.69444,.06389,0,.62847],8707:[0,.69444,0,0,.63889],8709:[.05556,.75,0,0,.575],8711:[0,.68611,0,0,.95833],8712:[.08556,.58556,0,0,.76666],8715:[.08556,.58556,0,0,.76666],8722:[.13333,.63333,0,0,.89444],8723:[.13333,.63333,0,0,.89444],8725:[.25,.75,0,0,.575],8726:[.25,.75,0,0,.575],8727:[-.02778,.47222,0,0,.575],8728:[-.02639,.47361,0,0,.575],8729:[-.02639,.47361,0,0,.575],8730:[.18,.82,0,0,.95833],8733:[0,.44444,0,0,.89444],8734:[0,.44444,0,0,1.14999],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.31944],8741:[.25,.75,0,0,.575],8743:[0,.55556,0,0,.76666],8744:[0,.55556,0,0,.76666],8745:[0,.55556,0,0,.76666],8746:[0,.55556,0,0,.76666],8747:[.19444,.69444,.12778,0,.56875],8764:[-.10889,.39111,0,0,.89444],8768:[.19444,.69444,0,0,.31944],8771:[.00222,.50222,0,0,.89444],8773:[.027,.638,0,0,.894],8776:[.02444,.52444,0,0,.89444],8781:[.00222,.50222,0,0,.89444],8801:[.00222,.50222,0,0,.89444],8804:[.19667,.69667,0,0,.89444],8805:[.19667,.69667,0,0,.89444],8810:[.08556,.58556,0,0,1.14999],8811:[.08556,.58556,0,0,1.14999],8826:[.08556,.58556,0,0,.89444],8827:[.08556,.58556,0,0,.89444],8834:[.08556,.58556,0,0,.89444],8835:[.08556,.58556,0,0,.89444],8838:[.19667,.69667,0,0,.89444],8839:[.19667,.69667,0,0,.89444],8846:[0,.55556,0,0,.76666],8849:[.19667,.69667,0,0,.89444],8850:[.19667,.69667,0,0,.89444],8851:[0,.55556,0,0,.76666],8852:[0,.55556,0,0,.76666],8853:[.13333,.63333,0,0,.89444],8854:[.13333,.63333,0,0,.89444],8855:[.13333,.63333,0,0,.89444],8856:[.13333,.63333,0,0,.89444],8857:[.13333,.63333,0,0,.89444],8866:[0,.69444,0,0,.70277],8867:[0,.69444,0,0,.70277],8868:[0,.69444,0,0,.89444],8869:[0,.69444,0,0,.89444],8900:[-.02639,.47361,0,0,.575],8901:[-.02639,.47361,0,0,.31944],8902:[-.02778,.47222,0,0,.575],8968:[.25,.75,0,0,.51111],8969:[.25,.75,0,0,.51111],8970:[.25,.75,0,0,.51111],8971:[.25,.75,0,0,.51111],8994:[-.13889,.36111,0,0,1.14999],8995:[-.13889,.36111,0,0,1.14999],9651:[.19444,.69444,0,0,1.02222],9657:[-.02778,.47222,0,0,.575],9661:[.19444,.69444,0,0,1.02222],9667:[-.02778,.47222,0,0,.575],9711:[.19444,.69444,0,0,1.14999],9824:[.12963,.69444,0,0,.89444],9825:[.12963,.69444,0,0,.89444],9826:[.12963,.69444,0,0,.89444],9827:[.12963,.69444,0,0,.89444],9837:[0,.75,0,0,.44722],9838:[.19444,.69444,0,0,.44722],9839:[.19444,.69444,0,0,.44722],10216:[.25,.75,0,0,.44722],10217:[.25,.75,0,0,.44722],10815:[0,.68611,0,0,.9],10927:[.19667,.69667,0,0,.89444],10928:[.19667,.69667,0,0,.89444],57376:[.19444,.69444,0,0,0]},"Main-BoldItalic":{32:[0,0,0,0,.25],33:[0,.69444,.11417,0,.38611],34:[0,.69444,.07939,0,.62055],35:[.19444,.69444,.06833,0,.94444],37:[.05556,.75,.12861,0,.94444],38:[0,.69444,.08528,0,.88555],39:[0,.69444,.12945,0,.35555],40:[.25,.75,.15806,0,.47333],41:[.25,.75,.03306,0,.47333],42:[0,.75,.14333,0,.59111],43:[.10333,.60333,.03306,0,.88555],44:[.19444,.14722,0,0,.35555],45:[0,.44444,.02611,0,.41444],46:[0,.14722,0,0,.35555],47:[.25,.75,.15806,0,.59111],48:[0,.64444,.13167,0,.59111],49:[0,.64444,.13167,0,.59111],50:[0,.64444,.13167,0,.59111],51:[0,.64444,.13167,0,.59111],52:[.19444,.64444,.13167,0,.59111],53:[0,.64444,.13167,0,.59111],54:[0,.64444,.13167,0,.59111],55:[.19444,.64444,.13167,0,.59111],56:[0,.64444,.13167,0,.59111],57:[0,.64444,.13167,0,.59111],58:[0,.44444,.06695,0,.35555],59:[.19444,.44444,.06695,0,.35555],61:[-.10889,.39111,.06833,0,.88555],63:[0,.69444,.11472,0,.59111],64:[0,.69444,.09208,0,.88555],65:[0,.68611,0,0,.86555],66:[0,.68611,.0992,0,.81666],67:[0,.68611,.14208,0,.82666],68:[0,.68611,.09062,0,.87555],69:[0,.68611,.11431,0,.75666],70:[0,.68611,.12903,0,.72722],71:[0,.68611,.07347,0,.89527],72:[0,.68611,.17208,0,.8961],73:[0,.68611,.15681,0,.47166],74:[0,.68611,.145,0,.61055],75:[0,.68611,.14208,0,.89499],76:[0,.68611,0,0,.69777],77:[0,.68611,.17208,0,1.07277],78:[0,.68611,.17208,0,.8961],79:[0,.68611,.09062,0,.85499],80:[0,.68611,.0992,0,.78721],81:[.19444,.68611,.09062,0,.85499],82:[0,.68611,.02559,0,.85944],83:[0,.68611,.11264,0,.64999],84:[0,.68611,.12903,0,.7961],85:[0,.68611,.17208,0,.88083],86:[0,.68611,.18625,0,.86555],87:[0,.68611,.18625,0,1.15999],88:[0,.68611,.15681,0,.86555],89:[0,.68611,.19803,0,.86555],90:[0,.68611,.14208,0,.70888],91:[.25,.75,.1875,0,.35611],93:[.25,.75,.09972,0,.35611],94:[0,.69444,.06709,0,.59111],95:[.31,.13444,.09811,0,.59111],97:[0,.44444,.09426,0,.59111],98:[0,.69444,.07861,0,.53222],99:[0,.44444,.05222,0,.53222],100:[0,.69444,.10861,0,.59111],101:[0,.44444,.085,0,.53222],102:[.19444,.69444,.21778,0,.4],103:[.19444,.44444,.105,0,.53222],104:[0,.69444,.09426,0,.59111],105:[0,.69326,.11387,0,.35555],106:[.19444,.69326,.1672,0,.35555],107:[0,.69444,.11111,0,.53222],108:[0,.69444,.10861,0,.29666],109:[0,.44444,.09426,0,.94444],110:[0,.44444,.09426,0,.64999],111:[0,.44444,.07861,0,.59111],112:[.19444,.44444,.07861,0,.59111],113:[.19444,.44444,.105,0,.53222],114:[0,.44444,.11111,0,.50167],115:[0,.44444,.08167,0,.48694],116:[0,.63492,.09639,0,.385],117:[0,.44444,.09426,0,.62055],118:[0,.44444,.11111,0,.53222],119:[0,.44444,.11111,0,.76777],120:[0,.44444,.12583,0,.56055],121:[.19444,.44444,.105,0,.56166],122:[0,.44444,.13889,0,.49055],126:[.35,.34444,.11472,0,.59111],160:[0,0,0,0,.25],168:[0,.69444,.11473,0,.59111],176:[0,.69444,0,0,.94888],184:[.17014,0,0,0,.53222],198:[0,.68611,.11431,0,1.02277],216:[.04861,.73472,.09062,0,.88555],223:[.19444,.69444,.09736,0,.665],230:[0,.44444,.085,0,.82666],248:[.09722,.54167,.09458,0,.59111],305:[0,.44444,.09426,0,.35555],338:[0,.68611,.11431,0,1.14054],339:[0,.44444,.085,0,.82666],567:[.19444,.44444,.04611,0,.385],710:[0,.69444,.06709,0,.59111],711:[0,.63194,.08271,0,.59111],713:[0,.59444,.10444,0,.59111],714:[0,.69444,.08528,0,.59111],715:[0,.69444,0,0,.59111],728:[0,.69444,.10333,0,.59111],729:[0,.69444,.12945,0,.35555],730:[0,.69444,0,0,.94888],732:[0,.69444,.11472,0,.59111],733:[0,.69444,.11472,0,.59111],915:[0,.68611,.12903,0,.69777],916:[0,.68611,0,0,.94444],920:[0,.68611,.09062,0,.88555],923:[0,.68611,0,0,.80666],926:[0,.68611,.15092,0,.76777],928:[0,.68611,.17208,0,.8961],931:[0,.68611,.11431,0,.82666],933:[0,.68611,.10778,0,.88555],934:[0,.68611,.05632,0,.82666],936:[0,.68611,.10778,0,.88555],937:[0,.68611,.0992,0,.82666],8211:[0,.44444,.09811,0,.59111],8212:[0,.44444,.09811,0,1.18221],8216:[0,.69444,.12945,0,.35555],8217:[0,.69444,.12945,0,.35555],8220:[0,.69444,.16772,0,.62055],8221:[0,.69444,.07939,0,.62055]},"Main-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.12417,0,.30667],34:[0,.69444,.06961,0,.51444],35:[.19444,.69444,.06616,0,.81777],37:[.05556,.75,.13639,0,.81777],38:[0,.69444,.09694,0,.76666],39:[0,.69444,.12417,0,.30667],40:[.25,.75,.16194,0,.40889],41:[.25,.75,.03694,0,.40889],42:[0,.75,.14917,0,.51111],43:[.05667,.56167,.03694,0,.76666],44:[.19444,.10556,0,0,.30667],45:[0,.43056,.02826,0,.35778],46:[0,.10556,0,0,.30667],47:[.25,.75,.16194,0,.51111],48:[0,.64444,.13556,0,.51111],49:[0,.64444,.13556,0,.51111],50:[0,.64444,.13556,0,.51111],51:[0,.64444,.13556,0,.51111],52:[.19444,.64444,.13556,0,.51111],53:[0,.64444,.13556,0,.51111],54:[0,.64444,.13556,0,.51111],55:[.19444,.64444,.13556,0,.51111],56:[0,.64444,.13556,0,.51111],57:[0,.64444,.13556,0,.51111],58:[0,.43056,.0582,0,.30667],59:[.19444,.43056,.0582,0,.30667],61:[-.13313,.36687,.06616,0,.76666],63:[0,.69444,.1225,0,.51111],64:[0,.69444,.09597,0,.76666],65:[0,.68333,0,0,.74333],66:[0,.68333,.10257,0,.70389],67:[0,.68333,.14528,0,.71555],68:[0,.68333,.09403,0,.755],69:[0,.68333,.12028,0,.67833],70:[0,.68333,.13305,0,.65277],71:[0,.68333,.08722,0,.77361],72:[0,.68333,.16389,0,.74333],73:[0,.68333,.15806,0,.38555],74:[0,.68333,.14028,0,.525],75:[0,.68333,.14528,0,.76888],76:[0,.68333,0,0,.62722],77:[0,.68333,.16389,0,.89666],78:[0,.68333,.16389,0,.74333],79:[0,.68333,.09403,0,.76666],80:[0,.68333,.10257,0,.67833],81:[.19444,.68333,.09403,0,.76666],82:[0,.68333,.03868,0,.72944],83:[0,.68333,.11972,0,.56222],84:[0,.68333,.13305,0,.71555],85:[0,.68333,.16389,0,.74333],86:[0,.68333,.18361,0,.74333],87:[0,.68333,.18361,0,.99888],88:[0,.68333,.15806,0,.74333],89:[0,.68333,.19383,0,.74333],90:[0,.68333,.14528,0,.61333],91:[.25,.75,.1875,0,.30667],93:[.25,.75,.10528,0,.30667],94:[0,.69444,.06646,0,.51111],95:[.31,.12056,.09208,0,.51111],97:[0,.43056,.07671,0,.51111],98:[0,.69444,.06312,0,.46],99:[0,.43056,.05653,0,.46],100:[0,.69444,.10333,0,.51111],101:[0,.43056,.07514,0,.46],102:[.19444,.69444,.21194,0,.30667],103:[.19444,.43056,.08847,0,.46],104:[0,.69444,.07671,0,.51111],105:[0,.65536,.1019,0,.30667],106:[.19444,.65536,.14467,0,.30667],107:[0,.69444,.10764,0,.46],108:[0,.69444,.10333,0,.25555],109:[0,.43056,.07671,0,.81777],110:[0,.43056,.07671,0,.56222],111:[0,.43056,.06312,0,.51111],112:[.19444,.43056,.06312,0,.51111],113:[.19444,.43056,.08847,0,.46],114:[0,.43056,.10764,0,.42166],115:[0,.43056,.08208,0,.40889],116:[0,.61508,.09486,0,.33222],117:[0,.43056,.07671,0,.53666],118:[0,.43056,.10764,0,.46],119:[0,.43056,.10764,0,.66444],120:[0,.43056,.12042,0,.46389],121:[.19444,.43056,.08847,0,.48555],122:[0,.43056,.12292,0,.40889],126:[.35,.31786,.11585,0,.51111],160:[0,0,0,0,.25],168:[0,.66786,.10474,0,.51111],176:[0,.69444,0,0,.83129],184:[.17014,0,0,0,.46],198:[0,.68333,.12028,0,.88277],216:[.04861,.73194,.09403,0,.76666],223:[.19444,.69444,.10514,0,.53666],230:[0,.43056,.07514,0,.71555],248:[.09722,.52778,.09194,0,.51111],338:[0,.68333,.12028,0,.98499],339:[0,.43056,.07514,0,.71555],710:[0,.69444,.06646,0,.51111],711:[0,.62847,.08295,0,.51111],713:[0,.56167,.10333,0,.51111],714:[0,.69444,.09694,0,.51111],715:[0,.69444,0,0,.51111],728:[0,.69444,.10806,0,.51111],729:[0,.66786,.11752,0,.30667],730:[0,.69444,0,0,.83129],732:[0,.66786,.11585,0,.51111],733:[0,.69444,.1225,0,.51111],915:[0,.68333,.13305,0,.62722],916:[0,.68333,0,0,.81777],920:[0,.68333,.09403,0,.76666],923:[0,.68333,0,0,.69222],926:[0,.68333,.15294,0,.66444],928:[0,.68333,.16389,0,.74333],931:[0,.68333,.12028,0,.71555],933:[0,.68333,.11111,0,.76666],934:[0,.68333,.05986,0,.71555],936:[0,.68333,.11111,0,.76666],937:[0,.68333,.10257,0,.71555],8211:[0,.43056,.09208,0,.51111],8212:[0,.43056,.09208,0,1.02222],8216:[0,.69444,.12417,0,.30667],8217:[0,.69444,.12417,0,.30667],8220:[0,.69444,.1685,0,.51444],8221:[0,.69444,.06961,0,.51444],8463:[0,.68889,0,0,.54028]},"Main-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.27778],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.77778],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.19444,.10556,0,0,.27778],45:[0,.43056,0,0,.33333],46:[0,.10556,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.64444,0,0,.5],49:[0,.64444,0,0,.5],50:[0,.64444,0,0,.5],51:[0,.64444,0,0,.5],52:[0,.64444,0,0,.5],53:[0,.64444,0,0,.5],54:[0,.64444,0,0,.5],55:[0,.64444,0,0,.5],56:[0,.64444,0,0,.5],57:[0,.64444,0,0,.5],58:[0,.43056,0,0,.27778],59:[.19444,.43056,0,0,.27778],60:[.0391,.5391,0,0,.77778],61:[-.13313,.36687,0,0,.77778],62:[.0391,.5391,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.77778],65:[0,.68333,0,0,.75],66:[0,.68333,0,0,.70834],67:[0,.68333,0,0,.72222],68:[0,.68333,0,0,.76389],69:[0,.68333,0,0,.68056],70:[0,.68333,0,0,.65278],71:[0,.68333,0,0,.78472],72:[0,.68333,0,0,.75],73:[0,.68333,0,0,.36111],74:[0,.68333,0,0,.51389],75:[0,.68333,0,0,.77778],76:[0,.68333,0,0,.625],77:[0,.68333,0,0,.91667],78:[0,.68333,0,0,.75],79:[0,.68333,0,0,.77778],80:[0,.68333,0,0,.68056],81:[.19444,.68333,0,0,.77778],82:[0,.68333,0,0,.73611],83:[0,.68333,0,0,.55556],84:[0,.68333,0,0,.72222],85:[0,.68333,0,0,.75],86:[0,.68333,.01389,0,.75],87:[0,.68333,.01389,0,1.02778],88:[0,.68333,0,0,.75],89:[0,.68333,.025,0,.75],90:[0,.68333,0,0,.61111],91:[.25,.75,0,0,.27778],92:[.25,.75,0,0,.5],93:[.25,.75,0,0,.27778],94:[0,.69444,0,0,.5],95:[.31,.12056,.02778,0,.5],97:[0,.43056,0,0,.5],98:[0,.69444,0,0,.55556],99:[0,.43056,0,0,.44445],100:[0,.69444,0,0,.55556],101:[0,.43056,0,0,.44445],102:[0,.69444,.07778,0,.30556],103:[.19444,.43056,.01389,0,.5],104:[0,.69444,0,0,.55556],105:[0,.66786,0,0,.27778],106:[.19444,.66786,0,0,.30556],107:[0,.69444,0,0,.52778],108:[0,.69444,0,0,.27778],109:[0,.43056,0,0,.83334],110:[0,.43056,0,0,.55556],111:[0,.43056,0,0,.5],112:[.19444,.43056,0,0,.55556],113:[.19444,.43056,0,0,.52778],114:[0,.43056,0,0,.39167],115:[0,.43056,0,0,.39445],116:[0,.61508,0,0,.38889],117:[0,.43056,0,0,.55556],118:[0,.43056,.01389,0,.52778],119:[0,.43056,.01389,0,.72222],120:[0,.43056,0,0,.52778],121:[.19444,.43056,.01389,0,.52778],122:[0,.43056,0,0,.44445],123:[.25,.75,0,0,.5],124:[.25,.75,0,0,.27778],125:[.25,.75,0,0,.5],126:[.35,.31786,0,0,.5],160:[0,0,0,0,.25],163:[0,.69444,0,0,.76909],167:[.19444,.69444,0,0,.44445],168:[0,.66786,0,0,.5],172:[0,.43056,0,0,.66667],176:[0,.69444,0,0,.75],177:[.08333,.58333,0,0,.77778],182:[.19444,.69444,0,0,.61111],184:[.17014,0,0,0,.44445],198:[0,.68333,0,0,.90278],215:[.08333,.58333,0,0,.77778],216:[.04861,.73194,0,0,.77778],223:[0,.69444,0,0,.5],230:[0,.43056,0,0,.72222],247:[.08333,.58333,0,0,.77778],248:[.09722,.52778,0,0,.5],305:[0,.43056,0,0,.27778],338:[0,.68333,0,0,1.01389],339:[0,.43056,0,0,.77778],567:[.19444,.43056,0,0,.30556],710:[0,.69444,0,0,.5],711:[0,.62847,0,0,.5],713:[0,.56778,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.66786,0,0,.27778],730:[0,.69444,0,0,.75],732:[0,.66786,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.68333,0,0,.625],916:[0,.68333,0,0,.83334],920:[0,.68333,0,0,.77778],923:[0,.68333,0,0,.69445],926:[0,.68333,0,0,.66667],928:[0,.68333,0,0,.75],931:[0,.68333,0,0,.72222],933:[0,.68333,0,0,.77778],934:[0,.68333,0,0,.72222],936:[0,.68333,0,0,.77778],937:[0,.68333,0,0,.72222],8211:[0,.43056,.02778,0,.5],8212:[0,.43056,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5],8224:[.19444,.69444,0,0,.44445],8225:[.19444,.69444,0,0,.44445],8230:[0,.123,0,0,1.172],8242:[0,.55556,0,0,.275],8407:[0,.71444,.15382,0,.5],8463:[0,.68889,0,0,.54028],8465:[0,.69444,0,0,.72222],8467:[0,.69444,0,.11111,.41667],8472:[.19444,.43056,0,.11111,.63646],8476:[0,.69444,0,0,.72222],8501:[0,.69444,0,0,.61111],8592:[-.13313,.36687,0,0,1],8593:[.19444,.69444,0,0,.5],8594:[-.13313,.36687,0,0,1],8595:[.19444,.69444,0,0,.5],8596:[-.13313,.36687,0,0,1],8597:[.25,.75,0,0,.5],8598:[.19444,.69444,0,0,1],8599:[.19444,.69444,0,0,1],8600:[.19444,.69444,0,0,1],8601:[.19444,.69444,0,0,1],8614:[.011,.511,0,0,1],8617:[.011,.511,0,0,1.126],8618:[.011,.511,0,0,1.126],8636:[-.13313,.36687,0,0,1],8637:[-.13313,.36687,0,0,1],8640:[-.13313,.36687,0,0,1],8641:[-.13313,.36687,0,0,1],8652:[.011,.671,0,0,1],8656:[-.13313,.36687,0,0,1],8657:[.19444,.69444,0,0,.61111],8658:[-.13313,.36687,0,0,1],8659:[.19444,.69444,0,0,.61111],8660:[-.13313,.36687,0,0,1],8661:[.25,.75,0,0,.61111],8704:[0,.69444,0,0,.55556],8706:[0,.69444,.05556,.08334,.5309],8707:[0,.69444,0,0,.55556],8709:[.05556,.75,0,0,.5],8711:[0,.68333,0,0,.83334],8712:[.0391,.5391,0,0,.66667],8715:[.0391,.5391,0,0,.66667],8722:[.08333,.58333,0,0,.77778],8723:[.08333,.58333,0,0,.77778],8725:[.25,.75,0,0,.5],8726:[.25,.75,0,0,.5],8727:[-.03472,.46528,0,0,.5],8728:[-.05555,.44445,0,0,.5],8729:[-.05555,.44445,0,0,.5],8730:[.2,.8,0,0,.83334],8733:[0,.43056,0,0,.77778],8734:[0,.43056,0,0,1],8736:[0,.69224,0,0,.72222],8739:[.25,.75,0,0,.27778],8741:[.25,.75,0,0,.5],8743:[0,.55556,0,0,.66667],8744:[0,.55556,0,0,.66667],8745:[0,.55556,0,0,.66667],8746:[0,.55556,0,0,.66667],8747:[.19444,.69444,.11111,0,.41667],8764:[-.13313,.36687,0,0,.77778],8768:[.19444,.69444,0,0,.27778],8771:[-.03625,.46375,0,0,.77778],8773:[-.022,.589,0,0,.778],8776:[-.01688,.48312,0,0,.77778],8781:[-.03625,.46375,0,0,.77778],8784:[-.133,.673,0,0,.778],8801:[-.03625,.46375,0,0,.77778],8804:[.13597,.63597,0,0,.77778],8805:[.13597,.63597,0,0,.77778],8810:[.0391,.5391,0,0,1],8811:[.0391,.5391,0,0,1],8826:[.0391,.5391,0,0,.77778],8827:[.0391,.5391,0,0,.77778],8834:[.0391,.5391,0,0,.77778],8835:[.0391,.5391,0,0,.77778],8838:[.13597,.63597,0,0,.77778],8839:[.13597,.63597,0,0,.77778],8846:[0,.55556,0,0,.66667],8849:[.13597,.63597,0,0,.77778],8850:[.13597,.63597,0,0,.77778],8851:[0,.55556,0,0,.66667],8852:[0,.55556,0,0,.66667],8853:[.08333,.58333,0,0,.77778],8854:[.08333,.58333,0,0,.77778],8855:[.08333,.58333,0,0,.77778],8856:[.08333,.58333,0,0,.77778],8857:[.08333,.58333,0,0,.77778],8866:[0,.69444,0,0,.61111],8867:[0,.69444,0,0,.61111],8868:[0,.69444,0,0,.77778],8869:[0,.69444,0,0,.77778],8872:[.249,.75,0,0,.867],8900:[-.05555,.44445,0,0,.5],8901:[-.05555,.44445,0,0,.27778],8902:[-.03472,.46528,0,0,.5],8904:[.005,.505,0,0,.9],8942:[.03,.903,0,0,.278],8943:[-.19,.313,0,0,1.172],8945:[-.1,.823,0,0,1.282],8968:[.25,.75,0,0,.44445],8969:[.25,.75,0,0,.44445],8970:[.25,.75,0,0,.44445],8971:[.25,.75,0,0,.44445],8994:[-.14236,.35764,0,0,1],8995:[-.14236,.35764,0,0,1],9136:[.244,.744,0,0,.412],9137:[.244,.745,0,0,.412],9651:[.19444,.69444,0,0,.88889],9657:[-.03472,.46528,0,0,.5],9661:[.19444,.69444,0,0,.88889],9667:[-.03472,.46528,0,0,.5],9711:[.19444,.69444,0,0,1],9824:[.12963,.69444,0,0,.77778],9825:[.12963,.69444,0,0,.77778],9826:[.12963,.69444,0,0,.77778],9827:[.12963,.69444,0,0,.77778],9837:[0,.75,0,0,.38889],9838:[.19444,.69444,0,0,.38889],9839:[.19444,.69444,0,0,.38889],10216:[.25,.75,0,0,.38889],10217:[.25,.75,0,0,.38889],10222:[.244,.744,0,0,.412],10223:[.244,.745,0,0,.412],10229:[.011,.511,0,0,1.609],10230:[.011,.511,0,0,1.638],10231:[.011,.511,0,0,1.859],10232:[.024,.525,0,0,1.609],10233:[.024,.525,0,0,1.638],10234:[.024,.525,0,0,1.858],10236:[.011,.511,0,0,1.638],10815:[0,.68333,0,0,.75],10927:[.13597,.63597,0,0,.77778],10928:[.13597,.63597,0,0,.77778],57376:[.19444,.69444,0,0,0]},"Math-BoldItalic":{32:[0,0,0,0,.25],48:[0,.44444,0,0,.575],49:[0,.44444,0,0,.575],50:[0,.44444,0,0,.575],51:[.19444,.44444,0,0,.575],52:[.19444,.44444,0,0,.575],53:[.19444,.44444,0,0,.575],54:[0,.64444,0,0,.575],55:[.19444,.44444,0,0,.575],56:[0,.64444,0,0,.575],57:[.19444,.44444,0,0,.575],65:[0,.68611,0,0,.86944],66:[0,.68611,.04835,0,.8664],67:[0,.68611,.06979,0,.81694],68:[0,.68611,.03194,0,.93812],69:[0,.68611,.05451,0,.81007],70:[0,.68611,.15972,0,.68889],71:[0,.68611,0,0,.88673],72:[0,.68611,.08229,0,.98229],73:[0,.68611,.07778,0,.51111],74:[0,.68611,.10069,0,.63125],75:[0,.68611,.06979,0,.97118],76:[0,.68611,0,0,.75555],77:[0,.68611,.11424,0,1.14201],78:[0,.68611,.11424,0,.95034],79:[0,.68611,.03194,0,.83666],80:[0,.68611,.15972,0,.72309],81:[.19444,.68611,0,0,.86861],82:[0,.68611,.00421,0,.87235],83:[0,.68611,.05382,0,.69271],84:[0,.68611,.15972,0,.63663],85:[0,.68611,.11424,0,.80027],86:[0,.68611,.25555,0,.67778],87:[0,.68611,.15972,0,1.09305],88:[0,.68611,.07778,0,.94722],89:[0,.68611,.25555,0,.67458],90:[0,.68611,.06979,0,.77257],97:[0,.44444,0,0,.63287],98:[0,.69444,0,0,.52083],99:[0,.44444,0,0,.51342],100:[0,.69444,0,0,.60972],101:[0,.44444,0,0,.55361],102:[.19444,.69444,.11042,0,.56806],103:[.19444,.44444,.03704,0,.5449],104:[0,.69444,0,0,.66759],105:[0,.69326,0,0,.4048],106:[.19444,.69326,.0622,0,.47083],107:[0,.69444,.01852,0,.6037],108:[0,.69444,.0088,0,.34815],109:[0,.44444,0,0,1.0324],110:[0,.44444,0,0,.71296],111:[0,.44444,0,0,.58472],112:[.19444,.44444,0,0,.60092],113:[.19444,.44444,.03704,0,.54213],114:[0,.44444,.03194,0,.5287],115:[0,.44444,0,0,.53125],116:[0,.63492,0,0,.41528],117:[0,.44444,0,0,.68102],118:[0,.44444,.03704,0,.56666],119:[0,.44444,.02778,0,.83148],120:[0,.44444,0,0,.65903],121:[.19444,.44444,.03704,0,.59028],122:[0,.44444,.04213,0,.55509],160:[0,0,0,0,.25],915:[0,.68611,.15972,0,.65694],916:[0,.68611,0,0,.95833],920:[0,.68611,.03194,0,.86722],923:[0,.68611,0,0,.80555],926:[0,.68611,.07458,0,.84125],928:[0,.68611,.08229,0,.98229],931:[0,.68611,.05451,0,.88507],933:[0,.68611,.15972,0,.67083],934:[0,.68611,0,0,.76666],936:[0,.68611,.11653,0,.71402],937:[0,.68611,.04835,0,.8789],945:[0,.44444,0,0,.76064],946:[.19444,.69444,.03403,0,.65972],947:[.19444,.44444,.06389,0,.59003],948:[0,.69444,.03819,0,.52222],949:[0,.44444,0,0,.52882],950:[.19444,.69444,.06215,0,.50833],951:[.19444,.44444,.03704,0,.6],952:[0,.69444,.03194,0,.5618],953:[0,.44444,0,0,.41204],954:[0,.44444,0,0,.66759],955:[0,.69444,0,0,.67083],956:[.19444,.44444,0,0,.70787],957:[0,.44444,.06898,0,.57685],958:[.19444,.69444,.03021,0,.50833],959:[0,.44444,0,0,.58472],960:[0,.44444,.03704,0,.68241],961:[.19444,.44444,0,0,.6118],962:[.09722,.44444,.07917,0,.42361],963:[0,.44444,.03704,0,.68588],964:[0,.44444,.13472,0,.52083],965:[0,.44444,.03704,0,.63055],966:[.19444,.44444,0,0,.74722],967:[.19444,.44444,0,0,.71805],968:[.19444,.69444,.03704,0,.75833],969:[0,.44444,.03704,0,.71782],977:[0,.69444,0,0,.69155],981:[.19444,.69444,0,0,.7125],982:[0,.44444,.03194,0,.975],1009:[.19444,.44444,0,0,.6118],1013:[0,.44444,0,0,.48333],57649:[0,.44444,0,0,.39352],57911:[.19444,.44444,0,0,.43889]},"Math-Italic":{32:[0,0,0,0,.25],48:[0,.43056,0,0,.5],49:[0,.43056,0,0,.5],50:[0,.43056,0,0,.5],51:[.19444,.43056,0,0,.5],52:[.19444,.43056,0,0,.5],53:[.19444,.43056,0,0,.5],54:[0,.64444,0,0,.5],55:[.19444,.43056,0,0,.5],56:[0,.64444,0,0,.5],57:[.19444,.43056,0,0,.5],65:[0,.68333,0,.13889,.75],66:[0,.68333,.05017,.08334,.75851],67:[0,.68333,.07153,.08334,.71472],68:[0,.68333,.02778,.05556,.82792],69:[0,.68333,.05764,.08334,.7382],70:[0,.68333,.13889,.08334,.64306],71:[0,.68333,0,.08334,.78625],72:[0,.68333,.08125,.05556,.83125],73:[0,.68333,.07847,.11111,.43958],74:[0,.68333,.09618,.16667,.55451],75:[0,.68333,.07153,.05556,.84931],76:[0,.68333,0,.02778,.68056],77:[0,.68333,.10903,.08334,.97014],78:[0,.68333,.10903,.08334,.80347],79:[0,.68333,.02778,.08334,.76278],80:[0,.68333,.13889,.08334,.64201],81:[.19444,.68333,0,.08334,.79056],82:[0,.68333,.00773,.08334,.75929],83:[0,.68333,.05764,.08334,.6132],84:[0,.68333,.13889,.08334,.58438],85:[0,.68333,.10903,.02778,.68278],86:[0,.68333,.22222,0,.58333],87:[0,.68333,.13889,0,.94445],88:[0,.68333,.07847,.08334,.82847],89:[0,.68333,.22222,0,.58056],90:[0,.68333,.07153,.08334,.68264],97:[0,.43056,0,0,.52859],98:[0,.69444,0,0,.42917],99:[0,.43056,0,.05556,.43276],100:[0,.69444,0,.16667,.52049],101:[0,.43056,0,.05556,.46563],102:[.19444,.69444,.10764,.16667,.48959],103:[.19444,.43056,.03588,.02778,.47697],104:[0,.69444,0,0,.57616],105:[0,.65952,0,0,.34451],106:[.19444,.65952,.05724,0,.41181],107:[0,.69444,.03148,0,.5206],108:[0,.69444,.01968,.08334,.29838],109:[0,.43056,0,0,.87801],110:[0,.43056,0,0,.60023],111:[0,.43056,0,.05556,.48472],112:[.19444,.43056,0,.08334,.50313],113:[.19444,.43056,.03588,.08334,.44641],114:[0,.43056,.02778,.05556,.45116],115:[0,.43056,0,.05556,.46875],116:[0,.61508,0,.08334,.36111],117:[0,.43056,0,.02778,.57246],118:[0,.43056,.03588,.02778,.48472],119:[0,.43056,.02691,.08334,.71592],120:[0,.43056,0,.02778,.57153],121:[.19444,.43056,.03588,.05556,.49028],122:[0,.43056,.04398,.05556,.46505],160:[0,0,0,0,.25],915:[0,.68333,.13889,.08334,.61528],916:[0,.68333,0,.16667,.83334],920:[0,.68333,.02778,.08334,.76278],923:[0,.68333,0,.16667,.69445],926:[0,.68333,.07569,.08334,.74236],928:[0,.68333,.08125,.05556,.83125],931:[0,.68333,.05764,.08334,.77986],933:[0,.68333,.13889,.05556,.58333],934:[0,.68333,0,.08334,.66667],936:[0,.68333,.11,.05556,.61222],937:[0,.68333,.05017,.08334,.7724],945:[0,.43056,.0037,.02778,.6397],946:[.19444,.69444,.05278,.08334,.56563],947:[.19444,.43056,.05556,0,.51773],948:[0,.69444,.03785,.05556,.44444],949:[0,.43056,0,.08334,.46632],950:[.19444,.69444,.07378,.08334,.4375],951:[.19444,.43056,.03588,.05556,.49653],952:[0,.69444,.02778,.08334,.46944],953:[0,.43056,0,.05556,.35394],954:[0,.43056,0,0,.57616],955:[0,.69444,0,0,.58334],956:[.19444,.43056,0,.02778,.60255],957:[0,.43056,.06366,.02778,.49398],958:[.19444,.69444,.04601,.11111,.4375],959:[0,.43056,0,.05556,.48472],960:[0,.43056,.03588,0,.57003],961:[.19444,.43056,0,.08334,.51702],962:[.09722,.43056,.07986,.08334,.36285],963:[0,.43056,.03588,0,.57141],964:[0,.43056,.1132,.02778,.43715],965:[0,.43056,.03588,.02778,.54028],966:[.19444,.43056,0,.08334,.65417],967:[.19444,.43056,0,.05556,.62569],968:[.19444,.69444,.03588,.11111,.65139],969:[0,.43056,.03588,0,.62245],977:[0,.69444,0,.08334,.59144],981:[.19444,.69444,0,.08334,.59583],982:[0,.43056,.02778,0,.82813],1009:[.19444,.43056,0,.08334,.51702],1013:[0,.43056,0,.05556,.4059],57649:[0,.43056,0,.02778,.32246],57911:[.19444,.43056,0,.08334,.38403]},"SansSerif-Bold":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.36667],34:[0,.69444,0,0,.55834],35:[.19444,.69444,0,0,.91667],36:[.05556,.75,0,0,.55],37:[.05556,.75,0,0,1.02912],38:[0,.69444,0,0,.83056],39:[0,.69444,0,0,.30556],40:[.25,.75,0,0,.42778],41:[.25,.75,0,0,.42778],42:[0,.75,0,0,.55],43:[.11667,.61667,0,0,.85556],44:[.10556,.13056,0,0,.30556],45:[0,.45833,0,0,.36667],46:[0,.13056,0,0,.30556],47:[.25,.75,0,0,.55],48:[0,.69444,0,0,.55],49:[0,.69444,0,0,.55],50:[0,.69444,0,0,.55],51:[0,.69444,0,0,.55],52:[0,.69444,0,0,.55],53:[0,.69444,0,0,.55],54:[0,.69444,0,0,.55],55:[0,.69444,0,0,.55],56:[0,.69444,0,0,.55],57:[0,.69444,0,0,.55],58:[0,.45833,0,0,.30556],59:[.10556,.45833,0,0,.30556],61:[-.09375,.40625,0,0,.85556],63:[0,.69444,0,0,.51945],64:[0,.69444,0,0,.73334],65:[0,.69444,0,0,.73334],66:[0,.69444,0,0,.73334],67:[0,.69444,0,0,.70278],68:[0,.69444,0,0,.79445],69:[0,.69444,0,0,.64167],70:[0,.69444,0,0,.61111],71:[0,.69444,0,0,.73334],72:[0,.69444,0,0,.79445],73:[0,.69444,0,0,.33056],74:[0,.69444,0,0,.51945],75:[0,.69444,0,0,.76389],76:[0,.69444,0,0,.58056],77:[0,.69444,0,0,.97778],78:[0,.69444,0,0,.79445],79:[0,.69444,0,0,.79445],80:[0,.69444,0,0,.70278],81:[.10556,.69444,0,0,.79445],82:[0,.69444,0,0,.70278],83:[0,.69444,0,0,.61111],84:[0,.69444,0,0,.73334],85:[0,.69444,0,0,.76389],86:[0,.69444,.01528,0,.73334],87:[0,.69444,.01528,0,1.03889],88:[0,.69444,0,0,.73334],89:[0,.69444,.0275,0,.73334],90:[0,.69444,0,0,.67223],91:[.25,.75,0,0,.34306],93:[.25,.75,0,0,.34306],94:[0,.69444,0,0,.55],95:[.35,.10833,.03056,0,.55],97:[0,.45833,0,0,.525],98:[0,.69444,0,0,.56111],99:[0,.45833,0,0,.48889],100:[0,.69444,0,0,.56111],101:[0,.45833,0,0,.51111],102:[0,.69444,.07639,0,.33611],103:[.19444,.45833,.01528,0,.55],104:[0,.69444,0,0,.56111],105:[0,.69444,0,0,.25556],106:[.19444,.69444,0,0,.28611],107:[0,.69444,0,0,.53056],108:[0,.69444,0,0,.25556],109:[0,.45833,0,0,.86667],110:[0,.45833,0,0,.56111],111:[0,.45833,0,0,.55],112:[.19444,.45833,0,0,.56111],113:[.19444,.45833,0,0,.56111],114:[0,.45833,.01528,0,.37222],115:[0,.45833,0,0,.42167],116:[0,.58929,0,0,.40417],117:[0,.45833,0,0,.56111],118:[0,.45833,.01528,0,.5],119:[0,.45833,.01528,0,.74445],120:[0,.45833,0,0,.5],121:[.19444,.45833,.01528,0,.5],122:[0,.45833,0,0,.47639],126:[.35,.34444,0,0,.55],160:[0,0,0,0,.25],168:[0,.69444,0,0,.55],176:[0,.69444,0,0,.73334],180:[0,.69444,0,0,.55],184:[.17014,0,0,0,.48889],305:[0,.45833,0,0,.25556],567:[.19444,.45833,0,0,.28611],710:[0,.69444,0,0,.55],711:[0,.63542,0,0,.55],713:[0,.63778,0,0,.55],728:[0,.69444,0,0,.55],729:[0,.69444,0,0,.30556],730:[0,.69444,0,0,.73334],732:[0,.69444,0,0,.55],733:[0,.69444,0,0,.55],915:[0,.69444,0,0,.58056],916:[0,.69444,0,0,.91667],920:[0,.69444,0,0,.85556],923:[0,.69444,0,0,.67223],926:[0,.69444,0,0,.73334],928:[0,.69444,0,0,.79445],931:[0,.69444,0,0,.79445],933:[0,.69444,0,0,.85556],934:[0,.69444,0,0,.79445],936:[0,.69444,0,0,.85556],937:[0,.69444,0,0,.79445],8211:[0,.45833,.03056,0,.55],8212:[0,.45833,.03056,0,1.10001],8216:[0,.69444,0,0,.30556],8217:[0,.69444,0,0,.30556],8220:[0,.69444,0,0,.55834],8221:[0,.69444,0,0,.55834]},"SansSerif-Italic":{32:[0,0,0,0,.25],33:[0,.69444,.05733,0,.31945],34:[0,.69444,.00316,0,.5],35:[.19444,.69444,.05087,0,.83334],36:[.05556,.75,.11156,0,.5],37:[.05556,.75,.03126,0,.83334],38:[0,.69444,.03058,0,.75834],39:[0,.69444,.07816,0,.27778],40:[.25,.75,.13164,0,.38889],41:[.25,.75,.02536,0,.38889],42:[0,.75,.11775,0,.5],43:[.08333,.58333,.02536,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,.01946,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,.13164,0,.5],48:[0,.65556,.11156,0,.5],49:[0,.65556,.11156,0,.5],50:[0,.65556,.11156,0,.5],51:[0,.65556,.11156,0,.5],52:[0,.65556,.11156,0,.5],53:[0,.65556,.11156,0,.5],54:[0,.65556,.11156,0,.5],55:[0,.65556,.11156,0,.5],56:[0,.65556,.11156,0,.5],57:[0,.65556,.11156,0,.5],58:[0,.44444,.02502,0,.27778],59:[.125,.44444,.02502,0,.27778],61:[-.13,.37,.05087,0,.77778],63:[0,.69444,.11809,0,.47222],64:[0,.69444,.07555,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,.08293,0,.66667],67:[0,.69444,.11983,0,.63889],68:[0,.69444,.07555,0,.72223],69:[0,.69444,.11983,0,.59722],70:[0,.69444,.13372,0,.56945],71:[0,.69444,.11983,0,.66667],72:[0,.69444,.08094,0,.70834],73:[0,.69444,.13372,0,.27778],74:[0,.69444,.08094,0,.47222],75:[0,.69444,.11983,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,.08094,0,.875],78:[0,.69444,.08094,0,.70834],79:[0,.69444,.07555,0,.73611],80:[0,.69444,.08293,0,.63889],81:[.125,.69444,.07555,0,.73611],82:[0,.69444,.08293,0,.64584],83:[0,.69444,.09205,0,.55556],84:[0,.69444,.13372,0,.68056],85:[0,.69444,.08094,0,.6875],86:[0,.69444,.1615,0,.66667],87:[0,.69444,.1615,0,.94445],88:[0,.69444,.13372,0,.66667],89:[0,.69444,.17261,0,.66667],90:[0,.69444,.11983,0,.61111],91:[.25,.75,.15942,0,.28889],93:[.25,.75,.08719,0,.28889],94:[0,.69444,.0799,0,.5],95:[.35,.09444,.08616,0,.5],97:[0,.44444,.00981,0,.48056],98:[0,.69444,.03057,0,.51667],99:[0,.44444,.08336,0,.44445],100:[0,.69444,.09483,0,.51667],101:[0,.44444,.06778,0,.44445],102:[0,.69444,.21705,0,.30556],103:[.19444,.44444,.10836,0,.5],104:[0,.69444,.01778,0,.51667],105:[0,.67937,.09718,0,.23889],106:[.19444,.67937,.09162,0,.26667],107:[0,.69444,.08336,0,.48889],108:[0,.69444,.09483,0,.23889],109:[0,.44444,.01778,0,.79445],110:[0,.44444,.01778,0,.51667],111:[0,.44444,.06613,0,.5],112:[.19444,.44444,.0389,0,.51667],113:[.19444,.44444,.04169,0,.51667],114:[0,.44444,.10836,0,.34167],115:[0,.44444,.0778,0,.38333],116:[0,.57143,.07225,0,.36111],117:[0,.44444,.04169,0,.51667],118:[0,.44444,.10836,0,.46111],119:[0,.44444,.10836,0,.68334],120:[0,.44444,.09169,0,.46111],121:[.19444,.44444,.10836,0,.46111],122:[0,.44444,.08752,0,.43472],126:[.35,.32659,.08826,0,.5],160:[0,0,0,0,.25],168:[0,.67937,.06385,0,.5],176:[0,.69444,0,0,.73752],184:[.17014,0,0,0,.44445],305:[0,.44444,.04169,0,.23889],567:[.19444,.44444,.04169,0,.26667],710:[0,.69444,.0799,0,.5],711:[0,.63194,.08432,0,.5],713:[0,.60889,.08776,0,.5],714:[0,.69444,.09205,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,.09483,0,.5],729:[0,.67937,.07774,0,.27778],730:[0,.69444,0,0,.73752],732:[0,.67659,.08826,0,.5],733:[0,.69444,.09205,0,.5],915:[0,.69444,.13372,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,.07555,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,.12816,0,.66667],928:[0,.69444,.08094,0,.70834],931:[0,.69444,.11983,0,.72222],933:[0,.69444,.09031,0,.77778],934:[0,.69444,.04603,0,.72222],936:[0,.69444,.09031,0,.77778],937:[0,.69444,.08293,0,.72222],8211:[0,.44444,.08616,0,.5],8212:[0,.44444,.08616,0,1],8216:[0,.69444,.07816,0,.27778],8217:[0,.69444,.07816,0,.27778],8220:[0,.69444,.14205,0,.5],8221:[0,.69444,.00316,0,.5]},"SansSerif-Regular":{32:[0,0,0,0,.25],33:[0,.69444,0,0,.31945],34:[0,.69444,0,0,.5],35:[.19444,.69444,0,0,.83334],36:[.05556,.75,0,0,.5],37:[.05556,.75,0,0,.83334],38:[0,.69444,0,0,.75834],39:[0,.69444,0,0,.27778],40:[.25,.75,0,0,.38889],41:[.25,.75,0,0,.38889],42:[0,.75,0,0,.5],43:[.08333,.58333,0,0,.77778],44:[.125,.08333,0,0,.27778],45:[0,.44444,0,0,.33333],46:[0,.08333,0,0,.27778],47:[.25,.75,0,0,.5],48:[0,.65556,0,0,.5],49:[0,.65556,0,0,.5],50:[0,.65556,0,0,.5],51:[0,.65556,0,0,.5],52:[0,.65556,0,0,.5],53:[0,.65556,0,0,.5],54:[0,.65556,0,0,.5],55:[0,.65556,0,0,.5],56:[0,.65556,0,0,.5],57:[0,.65556,0,0,.5],58:[0,.44444,0,0,.27778],59:[.125,.44444,0,0,.27778],61:[-.13,.37,0,0,.77778],63:[0,.69444,0,0,.47222],64:[0,.69444,0,0,.66667],65:[0,.69444,0,0,.66667],66:[0,.69444,0,0,.66667],67:[0,.69444,0,0,.63889],68:[0,.69444,0,0,.72223],69:[0,.69444,0,0,.59722],70:[0,.69444,0,0,.56945],71:[0,.69444,0,0,.66667],72:[0,.69444,0,0,.70834],73:[0,.69444,0,0,.27778],74:[0,.69444,0,0,.47222],75:[0,.69444,0,0,.69445],76:[0,.69444,0,0,.54167],77:[0,.69444,0,0,.875],78:[0,.69444,0,0,.70834],79:[0,.69444,0,0,.73611],80:[0,.69444,0,0,.63889],81:[.125,.69444,0,0,.73611],82:[0,.69444,0,0,.64584],83:[0,.69444,0,0,.55556],84:[0,.69444,0,0,.68056],85:[0,.69444,0,0,.6875],86:[0,.69444,.01389,0,.66667],87:[0,.69444,.01389,0,.94445],88:[0,.69444,0,0,.66667],89:[0,.69444,.025,0,.66667],90:[0,.69444,0,0,.61111],91:[.25,.75,0,0,.28889],93:[.25,.75,0,0,.28889],94:[0,.69444,0,0,.5],95:[.35,.09444,.02778,0,.5],97:[0,.44444,0,0,.48056],98:[0,.69444,0,0,.51667],99:[0,.44444,0,0,.44445],100:[0,.69444,0,0,.51667],101:[0,.44444,0,0,.44445],102:[0,.69444,.06944,0,.30556],103:[.19444,.44444,.01389,0,.5],104:[0,.69444,0,0,.51667],105:[0,.67937,0,0,.23889],106:[.19444,.67937,0,0,.26667],107:[0,.69444,0,0,.48889],108:[0,.69444,0,0,.23889],109:[0,.44444,0,0,.79445],110:[0,.44444,0,0,.51667],111:[0,.44444,0,0,.5],112:[.19444,.44444,0,0,.51667],113:[.19444,.44444,0,0,.51667],114:[0,.44444,.01389,0,.34167],115:[0,.44444,0,0,.38333],116:[0,.57143,0,0,.36111],117:[0,.44444,0,0,.51667],118:[0,.44444,.01389,0,.46111],119:[0,.44444,.01389,0,.68334],120:[0,.44444,0,0,.46111],121:[.19444,.44444,.01389,0,.46111],122:[0,.44444,0,0,.43472],126:[.35,.32659,0,0,.5],160:[0,0,0,0,.25],168:[0,.67937,0,0,.5],176:[0,.69444,0,0,.66667],184:[.17014,0,0,0,.44445],305:[0,.44444,0,0,.23889],567:[.19444,.44444,0,0,.26667],710:[0,.69444,0,0,.5],711:[0,.63194,0,0,.5],713:[0,.60889,0,0,.5],714:[0,.69444,0,0,.5],715:[0,.69444,0,0,.5],728:[0,.69444,0,0,.5],729:[0,.67937,0,0,.27778],730:[0,.69444,0,0,.66667],732:[0,.67659,0,0,.5],733:[0,.69444,0,0,.5],915:[0,.69444,0,0,.54167],916:[0,.69444,0,0,.83334],920:[0,.69444,0,0,.77778],923:[0,.69444,0,0,.61111],926:[0,.69444,0,0,.66667],928:[0,.69444,0,0,.70834],931:[0,.69444,0,0,.72222],933:[0,.69444,0,0,.77778],934:[0,.69444,0,0,.72222],936:[0,.69444,0,0,.77778],937:[0,.69444,0,0,.72222],8211:[0,.44444,.02778,0,.5],8212:[0,.44444,.02778,0,1],8216:[0,.69444,0,0,.27778],8217:[0,.69444,0,0,.27778],8220:[0,.69444,0,0,.5],8221:[0,.69444,0,0,.5]},"Script-Regular":{32:[0,0,0,0,.25],65:[0,.7,.22925,0,.80253],66:[0,.7,.04087,0,.90757],67:[0,.7,.1689,0,.66619],68:[0,.7,.09371,0,.77443],69:[0,.7,.18583,0,.56162],70:[0,.7,.13634,0,.89544],71:[0,.7,.17322,0,.60961],72:[0,.7,.29694,0,.96919],73:[0,.7,.19189,0,.80907],74:[.27778,.7,.19189,0,1.05159],75:[0,.7,.31259,0,.91364],76:[0,.7,.19189,0,.87373],77:[0,.7,.15981,0,1.08031],78:[0,.7,.3525,0,.9015],79:[0,.7,.08078,0,.73787],80:[0,.7,.08078,0,1.01262],81:[0,.7,.03305,0,.88282],82:[0,.7,.06259,0,.85],83:[0,.7,.19189,0,.86767],84:[0,.7,.29087,0,.74697],85:[0,.7,.25815,0,.79996],86:[0,.7,.27523,0,.62204],87:[0,.7,.27523,0,.80532],88:[0,.7,.26006,0,.94445],89:[0,.7,.2939,0,.70961],90:[0,.7,.24037,0,.8212],160:[0,0,0,0,.25]},"Size1-Regular":{32:[0,0,0,0,.25],40:[.35001,.85,0,0,.45834],41:[.35001,.85,0,0,.45834],47:[.35001,.85,0,0,.57778],91:[.35001,.85,0,0,.41667],92:[.35001,.85,0,0,.57778],93:[.35001,.85,0,0,.41667],123:[.35001,.85,0,0,.58334],125:[.35001,.85,0,0,.58334],160:[0,0,0,0,.25],710:[0,.72222,0,0,.55556],732:[0,.72222,0,0,.55556],770:[0,.72222,0,0,.55556],771:[0,.72222,0,0,.55556],8214:[-99e-5,.601,0,0,.77778],8593:[1e-5,.6,0,0,.66667],8595:[1e-5,.6,0,0,.66667],8657:[1e-5,.6,0,0,.77778],8659:[1e-5,.6,0,0,.77778],8719:[.25001,.75,0,0,.94445],8720:[.25001,.75,0,0,.94445],8721:[.25001,.75,0,0,1.05556],8730:[.35001,.85,0,0,1],8739:[-.00599,.606,0,0,.33333],8741:[-.00599,.606,0,0,.55556],8747:[.30612,.805,.19445,0,.47222],8748:[.306,.805,.19445,0,.47222],8749:[.306,.805,.19445,0,.47222],8750:[.30612,.805,.19445,0,.47222],8896:[.25001,.75,0,0,.83334],8897:[.25001,.75,0,0,.83334],8898:[.25001,.75,0,0,.83334],8899:[.25001,.75,0,0,.83334],8968:[.35001,.85,0,0,.47222],8969:[.35001,.85,0,0,.47222],8970:[.35001,.85,0,0,.47222],8971:[.35001,.85,0,0,.47222],9168:[-99e-5,.601,0,0,.66667],10216:[.35001,.85,0,0,.47222],10217:[.35001,.85,0,0,.47222],10752:[.25001,.75,0,0,1.11111],10753:[.25001,.75,0,0,1.11111],10754:[.25001,.75,0,0,1.11111],10756:[.25001,.75,0,0,.83334],10758:[.25001,.75,0,0,.83334]},"Size2-Regular":{32:[0,0,0,0,.25],40:[.65002,1.15,0,0,.59722],41:[.65002,1.15,0,0,.59722],47:[.65002,1.15,0,0,.81111],91:[.65002,1.15,0,0,.47222],92:[.65002,1.15,0,0,.81111],93:[.65002,1.15,0,0,.47222],123:[.65002,1.15,0,0,.66667],125:[.65002,1.15,0,0,.66667],160:[0,0,0,0,.25],710:[0,.75,0,0,1],732:[0,.75,0,0,1],770:[0,.75,0,0,1],771:[0,.75,0,0,1],8719:[.55001,1.05,0,0,1.27778],8720:[.55001,1.05,0,0,1.27778],8721:[.55001,1.05,0,0,1.44445],8730:[.65002,1.15,0,0,1],8747:[.86225,1.36,.44445,0,.55556],8748:[.862,1.36,.44445,0,.55556],8749:[.862,1.36,.44445,0,.55556],8750:[.86225,1.36,.44445,0,.55556],8896:[.55001,1.05,0,0,1.11111],8897:[.55001,1.05,0,0,1.11111],8898:[.55001,1.05,0,0,1.11111],8899:[.55001,1.05,0,0,1.11111],8968:[.65002,1.15,0,0,.52778],8969:[.65002,1.15,0,0,.52778],8970:[.65002,1.15,0,0,.52778],8971:[.65002,1.15,0,0,.52778],10216:[.65002,1.15,0,0,.61111],10217:[.65002,1.15,0,0,.61111],10752:[.55001,1.05,0,0,1.51112],10753:[.55001,1.05,0,0,1.51112],10754:[.55001,1.05,0,0,1.51112],10756:[.55001,1.05,0,0,1.11111],10758:[.55001,1.05,0,0,1.11111]},"Size3-Regular":{32:[0,0,0,0,.25],40:[.95003,1.45,0,0,.73611],41:[.95003,1.45,0,0,.73611],47:[.95003,1.45,0,0,1.04445],91:[.95003,1.45,0,0,.52778],92:[.95003,1.45,0,0,1.04445],93:[.95003,1.45,0,0,.52778],123:[.95003,1.45,0,0,.75],125:[.95003,1.45,0,0,.75],160:[0,0,0,0,.25],710:[0,.75,0,0,1.44445],732:[0,.75,0,0,1.44445],770:[0,.75,0,0,1.44445],771:[0,.75,0,0,1.44445],8730:[.95003,1.45,0,0,1],8968:[.95003,1.45,0,0,.58334],8969:[.95003,1.45,0,0,.58334],8970:[.95003,1.45,0,0,.58334],8971:[.95003,1.45,0,0,.58334],10216:[.95003,1.45,0,0,.75],10217:[.95003,1.45,0,0,.75]},"Size4-Regular":{32:[0,0,0,0,.25],40:[1.25003,1.75,0,0,.79167],41:[1.25003,1.75,0,0,.79167],47:[1.25003,1.75,0,0,1.27778],91:[1.25003,1.75,0,0,.58334],92:[1.25003,1.75,0,0,1.27778],93:[1.25003,1.75,0,0,.58334],123:[1.25003,1.75,0,0,.80556],125:[1.25003,1.75,0,0,.80556],160:[0,0,0,0,.25],710:[0,.825,0,0,1.8889],732:[0,.825,0,0,1.8889],770:[0,.825,0,0,1.8889],771:[0,.825,0,0,1.8889],8730:[1.25003,1.75,0,0,1],8968:[1.25003,1.75,0,0,.63889],8969:[1.25003,1.75,0,0,.63889],8970:[1.25003,1.75,0,0,.63889],8971:[1.25003,1.75,0,0,.63889],9115:[.64502,1.155,0,0,.875],9116:[1e-5,.6,0,0,.875],9117:[.64502,1.155,0,0,.875],9118:[.64502,1.155,0,0,.875],9119:[1e-5,.6,0,0,.875],9120:[.64502,1.155,0,0,.875],9121:[.64502,1.155,0,0,.66667],9122:[-99e-5,.601,0,0,.66667],9123:[.64502,1.155,0,0,.66667],9124:[.64502,1.155,0,0,.66667],9125:[-99e-5,.601,0,0,.66667],9126:[.64502,1.155,0,0,.66667],9127:[1e-5,.9,0,0,.88889],9128:[.65002,1.15,0,0,.88889],9129:[.90001,0,0,0,.88889],9130:[0,.3,0,0,.88889],9131:[1e-5,.9,0,0,.88889],9132:[.65002,1.15,0,0,.88889],9133:[.90001,0,0,0,.88889],9143:[.88502,.915,0,0,1.05556],10216:[1.25003,1.75,0,0,.80556],10217:[1.25003,1.75,0,0,.80556],57344:[-.00499,.605,0,0,1.05556],57345:[-.00499,.605,0,0,1.05556],57680:[0,.12,0,0,.45],57681:[0,.12,0,0,.45],57682:[0,.12,0,0,.45],57683:[0,.12,0,0,.45]},"Typewriter-Regular":{32:[0,0,0,0,.525],33:[0,.61111,0,0,.525],34:[0,.61111,0,0,.525],35:[0,.61111,0,0,.525],36:[.08333,.69444,0,0,.525],37:[.08333,.69444,0,0,.525],38:[0,.61111,0,0,.525],39:[0,.61111,0,0,.525],40:[.08333,.69444,0,0,.525],41:[.08333,.69444,0,0,.525],42:[0,.52083,0,0,.525],43:[-.08056,.53055,0,0,.525],44:[.13889,.125,0,0,.525],45:[-.08056,.53055,0,0,.525],46:[0,.125,0,0,.525],47:[.08333,.69444,0,0,.525],48:[0,.61111,0,0,.525],49:[0,.61111,0,0,.525],50:[0,.61111,0,0,.525],51:[0,.61111,0,0,.525],52:[0,.61111,0,0,.525],53:[0,.61111,0,0,.525],54:[0,.61111,0,0,.525],55:[0,.61111,0,0,.525],56:[0,.61111,0,0,.525],57:[0,.61111,0,0,.525],58:[0,.43056,0,0,.525],59:[.13889,.43056,0,0,.525],60:[-.05556,.55556,0,0,.525],61:[-.19549,.41562,0,0,.525],62:[-.05556,.55556,0,0,.525],63:[0,.61111,0,0,.525],64:[0,.61111,0,0,.525],65:[0,.61111,0,0,.525],66:[0,.61111,0,0,.525],67:[0,.61111,0,0,.525],68:[0,.61111,0,0,.525],69:[0,.61111,0,0,.525],70:[0,.61111,0,0,.525],71:[0,.61111,0,0,.525],72:[0,.61111,0,0,.525],73:[0,.61111,0,0,.525],74:[0,.61111,0,0,.525],75:[0,.61111,0,0,.525],76:[0,.61111,0,0,.525],77:[0,.61111,0,0,.525],78:[0,.61111,0,0,.525],79:[0,.61111,0,0,.525],80:[0,.61111,0,0,.525],81:[.13889,.61111,0,0,.525],82:[0,.61111,0,0,.525],83:[0,.61111,0,0,.525],84:[0,.61111,0,0,.525],85:[0,.61111,0,0,.525],86:[0,.61111,0,0,.525],87:[0,.61111,0,0,.525],88:[0,.61111,0,0,.525],89:[0,.61111,0,0,.525],90:[0,.61111,0,0,.525],91:[.08333,.69444,0,0,.525],92:[.08333,.69444,0,0,.525],93:[.08333,.69444,0,0,.525],94:[0,.61111,0,0,.525],95:[.09514,0,0,0,.525],96:[0,.61111,0,0,.525],97:[0,.43056,0,0,.525],98:[0,.61111,0,0,.525],99:[0,.43056,0,0,.525],100:[0,.61111,0,0,.525],101:[0,.43056,0,0,.525],102:[0,.61111,0,0,.525],103:[.22222,.43056,0,0,.525],104:[0,.61111,0,0,.525],105:[0,.61111,0,0,.525],106:[.22222,.61111,0,0,.525],107:[0,.61111,0,0,.525],108:[0,.61111,0,0,.525],109:[0,.43056,0,0,.525],110:[0,.43056,0,0,.525],111:[0,.43056,0,0,.525],112:[.22222,.43056,0,0,.525],113:[.22222,.43056,0,0,.525],114:[0,.43056,0,0,.525],115:[0,.43056,0,0,.525],116:[0,.55358,0,0,.525],117:[0,.43056,0,0,.525],118:[0,.43056,0,0,.525],119:[0,.43056,0,0,.525],120:[0,.43056,0,0,.525],121:[.22222,.43056,0,0,.525],122:[0,.43056,0,0,.525],123:[.08333,.69444,0,0,.525],124:[.08333,.69444,0,0,.525],125:[.08333,.69444,0,0,.525],126:[0,.61111,0,0,.525],127:[0,.61111,0,0,.525],160:[0,0,0,0,.525],176:[0,.61111,0,0,.525],184:[.19445,0,0,0,.525],305:[0,.43056,0,0,.525],567:[.22222,.43056,0,0,.525],711:[0,.56597,0,0,.525],713:[0,.56555,0,0,.525],714:[0,.61111,0,0,.525],715:[0,.61111,0,0,.525],728:[0,.61111,0,0,.525],730:[0,.61111,0,0,.525],770:[0,.61111,0,0,.525],771:[0,.61111,0,0,.525],776:[0,.61111,0,0,.525],915:[0,.61111,0,0,.525],916:[0,.61111,0,0,.525],920:[0,.61111,0,0,.525],923:[0,.61111,0,0,.525],926:[0,.61111,0,0,.525],928:[0,.61111,0,0,.525],931:[0,.61111,0,0,.525],933:[0,.61111,0,0,.525],934:[0,.61111,0,0,.525],936:[0,.61111,0,0,.525],937:[0,.61111,0,0,.525],8216:[0,.61111,0,0,.525],8217:[0,.61111,0,0,.525],8242:[0,.61111,0,0,.525],9251:[.11111,.21944,0,0,.525]}},sigmasAndXis={slant:[.25,.25,.25],space:[0,0,0],stretch:[0,0,0],shrink:[0,0,0],xHeight:[.431,.431,.431],quad:[1,1.171,1.472],extraSpace:[0,0,0],num1:[.677,.732,.925],num2:[.394,.384,.387],num3:[.444,.471,.504],denom1:[.686,.752,1.025],denom2:[.345,.344,.532],sup1:[.413,.503,.504],sup2:[.363,.431,.404],sup3:[.289,.286,.294],sub1:[.15,.143,.2],sub2:[.247,.286,.4],supDrop:[.386,.353,.494],subDrop:[.05,.071,.1],delim1:[2.39,1.7,1.98],delim2:[1.01,1.157,1.42],axisHeight:[.25,.25,.25],defaultRuleThickness:[.04,.049,.049],bigOpSpacing1:[.111,.111,.111],bigOpSpacing2:[.166,.166,.166],bigOpSpacing3:[.2,.2,.2],bigOpSpacing4:[.6,.611,.611],bigOpSpacing5:[.1,.143,.143],sqrtRuleThickness:[.04,.04,.04],ptPerEm:[10,10,10],doubleRuleSep:[.2,.2,.2],arrayRuleWidth:[.04,.04,.04],fboxsep:[.3,.3,.3],fboxrule:[.04,.04,.04]},extraCharacterMap={Å:"A",Ð:"D",Þ:"o",å:"a",ð:"d",þ:"o",А:"A",Б:"B",В:"B",Г:"F",Д:"A",Е:"E",Ж:"K",З:"3",И:"N",Й:"N",К:"K",Л:"N",М:"M",Н:"H",О:"O",П:"N",Р:"P",С:"C",Т:"T",У:"y",Ф:"O",Х:"X",Ц:"U",Ч:"h",Ш:"W",Щ:"W",Ъ:"B",Ы:"X",Ь:"B",Э:"3",Ю:"X",Я:"R",а:"a",б:"b",в:"a",г:"r",д:"y",е:"e",ж:"m",з:"e",и:"n",й:"n",к:"n",л:"n",м:"m",н:"n",о:"o",п:"n",р:"p",с:"c",т:"o",у:"y",ф:"b",х:"x",ц:"n",ч:"n",ш:"w",щ:"w",ъ:"a",ы:"m",ь:"a",э:"e",ю:"m",я:"r"};function setFontMetrics(a,c){fontMetricsData[a]=c}function getCharacterMetrics(a,c,u){if(!fontMetricsData[c])throw new Error("Font metrics not found for font: "+c+".");var d=a.charCodeAt(0),f=fontMetricsData[c][d];if(!f&&a[0]in extraCharacterMap&&(d=extraCharacterMap[a[0]].charCodeAt(0),f=fontMetricsData[c][d]),!f&&u==="text"&&supportedCodepoint(d)&&(f=fontMetricsData[c][77]),f)return{depth:f[0],height:f[1],italic:f[2],skew:f[3],width:f[4]}}var fontMetricsBySizeIndex={};function getGlobalMetrics(a){var c;if(a>=5?c=0:a>=3?c=1:c=2,!fontMetricsBySizeIndex[c]){var u=fontMetricsBySizeIndex[c]={cssEmPerMu:sigmasAndXis.quad[c]/18};for(var d in sigmasAndXis)sigmasAndXis.hasOwnProperty(d)&&(u[d]=sigmasAndXis[d][c])}return fontMetricsBySizeIndex[c]}var sizeStyleMap=[[1,1,1],[2,1,1],[3,1,1],[4,2,1],[5,2,1],[6,3,1],[7,4,2],[8,6,3],[9,7,6],[10,8,7],[11,10,9]],sizeMultipliers=[.5,.6,.7,.8,.9,1,1.2,1.44,1.728,2.074,2.488],sizeAtStyle=function(c,u){return u.size<2?c:sizeStyleMap[c-1][u.size-1]};class Options{constructor(c){this.style=void 0,this.color=void 0,this.size=void 0,this.textSize=void 0,this.phantom=void 0,this.font=void 0,this.fontFamily=void 0,this.fontWeight=void 0,this.fontShape=void 0,this.sizeMultiplier=void 0,this.maxSize=void 0,this.minRuleThickness=void 0,this._fontMetrics=void 0,this.style=c.style,this.color=c.color,this.size=c.size||Options.BASESIZE,this.textSize=c.textSize||this.size,this.phantom=!!c.phantom,this.font=c.font||"",this.fontFamily=c.fontFamily||"",this.fontWeight=c.fontWeight||"",this.fontShape=c.fontShape||"",this.sizeMultiplier=sizeMultipliers[this.size-1],this.maxSize=c.maxSize,this.minRuleThickness=c.minRuleThickness,this._fontMetrics=void 0}extend(c){var u={style:this.style,size:this.size,textSize:this.textSize,color:this.color,phantom:this.phantom,font:this.font,fontFamily:this.fontFamily,fontWeight:this.fontWeight,fontShape:this.fontShape,maxSize:this.maxSize,minRuleThickness:this.minRuleThickness};for(var d in c)c.hasOwnProperty(d)&&(u[d]=c[d]);return new Options(u)}havingStyle(c){return this.style===c?this:this.extend({style:c,size:sizeAtStyle(this.textSize,c)})}havingCrampedStyle(){return this.havingStyle(this.style.cramp())}havingSize(c){return this.size===c&&this.textSize===c?this:this.extend({style:this.style.text(),size:c,textSize:c,sizeMultiplier:sizeMultipliers[c-1]})}havingBaseStyle(c){c=c||this.style.text();var u=sizeAtStyle(Options.BASESIZE,c);return this.size===u&&this.textSize===Options.BASESIZE&&this.style===c?this:this.extend({style:c,size:u})}havingBaseSizing(){var c;switch(this.style.id){case 4:case 5:c=3;break;case 6:case 7:c=1;break;default:c=6}return this.extend({style:this.style.text(),size:c})}withColor(c){return this.extend({color:c})}withPhantom(){return this.extend({phantom:!0})}withFont(c){return this.extend({font:c})}withTextFontFamily(c){return this.extend({fontFamily:c,font:""})}withTextFontWeight(c){return this.extend({fontWeight:c,font:""})}withTextFontShape(c){return this.extend({fontShape:c,font:""})}sizingClasses(c){return c.size!==this.size?["sizing","reset-size"+c.size,"size"+this.size]:[]}baseSizingClasses(){return this.size!==Options.BASESIZE?["sizing","reset-size"+this.size,"size"+Options.BASESIZE]:[]}fontMetrics(){return this._fontMetrics||(this._fontMetrics=getGlobalMetrics(this.size)),this._fontMetrics}getColor(){return this.phantom?"transparent":this.color}}Options.BASESIZE=6;var ptPerUnit={pt:1,mm:7227/2540,cm:7227/254,in:72.27,bp:803/800,pc:12,dd:1238/1157,cc:14856/1157,nd:685/642,nc:1370/107,sp:1/65536,px:803/800},relativeUnit={ex:!0,em:!0,mu:!0},validUnit=function(c){return typeof c!="string"&&(c=c.unit),c in ptPerUnit||c in relativeUnit||c==="ex"},calculateSize=function(c,u){var d;if(c.unit in ptPerUnit)d=ptPerUnit[c.unit]/u.fontMetrics().ptPerEm/u.sizeMultiplier;else if(c.unit==="mu")d=u.fontMetrics().cssEmPerMu;else{var f;if(u.style.isTight()?f=u.havingStyle(u.style.text()):f=u,c.unit==="ex")d=f.fontMetrics().xHeight;else if(c.unit==="em")d=f.fontMetrics().quad;else throw new ParseError("Invalid unit: '"+c.unit+"'");f!==u&&(d*=f.sizeMultiplier/u.sizeMultiplier)}return Math.min(c.number*d,u.maxSize)},makeEm=function(c){return+c.toFixed(4)+"em"},createClass=function(c){return c.filter(u=>u).join(" ")},initNode=function(c,u,d){if(this.classes=c||[],this.attributes={},this.height=0,this.depth=0,this.maxFontSize=0,this.style=d||{},u){u.style.isTight()&&this.classes.push("mtight");var f=u.getColor();f&&(this.style.color=f)}},toNode=function(c){var u=document.createElement(c);u.className=createClass(this.classes);for(var d in this.style)this.style.hasOwnProperty(d)&&(u.style[d]=this.style[d]);for(var f in this.attributes)this.attributes.hasOwnProperty(f)&&u.setAttribute(f,this.attributes[f]);for(var m=0;m<this.children.length;m++)u.appendChild(this.children[m].toNode());return u},invalidAttributeNameRegex=/[\s"'>/=\x00-\x1f]/,toMarkup=function(c){var u="<"+c;this.classes.length&&(u+=' class="'+utils.escape(createClass(this.classes))+'"');var d="";for(var f in this.style)this.style.hasOwnProperty(f)&&(d+=utils.hyphenate(f)+":"+this.style[f]+";");d&&(u+=' style="'+utils.escape(d)+'"');for(var m in this.attributes)if(this.attributes.hasOwnProperty(m)){if(invalidAttributeNameRegex.test(m))throw new ParseError("Invalid attribute name '"+m+"'");u+=" "+m+'="'+utils.escape(this.attributes[m])+'"'}u+=">";for(var g=0;g<this.children.length;g++)u+=this.children[g].toMarkup();return u+="</"+c+">",u};class Span{constructor(c,u,d,f){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.width=void 0,this.maxFontSize=void 0,this.style=void 0,initNode.call(this,c,d,f),this.children=u||[]}setAttribute(c,u){this.attributes[c]=u}hasClass(c){return utils.contains(this.classes,c)}toNode(){return toNode.call(this,"span")}toMarkup(){return toMarkup.call(this,"span")}}class Anchor{constructor(c,u,d,f){this.children=void 0,this.attributes=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,initNode.call(this,u,f),this.children=d||[],this.setAttribute("href",c)}setAttribute(c,u){this.attributes[c]=u}hasClass(c){return utils.contains(this.classes,c)}toNode(){return toNode.call(this,"a")}toMarkup(){return toMarkup.call(this,"a")}}class Img{constructor(c,u,d){this.src=void 0,this.alt=void 0,this.classes=void 0,this.height=void 0,this.depth=void 0,this.maxFontSize=void 0,this.style=void 0,this.alt=u,this.src=c,this.classes=["mord"],this.style=d}hasClass(c){return utils.contains(this.classes,c)}toNode(){var c=document.createElement("img");c.src=this.src,c.alt=this.alt,c.className="mord";for(var u in this.style)this.style.hasOwnProperty(u)&&(c.style[u]=this.style[u]);return c}toMarkup(){var c='<img src="'+utils.escape(this.src)+'"'+(' alt="'+utils.escape(this.alt)+'"'),u="";for(var d in this.style)this.style.hasOwnProperty(d)&&(u+=utils.hyphenate(d)+":"+this.style[d]+";");return u&&(c+=' style="'+utils.escape(u)+'"'),c+="'/>",c}}var iCombinations={î:"ı̂",ï:"ı̈",í:"ı́",ì:"ı̀"};class SymbolNode{constructor(c,u,d,f,m,g,y,b){this.text=void 0,this.height=void 0,this.depth=void 0,this.italic=void 0,this.skew=void 0,this.width=void 0,this.maxFontSize=void 0,this.classes=void 0,this.style=void 0,this.text=c,this.height=u||0,this.depth=d||0,this.italic=f||0,this.skew=m||0,this.width=g||0,this.classes=y||[],this.style=b||{},this.maxFontSize=0;var E=scriptFromCodepoint(this.text.charCodeAt(0));E&&this.classes.push(E+"_fallback"),/[îïíì]/.test(this.text)&&(this.text=iCombinations[this.text])}hasClass(c){return utils.contains(this.classes,c)}toNode(){var c=document.createTextNode(this.text),u=null;this.italic>0&&(u=document.createElement("span"),u.style.marginRight=makeEm(this.italic)),this.classes.length>0&&(u=u||document.createElement("span"),u.className=createClass(this.classes));for(var d in this.style)this.style.hasOwnProperty(d)&&(u=u||document.createElement("span"),u.style[d]=this.style[d]);return u?(u.appendChild(c),u):c}toMarkup(){var c=!1,u="<span";this.classes.length&&(c=!0,u+=' class="',u+=utils.escape(createClass(this.classes)),u+='"');var d="";this.italic>0&&(d+="margin-right:"+this.italic+"em;");for(var f in this.style)this.style.hasOwnProperty(f)&&(d+=utils.hyphenate(f)+":"+this.style[f]+";");d&&(c=!0,u+=' style="'+utils.escape(d)+'"');var m=utils.escape(this.text);return c?(u+=">",u+=m,u+="</span>",u):m}}class SvgNode{constructor(c,u){this.children=void 0,this.attributes=void 0,this.children=c||[],this.attributes=u||{}}toNode(){var c="http://www.w3.org/2000/svg",u=document.createElementNS(c,"svg");for(var d in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,d)&&u.setAttribute(d,this.attributes[d]);for(var f=0;f<this.children.length;f++)u.appendChild(this.children[f].toNode());return u}toMarkup(){var c='<svg xmlns="http://www.w3.org/2000/svg"';for(var u in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,u)&&(c+=" "+u+'="'+utils.escape(this.attributes[u])+'"');c+=">";for(var d=0;d<this.children.length;d++)c+=this.children[d].toMarkup();return c+="</svg>",c}}class PathNode{constructor(c,u){this.pathName=void 0,this.alternate=void 0,this.pathName=c,this.alternate=u}toNode(){var c="http://www.w3.org/2000/svg",u=document.createElementNS(c,"path");return this.alternate?u.setAttribute("d",this.alternate):u.setAttribute("d",path[this.pathName]),u}toMarkup(){return this.alternate?'<path d="'+utils.escape(this.alternate)+'"/>':'<path d="'+utils.escape(path[this.pathName])+'"/>'}}class LineNode{constructor(c){this.attributes=void 0,this.attributes=c||{}}toNode(){var c="http://www.w3.org/2000/svg",u=document.createElementNS(c,"line");for(var d in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,d)&&u.setAttribute(d,this.attributes[d]);return u}toMarkup(){var c="<line";for(var u in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,u)&&(c+=" "+u+'="'+utils.escape(this.attributes[u])+'"');return c+="/>",c}}function assertSymbolDomNode(a){if(a instanceof SymbolNode)return a;throw new Error("Expected symbolNode but got "+String(a)+".")}function assertSpan(a){if(a instanceof Span)return a;throw new Error("Expected span<HtmlDomNode> but got "+String(a)+".")}var ATOMS={bin:1,close:1,inner:1,open:1,punct:1,rel:1},NON_ATOMS={"accent-token":1,mathord:1,"op-token":1,spacing:1,textord:1},symbols={math:{},text:{}};function defineSymbol(a,c,u,d,f,m){symbols[a][f]={font:c,group:u,replace:d},m&&d&&(symbols[a][d]=symbols[a][f])}var math="math",text$2="text",main="main",ams="ams",accent="accent-token",bin="bin",close="close",inner="inner",mathord="mathord",op="op-token",open="open",punct="punct",rel="rel",spacing="spacing",textord="textord";defineSymbol(math,main,rel,"≡","\\equiv",!0);defineSymbol(math,main,rel,"≺","\\prec",!0);defineSymbol(math,main,rel,"≻","\\succ",!0);defineSymbol(math,main,rel,"∼","\\sim",!0);defineSymbol(math,main,rel,"⊥","\\perp");defineSymbol(math,main,rel,"⪯","\\preceq",!0);defineSymbol(math,main,rel,"⪰","\\succeq",!0);defineSymbol(math,main,rel,"≃","\\simeq",!0);defineSymbol(math,main,rel,"∣","\\mid",!0);defineSymbol(math,main,rel,"≪","\\ll",!0);defineSymbol(math,main,rel,"≫","\\gg",!0);defineSymbol(math,main,rel,"≍","\\asymp",!0);defineSymbol(math,main,rel,"∥","\\parallel");defineSymbol(math,main,rel,"⋈","\\bowtie",!0);defineSymbol(math,main,rel,"⌣","\\smile",!0);defineSymbol(math,main,rel,"⊑","\\sqsubseteq",!0);defineSymbol(math,main,rel,"⊒","\\sqsupseteq",!0);defineSymbol(math,main,rel,"≐","\\doteq",!0);defineSymbol(math,main,rel,"⌢","\\frown",!0);defineSymbol(math,main,rel,"∋","\\ni",!0);defineSymbol(math,main,rel,"∝","\\propto",!0);defineSymbol(math,main,rel,"⊢","\\vdash",!0);defineSymbol(math,main,rel,"⊣","\\dashv",!0);defineSymbol(math,main,rel,"∋","\\owns");defineSymbol(math,main,punct,".","\\ldotp");defineSymbol(math,main,punct,"⋅","\\cdotp");defineSymbol(math,main,textord,"#","\\#");defineSymbol(text$2,main,textord,"#","\\#");defineSymbol(math,main,textord,"&","\\&");defineSymbol(text$2,main,textord,"&","\\&");defineSymbol(math,main,textord,"ℵ","\\aleph",!0);defineSymbol(math,main,textord,"∀","\\forall",!0);defineSymbol(math,main,textord,"ℏ","\\hbar",!0);defineSymbol(math,main,textord,"∃","\\exists",!0);defineSymbol(math,main,textord,"∇","\\nabla",!0);defineSymbol(math,main,textord,"♭","\\flat",!0);defineSymbol(math,main,textord,"ℓ","\\ell",!0);defineSymbol(math,main,textord,"♮","\\natural",!0);defineSymbol(math,main,textord,"♣","\\clubsuit",!0);defineSymbol(math,main,textord,"℘","\\wp",!0);defineSymbol(math,main,textord,"♯","\\sharp",!0);defineSymbol(math,main,textord,"♢","\\diamondsuit",!0);defineSymbol(math,main,textord,"ℜ","\\Re",!0);defineSymbol(math,main,textord,"♡","\\heartsuit",!0);defineSymbol(math,main,textord,"ℑ","\\Im",!0);defineSymbol(math,main,textord,"♠","\\spadesuit",!0);defineSymbol(math,main,textord,"§","\\S",!0);defineSymbol(text$2,main,textord,"§","\\S");defineSymbol(math,main,textord,"¶","\\P",!0);defineSymbol(text$2,main,textord,"¶","\\P");defineSymbol(math,main,textord,"†","\\dag");defineSymbol(text$2,main,textord,"†","\\dag");defineSymbol(text$2,main,textord,"†","\\textdagger");defineSymbol(math,main,textord,"‡","\\ddag");defineSymbol(text$2,main,textord,"‡","\\ddag");defineSymbol(text$2,main,textord,"‡","\\textdaggerdbl");defineSymbol(math,main,close,"⎱","\\rmoustache",!0);defineSymbol(math,main,open,"⎰","\\lmoustache",!0);defineSymbol(math,main,close,"⟯","\\rgroup",!0);defineSymbol(math,main,open,"⟮","\\lgroup",!0);defineSymbol(math,main,bin,"∓","\\mp",!0);defineSymbol(math,main,bin,"⊖","\\ominus",!0);defineSymbol(math,main,bin,"⊎","\\uplus",!0);defineSymbol(math,main,bin,"⊓","\\sqcap",!0);defineSymbol(math,main,bin,"∗","\\ast");defineSymbol(math,main,bin,"⊔","\\sqcup",!0);defineSymbol(math,main,bin,"◯","\\bigcirc",!0);defineSymbol(math,main,bin,"∙","\\bullet",!0);defineSymbol(math,main,bin,"‡","\\ddagger");defineSymbol(math,main,bin,"≀","\\wr",!0);defineSymbol(math,main,bin,"⨿","\\amalg");defineSymbol(math,main,bin,"&","\\And");defineSymbol(math,main,rel,"⟵","\\longleftarrow",!0);defineSymbol(math,main,rel,"⇐","\\Leftarrow",!0);defineSymbol(math,main,rel,"⟸","\\Longleftarrow",!0);defineSymbol(math,main,rel,"⟶","\\longrightarrow",!0);defineSymbol(math,main,rel,"⇒","\\Rightarrow",!0);defineSymbol(math,main,rel,"⟹","\\Longrightarrow",!0);defineSymbol(math,main,rel,"↔","\\leftrightarrow",!0);defineSymbol(math,main,rel,"⟷","\\longleftrightarrow",!0);defineSymbol(math,main,rel,"⇔","\\Leftrightarrow",!0);defineSymbol(math,main,rel,"⟺","\\Longleftrightarrow",!0);defineSymbol(math,main,rel,"↦","\\mapsto",!0);defineSymbol(math,main,rel,"⟼","\\longmapsto",!0);defineSymbol(math,main,rel,"↗","\\nearrow",!0);defineSymbol(math,main,rel,"↩","\\hookleftarrow",!0);defineSymbol(math,main,rel,"↪","\\hookrightarrow",!0);defineSymbol(math,main,rel,"↘","\\searrow",!0);defineSymbol(math,main,rel,"↼","\\leftharpoonup",!0);defineSymbol(math,main,rel,"⇀","\\rightharpoonup",!0);defineSymbol(math,main,rel,"↙","\\swarrow",!0);defineSymbol(math,main,rel,"↽","\\leftharpoondown",!0);defineSymbol(math,main,rel,"⇁","\\rightharpoondown",!0);defineSymbol(math,main,rel,"↖","\\nwarrow",!0);defineSymbol(math,main,rel,"⇌","\\rightleftharpoons",!0);defineSymbol(math,ams,rel,"≮","\\nless",!0);defineSymbol(math,ams,rel,"","\\@nleqslant");defineSymbol(math,ams,rel,"","\\@nleqq");defineSymbol(math,ams,rel,"⪇","\\lneq",!0);defineSymbol(math,ams,rel,"≨","\\lneqq",!0);defineSymbol(math,ams,rel,"","\\@lvertneqq");defineSymbol(math,ams,rel,"⋦","\\lnsim",!0);defineSymbol(math,ams,rel,"⪉","\\lnapprox",!0);defineSymbol(math,ams,rel,"⊀","\\nprec",!0);defineSymbol(math,ams,rel,"⋠","\\npreceq",!0);defineSymbol(math,ams,rel,"⋨","\\precnsim",!0);defineSymbol(math,ams,rel,"⪹","\\precnapprox",!0);defineSymbol(math,ams,rel,"≁","\\nsim",!0);defineSymbol(math,ams,rel,"","\\@nshortmid");defineSymbol(math,ams,rel,"∤","\\nmid",!0);defineSymbol(math,ams,rel,"⊬","\\nvdash",!0);defineSymbol(math,ams,rel,"⊭","\\nvDash",!0);defineSymbol(math,ams,rel,"⋪","\\ntriangleleft");defineSymbol(math,ams,rel,"⋬","\\ntrianglelefteq",!0);defineSymbol(math,ams,rel,"⊊","\\subsetneq",!0);defineSymbol(math,ams,rel,"","\\@varsubsetneq");defineSymbol(math,ams,rel,"⫋","\\subsetneqq",!0);defineSymbol(math,ams,rel,"","\\@varsubsetneqq");defineSymbol(math,ams,rel,"≯","\\ngtr",!0);defineSymbol(math,ams,rel,"","\\@ngeqslant");defineSymbol(math,ams,rel,"","\\@ngeqq");defineSymbol(math,ams,rel,"⪈","\\gneq",!0);defineSymbol(math,ams,rel,"≩","\\gneqq",!0);defineSymbol(math,ams,rel,"","\\@gvertneqq");defineSymbol(math,ams,rel,"⋧","\\gnsim",!0);defineSymbol(math,ams,rel,"⪊","\\gnapprox",!0);defineSymbol(math,ams,rel,"⊁","\\nsucc",!0);defineSymbol(math,ams,rel,"⋡","\\nsucceq",!0);defineSymbol(math,ams,rel,"⋩","\\succnsim",!0);defineSymbol(math,ams,rel,"⪺","\\succnapprox",!0);defineSymbol(math,ams,rel,"≆","\\ncong",!0);defineSymbol(math,ams,rel,"","\\@nshortparallel");defineSymbol(math,ams,rel,"∦","\\nparallel",!0);defineSymbol(math,ams,rel,"⊯","\\nVDash",!0);defineSymbol(math,ams,rel,"⋫","\\ntriangleright");defineSymbol(math,ams,rel,"⋭","\\ntrianglerighteq",!0);defineSymbol(math,ams,rel,"","\\@nsupseteqq");defineSymbol(math,ams,rel,"⊋","\\supsetneq",!0);defineSymbol(math,ams,rel,"","\\@varsupsetneq");defineSymbol(math,ams,rel,"⫌","\\supsetneqq",!0);defineSymbol(math,ams,rel,"","\\@varsupsetneqq");defineSymbol(math,ams,rel,"⊮","\\nVdash",!0);defineSymbol(math,ams,rel,"⪵","\\precneqq",!0);defineSymbol(math,ams,rel,"⪶","\\succneqq",!0);defineSymbol(math,ams,rel,"","\\@nsubseteqq");defineSymbol(math,ams,bin,"⊴","\\unlhd");defineSymbol(math,ams,bin,"⊵","\\unrhd");defineSymbol(math,ams,rel,"↚","\\nleftarrow",!0);defineSymbol(math,ams,rel,"↛","\\nrightarrow",!0);defineSymbol(math,ams,rel,"⇍","\\nLeftarrow",!0);defineSymbol(math,ams,rel,"⇏","\\nRightarrow",!0);defineSymbol(math,ams,rel,"↮","\\nleftrightarrow",!0);defineSymbol(math,ams,rel,"⇎","\\nLeftrightarrow",!0);defineSymbol(math,ams,rel,"△","\\vartriangle");defineSymbol(math,ams,textord,"ℏ","\\hslash");defineSymbol(math,ams,textord,"▽","\\triangledown");defineSymbol(math,ams,textord,"◊","\\lozenge");defineSymbol(math,ams,textord,"Ⓢ","\\circledS");defineSymbol(math,ams,textord,"®","\\circledR");defineSymbol(text$2,ams,textord,"®","\\circledR");defineSymbol(math,ams,textord,"∡","\\measuredangle",!0);defineSymbol(math,ams,textord,"∄","\\nexists");defineSymbol(math,ams,textord,"℧","\\mho");defineSymbol(math,ams,textord,"Ⅎ","\\Finv",!0);defineSymbol(math,ams,textord,"⅁","\\Game",!0);defineSymbol(math,ams,textord,"‵","\\backprime");defineSymbol(math,ams,textord,"▲","\\blacktriangle");defineSymbol(math,ams,textord,"▼","\\blacktriangledown");defineSymbol(math,ams,textord,"■","\\blacksquare");defineSymbol(math,ams,textord,"⧫","\\blacklozenge");defineSymbol(math,ams,textord,"★","\\bigstar");defineSymbol(math,ams,textord,"∢","\\sphericalangle",!0);defineSymbol(math,ams,textord,"∁","\\complement",!0);defineSymbol(math,ams,textord,"ð","\\eth",!0);defineSymbol(text$2,main,textord,"ð","ð");defineSymbol(math,ams,textord,"╱","\\diagup");defineSymbol(math,ams,textord,"╲","\\diagdown");defineSymbol(math,ams,textord,"□","\\square");defineSymbol(math,ams,textord,"□","\\Box");defineSymbol(math,ams,textord,"◊","\\Diamond");defineSymbol(math,ams,textord,"¥","\\yen",!0);defineSymbol(text$2,ams,textord,"¥","\\yen",!0);defineSymbol(math,ams,textord,"✓","\\checkmark",!0);defineSymbol(text$2,ams,textord,"✓","\\checkmark");defineSymbol(math,ams,textord,"ℶ","\\beth",!0);defineSymbol(math,ams,textord,"ℸ","\\daleth",!0);defineSymbol(math,ams,textord,"ℷ","\\gimel",!0);defineSymbol(math,ams,textord,"ϝ","\\digamma",!0);defineSymbol(math,ams,textord,"ϰ","\\varkappa");defineSymbol(math,ams,open,"┌","\\@ulcorner",!0);defineSymbol(math,ams,close,"┐","\\@urcorner",!0);defineSymbol(math,ams,open,"└","\\@llcorner",!0);defineSymbol(math,ams,close,"┘","\\@lrcorner",!0);defineSymbol(math,ams,rel,"≦","\\leqq",!0);defineSymbol(math,ams,rel,"⩽","\\leqslant",!0);defineSymbol(math,ams,rel,"⪕","\\eqslantless",!0);defineSymbol(math,ams,rel,"≲","\\lesssim",!0);defineSymbol(math,ams,rel,"⪅","\\lessapprox",!0);defineSymbol(math,ams,rel,"≊","\\approxeq",!0);defineSymbol(math,ams,bin,"⋖","\\lessdot");defineSymbol(math,ams,rel,"⋘","\\lll",!0);defineSymbol(math,ams,rel,"≶","\\lessgtr",!0);defineSymbol(math,ams,rel,"⋚","\\lesseqgtr",!0);defineSymbol(math,ams,rel,"⪋","\\lesseqqgtr",!0);defineSymbol(math,ams,rel,"≑","\\doteqdot");defineSymbol(math,ams,rel,"≓","\\risingdotseq",!0);defineSymbol(math,ams,rel,"≒","\\fallingdotseq",!0);defineSymbol(math,ams,rel,"∽","\\backsim",!0);defineSymbol(math,ams,rel,"⋍","\\backsimeq",!0);defineSymbol(math,ams,rel,"⫅","\\subseteqq",!0);defineSymbol(math,ams,rel,"⋐","\\Subset",!0);defineSymbol(math,ams,rel,"⊏","\\sqsubset",!0);defineSymbol(math,ams,rel,"≼","\\preccurlyeq",!0);defineSymbol(math,ams,rel,"⋞","\\curlyeqprec",!0);defineSymbol(math,ams,rel,"≾","\\precsim",!0);defineSymbol(math,ams,rel,"⪷","\\precapprox",!0);defineSymbol(math,ams,rel,"⊲","\\vartriangleleft");defineSymbol(math,ams,rel,"⊴","\\trianglelefteq");defineSymbol(math,ams,rel,"⊨","\\vDash",!0);defineSymbol(math,ams,rel,"⊪","\\Vvdash",!0);defineSymbol(math,ams,rel,"⌣","\\smallsmile");defineSymbol(math,ams,rel,"⌢","\\smallfrown");defineSymbol(math,ams,rel,"≏","\\bumpeq",!0);defineSymbol(math,ams,rel,"≎","\\Bumpeq",!0);defineSymbol(math,ams,rel,"≧","\\geqq",!0);defineSymbol(math,ams,rel,"⩾","\\geqslant",!0);defineSymbol(math,ams,rel,"⪖","\\eqslantgtr",!0);defineSymbol(math,ams,rel,"≳","\\gtrsim",!0);defineSymbol(math,ams,rel,"⪆","\\gtrapprox",!0);defineSymbol(math,ams,bin,"⋗","\\gtrdot");defineSymbol(math,ams,rel,"⋙","\\ggg",!0);defineSymbol(math,ams,rel,"≷","\\gtrless",!0);defineSymbol(math,ams,rel,"⋛","\\gtreqless",!0);defineSymbol(math,ams,rel,"⪌","\\gtreqqless",!0);defineSymbol(math,ams,rel,"≖","\\eqcirc",!0);defineSymbol(math,ams,rel,"≗","\\circeq",!0);defineSymbol(math,ams,rel,"≜","\\triangleq",!0);defineSymbol(math,ams,rel,"∼","\\thicksim");defineSymbol(math,ams,rel,"≈","\\thickapprox");defineSymbol(math,ams,rel,"⫆","\\supseteqq",!0);defineSymbol(math,ams,rel,"⋑","\\Supset",!0);defineSymbol(math,ams,rel,"⊐","\\sqsupset",!0);defineSymbol(math,ams,rel,"≽","\\succcurlyeq",!0);defineSymbol(math,ams,rel,"⋟","\\curlyeqsucc",!0);defineSymbol(math,ams,rel,"≿","\\succsim",!0);defineSymbol(math,ams,rel,"⪸","\\succapprox",!0);defineSymbol(math,ams,rel,"⊳","\\vartriangleright");defineSymbol(math,ams,rel,"⊵","\\trianglerighteq");defineSymbol(math,ams,rel,"⊩","\\Vdash",!0);defineSymbol(math,ams,rel,"∣","\\shortmid");defineSymbol(math,ams,rel,"∥","\\shortparallel");defineSymbol(math,ams,rel,"≬","\\between",!0);defineSymbol(math,ams,rel,"⋔","\\pitchfork",!0);defineSymbol(math,ams,rel,"∝","\\varpropto");defineSymbol(math,ams,rel,"◀","\\blacktriangleleft");defineSymbol(math,ams,rel,"∴","\\therefore",!0);defineSymbol(math,ams,rel,"∍","\\backepsilon");defineSymbol(math,ams,rel,"▶","\\blacktriangleright");defineSymbol(math,ams,rel,"∵","\\because",!0);defineSymbol(math,ams,rel,"⋘","\\llless");defineSymbol(math,ams,rel,"⋙","\\gggtr");defineSymbol(math,ams,bin,"⊲","\\lhd");defineSymbol(math,ams,bin,"⊳","\\rhd");defineSymbol(math,ams,rel,"≂","\\eqsim",!0);defineSymbol(math,main,rel,"⋈","\\Join");defineSymbol(math,ams,rel,"≑","\\Doteq",!0);defineSymbol(math,ams,bin,"∔","\\dotplus",!0);defineSymbol(math,ams,bin,"∖","\\smallsetminus");defineSymbol(math,ams,bin,"⋒","\\Cap",!0);defineSymbol(math,ams,bin,"⋓","\\Cup",!0);defineSymbol(math,ams,bin,"⩞","\\doublebarwedge",!0);defineSymbol(math,ams,bin,"⊟","\\boxminus",!0);defineSymbol(math,ams,bin,"⊞","\\boxplus",!0);defineSymbol(math,ams,bin,"⋇","\\divideontimes",!0);defineSymbol(math,ams,bin,"⋉","\\ltimes",!0);defineSymbol(math,ams,bin,"⋊","\\rtimes",!0);defineSymbol(math,ams,bin,"⋋","\\leftthreetimes",!0);defineSymbol(math,ams,bin,"⋌","\\rightthreetimes",!0);defineSymbol(math,ams,bin,"⋏","\\curlywedge",!0);defineSymbol(math,ams,bin,"⋎","\\curlyvee",!0);defineSymbol(math,ams,bin,"⊝","\\circleddash",!0);defineSymbol(math,ams,bin,"⊛","\\circledast",!0);defineSymbol(math,ams,bin,"⋅","\\centerdot");defineSymbol(math,ams,bin,"⊺","\\intercal",!0);defineSymbol(math,ams,bin,"⋒","\\doublecap");defineSymbol(math,ams,bin,"⋓","\\doublecup");defineSymbol(math,ams,bin,"⊠","\\boxtimes",!0);defineSymbol(math,ams,rel,"⇢","\\dashrightarrow",!0);defineSymbol(math,ams,rel,"⇠","\\dashleftarrow",!0);defineSymbol(math,ams,rel,"⇇","\\leftleftarrows",!0);defineSymbol(math,ams,rel,"⇆","\\leftrightarrows",!0);defineSymbol(math,ams,rel,"⇚","\\Lleftarrow",!0);defineSymbol(math,ams,rel,"↞","\\twoheadleftarrow",!0);defineSymbol(math,ams,rel,"↢","\\leftarrowtail",!0);defineSymbol(math,ams,rel,"↫","\\looparrowleft",!0);defineSymbol(math,ams,rel,"⇋","\\leftrightharpoons",!0);defineSymbol(math,ams,rel,"↶","\\curvearrowleft",!0);defineSymbol(math,ams,rel,"↺","\\circlearrowleft",!0);defineSymbol(math,ams,rel,"↰","\\Lsh",!0);defineSymbol(math,ams,rel,"⇈","\\upuparrows",!0);defineSymbol(math,ams,rel,"↿","\\upharpoonleft",!0);defineSymbol(math,ams,rel,"⇃","\\downharpoonleft",!0);defineSymbol(math,main,rel,"⊶","\\origof",!0);defineSymbol(math,main,rel,"⊷","\\imageof",!0);defineSymbol(math,ams,rel,"⊸","\\multimap",!0);defineSymbol(math,ams,rel,"↭","\\leftrightsquigarrow",!0);defineSymbol(math,ams,rel,"⇉","\\rightrightarrows",!0);defineSymbol(math,ams,rel,"⇄","\\rightleftarrows",!0);defineSymbol(math,ams,rel,"↠","\\twoheadrightarrow",!0);defineSymbol(math,ams,rel,"↣","\\rightarrowtail",!0);defineSymbol(math,ams,rel,"↬","\\looparrowright",!0);defineSymbol(math,ams,rel,"↷","\\curvearrowright",!0);defineSymbol(math,ams,rel,"↻","\\circlearrowright",!0);defineSymbol(math,ams,rel,"↱","\\Rsh",!0);defineSymbol(math,ams,rel,"⇊","\\downdownarrows",!0);defineSymbol(math,ams,rel,"↾","\\upharpoonright",!0);defineSymbol(math,ams,rel,"⇂","\\downharpoonright",!0);defineSymbol(math,ams,rel,"⇝","\\rightsquigarrow",!0);defineSymbol(math,ams,rel,"⇝","\\leadsto");defineSymbol(math,ams,rel,"⇛","\\Rrightarrow",!0);defineSymbol(math,ams,rel,"↾","\\restriction");defineSymbol(math,main,textord,"‘","`");defineSymbol(math,main,textord,"$","\\$");defineSymbol(text$2,main,textord,"$","\\$");defineSymbol(text$2,main,textord,"$","\\textdollar");defineSymbol(math,main,textord,"%","\\%");defineSymbol(text$2,main,textord,"%","\\%");defineSymbol(math,main,textord,"_","\\_");defineSymbol(text$2,main,textord,"_","\\_");defineSymbol(text$2,main,textord,"_","\\textunderscore");defineSymbol(math,main,textord,"∠","\\angle",!0);defineSymbol(math,main,textord,"∞","\\infty",!0);defineSymbol(math,main,textord,"′","\\prime");defineSymbol(math,main,textord,"△","\\triangle");defineSymbol(math,main,textord,"Γ","\\Gamma",!0);defineSymbol(math,main,textord,"Δ","\\Delta",!0);defineSymbol(math,main,textord,"Θ","\\Theta",!0);defineSymbol(math,main,textord,"Λ","\\Lambda",!0);defineSymbol(math,main,textord,"Ξ","\\Xi",!0);defineSymbol(math,main,textord,"Π","\\Pi",!0);defineSymbol(math,main,textord,"Σ","\\Sigma",!0);defineSymbol(math,main,textord,"Υ","\\Upsilon",!0);defineSymbol(math,main,textord,"Φ","\\Phi",!0);defineSymbol(math,main,textord,"Ψ","\\Psi",!0);defineSymbol(math,main,textord,"Ω","\\Omega",!0);defineSymbol(math,main,textord,"A","Α");defineSymbol(math,main,textord,"B","Β");defineSymbol(math,main,textord,"E","Ε");defineSymbol(math,main,textord,"Z","Ζ");defineSymbol(math,main,textord,"H","Η");defineSymbol(math,main,textord,"I","Ι");defineSymbol(math,main,textord,"K","Κ");defineSymbol(math,main,textord,"M","Μ");defineSymbol(math,main,textord,"N","Ν");defineSymbol(math,main,textord,"O","Ο");defineSymbol(math,main,textord,"P","Ρ");defineSymbol(math,main,textord,"T","Τ");defineSymbol(math,main,textord,"X","Χ");defineSymbol(math,main,textord,"¬","\\neg",!0);defineSymbol(math,main,textord,"¬","\\lnot");defineSymbol(math,main,textord,"⊤","\\top");defineSymbol(math,main,textord,"⊥","\\bot");defineSymbol(math,main,textord,"∅","\\emptyset");defineSymbol(math,ams,textord,"∅","\\varnothing");defineSymbol(math,main,mathord,"α","\\alpha",!0);defineSymbol(math,main,mathord,"β","\\beta",!0);defineSymbol(math,main,mathord,"γ","\\gamma",!0);defineSymbol(math,main,mathord,"δ","\\delta",!0);defineSymbol(math,main,mathord,"ϵ","\\epsilon",!0);defineSymbol(math,main,mathord,"ζ","\\zeta",!0);defineSymbol(math,main,mathord,"η","\\eta",!0);defineSymbol(math,main,mathord,"θ","\\theta",!0);defineSymbol(math,main,mathord,"ι","\\iota",!0);defineSymbol(math,main,mathord,"κ","\\kappa",!0);defineSymbol(math,main,mathord,"λ","\\lambda",!0);defineSymbol(math,main,mathord,"μ","\\mu",!0);defineSymbol(math,main,mathord,"ν","\\nu",!0);defineSymbol(math,main,mathord,"ξ","\\xi",!0);defineSymbol(math,main,mathord,"ο","\\omicron",!0);defineSymbol(math,main,mathord,"π","\\pi",!0);defineSymbol(math,main,mathord,"ρ","\\rho",!0);defineSymbol(math,main,mathord,"σ","\\sigma",!0);defineSymbol(math,main,mathord,"τ","\\tau",!0);defineSymbol(math,main,mathord,"υ","\\upsilon",!0);defineSymbol(math,main,mathord,"ϕ","\\phi",!0);defineSymbol(math,main,mathord,"χ","\\chi",!0);defineSymbol(math,main,mathord,"ψ","\\psi",!0);defineSymbol(math,main,mathord,"ω","\\omega",!0);defineSymbol(math,main,mathord,"ε","\\varepsilon",!0);defineSymbol(math,main,mathord,"ϑ","\\vartheta",!0);defineSymbol(math,main,mathord,"ϖ","\\varpi",!0);defineSymbol(math,main,mathord,"ϱ","\\varrho",!0);defineSymbol(math,main,mathord,"ς","\\varsigma",!0);defineSymbol(math,main,mathord,"φ","\\varphi",!0);defineSymbol(math,main,bin,"∗","*",!0);defineSymbol(math,main,bin,"+","+");defineSymbol(math,main,bin,"−","-",!0);defineSymbol(math,main,bin,"⋅","\\cdot",!0);defineSymbol(math,main,bin,"∘","\\circ",!0);defineSymbol(math,main,bin,"÷","\\div",!0);defineSymbol(math,main,bin,"±","\\pm",!0);defineSymbol(math,main,bin,"×","\\times",!0);defineSymbol(math,main,bin,"∩","\\cap",!0);defineSymbol(math,main,bin,"∪","\\cup",!0);defineSymbol(math,main,bin,"∖","\\setminus",!0);defineSymbol(math,main,bin,"∧","\\land");defineSymbol(math,main,bin,"∨","\\lor");defineSymbol(math,main,bin,"∧","\\wedge",!0);defineSymbol(math,main,bin,"∨","\\vee",!0);defineSymbol(math,main,textord,"√","\\surd");defineSymbol(math,main,open,"⟨","\\langle",!0);defineSymbol(math,main,open,"∣","\\lvert");defineSymbol(math,main,open,"∥","\\lVert");defineSymbol(math,main,close,"?","?");defineSymbol(math,main,close,"!","!");defineSymbol(math,main,close,"⟩","\\rangle",!0);defineSymbol(math,main,close,"∣","\\rvert");defineSymbol(math,main,close,"∥","\\rVert");defineSymbol(math,main,rel,"=","=");defineSymbol(math,main,rel,":",":");defineSymbol(math,main,rel,"≈","\\approx",!0);defineSymbol(math,main,rel,"≅","\\cong",!0);defineSymbol(math,main,rel,"≥","\\ge");defineSymbol(math,main,rel,"≥","\\geq",!0);defineSymbol(math,main,rel,"←","\\gets");defineSymbol(math,main,rel,">","\\gt",!0);defineSymbol(math,main,rel,"∈","\\in",!0);defineSymbol(math,main,rel,"","\\@not");defineSymbol(math,main,rel,"⊂","\\subset",!0);defineSymbol(math,main,rel,"⊃","\\supset",!0);defineSymbol(math,main,rel,"⊆","\\subseteq",!0);defineSymbol(math,main,rel,"⊇","\\supseteq",!0);defineSymbol(math,ams,rel,"⊈","\\nsubseteq",!0);defineSymbol(math,ams,rel,"⊉","\\nsupseteq",!0);defineSymbol(math,main,rel,"⊨","\\models");defineSymbol(math,main,rel,"←","\\leftarrow",!0);defineSymbol(math,main,rel,"≤","\\le");defineSymbol(math,main,rel,"≤","\\leq",!0);defineSymbol(math,main,rel,"<","\\lt",!0);defineSymbol(math,main,rel,"→","\\rightarrow",!0);defineSymbol(math,main,rel,"→","\\to");defineSymbol(math,ams,rel,"≱","\\ngeq",!0);defineSymbol(math,ams,rel,"≰","\\nleq",!0);defineSymbol(math,main,spacing," ","\\ ");defineSymbol(math,main,spacing," ","\\space");defineSymbol(math,main,spacing," ","\\nobreakspace");defineSymbol(text$2,main,spacing," ","\\ ");defineSymbol(text$2,main,spacing," "," ");defineSymbol(text$2,main,spacing," ","\\space");defineSymbol(text$2,main,spacing," ","\\nobreakspace");defineSymbol(math,main,spacing,null,"\\nobreak");defineSymbol(math,main,spacing,null,"\\allowbreak");defineSymbol(math,main,punct,",",",");defineSymbol(math,main,punct,";",";");defineSymbol(math,ams,bin,"⊼","\\barwedge",!0);defineSymbol(math,ams,bin,"⊻","\\veebar",!0);defineSymbol(math,main,bin,"⊙","\\odot",!0);defineSymbol(math,main,bin,"⊕","\\oplus",!0);defineSymbol(math,main,bin,"⊗","\\otimes",!0);defineSymbol(math,main,textord,"∂","\\partial",!0);defineSymbol(math,main,bin,"⊘","\\oslash",!0);defineSymbol(math,ams,bin,"⊚","\\circledcirc",!0);defineSymbol(math,ams,bin,"⊡","\\boxdot",!0);defineSymbol(math,main,bin,"△","\\bigtriangleup");defineSymbol(math,main,bin,"▽","\\bigtriangledown");defineSymbol(math,main,bin,"†","\\dagger");defineSymbol(math,main,bin,"⋄","\\diamond");defineSymbol(math,main,bin,"⋆","\\star");defineSymbol(math,main,bin,"◃","\\triangleleft");defineSymbol(math,main,bin,"▹","\\triangleright");defineSymbol(math,main,open,"{","\\{");defineSymbol(text$2,main,textord,"{","\\{");defineSymbol(text$2,main,textord,"{","\\textbraceleft");defineSymbol(math,main,close,"}","\\}");defineSymbol(text$2,main,textord,"}","\\}");defineSymbol(text$2,main,textord,"}","\\textbraceright");defineSymbol(math,main,open,"{","\\lbrace");defineSymbol(math,main,close,"}","\\rbrace");defineSymbol(math,main,open,"[","\\lbrack",!0);defineSymbol(text$2,main,textord,"[","\\lbrack",!0);defineSymbol(math,main,close,"]","\\rbrack",!0);defineSymbol(text$2,main,textord,"]","\\rbrack",!0);defineSymbol(math,main,open,"(","\\lparen",!0);defineSymbol(math,main,close,")","\\rparen",!0);defineSymbol(text$2,main,textord,"<","\\textless",!0);defineSymbol(text$2,main,textord,">","\\textgreater",!0);defineSymbol(math,main,open,"⌊","\\lfloor",!0);defineSymbol(math,main,close,"⌋","\\rfloor",!0);defineSymbol(math,main,open,"⌈","\\lceil",!0);defineSymbol(math,main,close,"⌉","\\rceil",!0);defineSymbol(math,main,textord,"\\","\\backslash");defineSymbol(math,main,textord,"∣","|");defineSymbol(math,main,textord,"∣","\\vert");defineSymbol(text$2,main,textord,"|","\\textbar",!0);defineSymbol(math,main,textord,"∥","\\|");defineSymbol(math,main,textord,"∥","\\Vert");defineSymbol(text$2,main,textord,"∥","\\textbardbl");defineSymbol(text$2,main,textord,"~","\\textasciitilde");defineSymbol(text$2,main,textord,"\\","\\textbackslash");defineSymbol(text$2,main,textord,"^","\\textasciicircum");defineSymbol(math,main,rel,"↑","\\uparrow",!0);defineSymbol(math,main,rel,"⇑","\\Uparrow",!0);defineSymbol(math,main,rel,"↓","\\downarrow",!0);defineSymbol(math,main,rel,"⇓","\\Downarrow",!0);defineSymbol(math,main,rel,"↕","\\updownarrow",!0);defineSymbol(math,main,rel,"⇕","\\Updownarrow",!0);defineSymbol(math,main,op,"∐","\\coprod");defineSymbol(math,main,op,"⋁","\\bigvee");defineSymbol(math,main,op,"⋀","\\bigwedge");defineSymbol(math,main,op,"⨄","\\biguplus");defineSymbol(math,main,op,"⋂","\\bigcap");defineSymbol(math,main,op,"⋃","\\bigcup");defineSymbol(math,main,op,"∫","\\int");defineSymbol(math,main,op,"∫","\\intop");defineSymbol(math,main,op,"∬","\\iint");defineSymbol(math,main,op,"∭","\\iiint");defineSymbol(math,main,op,"∏","\\prod");defineSymbol(math,main,op,"∑","\\sum");defineSymbol(math,main,op,"⨂","\\bigotimes");defineSymbol(math,main,op,"⨁","\\bigoplus");defineSymbol(math,main,op,"⨀","\\bigodot");defineSymbol(math,main,op,"∮","\\oint");defineSymbol(math,main,op,"∯","\\oiint");defineSymbol(math,main,op,"∰","\\oiiint");defineSymbol(math,main,op,"⨆","\\bigsqcup");defineSymbol(math,main,op,"∫","\\smallint");defineSymbol(text$2,main,inner,"…","\\textellipsis");defineSymbol(math,main,inner,"…","\\mathellipsis");defineSymbol(text$2,main,inner,"…","\\ldots",!0);defineSymbol(math,main,inner,"…","\\ldots",!0);defineSymbol(math,main,inner,"⋯","\\@cdots",!0);defineSymbol(math,main,inner,"⋱","\\ddots",!0);defineSymbol(math,main,textord,"⋮","\\varvdots");defineSymbol(text$2,main,textord,"⋮","\\varvdots");defineSymbol(math,main,accent,"ˊ","\\acute");defineSymbol(math,main,accent,"ˋ","\\grave");defineSymbol(math,main,accent,"¨","\\ddot");defineSymbol(math,main,accent,"~","\\tilde");defineSymbol(math,main,accent,"ˉ","\\bar");defineSymbol(math,main,accent,"˘","\\breve");defineSymbol(math,main,accent,"ˇ","\\check");defineSymbol(math,main,accent,"^","\\hat");defineSymbol(math,main,accent,"⃗","\\vec");defineSymbol(math,main,accent,"˙","\\dot");defineSymbol(math,main,accent,"˚","\\mathring");defineSymbol(math,main,mathord,"","\\@imath");defineSymbol(math,main,mathord,"","\\@jmath");defineSymbol(math,main,textord,"ı","ı");defineSymbol(math,main,textord,"ȷ","ȷ");defineSymbol(text$2,main,textord,"ı","\\i",!0);defineSymbol(text$2,main,textord,"ȷ","\\j",!0);defineSymbol(text$2,main,textord,"ß","\\ss",!0);defineSymbol(text$2,main,textord,"æ","\\ae",!0);defineSymbol(text$2,main,textord,"œ","\\oe",!0);defineSymbol(text$2,main,textord,"ø","\\o",!0);defineSymbol(text$2,main,textord,"Æ","\\AE",!0);defineSymbol(text$2,main,textord,"Œ","\\OE",!0);defineSymbol(text$2,main,textord,"Ø","\\O",!0);defineSymbol(text$2,main,accent,"ˊ","\\'");defineSymbol(text$2,main,accent,"ˋ","\\`");defineSymbol(text$2,main,accent,"ˆ","\\^");defineSymbol(text$2,main,accent,"˜","\\~");defineSymbol(text$2,main,accent,"ˉ","\\=");defineSymbol(text$2,main,accent,"˘","\\u");defineSymbol(text$2,main,accent,"˙","\\.");defineSymbol(text$2,main,accent,"¸","\\c");defineSymbol(text$2,main,accent,"˚","\\r");defineSymbol(text$2,main,accent,"ˇ","\\v");defineSymbol(text$2,main,accent,"¨",'\\"');defineSymbol(text$2,main,accent,"˝","\\H");defineSymbol(text$2,main,accent,"◯","\\textcircled");var ligatures={"--":!0,"---":!0,"``":!0,"''":!0};defineSymbol(text$2,main,textord,"–","--",!0);defineSymbol(text$2,main,textord,"–","\\textendash");defineSymbol(text$2,main,textord,"—","---",!0);defineSymbol(text$2,main,textord,"—","\\textemdash");defineSymbol(text$2,main,textord,"‘","`",!0);defineSymbol(text$2,main,textord,"‘","\\textquoteleft");defineSymbol(text$2,main,textord,"’","'",!0);defineSymbol(text$2,main,textord,"’","\\textquoteright");defineSymbol(text$2,main,textord,"“","``",!0);defineSymbol(text$2,main,textord,"“","\\textquotedblleft");defineSymbol(text$2,main,textord,"”","''",!0);defineSymbol(text$2,main,textord,"”","\\textquotedblright");defineSymbol(math,main,textord,"°","\\degree",!0);defineSymbol(text$2,main,textord,"°","\\degree");defineSymbol(text$2,main,textord,"°","\\textdegree",!0);defineSymbol(math,main,textord,"£","\\pounds");defineSymbol(math,main,textord,"£","\\mathsterling",!0);defineSymbol(text$2,main,textord,"£","\\pounds");defineSymbol(text$2,main,textord,"£","\\textsterling",!0);defineSymbol(math,ams,textord,"✠","\\maltese");defineSymbol(text$2,ams,textord,"✠","\\maltese");var mathTextSymbols='0123456789/@."';for(var i=0;i<mathTextSymbols.length;i++){var ch=mathTextSymbols.charAt(i);defineSymbol(math,main,textord,ch,ch)}var textSymbols='0123456789!@*()-=+";:?/.,';for(var _i=0;_i<textSymbols.length;_i++){var _ch=textSymbols.charAt(_i);defineSymbol(text$2,main,textord,_ch,_ch)}var letters="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";for(var _i2=0;_i2<letters.length;_i2++){var _ch2=letters.charAt(_i2);defineSymbol(math,main,mathord,_ch2,_ch2),defineSymbol(text$2,main,textord,_ch2,_ch2)}defineSymbol(math,ams,textord,"C","ℂ");defineSymbol(text$2,ams,textord,"C","ℂ");defineSymbol(math,ams,textord,"H","ℍ");defineSymbol(text$2,ams,textord,"H","ℍ");defineSymbol(math,ams,textord,"N","ℕ");defineSymbol(text$2,ams,textord,"N","ℕ");defineSymbol(math,ams,textord,"P","ℙ");defineSymbol(text$2,ams,textord,"P","ℙ");defineSymbol(math,ams,textord,"Q","ℚ");defineSymbol(text$2,ams,textord,"Q","ℚ");defineSymbol(math,ams,textord,"R","ℝ");defineSymbol(text$2,ams,textord,"R","ℝ");defineSymbol(math,ams,textord,"Z","ℤ");defineSymbol(text$2,ams,textord,"Z","ℤ");defineSymbol(math,main,mathord,"h","ℎ");defineSymbol(text$2,main,mathord,"h","ℎ");var wideChar="";for(var _i3=0;_i3<letters.length;_i3++){var _ch3=letters.charAt(_i3);wideChar=String.fromCharCode(55349,56320+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56372+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56424+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56580+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56684+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56736+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56788+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56840+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56944+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),_i3<26&&(wideChar=String.fromCharCode(55349,56632+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar),wideChar=String.fromCharCode(55349,56476+_i3),defineSymbol(math,main,mathord,_ch3,wideChar),defineSymbol(text$2,main,textord,_ch3,wideChar))}wideChar="𝕜";defineSymbol(math,main,mathord,"k",wideChar);defineSymbol(text$2,main,textord,"k",wideChar);for(var _i4=0;_i4<10;_i4++){var _ch4=_i4.toString();wideChar=String.fromCharCode(55349,57294+_i4),defineSymbol(math,main,mathord,_ch4,wideChar),defineSymbol(text$2,main,textord,_ch4,wideChar),wideChar=String.fromCharCode(55349,57314+_i4),defineSymbol(math,main,mathord,_ch4,wideChar),defineSymbol(text$2,main,textord,_ch4,wideChar),wideChar=String.fromCharCode(55349,57324+_i4),defineSymbol(math,main,mathord,_ch4,wideChar),defineSymbol(text$2,main,textord,_ch4,wideChar),wideChar=String.fromCharCode(55349,57334+_i4),defineSymbol(math,main,mathord,_ch4,wideChar),defineSymbol(text$2,main,textord,_ch4,wideChar)}var extraLatin="ÐÞþ";for(var _i5=0;_i5<extraLatin.length;_i5++){var _ch5=extraLatin.charAt(_i5);defineSymbol(math,main,mathord,_ch5,_ch5),defineSymbol(text$2,main,textord,_ch5,_ch5)}var wideLatinLetterData=[["mathbf","textbf","Main-Bold"],["mathbf","textbf","Main-Bold"],["mathnormal","textit","Math-Italic"],["mathnormal","textit","Math-Italic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["boldsymbol","boldsymbol","Main-BoldItalic"],["mathscr","textscr","Script-Regular"],["","",""],["","",""],["","",""],["mathfrak","textfrak","Fraktur-Regular"],["mathfrak","textfrak","Fraktur-Regular"],["mathbb","textbb","AMS-Regular"],["mathbb","textbb","AMS-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathboldfrak","textboldfrak","Fraktur-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathitsf","textitsf","SansSerif-Italic"],["mathitsf","textitsf","SansSerif-Italic"],["","",""],["","",""],["mathtt","texttt","Typewriter-Regular"],["mathtt","texttt","Typewriter-Regular"]],wideNumeralData=[["mathbf","textbf","Main-Bold"],["","",""],["mathsf","textsf","SansSerif-Regular"],["mathboldsf","textboldsf","SansSerif-Bold"],["mathtt","texttt","Typewriter-Regular"]],wideCharacterFont=function(c,u){var d=c.charCodeAt(0),f=c.charCodeAt(1),m=(d-55296)*1024+(f-56320)+65536,g=u==="math"?0:1;if(119808<=m&&m<120484){var y=Math.floor((m-119808)/26);return[wideLatinLetterData[y][2],wideLatinLetterData[y][g]]}else if(120782<=m&&m<=120831){var b=Math.floor((m-120782)/10);return[wideNumeralData[b][2],wideNumeralData[b][g]]}else{if(m===120485||m===120486)return[wideLatinLetterData[0][2],wideLatinLetterData[0][g]];if(120486<m&&m<120782)return["",""];throw new ParseError("Unsupported character: "+c)}},lookupSymbol=function(c,u,d){return symbols[d][c]&&symbols[d][c].replace&&(c=symbols[d][c].replace),{value:c,metrics:getCharacterMetrics(c,u,d)}},makeSymbol=function(c,u,d,f,m){var g=lookupSymbol(c,u,d),y=g.metrics;c=g.value;var b;if(y){var E=y.italic;(d==="text"||f&&f.font==="mathit")&&(E=0),b=new SymbolNode(c,y.height,y.depth,E,y.skew,y.width,m)}else typeof console<"u"&&console.warn("No character metrics "+("for '"+c+"' in style '"+u+"' and mode '"+d+"'")),b=new SymbolNode(c,0,0,0,0,0,m);if(f){b.maxFontSize=f.sizeMultiplier,f.style.isTight()&&b.classes.push("mtight");var C=f.getColor();C&&(b.style.color=C)}return b},mathsym=function(c,u,d,f){return f===void 0&&(f=[]),d.font==="boldsymbol"&&lookupSymbol(c,"Main-Bold",u).metrics?makeSymbol(c,"Main-Bold",u,d,f.concat(["mathbf"])):c==="\\"||symbols[u][c].font==="main"?makeSymbol(c,"Main-Regular",u,d,f):makeSymbol(c,"AMS-Regular",u,d,f.concat(["amsrm"]))},boldsymbol=function(c,u,d,f,m){return m!=="textord"&&lookupSymbol(c,"Math-BoldItalic",u).metrics?{fontName:"Math-BoldItalic",fontClass:"boldsymbol"}:{fontName:"Main-Bold",fontClass:"mathbf"}},makeOrd=function(c,u,d){var f=c.mode,m=c.text,g=["mord"],y=f==="math"||f==="text"&&u.font,b=y?u.font:u.fontFamily,E="",C="";if(m.charCodeAt(0)===55349&&([E,C]=wideCharacterFont(m,f)),E.length>0)return makeSymbol(m,E,f,u,g.concat(C));if(b){var w,R;if(b==="boldsymbol"){var _=boldsymbol(m,f,u,g,d);w=_.fontName,R=[_.fontClass]}else y?(w=fontMap[b].fontName,R=[b]):(w=retrieveTextFontName(b,u.fontWeight,u.fontShape),R=[b,u.fontWeight,u.fontShape]);if(lookupSymbol(m,w,f).metrics)return makeSymbol(m,w,f,u,g.concat(R));if(ligatures.hasOwnProperty(m)&&w.slice(0,10)==="Typewriter"){for(var M=[],I=0;I<m.length;I++)M.push(makeSymbol(m[I],w,f,u,g.concat(R)));return makeFragment(M)}}if(d==="mathord")return makeSymbol(m,"Math-Italic",f,u,g.concat(["mathnormal"]));if(d==="textord"){var N=symbols[f][m]&&symbols[f][m].font;if(N==="ams"){var A=retrieveTextFontName("amsrm",u.fontWeight,u.fontShape);return makeSymbol(m,A,f,u,g.concat("amsrm",u.fontWeight,u.fontShape))}else if(N==="main"||!N){var P=retrieveTextFontName("textrm",u.fontWeight,u.fontShape);return makeSymbol(m,P,f,u,g.concat(u.fontWeight,u.fontShape))}else{var z=retrieveTextFontName(N,u.fontWeight,u.fontShape);return makeSymbol(m,z,f,u,g.concat(z,u.fontWeight,u.fontShape))}}else throw new Error("unexpected type: "+d+" in makeOrd")},canCombine=(a,c)=>{if(createClass(a.classes)!==createClass(c.classes)||a.skew!==c.skew||a.maxFontSize!==c.maxFontSize)return!1;if(a.classes.length===1){var u=a.classes[0];if(u==="mbin"||u==="mord")return!1}for(var d in a.style)if(a.style.hasOwnProperty(d)&&a.style[d]!==c.style[d])return!1;for(var f in c.style)if(c.style.hasOwnProperty(f)&&a.style[f]!==c.style[f])return!1;return!0},tryCombineChars=a=>{for(var c=0;c<a.length-1;c++){var u=a[c],d=a[c+1];u instanceof SymbolNode&&d instanceof SymbolNode&&canCombine(u,d)&&(u.text+=d.text,u.height=Math.max(u.height,d.height),u.depth=Math.max(u.depth,d.depth),u.italic=d.italic,a.splice(c+1,1),c--)}return a},sizeElementFromChildren=function(c){for(var u=0,d=0,f=0,m=0;m<c.children.length;m++){var g=c.children[m];g.height>u&&(u=g.height),g.depth>d&&(d=g.depth),g.maxFontSize>f&&(f=g.maxFontSize)}c.height=u,c.depth=d,c.maxFontSize=f},makeSpan$2=function(c,u,d,f){var m=new Span(c,u,d,f);return sizeElementFromChildren(m),m},makeSvgSpan=(a,c,u,d)=>new Span(a,c,u,d),makeLineSpan=function(c,u,d){var f=makeSpan$2([c],[],u);return f.height=Math.max(d||u.fontMetrics().defaultRuleThickness,u.minRuleThickness),f.style.borderBottomWidth=makeEm(f.height),f.maxFontSize=1,f},makeAnchor=function(c,u,d,f){var m=new Anchor(c,u,d,f);return sizeElementFromChildren(m),m},makeFragment=function(c){var u=new DocumentFragment(c);return sizeElementFromChildren(u),u},wrapFragment=function(c,u){return c instanceof DocumentFragment?makeSpan$2([],[c],u):c},getVListChildrenAndDepth=function(c){if(c.positionType==="individualShift"){for(var u=c.children,d=[u[0]],f=-u[0].shift-u[0].elem.depth,m=f,g=1;g<u.length;g++){var y=-u[g].shift-m-u[g].elem.depth,b=y-(u[g-1].elem.height+u[g-1].elem.depth);m=m+y,d.push({type:"kern",size:b}),d.push(u[g])}return{children:d,depth:f}}var E;if(c.positionType==="top"){for(var C=c.positionData,w=0;w<c.children.length;w++){var R=c.children[w];C-=R.type==="kern"?R.size:R.elem.height+R.elem.depth}E=C}else if(c.positionType==="bottom")E=-c.positionData;else{var _=c.children[0];if(_.type!=="elem")throw new Error('First child must have type "elem".');if(c.positionType==="shift")E=-_.elem.depth-c.positionData;else if(c.positionType==="firstBaseline")E=-_.elem.depth;else throw new Error("Invalid positionType "+c.positionType+".")}return{children:c.children,depth:E}},makeVList=function(c,u){for(var{children:d,depth:f}=getVListChildrenAndDepth(c),m=0,g=0;g<d.length;g++){var y=d[g];if(y.type==="elem"){var b=y.elem;m=Math.max(m,b.maxFontSize,b.height)}}m+=2;var E=makeSpan$2(["pstrut"],[]);E.style.height=makeEm(m);for(var C=[],w=f,R=f,_=f,M=0;M<d.length;M++){var I=d[M];if(I.type==="kern")_+=I.size;else{var N=I.elem,A=I.wrapperClasses||[],P=I.wrapperStyle||{},z=makeSpan$2(A,[E,N],void 0,P);z.style.top=makeEm(-m-_-N.depth),I.marginLeft&&(z.style.marginLeft=I.marginLeft),I.marginRight&&(z.style.marginRight=I.marginRight),C.push(z),_+=N.height+N.depth}w=Math.min(w,_),R=Math.max(R,_)}var B=makeSpan$2(["vlist"],C);B.style.height=makeEm(R);var j;if(w<0){var L=makeSpan$2([],[]),U=makeSpan$2(["vlist"],[L]);U.style.height=makeEm(-w);var q=makeSpan$2(["vlist-s"],[new SymbolNode("​")]);j=[makeSpan$2(["vlist-r"],[B,q]),makeSpan$2(["vlist-r"],[U])]}else j=[makeSpan$2(["vlist-r"],[B])];var F=makeSpan$2(["vlist-t"],j);return j.length===2&&F.classes.push("vlist-t2"),F.height=R,F.depth=-w,F},makeGlue=(a,c)=>{var u=makeSpan$2(["mspace"],[],c),d=calculateSize(a,c);return u.style.marginRight=makeEm(d),u},retrieveTextFontName=function(c,u,d){var f="";switch(c){case"amsrm":f="AMS";break;case"textrm":f="Main";break;case"textsf":f="SansSerif";break;case"texttt":f="Typewriter";break;default:f=c}var m;return u==="textbf"&&d==="textit"?m="BoldItalic":u==="textbf"?m="Bold":u==="textit"?m="Italic":m="Regular",f+"-"+m},fontMap={mathbf:{variant:"bold",fontName:"Main-Bold"},mathrm:{variant:"normal",fontName:"Main-Regular"},textit:{variant:"italic",fontName:"Main-Italic"},mathit:{variant:"italic",fontName:"Main-Italic"},mathnormal:{variant:"italic",fontName:"Math-Italic"},mathsfit:{variant:"sans-serif-italic",fontName:"SansSerif-Italic"},mathbb:{variant:"double-struck",fontName:"AMS-Regular"},mathcal:{variant:"script",fontName:"Caligraphic-Regular"},mathfrak:{variant:"fraktur",fontName:"Fraktur-Regular"},mathscr:{variant:"script",fontName:"Script-Regular"},mathsf:{variant:"sans-serif",fontName:"SansSerif-Regular"},mathtt:{variant:"monospace",fontName:"Typewriter-Regular"}},svgData={vec:["vec",.471,.714],oiintSize1:["oiintSize1",.957,.499],oiintSize2:["oiintSize2",1.472,.659],oiiintSize1:["oiiintSize1",1.304,.499],oiiintSize2:["oiiintSize2",1.98,.659]},staticSvg=function(c,u){var[d,f,m]=svgData[c],g=new PathNode(d),y=new SvgNode([g],{width:makeEm(f),height:makeEm(m),style:"width:"+makeEm(f),viewBox:"0 0 "+1e3*f+" "+1e3*m,preserveAspectRatio:"xMinYMin"}),b=makeSvgSpan(["overlay"],[y],u);return b.height=m,b.style.height=makeEm(m),b.style.width=makeEm(f),b},buildCommon={fontMap,makeSymbol,mathsym,makeSpan:makeSpan$2,makeSvgSpan,makeLineSpan,makeAnchor,makeFragment,wrapFragment,makeVList,makeOrd,makeGlue,staticSvg,svgData,tryCombineChars},thinspace={number:3,unit:"mu"},mediumspace={number:4,unit:"mu"},thickspace={number:5,unit:"mu"},spacings={mord:{mop:thinspace,mbin:mediumspace,mrel:thickspace,minner:thinspace},mop:{mord:thinspace,mop:thinspace,mrel:thickspace,minner:thinspace},mbin:{mord:mediumspace,mop:mediumspace,mopen:mediumspace,minner:mediumspace},mrel:{mord:thickspace,mop:thickspace,mopen:thickspace,minner:thickspace},mopen:{},mclose:{mop:thinspace,mbin:mediumspace,mrel:thickspace,minner:thinspace},mpunct:{mord:thinspace,mop:thinspace,mrel:thickspace,mopen:thinspace,mclose:thinspace,mpunct:thinspace,minner:thinspace},minner:{mord:thinspace,mop:thinspace,mbin:mediumspace,mrel:thickspace,mopen:thinspace,mpunct:thinspace,minner:thinspace}},tightSpacings={mord:{mop:thinspace},mop:{mord:thinspace,mop:thinspace},mbin:{},mrel:{},mopen:{},mclose:{mop:thinspace},mpunct:{},minner:{mop:thinspace}},_functions={},_htmlGroupBuilders={},_mathmlGroupBuilders={};function defineFunction(a){for(var{type:c,names:u,props:d,handler:f,htmlBuilder:m,mathmlBuilder:g}=a,y={type:c,numArgs:d.numArgs,argTypes:d.argTypes,allowedInArgument:!!d.allowedInArgument,allowedInText:!!d.allowedInText,allowedInMath:d.allowedInMath===void 0?!0:d.allowedInMath,numOptionalArgs:d.numOptionalArgs||0,infix:!!d.infix,primitive:!!d.primitive,handler:f},b=0;b<u.length;++b)_functions[u[b]]=y;c&&(m&&(_htmlGroupBuilders[c]=m),g&&(_mathmlGroupBuilders[c]=g))}function defineFunctionBuilders(a){var{type:c,htmlBuilder:u,mathmlBuilder:d}=a;defineFunction({type:c,names:[],props:{numArgs:0},handler(){throw new Error("Should never be called.")},htmlBuilder:u,mathmlBuilder:d})}var normalizeArgument=function(c){return c.type==="ordgroup"&&c.body.length===1?c.body[0]:c},ordargument=function(c){return c.type==="ordgroup"?c.body:[c]},makeSpan$1=buildCommon.makeSpan,binLeftCanceller=["leftmost","mbin","mopen","mrel","mop","mpunct"],binRightCanceller=["rightmost","mrel","mclose","mpunct"],styleMap$1={display:Style$1.DISPLAY,text:Style$1.TEXT,script:Style$1.SCRIPT,scriptscript:Style$1.SCRIPTSCRIPT},DomEnum={mord:"mord",mop:"mop",mbin:"mbin",mrel:"mrel",mopen:"mopen",mclose:"mclose",mpunct:"mpunct",minner:"minner"},buildExpression$1=function(c,u,d,f){f===void 0&&(f=[null,null]);for(var m=[],g=0;g<c.length;g++){var y=buildGroup$1(c[g],u);if(y instanceof DocumentFragment){var b=y.children;m.push(...b)}else m.push(y)}if(buildCommon.tryCombineChars(m),!d)return m;var E=u;if(c.length===1){var C=c[0];C.type==="sizing"?E=u.havingSize(C.size):C.type==="styling"&&(E=u.havingStyle(styleMap$1[C.style]))}var w=makeSpan$1([f[0]||"leftmost"],[],u),R=makeSpan$1([f[1]||"rightmost"],[],u),_=d==="root";return traverseNonSpaceNodes(m,(M,I)=>{var N=I.classes[0],A=M.classes[0];N==="mbin"&&utils.contains(binRightCanceller,A)?I.classes[0]="mord":A==="mbin"&&utils.contains(binLeftCanceller,N)&&(M.classes[0]="mord")},{node:w},R,_),traverseNonSpaceNodes(m,(M,I)=>{var N=getTypeOfDomTree(I),A=getTypeOfDomTree(M),P=N&&A?M.hasClass("mtight")?tightSpacings[N][A]:spacings[N][A]:null;if(P)return buildCommon.makeGlue(P,E)},{node:w},R,_),m},traverseNonSpaceNodes=function a(c,u,d,f,m){f&&c.push(f);for(var g=0;g<c.length;g++){var y=c[g],b=checkPartialGroup(y);if(b){a(b.children,u,d,null,m);continue}var E=!y.hasClass("mspace");if(E){var C=u(y,d.node);C&&(d.insertAfter?d.insertAfter(C):(c.unshift(C),g++))}E?d.node=y:m&&y.hasClass("newline")&&(d.node=makeSpan$1(["leftmost"])),d.insertAfter=(w=>R=>{c.splice(w+1,0,R),g++})(g)}f&&c.pop()},checkPartialGroup=function(c){return c instanceof DocumentFragment||c instanceof Anchor||c instanceof Span&&c.hasClass("enclosing")?c:null},getOutermostNode=function a(c,u){var d=checkPartialGroup(c);if(d){var f=d.children;if(f.length){if(u==="right")return a(f[f.length-1],"right");if(u==="left")return a(f[0],"left")}}return c},getTypeOfDomTree=function(c,u){return c?(u&&(c=getOutermostNode(c,u)),DomEnum[c.classes[0]]||null):null},makeNullDelimiter=function(c,u){var d=["nulldelimiter"].concat(c.baseSizingClasses());return makeSpan$1(u.concat(d))},buildGroup$1=function(c,u,d){if(!c)return makeSpan$1();if(_htmlGroupBuilders[c.type]){var f=_htmlGroupBuilders[c.type](c,u);if(d&&u.size!==d.size){f=makeSpan$1(u.sizingClasses(d),[f],u);var m=u.sizeMultiplier/d.sizeMultiplier;f.height*=m,f.depth*=m}return f}else throw new ParseError("Got group of unknown type: '"+c.type+"'")};function buildHTMLUnbreakable(a,c){var u=makeSpan$1(["base"],a,c),d=makeSpan$1(["strut"]);return d.style.height=makeEm(u.height+u.depth),u.depth&&(d.style.verticalAlign=makeEm(-u.depth)),u.children.unshift(d),u}function buildHTML(a,c){var u=null;a.length===1&&a[0].type==="tag"&&(u=a[0].tag,a=a[0].body);var d=buildExpression$1(a,c,"root"),f;d.length===2&&d[1].hasClass("tag")&&(f=d.pop());for(var m=[],g=[],y=0;y<d.length;y++)if(g.push(d[y]),d[y].hasClass("mbin")||d[y].hasClass("mrel")||d[y].hasClass("allowbreak")){for(var b=!1;y<d.length-1&&d[y+1].hasClass("mspace")&&!d[y+1].hasClass("newline");)y++,g.push(d[y]),d[y].hasClass("nobreak")&&(b=!0);b||(m.push(buildHTMLUnbreakable(g,c)),g=[])}else d[y].hasClass("newline")&&(g.pop(),g.length>0&&(m.push(buildHTMLUnbreakable(g,c)),g=[]),m.push(d[y]));g.length>0&&m.push(buildHTMLUnbreakable(g,c));var E;u?(E=buildHTMLUnbreakable(buildExpression$1(u,c,!0)),E.classes=["tag"],m.push(E)):f&&m.push(f);var C=makeSpan$1(["katex-html"],m);if(C.setAttribute("aria-hidden","true"),E){var w=E.children[0];w.style.height=makeEm(C.height+C.depth),C.depth&&(w.style.verticalAlign=makeEm(-C.depth))}return C}function newDocumentFragment(a){return new DocumentFragment(a)}class MathNode{constructor(c,u,d){this.type=void 0,this.attributes=void 0,this.children=void 0,this.classes=void 0,this.type=c,this.attributes={},this.children=u||[],this.classes=d||[]}setAttribute(c,u){this.attributes[c]=u}getAttribute(c){return this.attributes[c]}toNode(){var c=document.createElementNS("http://www.w3.org/1998/Math/MathML",this.type);for(var u in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,u)&&c.setAttribute(u,this.attributes[u]);this.classes.length>0&&(c.className=createClass(this.classes));for(var d=0;d<this.children.length;d++)if(this.children[d]instanceof TextNode&&this.children[d+1]instanceof TextNode){for(var f=this.children[d].toText()+this.children[++d].toText();this.children[d+1]instanceof TextNode;)f+=this.children[++d].toText();c.appendChild(new TextNode(f).toNode())}else c.appendChild(this.children[d].toNode());return c}toMarkup(){var c="<"+this.type;for(var u in this.attributes)Object.prototype.hasOwnProperty.call(this.attributes,u)&&(c+=" "+u+'="',c+=utils.escape(this.attributes[u]),c+='"');this.classes.length>0&&(c+=' class ="'+utils.escape(createClass(this.classes))+'"'),c+=">";for(var d=0;d<this.children.length;d++)c+=this.children[d].toMarkup();return c+="</"+this.type+">",c}toText(){return this.children.map(c=>c.toText()).join("")}}class TextNode{constructor(c){this.text=void 0,this.text=c}toNode(){return document.createTextNode(this.text)}toMarkup(){return utils.escape(this.toText())}toText(){return this.text}}class SpaceNode{constructor(c){this.width=void 0,this.character=void 0,this.width=c,c>=.05555&&c<=.05556?this.character=" ":c>=.1666&&c<=.1667?this.character=" ":c>=.2222&&c<=.2223?this.character=" ":c>=.2777&&c<=.2778?this.character="  ":c>=-.05556&&c<=-.05555?this.character=" ⁣":c>=-.1667&&c<=-.1666?this.character=" ⁣":c>=-.2223&&c<=-.2222?this.character=" ⁣":c>=-.2778&&c<=-.2777?this.character=" ⁣":this.character=null}toNode(){if(this.character)return document.createTextNode(this.character);var c=document.createElementNS("http://www.w3.org/1998/Math/MathML","mspace");return c.setAttribute("width",makeEm(this.width)),c}toMarkup(){return this.character?"<mtext>"+this.character+"</mtext>":'<mspace width="'+makeEm(this.width)+'"/>'}toText(){return this.character?this.character:" "}}var mathMLTree={MathNode,TextNode,SpaceNode,newDocumentFragment},makeText=function(c,u,d){return symbols[u][c]&&symbols[u][c].replace&&c.charCodeAt(0)!==55349&&!(ligatures.hasOwnProperty(c)&&d&&(d.fontFamily&&d.fontFamily.slice(4,6)==="tt"||d.font&&d.font.slice(4,6)==="tt"))&&(c=symbols[u][c].replace),new mathMLTree.TextNode(c)},makeRow=function(c){return c.length===1?c[0]:new mathMLTree.MathNode("mrow",c)},getVariant=function(c,u){if(u.fontFamily==="texttt")return"monospace";if(u.fontFamily==="textsf")return u.fontShape==="textit"&&u.fontWeight==="textbf"?"sans-serif-bold-italic":u.fontShape==="textit"?"sans-serif-italic":u.fontWeight==="textbf"?"bold-sans-serif":"sans-serif";if(u.fontShape==="textit"&&u.fontWeight==="textbf")return"bold-italic";if(u.fontShape==="textit")return"italic";if(u.fontWeight==="textbf")return"bold";var d=u.font;if(!d||d==="mathnormal")return null;var f=c.mode;if(d==="mathit")return"italic";if(d==="boldsymbol")return c.type==="textord"?"bold":"bold-italic";if(d==="mathbf")return"bold";if(d==="mathbb")return"double-struck";if(d==="mathsfit")return"sans-serif-italic";if(d==="mathfrak")return"fraktur";if(d==="mathscr"||d==="mathcal")return"script";if(d==="mathsf")return"sans-serif";if(d==="mathtt")return"monospace";var m=c.text;if(utils.contains(["\\imath","\\jmath"],m))return null;symbols[f][m]&&symbols[f][m].replace&&(m=symbols[f][m].replace);var g=buildCommon.fontMap[d].fontName;return getCharacterMetrics(m,g,f)?buildCommon.fontMap[d].variant:null};function isNumberPunctuation(a){if(!a)return!1;if(a.type==="mi"&&a.children.length===1){var c=a.children[0];return c instanceof TextNode&&c.text==="."}else if(a.type==="mo"&&a.children.length===1&&a.getAttribute("separator")==="true"&&a.getAttribute("lspace")==="0em"&&a.getAttribute("rspace")==="0em"){var u=a.children[0];return u instanceof TextNode&&u.text===","}else return!1}var buildExpression=function(c,u,d){if(c.length===1){var f=buildGroup(c[0],u);return d&&f instanceof MathNode&&f.type==="mo"&&(f.setAttribute("lspace","0em"),f.setAttribute("rspace","0em")),[f]}for(var m=[],g,y=0;y<c.length;y++){var b=buildGroup(c[y],u);if(b instanceof MathNode&&g instanceof MathNode){if(b.type==="mtext"&&g.type==="mtext"&&b.getAttribute("mathvariant")===g.getAttribute("mathvariant")){g.children.push(...b.children);continue}else if(b.type==="mn"&&g.type==="mn"){g.children.push(...b.children);continue}else if(isNumberPunctuation(b)&&g.type==="mn"){g.children.push(...b.children);continue}else if(b.type==="mn"&&isNumberPunctuation(g))b.children=[...g.children,...b.children],m.pop();else if((b.type==="msup"||b.type==="msub")&&b.children.length>=1&&(g.type==="mn"||isNumberPunctuation(g))){var E=b.children[0];E instanceof MathNode&&E.type==="mn"&&(E.children=[...g.children,...E.children],m.pop())}else if(g.type==="mi"&&g.children.length===1){var C=g.children[0];if(C instanceof TextNode&&C.text==="̸"&&(b.type==="mo"||b.type==="mi"||b.type==="mn")){var w=b.children[0];w instanceof TextNode&&w.text.length>0&&(w.text=w.text.slice(0,1)+"̸"+w.text.slice(1),m.pop())}}}m.push(b),g=b}return m},buildExpressionRow=function(c,u,d){return makeRow(buildExpression(c,u,d))},buildGroup=function(c,u){if(!c)return new mathMLTree.MathNode("mrow");if(_mathmlGroupBuilders[c.type]){var d=_mathmlGroupBuilders[c.type](c,u);return d}else throw new ParseError("Got group of unknown type: '"+c.type+"'")};function buildMathML(a,c,u,d,f){var m=buildExpression(a,u),g;m.length===1&&m[0]instanceof MathNode&&utils.contains(["mrow","mtable"],m[0].type)?g=m[0]:g=new mathMLTree.MathNode("mrow",m);var y=new mathMLTree.MathNode("annotation",[new mathMLTree.TextNode(c)]);y.setAttribute("encoding","application/x-tex");var b=new mathMLTree.MathNode("semantics",[g,y]),E=new mathMLTree.MathNode("math",[b]);E.setAttribute("xmlns","http://www.w3.org/1998/Math/MathML"),d&&E.setAttribute("display","block");var C=f?"katex":"katex-mathml";return buildCommon.makeSpan([C],[E])}var optionsFromSettings=function(c){return new Options({style:c.displayMode?Style$1.DISPLAY:Style$1.TEXT,maxSize:c.maxSize,minRuleThickness:c.minRuleThickness})},displayWrap=function(c,u){if(u.displayMode){var d=["katex-display"];u.leqno&&d.push("leqno"),u.fleqn&&d.push("fleqn"),c=buildCommon.makeSpan(d,[c])}return c},buildTree=function(c,u,d){var f=optionsFromSettings(d),m;if(d.output==="mathml")return buildMathML(c,u,f,d.displayMode,!0);if(d.output==="html"){var g=buildHTML(c,f);m=buildCommon.makeSpan(["katex"],[g])}else{var y=buildMathML(c,u,f,d.displayMode,!1),b=buildHTML(c,f);m=buildCommon.makeSpan(["katex"],[y,b])}return displayWrap(m,d)},buildHTMLTree=function(c,u,d){var f=optionsFromSettings(d),m=buildHTML(c,f),g=buildCommon.makeSpan(["katex"],[m]);return displayWrap(g,d)},stretchyCodePoint={widehat:"^",widecheck:"ˇ",widetilde:"~",utilde:"~",overleftarrow:"←",underleftarrow:"←",xleftarrow:"←",overrightarrow:"→",underrightarrow:"→",xrightarrow:"→",underbrace:"⏟",overbrace:"⏞",overgroup:"⏠",undergroup:"⏡",overleftrightarrow:"↔",underleftrightarrow:"↔",xleftrightarrow:"↔",Overrightarrow:"⇒",xRightarrow:"⇒",overleftharpoon:"↼",xleftharpoonup:"↼",overrightharpoon:"⇀",xrightharpoonup:"⇀",xLeftarrow:"⇐",xLeftrightarrow:"⇔",xhookleftarrow:"↩",xhookrightarrow:"↪",xmapsto:"↦",xrightharpoondown:"⇁",xleftharpoondown:"↽",xrightleftharpoons:"⇌",xleftrightharpoons:"⇋",xtwoheadleftarrow:"↞",xtwoheadrightarrow:"↠",xlongequal:"=",xtofrom:"⇄",xrightleftarrows:"⇄",xrightequilibrium:"⇌",xleftequilibrium:"⇋","\\cdrightarrow":"→","\\cdleftarrow":"←","\\cdlongequal":"="},mathMLnode=function(c){var u=new mathMLTree.MathNode("mo",[new mathMLTree.TextNode(stretchyCodePoint[c.replace(/^\\/,"")])]);return u.setAttribute("stretchy","true"),u},katexImagesData={overrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],overleftarrow:[["leftarrow"],.888,522,"xMinYMin"],underrightarrow:[["rightarrow"],.888,522,"xMaxYMin"],underleftarrow:[["leftarrow"],.888,522,"xMinYMin"],xrightarrow:[["rightarrow"],1.469,522,"xMaxYMin"],"\\cdrightarrow":[["rightarrow"],3,522,"xMaxYMin"],xleftarrow:[["leftarrow"],1.469,522,"xMinYMin"],"\\cdleftarrow":[["leftarrow"],3,522,"xMinYMin"],Overrightarrow:[["doublerightarrow"],.888,560,"xMaxYMin"],xRightarrow:[["doublerightarrow"],1.526,560,"xMaxYMin"],xLeftarrow:[["doubleleftarrow"],1.526,560,"xMinYMin"],overleftharpoon:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoonup:[["leftharpoon"],.888,522,"xMinYMin"],xleftharpoondown:[["leftharpoondown"],.888,522,"xMinYMin"],overrightharpoon:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoonup:[["rightharpoon"],.888,522,"xMaxYMin"],xrightharpoondown:[["rightharpoondown"],.888,522,"xMaxYMin"],xlongequal:[["longequal"],.888,334,"xMinYMin"],"\\cdlongequal":[["longequal"],3,334,"xMinYMin"],xtwoheadleftarrow:[["twoheadleftarrow"],.888,334,"xMinYMin"],xtwoheadrightarrow:[["twoheadrightarrow"],.888,334,"xMaxYMin"],overleftrightarrow:[["leftarrow","rightarrow"],.888,522],overbrace:[["leftbrace","midbrace","rightbrace"],1.6,548],underbrace:[["leftbraceunder","midbraceunder","rightbraceunder"],1.6,548],underleftrightarrow:[["leftarrow","rightarrow"],.888,522],xleftrightarrow:[["leftarrow","rightarrow"],1.75,522],xLeftrightarrow:[["doubleleftarrow","doublerightarrow"],1.75,560],xrightleftharpoons:[["leftharpoondownplus","rightharpoonplus"],1.75,716],xleftrightharpoons:[["leftharpoonplus","rightharpoondownplus"],1.75,716],xhookleftarrow:[["leftarrow","righthook"],1.08,522],xhookrightarrow:[["lefthook","rightarrow"],1.08,522],overlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],underlinesegment:[["leftlinesegment","rightlinesegment"],.888,522],overgroup:[["leftgroup","rightgroup"],.888,342],undergroup:[["leftgroupunder","rightgroupunder"],.888,342],xmapsto:[["leftmapsto","rightarrow"],1.5,522],xtofrom:[["leftToFrom","rightToFrom"],1.75,528],xrightleftarrows:[["baraboveleftarrow","rightarrowabovebar"],1.75,901],xrightequilibrium:[["baraboveshortleftharpoon","rightharpoonaboveshortbar"],1.75,716],xleftequilibrium:[["shortbaraboveleftharpoon","shortrightharpoonabovebar"],1.75,716]},groupLength=function(c){return c.type==="ordgroup"?c.body.length:1},svgSpan=function(c,u){function d(){var y=4e5,b=c.label.slice(1);if(utils.contains(["widehat","widecheck","widetilde","utilde"],b)){var E=c,C=groupLength(E.base),w,R,_;if(C>5)b==="widehat"||b==="widecheck"?(w=420,y=2364,_=.42,R=b+"4"):(w=312,y=2340,_=.34,R="tilde4");else{var M=[1,1,2,2,3,3][C];b==="widehat"||b==="widecheck"?(y=[0,1062,2364,2364,2364][M],w=[0,239,300,360,420][M],_=[0,.24,.3,.3,.36,.42][M],R=b+M):(y=[0,600,1033,2339,2340][M],w=[0,260,286,306,312][M],_=[0,.26,.286,.3,.306,.34][M],R="tilde"+M)}var I=new PathNode(R),N=new SvgNode([I],{width:"100%",height:makeEm(_),viewBox:"0 0 "+y+" "+w,preserveAspectRatio:"none"});return{span:buildCommon.makeSvgSpan([],[N],u),minWidth:0,height:_}}else{var A=[],P=katexImagesData[b],[z,B,j]=P,L=j/1e3,U=z.length,q,F;if(U===1){var K=P[3];q=["hide-tail"],F=[K]}else if(U===2)q=["halfarrow-left","halfarrow-right"],F=["xMinYMin","xMaxYMin"];else if(U===3)q=["brace-left","brace-center","brace-right"],F=["xMinYMin","xMidYMin","xMaxYMin"];else throw new Error(`Correct katexImagesData or update code here to support
                    `+U+" children.");for(var X=0;X<U;X++){var Q=new PathNode(z[X]),Y=new SvgNode([Q],{width:"400em",height:makeEm(L),viewBox:"0 0 "+y+" "+j,preserveAspectRatio:F[X]+" slice"}),Z=buildCommon.makeSvgSpan([q[X]],[Y],u);if(U===1)return{span:Z,minWidth:B,height:L};Z.style.height=makeEm(L),A.push(Z)}return{span:buildCommon.makeSpan(["stretchy"],A,u),minWidth:B,height:L}}}var{span:f,minWidth:m,height:g}=d();return f.height=g,f.style.height=makeEm(g),m>0&&(f.style.minWidth=makeEm(m)),f},encloseSpan=function(c,u,d,f,m){var g,y=c.height+c.depth+d+f;if(/fbox|color|angl/.test(u)){if(g=buildCommon.makeSpan(["stretchy",u],[],m),u==="fbox"){var b=m.color&&m.getColor();b&&(g.style.borderColor=b)}}else{var E=[];/^[bx]cancel$/.test(u)&&E.push(new LineNode({x1:"0",y1:"0",x2:"100%",y2:"100%","stroke-width":"0.046em"})),/^x?cancel$/.test(u)&&E.push(new LineNode({x1:"0",y1:"100%",x2:"100%",y2:"0","stroke-width":"0.046em"}));var C=new SvgNode(E,{width:"100%",height:makeEm(y)});g=buildCommon.makeSvgSpan([],[C],m)}return g.height=y,g.style.height=makeEm(y),g},stretchy={encloseSpan,mathMLnode,svgSpan};function assertNodeType(a,c){if(!a||a.type!==c)throw new Error("Expected node of type "+c+", but got "+(a?"node of type "+a.type:String(a)));return a}function assertSymbolNodeType(a){var c=checkSymbolNodeType(a);if(!c)throw new Error("Expected node of symbol group type, but got "+(a?"node of type "+a.type:String(a)));return c}function checkSymbolNodeType(a){return a&&(a.type==="atom"||NON_ATOMS.hasOwnProperty(a.type))?a:null}var htmlBuilder$a=(a,c)=>{var u,d,f;a&&a.type==="supsub"?(d=assertNodeType(a.base,"accent"),u=d.base,a.base=u,f=assertSpan(buildGroup$1(a,c)),a.base=d):(d=assertNodeType(a,"accent"),u=d.base);var m=buildGroup$1(u,c.havingCrampedStyle()),g=d.isShifty&&utils.isCharacterBox(u),y=0;if(g){var b=utils.getBaseElem(u),E=buildGroup$1(b,c.havingCrampedStyle());y=assertSymbolDomNode(E).skew}var C=d.label==="\\c",w=C?m.height+m.depth:Math.min(m.height,c.fontMetrics().xHeight),R;if(d.isStretchy)R=stretchy.svgSpan(d,c),R=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:m},{type:"elem",elem:R,wrapperClasses:["svg-align"],wrapperStyle:y>0?{width:"calc(100% - "+makeEm(2*y)+")",marginLeft:makeEm(2*y)}:void 0}]},c);else{var _,M;d.label==="\\vec"?(_=buildCommon.staticSvg("vec",c),M=buildCommon.svgData.vec[1]):(_=buildCommon.makeOrd({mode:d.mode,text:d.label},c,"textord"),_=assertSymbolDomNode(_),_.italic=0,M=_.width,C&&(w+=_.depth)),R=buildCommon.makeSpan(["accent-body"],[_]);var I=d.label==="\\textcircled";I&&(R.classes.push("accent-full"),w=m.height);var N=y;I||(N-=M/2),R.style.left=makeEm(N),d.label==="\\textcircled"&&(R.style.top=".2em"),R=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:m},{type:"kern",size:-w},{type:"elem",elem:R}]},c)}var A=buildCommon.makeSpan(["mord","accent"],[R],c);return f?(f.children[0]=A,f.height=Math.max(A.height,f.height),f.classes[0]="mord",f):A},mathmlBuilder$9=(a,c)=>{var u=a.isStretchy?stretchy.mathMLnode(a.label):new mathMLTree.MathNode("mo",[makeText(a.label,a.mode)]),d=new mathMLTree.MathNode("mover",[buildGroup(a.base,c),u]);return d.setAttribute("accent","true"),d},NON_STRETCHY_ACCENT_REGEX=new RegExp(["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring"].map(a=>"\\"+a).join("|"));defineFunction({type:"accent",names:["\\acute","\\grave","\\ddot","\\tilde","\\bar","\\breve","\\check","\\hat","\\vec","\\dot","\\mathring","\\widecheck","\\widehat","\\widetilde","\\overrightarrow","\\overleftarrow","\\Overrightarrow","\\overleftrightarrow","\\overgroup","\\overlinesegment","\\overleftharpoon","\\overrightharpoon"],props:{numArgs:1},handler:(a,c)=>{var u=normalizeArgument(c[0]),d=!NON_STRETCHY_ACCENT_REGEX.test(a.funcName),f=!d||a.funcName==="\\widehat"||a.funcName==="\\widetilde"||a.funcName==="\\widecheck";return{type:"accent",mode:a.parser.mode,label:a.funcName,isStretchy:d,isShifty:f,base:u}},htmlBuilder:htmlBuilder$a,mathmlBuilder:mathmlBuilder$9});defineFunction({type:"accent",names:["\\'","\\`","\\^","\\~","\\=","\\u","\\.",'\\"',"\\c","\\r","\\H","\\v","\\textcircled"],props:{numArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["primitive"]},handler:(a,c)=>{var u=c[0],d=a.parser.mode;return d==="math"&&(a.parser.settings.reportNonstrict("mathVsTextAccents","LaTeX's accent "+a.funcName+" works only in text mode"),d="text"),{type:"accent",mode:d,label:a.funcName,isStretchy:!1,isShifty:!0,base:u}},htmlBuilder:htmlBuilder$a,mathmlBuilder:mathmlBuilder$9});defineFunction({type:"accentUnder",names:["\\underleftarrow","\\underrightarrow","\\underleftrightarrow","\\undergroup","\\underlinesegment","\\utilde"],props:{numArgs:1},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=c[0];return{type:"accentUnder",mode:u.mode,label:d,base:f}},htmlBuilder:(a,c)=>{var u=buildGroup$1(a.base,c),d=stretchy.svgSpan(a,c),f=a.label==="\\utilde"?.12:0,m=buildCommon.makeVList({positionType:"top",positionData:u.height,children:[{type:"elem",elem:d,wrapperClasses:["svg-align"]},{type:"kern",size:f},{type:"elem",elem:u}]},c);return buildCommon.makeSpan(["mord","accentunder"],[m],c)},mathmlBuilder:(a,c)=>{var u=stretchy.mathMLnode(a.label),d=new mathMLTree.MathNode("munder",[buildGroup(a.base,c),u]);return d.setAttribute("accentunder","true"),d}});var paddedNode=a=>{var c=new mathMLTree.MathNode("mpadded",a?[a]:[]);return c.setAttribute("width","+0.6em"),c.setAttribute("lspace","0.3em"),c};defineFunction({type:"xArrow",names:["\\xleftarrow","\\xrightarrow","\\xLeftarrow","\\xRightarrow","\\xleftrightarrow","\\xLeftrightarrow","\\xhookleftarrow","\\xhookrightarrow","\\xmapsto","\\xrightharpoondown","\\xrightharpoonup","\\xleftharpoondown","\\xleftharpoonup","\\xrightleftharpoons","\\xleftrightharpoons","\\xlongequal","\\xtwoheadrightarrow","\\xtwoheadleftarrow","\\xtofrom","\\xrightleftarrows","\\xrightequilibrium","\\xleftequilibrium","\\\\cdrightarrow","\\\\cdleftarrow","\\\\cdlongequal"],props:{numArgs:1,numOptionalArgs:1},handler(a,c,u){var{parser:d,funcName:f}=a;return{type:"xArrow",mode:d.mode,label:f,body:c[0],below:u[0]}},htmlBuilder(a,c){var u=c.style,d=c.havingStyle(u.sup()),f=buildCommon.wrapFragment(buildGroup$1(a.body,d,c),c),m=a.label.slice(0,2)==="\\x"?"x":"cd";f.classes.push(m+"-arrow-pad");var g;a.below&&(d=c.havingStyle(u.sub()),g=buildCommon.wrapFragment(buildGroup$1(a.below,d,c),c),g.classes.push(m+"-arrow-pad"));var y=stretchy.svgSpan(a,c),b=-c.fontMetrics().axisHeight+.5*y.height,E=-c.fontMetrics().axisHeight-.5*y.height-.111;(f.depth>.25||a.label==="\\xleftequilibrium")&&(E-=f.depth);var C;if(g){var w=-c.fontMetrics().axisHeight+g.height+.5*y.height+.111;C=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:f,shift:E},{type:"elem",elem:y,shift:b},{type:"elem",elem:g,shift:w}]},c)}else C=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:f,shift:E},{type:"elem",elem:y,shift:b}]},c);return C.children[0].children[0].children[1].classes.push("svg-align"),buildCommon.makeSpan(["mrel","x-arrow"],[C],c)},mathmlBuilder(a,c){var u=stretchy.mathMLnode(a.label);u.setAttribute("minsize",a.label.charAt(0)==="x"?"1.75em":"3.0em");var d;if(a.body){var f=paddedNode(buildGroup(a.body,c));if(a.below){var m=paddedNode(buildGroup(a.below,c));d=new mathMLTree.MathNode("munderover",[u,m,f])}else d=new mathMLTree.MathNode("mover",[u,f])}else if(a.below){var g=paddedNode(buildGroup(a.below,c));d=new mathMLTree.MathNode("munder",[u,g])}else d=paddedNode(),d=new mathMLTree.MathNode("mover",[u,d]);return d}});var makeSpan=buildCommon.makeSpan;function htmlBuilder$9(a,c){var u=buildExpression$1(a.body,c,!0);return makeSpan([a.mclass],u,c)}function mathmlBuilder$8(a,c){var u,d=buildExpression(a.body,c);return a.mclass==="minner"?u=new mathMLTree.MathNode("mpadded",d):a.mclass==="mord"?a.isCharacterBox?(u=d[0],u.type="mi"):u=new mathMLTree.MathNode("mi",d):(a.isCharacterBox?(u=d[0],u.type="mo"):u=new mathMLTree.MathNode("mo",d),a.mclass==="mbin"?(u.attributes.lspace="0.22em",u.attributes.rspace="0.22em"):a.mclass==="mpunct"?(u.attributes.lspace="0em",u.attributes.rspace="0.17em"):a.mclass==="mopen"||a.mclass==="mclose"?(u.attributes.lspace="0em",u.attributes.rspace="0em"):a.mclass==="minner"&&(u.attributes.lspace="0.0556em",u.attributes.width="+0.1111em")),u}defineFunction({type:"mclass",names:["\\mathord","\\mathbin","\\mathrel","\\mathopen","\\mathclose","\\mathpunct","\\mathinner"],props:{numArgs:1,primitive:!0},handler(a,c){var{parser:u,funcName:d}=a,f=c[0];return{type:"mclass",mode:u.mode,mclass:"m"+d.slice(5),body:ordargument(f),isCharacterBox:utils.isCharacterBox(f)}},htmlBuilder:htmlBuilder$9,mathmlBuilder:mathmlBuilder$8});var binrelClass=a=>{var c=a.type==="ordgroup"&&a.body.length?a.body[0]:a;return c.type==="atom"&&(c.family==="bin"||c.family==="rel")?"m"+c.family:"mord"};defineFunction({type:"mclass",names:["\\@binrel"],props:{numArgs:2},handler(a,c){var{parser:u}=a;return{type:"mclass",mode:u.mode,mclass:binrelClass(c[0]),body:ordargument(c[1]),isCharacterBox:utils.isCharacterBox(c[1])}}});defineFunction({type:"mclass",names:["\\stackrel","\\overset","\\underset"],props:{numArgs:2},handler(a,c){var{parser:u,funcName:d}=a,f=c[1],m=c[0],g;d!=="\\stackrel"?g=binrelClass(f):g="mrel";var y={type:"op",mode:f.mode,limits:!0,alwaysHandleSupSub:!0,parentIsSupSub:!1,symbol:!1,suppressBaseShift:d!=="\\stackrel",body:ordargument(f)},b={type:"supsub",mode:m.mode,base:y,sup:d==="\\underset"?null:m,sub:d==="\\underset"?m:null};return{type:"mclass",mode:u.mode,mclass:g,body:[b],isCharacterBox:utils.isCharacterBox(b)}},htmlBuilder:htmlBuilder$9,mathmlBuilder:mathmlBuilder$8});defineFunction({type:"pmb",names:["\\pmb"],props:{numArgs:1,allowedInText:!0},handler(a,c){var{parser:u}=a;return{type:"pmb",mode:u.mode,mclass:binrelClass(c[0]),body:ordargument(c[0])}},htmlBuilder(a,c){var u=buildExpression$1(a.body,c,!0),d=buildCommon.makeSpan([a.mclass],u,c);return d.style.textShadow="0.02em 0.01em 0.04px",d},mathmlBuilder(a,c){var u=buildExpression(a.body,c),d=new mathMLTree.MathNode("mstyle",u);return d.setAttribute("style","text-shadow: 0.02em 0.01em 0.04px"),d}});var cdArrowFunctionName={">":"\\\\cdrightarrow","<":"\\\\cdleftarrow","=":"\\\\cdlongequal",A:"\\uparrow",V:"\\downarrow","|":"\\Vert",".":"no arrow"},newCell=()=>({type:"styling",body:[],mode:"math",style:"display"}),isStartOfArrow=a=>a.type==="textord"&&a.text==="@",isLabelEnd=(a,c)=>(a.type==="mathord"||a.type==="atom")&&a.text===c;function cdArrow(a,c,u){var d=cdArrowFunctionName[a];switch(d){case"\\\\cdrightarrow":case"\\\\cdleftarrow":return u.callFunction(d,[c[0]],[c[1]]);case"\\uparrow":case"\\downarrow":{var f=u.callFunction("\\\\cdleft",[c[0]],[]),m={type:"atom",text:d,mode:"math",family:"rel"},g=u.callFunction("\\Big",[m],[]),y=u.callFunction("\\\\cdright",[c[1]],[]),b={type:"ordgroup",mode:"math",body:[f,g,y]};return u.callFunction("\\\\cdparent",[b],[])}case"\\\\cdlongequal":return u.callFunction("\\\\cdlongequal",[],[]);case"\\Vert":{var E={type:"textord",text:"\\Vert",mode:"math"};return u.callFunction("\\Big",[E],[])}default:return{type:"textord",text:" ",mode:"math"}}}function parseCD(a){var c=[];for(a.gullet.beginGroup(),a.gullet.macros.set("\\cr","\\\\\\relax"),a.gullet.beginGroup();;){c.push(a.parseExpression(!1,"\\\\")),a.gullet.endGroup(),a.gullet.beginGroup();var u=a.fetch().text;if(u==="&"||u==="\\\\")a.consume();else if(u==="\\end"){c[c.length-1].length===0&&c.pop();break}else throw new ParseError("Expected \\\\ or \\cr or \\end",a.nextToken)}for(var d=[],f=[d],m=0;m<c.length;m++){for(var g=c[m],y=newCell(),b=0;b<g.length;b++)if(!isStartOfArrow(g[b]))y.body.push(g[b]);else{d.push(y),b+=1;var E=assertSymbolNodeType(g[b]).text,C=new Array(2);if(C[0]={type:"ordgroup",mode:"math",body:[]},C[1]={type:"ordgroup",mode:"math",body:[]},!("=|.".indexOf(E)>-1))if("<>AV".indexOf(E)>-1)for(var w=0;w<2;w++){for(var R=!0,_=b+1;_<g.length;_++){if(isLabelEnd(g[_],E)){R=!1,b=_;break}if(isStartOfArrow(g[_]))throw new ParseError("Missing a "+E+" character to complete a CD arrow.",g[_]);C[w].body.push(g[_])}if(R)throw new ParseError("Missing a "+E+" character to complete a CD arrow.",g[b])}else throw new ParseError('Expected one of "<>AV=|." after @',g[b]);var M=cdArrow(E,C,a),I={type:"styling",body:[M],mode:"math",style:"display"};d.push(I),y=newCell()}m%2===0?d.push(y):d.shift(),d=[],f.push(d)}a.gullet.endGroup(),a.gullet.endGroup();var N=new Array(f[0].length).fill({type:"align",align:"c",pregap:.25,postgap:.25});return{type:"array",mode:"math",body:f,arraystretch:1,addJot:!0,rowGaps:[null],cols:N,colSeparationType:"CD",hLinesBeforeRow:new Array(f.length+1).fill([])}}defineFunction({type:"cdlabel",names:["\\\\cdleft","\\\\cdright"],props:{numArgs:1},handler(a,c){var{parser:u,funcName:d}=a;return{type:"cdlabel",mode:u.mode,side:d.slice(4),label:c[0]}},htmlBuilder(a,c){var u=c.havingStyle(c.style.sup()),d=buildCommon.wrapFragment(buildGroup$1(a.label,u,c),c);return d.classes.push("cd-label-"+a.side),d.style.bottom=makeEm(.8-d.depth),d.height=0,d.depth=0,d},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mrow",[buildGroup(a.label,c)]);return u=new mathMLTree.MathNode("mpadded",[u]),u.setAttribute("width","0"),a.side==="left"&&u.setAttribute("lspace","-1width"),u.setAttribute("voffset","0.7em"),u=new mathMLTree.MathNode("mstyle",[u]),u.setAttribute("displaystyle","false"),u.setAttribute("scriptlevel","1"),u}});defineFunction({type:"cdlabelparent",names:["\\\\cdparent"],props:{numArgs:1},handler(a,c){var{parser:u}=a;return{type:"cdlabelparent",mode:u.mode,fragment:c[0]}},htmlBuilder(a,c){var u=buildCommon.wrapFragment(buildGroup$1(a.fragment,c),c);return u.classes.push("cd-vert-arrow"),u},mathmlBuilder(a,c){return new mathMLTree.MathNode("mrow",[buildGroup(a.fragment,c)])}});defineFunction({type:"textord",names:["\\@char"],props:{numArgs:1,allowedInText:!0},handler(a,c){for(var{parser:u}=a,d=assertNodeType(c[0],"ordgroup"),f=d.body,m="",g=0;g<f.length;g++){var y=assertNodeType(f[g],"textord");m+=y.text}var b=parseInt(m),E;if(isNaN(b))throw new ParseError("\\@char has non-numeric argument "+m);if(b<0||b>=1114111)throw new ParseError("\\@char with invalid code point "+m);return b<=65535?E=String.fromCharCode(b):(b-=65536,E=String.fromCharCode((b>>10)+55296,(b&1023)+56320)),{type:"textord",mode:u.mode,text:E}}});var htmlBuilder$8=(a,c)=>{var u=buildExpression$1(a.body,c.withColor(a.color),!1);return buildCommon.makeFragment(u)},mathmlBuilder$7=(a,c)=>{var u=buildExpression(a.body,c.withColor(a.color)),d=new mathMLTree.MathNode("mstyle",u);return d.setAttribute("mathcolor",a.color),d};defineFunction({type:"color",names:["\\textcolor"],props:{numArgs:2,allowedInText:!0,argTypes:["color","original"]},handler(a,c){var{parser:u}=a,d=assertNodeType(c[0],"color-token").color,f=c[1];return{type:"color",mode:u.mode,color:d,body:ordargument(f)}},htmlBuilder:htmlBuilder$8,mathmlBuilder:mathmlBuilder$7});defineFunction({type:"color",names:["\\color"],props:{numArgs:1,allowedInText:!0,argTypes:["color"]},handler(a,c){var{parser:u,breakOnTokenText:d}=a,f=assertNodeType(c[0],"color-token").color;u.gullet.macros.set("\\current@color",f);var m=u.parseExpression(!0,d);return{type:"color",mode:u.mode,color:f,body:m}},htmlBuilder:htmlBuilder$8,mathmlBuilder:mathmlBuilder$7});defineFunction({type:"cr",names:["\\\\"],props:{numArgs:0,numOptionalArgs:0,allowedInText:!0},handler(a,c,u){var{parser:d}=a,f=d.gullet.future().text==="["?d.parseSizeGroup(!0):null,m=!d.settings.displayMode||!d.settings.useStrictBehavior("newLineInDisplayMode","In LaTeX, \\\\ or \\newline does nothing in display mode");return{type:"cr",mode:d.mode,newLine:m,size:f&&assertNodeType(f,"size").value}},htmlBuilder(a,c){var u=buildCommon.makeSpan(["mspace"],[],c);return a.newLine&&(u.classes.push("newline"),a.size&&(u.style.marginTop=makeEm(calculateSize(a.size,c)))),u},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mspace");return a.newLine&&(u.setAttribute("linebreak","newline"),a.size&&u.setAttribute("height",makeEm(calculateSize(a.size,c)))),u}});var globalMap={"\\global":"\\global","\\long":"\\\\globallong","\\\\globallong":"\\\\globallong","\\def":"\\gdef","\\gdef":"\\gdef","\\edef":"\\xdef","\\xdef":"\\xdef","\\let":"\\\\globallet","\\futurelet":"\\\\globalfuture"},checkControlSequence=a=>{var c=a.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(c))throw new ParseError("Expected a control sequence",a);return c},getRHS=a=>{var c=a.gullet.popToken();return c.text==="="&&(c=a.gullet.popToken(),c.text===" "&&(c=a.gullet.popToken())),c},letCommand=(a,c,u,d)=>{var f=a.gullet.macros.get(u.text);f==null&&(u.noexpand=!0,f={tokens:[u],numArgs:0,unexpandable:!a.gullet.isExpandable(u.text)}),a.gullet.macros.set(c,f,d)};defineFunction({type:"internal",names:["\\global","\\long","\\\\globallong"],props:{numArgs:0,allowedInText:!0},handler(a){var{parser:c,funcName:u}=a;c.consumeSpaces();var d=c.fetch();if(globalMap[d.text])return(u==="\\global"||u==="\\\\globallong")&&(d.text=globalMap[d.text]),assertNodeType(c.parseFunction(),"internal");throw new ParseError("Invalid token after macro prefix",d)}});defineFunction({type:"internal",names:["\\def","\\gdef","\\edef","\\xdef"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(a){var{parser:c,funcName:u}=a,d=c.gullet.popToken(),f=d.text;if(/^(?:[\\{}$&#^_]|EOF)$/.test(f))throw new ParseError("Expected a control sequence",d);for(var m=0,g,y=[[]];c.gullet.future().text!=="{";)if(d=c.gullet.popToken(),d.text==="#"){if(c.gullet.future().text==="{"){g=c.gullet.future(),y[m].push("{");break}if(d=c.gullet.popToken(),!/^[1-9]$/.test(d.text))throw new ParseError('Invalid argument number "'+d.text+'"');if(parseInt(d.text)!==m+1)throw new ParseError('Argument number "'+d.text+'" out of order');m++,y.push([])}else{if(d.text==="EOF")throw new ParseError("Expected a macro definition");y[m].push(d.text)}var{tokens:b}=c.gullet.consumeArg();return g&&b.unshift(g),(u==="\\edef"||u==="\\xdef")&&(b=c.gullet.expandTokens(b),b.reverse()),c.gullet.macros.set(f,{tokens:b,numArgs:m,delimiters:y},u===globalMap[u]),{type:"internal",mode:c.mode}}});defineFunction({type:"internal",names:["\\let","\\\\globallet"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(a){var{parser:c,funcName:u}=a,d=checkControlSequence(c.gullet.popToken());c.gullet.consumeSpaces();var f=getRHS(c);return letCommand(c,d,f,u==="\\\\globallet"),{type:"internal",mode:c.mode}}});defineFunction({type:"internal",names:["\\futurelet","\\\\globalfuture"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(a){var{parser:c,funcName:u}=a,d=checkControlSequence(c.gullet.popToken()),f=c.gullet.popToken(),m=c.gullet.popToken();return letCommand(c,d,m,u==="\\\\globalfuture"),c.gullet.pushToken(m),c.gullet.pushToken(f),{type:"internal",mode:c.mode}}});var getMetrics=function(c,u,d){var f=symbols.math[c]&&symbols.math[c].replace,m=getCharacterMetrics(f||c,u,d);if(!m)throw new Error("Unsupported symbol "+c+" and font size "+u+".");return m},styleWrap=function(c,u,d,f){var m=d.havingBaseStyle(u),g=buildCommon.makeSpan(f.concat(m.sizingClasses(d)),[c],d),y=m.sizeMultiplier/d.sizeMultiplier;return g.height*=y,g.depth*=y,g.maxFontSize=m.sizeMultiplier,g},centerSpan=function(c,u,d){var f=u.havingBaseStyle(d),m=(1-u.sizeMultiplier/f.sizeMultiplier)*u.fontMetrics().axisHeight;c.classes.push("delimcenter"),c.style.top=makeEm(m),c.height-=m,c.depth+=m},makeSmallDelim=function(c,u,d,f,m,g){var y=buildCommon.makeSymbol(c,"Main-Regular",m,f),b=styleWrap(y,u,f,g);return d&&centerSpan(b,f,u),b},mathrmSize=function(c,u,d,f){return buildCommon.makeSymbol(c,"Size"+u+"-Regular",d,f)},makeLargeDelim=function(c,u,d,f,m,g){var y=mathrmSize(c,u,m,f),b=styleWrap(buildCommon.makeSpan(["delimsizing","size"+u],[y],f),Style$1.TEXT,f,g);return d&&centerSpan(b,f,Style$1.TEXT),b},makeGlyphSpan=function(c,u,d){var f;u==="Size1-Regular"?f="delim-size1":f="delim-size4";var m=buildCommon.makeSpan(["delimsizinginner",f],[buildCommon.makeSpan([],[buildCommon.makeSymbol(c,u,d)])]);return{type:"elem",elem:m}},makeInner=function(c,u,d){var f=fontMetricsData["Size4-Regular"][c.charCodeAt(0)]?fontMetricsData["Size4-Regular"][c.charCodeAt(0)][4]:fontMetricsData["Size1-Regular"][c.charCodeAt(0)][4],m=new PathNode("inner",innerPath(c,Math.round(1e3*u))),g=new SvgNode([m],{width:makeEm(f),height:makeEm(u),style:"width:"+makeEm(f),viewBox:"0 0 "+1e3*f+" "+Math.round(1e3*u),preserveAspectRatio:"xMinYMin"}),y=buildCommon.makeSvgSpan([],[g],d);return y.height=u,y.style.height=makeEm(u),y.style.width=makeEm(f),{type:"elem",elem:y}},lapInEms=.008,lap={type:"kern",size:-1*lapInEms},verts=["|","\\lvert","\\rvert","\\vert"],doubleVerts=["\\|","\\lVert","\\rVert","\\Vert"],makeStackedDelim=function(c,u,d,f,m,g){var y,b,E,C,w="",R=0;y=E=C=c,b=null;var _="Size1-Regular";c==="\\uparrow"?E=C="⏐":c==="\\Uparrow"?E=C="‖":c==="\\downarrow"?y=E="⏐":c==="\\Downarrow"?y=E="‖":c==="\\updownarrow"?(y="\\uparrow",E="⏐",C="\\downarrow"):c==="\\Updownarrow"?(y="\\Uparrow",E="‖",C="\\Downarrow"):utils.contains(verts,c)?(E="∣",w="vert",R=333):utils.contains(doubleVerts,c)?(E="∥",w="doublevert",R=556):c==="["||c==="\\lbrack"?(y="⎡",E="⎢",C="⎣",_="Size4-Regular",w="lbrack",R=667):c==="]"||c==="\\rbrack"?(y="⎤",E="⎥",C="⎦",_="Size4-Regular",w="rbrack",R=667):c==="\\lfloor"||c==="⌊"?(E=y="⎢",C="⎣",_="Size4-Regular",w="lfloor",R=667):c==="\\lceil"||c==="⌈"?(y="⎡",E=C="⎢",_="Size4-Regular",w="lceil",R=667):c==="\\rfloor"||c==="⌋"?(E=y="⎥",C="⎦",_="Size4-Regular",w="rfloor",R=667):c==="\\rceil"||c==="⌉"?(y="⎤",E=C="⎥",_="Size4-Regular",w="rceil",R=667):c==="("||c==="\\lparen"?(y="⎛",E="⎜",C="⎝",_="Size4-Regular",w="lparen",R=875):c===")"||c==="\\rparen"?(y="⎞",E="⎟",C="⎠",_="Size4-Regular",w="rparen",R=875):c==="\\{"||c==="\\lbrace"?(y="⎧",b="⎨",C="⎩",E="⎪",_="Size4-Regular"):c==="\\}"||c==="\\rbrace"?(y="⎫",b="⎬",C="⎭",E="⎪",_="Size4-Regular"):c==="\\lgroup"||c==="⟮"?(y="⎧",C="⎩",E="⎪",_="Size4-Regular"):c==="\\rgroup"||c==="⟯"?(y="⎫",C="⎭",E="⎪",_="Size4-Regular"):c==="\\lmoustache"||c==="⎰"?(y="⎧",C="⎭",E="⎪",_="Size4-Regular"):(c==="\\rmoustache"||c==="⎱")&&(y="⎫",C="⎩",E="⎪",_="Size4-Regular");var M=getMetrics(y,_,m),I=M.height+M.depth,N=getMetrics(E,_,m),A=N.height+N.depth,P=getMetrics(C,_,m),z=P.height+P.depth,B=0,j=1;if(b!==null){var L=getMetrics(b,_,m);B=L.height+L.depth,j=2}var U=I+z+B,q=Math.max(0,Math.ceil((u-U)/(j*A))),F=U+q*j*A,K=f.fontMetrics().axisHeight;d&&(K*=f.sizeMultiplier);var X=F/2-K,Q=[];if(w.length>0){var Y=F-I-z,Z=Math.round(F*1e3),J=tallDelim(w,Math.round(Y*1e3)),W=new PathNode(w,J),G=(R/1e3).toFixed(3)+"em",te=(Z/1e3).toFixed(3)+"em",ae=new SvgNode([W],{width:G,height:te,viewBox:"0 0 "+R+" "+Z}),V=buildCommon.makeSvgSpan([],[ae],f);V.height=Z/1e3,V.style.width=G,V.style.height=te,Q.push({type:"elem",elem:V})}else{if(Q.push(makeGlyphSpan(C,_,m)),Q.push(lap),b===null){var ne=F-I-z+2*lapInEms;Q.push(makeInner(E,ne,f))}else{var le=(F-I-z-B)/2+2*lapInEms;Q.push(makeInner(E,le,f)),Q.push(lap),Q.push(makeGlyphSpan(b,_,m)),Q.push(lap),Q.push(makeInner(E,le,f))}Q.push(lap),Q.push(makeGlyphSpan(y,_,m))}var ee=f.havingBaseStyle(Style$1.TEXT),ie=buildCommon.makeVList({positionType:"bottom",positionData:X,children:Q},ee);return styleWrap(buildCommon.makeSpan(["delimsizing","mult"],[ie],ee),Style$1.TEXT,f,g)},vbPad=80,emPad=.08,sqrtSvg=function(c,u,d,f,m){var g=sqrtPath(c,f,d),y=new PathNode(c,g),b=new SvgNode([y],{width:"400em",height:makeEm(u),viewBox:"0 0 400000 "+d,preserveAspectRatio:"xMinYMin slice"});return buildCommon.makeSvgSpan(["hide-tail"],[b],m)},makeSqrtImage=function(c,u){var d=u.havingBaseSizing(),f=traverseSequence("\\surd",c*d.sizeMultiplier,stackLargeDelimiterSequence,d),m=d.sizeMultiplier,g=Math.max(0,u.minRuleThickness-u.fontMetrics().sqrtRuleThickness),y,b=0,E=0,C=0,w;return f.type==="small"?(C=1e3+1e3*g+vbPad,c<1?m=1:c<1.4&&(m=.7),b=(1+g+emPad)/m,E=(1+g)/m,y=sqrtSvg("sqrtMain",b,C,g,u),y.style.minWidth="0.853em",w=.833/m):f.type==="large"?(C=(1e3+vbPad)*sizeToMaxHeight[f.size],E=(sizeToMaxHeight[f.size]+g)/m,b=(sizeToMaxHeight[f.size]+g+emPad)/m,y=sqrtSvg("sqrtSize"+f.size,b,C,g,u),y.style.minWidth="1.02em",w=1/m):(b=c+g+emPad,E=c+g,C=Math.floor(1e3*c+g)+vbPad,y=sqrtSvg("sqrtTall",b,C,g,u),y.style.minWidth="0.742em",w=1.056),y.height=E,y.style.height=makeEm(b),{span:y,advanceWidth:w,ruleWidth:(u.fontMetrics().sqrtRuleThickness+g)*m}},stackLargeDelimiters=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","\\surd"],stackAlwaysDelimiters=["\\uparrow","\\downarrow","\\updownarrow","\\Uparrow","\\Downarrow","\\Updownarrow","|","\\|","\\vert","\\Vert","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱"],stackNeverDelimiters=["<",">","\\langle","\\rangle","/","\\backslash","\\lt","\\gt"],sizeToMaxHeight=[0,1.2,1.8,2.4,3],makeSizedDelim=function(c,u,d,f,m){if(c==="<"||c==="\\lt"||c==="⟨"?c="\\langle":(c===">"||c==="\\gt"||c==="⟩")&&(c="\\rangle"),utils.contains(stackLargeDelimiters,c)||utils.contains(stackNeverDelimiters,c))return makeLargeDelim(c,u,!1,d,f,m);if(utils.contains(stackAlwaysDelimiters,c))return makeStackedDelim(c,sizeToMaxHeight[u],!1,d,f,m);throw new ParseError("Illegal delimiter: '"+c+"'")},stackNeverDelimiterSequence=[{type:"small",style:Style$1.SCRIPTSCRIPT},{type:"small",style:Style$1.SCRIPT},{type:"small",style:Style$1.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4}],stackAlwaysDelimiterSequence=[{type:"small",style:Style$1.SCRIPTSCRIPT},{type:"small",style:Style$1.SCRIPT},{type:"small",style:Style$1.TEXT},{type:"stack"}],stackLargeDelimiterSequence=[{type:"small",style:Style$1.SCRIPTSCRIPT},{type:"small",style:Style$1.SCRIPT},{type:"small",style:Style$1.TEXT},{type:"large",size:1},{type:"large",size:2},{type:"large",size:3},{type:"large",size:4},{type:"stack"}],delimTypeToFont=function(c){if(c.type==="small")return"Main-Regular";if(c.type==="large")return"Size"+c.size+"-Regular";if(c.type==="stack")return"Size4-Regular";throw new Error("Add support for delim type '"+c.type+"' here.")},traverseSequence=function(c,u,d,f){for(var m=Math.min(2,3-f.style.size),g=m;g<d.length&&d[g].type!=="stack";g++){var y=getMetrics(c,delimTypeToFont(d[g]),"math"),b=y.height+y.depth;if(d[g].type==="small"){var E=f.havingBaseStyle(d[g].style);b*=E.sizeMultiplier}if(b>u)return d[g]}return d[d.length-1]},makeCustomSizedDelim=function(c,u,d,f,m,g){c==="<"||c==="\\lt"||c==="⟨"?c="\\langle":(c===">"||c==="\\gt"||c==="⟩")&&(c="\\rangle");var y;utils.contains(stackNeverDelimiters,c)?y=stackNeverDelimiterSequence:utils.contains(stackLargeDelimiters,c)?y=stackLargeDelimiterSequence:y=stackAlwaysDelimiterSequence;var b=traverseSequence(c,u,y,f);return b.type==="small"?makeSmallDelim(c,b.style,d,f,m,g):b.type==="large"?makeLargeDelim(c,b.size,d,f,m,g):makeStackedDelim(c,u,d,f,m,g)},makeLeftRightDelim=function(c,u,d,f,m,g){var y=f.fontMetrics().axisHeight*f.sizeMultiplier,b=901,E=5/f.fontMetrics().ptPerEm,C=Math.max(u-y,d+y),w=Math.max(C/500*b,2*C-E);return makeCustomSizedDelim(c,w,!0,f,m,g)},delimiter={sqrtImage:makeSqrtImage,sizedDelim:makeSizedDelim,sizeToMaxHeight,customSizedDelim:makeCustomSizedDelim,leftRightDelim:makeLeftRightDelim},delimiterSizes={"\\bigl":{mclass:"mopen",size:1},"\\Bigl":{mclass:"mopen",size:2},"\\biggl":{mclass:"mopen",size:3},"\\Biggl":{mclass:"mopen",size:4},"\\bigr":{mclass:"mclose",size:1},"\\Bigr":{mclass:"mclose",size:2},"\\biggr":{mclass:"mclose",size:3},"\\Biggr":{mclass:"mclose",size:4},"\\bigm":{mclass:"mrel",size:1},"\\Bigm":{mclass:"mrel",size:2},"\\biggm":{mclass:"mrel",size:3},"\\Biggm":{mclass:"mrel",size:4},"\\big":{mclass:"mord",size:1},"\\Big":{mclass:"mord",size:2},"\\bigg":{mclass:"mord",size:3},"\\Bigg":{mclass:"mord",size:4}},delimiters=["(","\\lparen",")","\\rparen","[","\\lbrack","]","\\rbrack","\\{","\\lbrace","\\}","\\rbrace","\\lfloor","\\rfloor","⌊","⌋","\\lceil","\\rceil","⌈","⌉","<",">","\\langle","⟨","\\rangle","⟩","\\lt","\\gt","\\lvert","\\rvert","\\lVert","\\rVert","\\lgroup","\\rgroup","⟮","⟯","\\lmoustache","\\rmoustache","⎰","⎱","/","\\backslash","|","\\vert","\\|","\\Vert","\\uparrow","\\Uparrow","\\downarrow","\\Downarrow","\\updownarrow","\\Updownarrow","."];function checkDelimiter(a,c){var u=checkSymbolNodeType(a);if(u&&utils.contains(delimiters,u.text))return u;throw u?new ParseError("Invalid delimiter '"+u.text+"' after '"+c.funcName+"'",a):new ParseError("Invalid delimiter type '"+a.type+"'",a)}defineFunction({type:"delimsizing",names:["\\bigl","\\Bigl","\\biggl","\\Biggl","\\bigr","\\Bigr","\\biggr","\\Biggr","\\bigm","\\Bigm","\\biggm","\\Biggm","\\big","\\Big","\\bigg","\\Bigg"],props:{numArgs:1,argTypes:["primitive"]},handler:(a,c)=>{var u=checkDelimiter(c[0],a);return{type:"delimsizing",mode:a.parser.mode,size:delimiterSizes[a.funcName].size,mclass:delimiterSizes[a.funcName].mclass,delim:u.text}},htmlBuilder:(a,c)=>a.delim==="."?buildCommon.makeSpan([a.mclass]):delimiter.sizedDelim(a.delim,a.size,c,a.mode,[a.mclass]),mathmlBuilder:a=>{var c=[];a.delim!=="."&&c.push(makeText(a.delim,a.mode));var u=new mathMLTree.MathNode("mo",c);a.mclass==="mopen"||a.mclass==="mclose"?u.setAttribute("fence","true"):u.setAttribute("fence","false"),u.setAttribute("stretchy","true");var d=makeEm(delimiter.sizeToMaxHeight[a.size]);return u.setAttribute("minsize",d),u.setAttribute("maxsize",d),u}});function assertParsed(a){if(!a.body)throw new Error("Bug: The leftright ParseNode wasn't fully parsed.")}defineFunction({type:"leftright-right",names:["\\right"],props:{numArgs:1,primitive:!0},handler:(a,c)=>{var u=a.parser.gullet.macros.get("\\current@color");if(u&&typeof u!="string")throw new ParseError("\\current@color set to non-string in \\right");return{type:"leftright-right",mode:a.parser.mode,delim:checkDelimiter(c[0],a).text,color:u}}});defineFunction({type:"leftright",names:["\\left"],props:{numArgs:1,primitive:!0},handler:(a,c)=>{var u=checkDelimiter(c[0],a),d=a.parser;++d.leftrightDepth;var f=d.parseExpression(!1);--d.leftrightDepth,d.expect("\\right",!1);var m=assertNodeType(d.parseFunction(),"leftright-right");return{type:"leftright",mode:d.mode,body:f,left:u.text,right:m.delim,rightColor:m.color}},htmlBuilder:(a,c)=>{assertParsed(a);for(var u=buildExpression$1(a.body,c,!0,["mopen","mclose"]),d=0,f=0,m=!1,g=0;g<u.length;g++)u[g].isMiddle?m=!0:(d=Math.max(u[g].height,d),f=Math.max(u[g].depth,f));d*=c.sizeMultiplier,f*=c.sizeMultiplier;var y;if(a.left==="."?y=makeNullDelimiter(c,["mopen"]):y=delimiter.leftRightDelim(a.left,d,f,c,a.mode,["mopen"]),u.unshift(y),m)for(var b=1;b<u.length;b++){var E=u[b],C=E.isMiddle;C&&(u[b]=delimiter.leftRightDelim(C.delim,d,f,C.options,a.mode,[]))}var w;if(a.right===".")w=makeNullDelimiter(c,["mclose"]);else{var R=a.rightColor?c.withColor(a.rightColor):c;w=delimiter.leftRightDelim(a.right,d,f,R,a.mode,["mclose"])}return u.push(w),buildCommon.makeSpan(["minner"],u,c)},mathmlBuilder:(a,c)=>{assertParsed(a);var u=buildExpression(a.body,c);if(a.left!=="."){var d=new mathMLTree.MathNode("mo",[makeText(a.left,a.mode)]);d.setAttribute("fence","true"),u.unshift(d)}if(a.right!=="."){var f=new mathMLTree.MathNode("mo",[makeText(a.right,a.mode)]);f.setAttribute("fence","true"),a.rightColor&&f.setAttribute("mathcolor",a.rightColor),u.push(f)}return makeRow(u)}});defineFunction({type:"middle",names:["\\middle"],props:{numArgs:1,primitive:!0},handler:(a,c)=>{var u=checkDelimiter(c[0],a);if(!a.parser.leftrightDepth)throw new ParseError("\\middle without preceding \\left",u);return{type:"middle",mode:a.parser.mode,delim:u.text}},htmlBuilder:(a,c)=>{var u;if(a.delim===".")u=makeNullDelimiter(c,[]);else{u=delimiter.sizedDelim(a.delim,1,c,a.mode,[]);var d={delim:a.delim,options:c};u.isMiddle=d}return u},mathmlBuilder:(a,c)=>{var u=a.delim==="\\vert"||a.delim==="|"?makeText("|","text"):makeText(a.delim,a.mode),d=new mathMLTree.MathNode("mo",[u]);return d.setAttribute("fence","true"),d.setAttribute("lspace","0.05em"),d.setAttribute("rspace","0.05em"),d}});var htmlBuilder$7=(a,c)=>{var u=buildCommon.wrapFragment(buildGroup$1(a.body,c),c),d=a.label.slice(1),f=c.sizeMultiplier,m,g=0,y=utils.isCharacterBox(a.body);if(d==="sout")m=buildCommon.makeSpan(["stretchy","sout"]),m.height=c.fontMetrics().defaultRuleThickness/f,g=-.5*c.fontMetrics().xHeight;else if(d==="phase"){var b=calculateSize({number:.6,unit:"pt"},c),E=calculateSize({number:.35,unit:"ex"},c),C=c.havingBaseSizing();f=f/C.sizeMultiplier;var w=u.height+u.depth+b+E;u.style.paddingLeft=makeEm(w/2+b);var R=Math.floor(1e3*w*f),_=phasePath(R),M=new SvgNode([new PathNode("phase",_)],{width:"400em",height:makeEm(R/1e3),viewBox:"0 0 400000 "+R,preserveAspectRatio:"xMinYMin slice"});m=buildCommon.makeSvgSpan(["hide-tail"],[M],c),m.style.height=makeEm(w),g=u.depth+b+E}else{/cancel/.test(d)?y||u.classes.push("cancel-pad"):d==="angl"?u.classes.push("anglpad"):u.classes.push("boxpad");var I=0,N=0,A=0;/box/.test(d)?(A=Math.max(c.fontMetrics().fboxrule,c.minRuleThickness),I=c.fontMetrics().fboxsep+(d==="colorbox"?0:A),N=I):d==="angl"?(A=Math.max(c.fontMetrics().defaultRuleThickness,c.minRuleThickness),I=4*A,N=Math.max(0,.25-u.depth)):(I=y?.2:0,N=I),m=stretchy.encloseSpan(u,d,I,N,c),/fbox|boxed|fcolorbox/.test(d)?(m.style.borderStyle="solid",m.style.borderWidth=makeEm(A)):d==="angl"&&A!==.049&&(m.style.borderTopWidth=makeEm(A),m.style.borderRightWidth=makeEm(A)),g=u.depth+N,a.backgroundColor&&(m.style.backgroundColor=a.backgroundColor,a.borderColor&&(m.style.borderColor=a.borderColor))}var P;if(a.backgroundColor)P=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:m,shift:g},{type:"elem",elem:u,shift:0}]},c);else{var z=/cancel|phase/.test(d)?["svg-align"]:[];P=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:u,shift:0},{type:"elem",elem:m,shift:g,wrapperClasses:z}]},c)}return/cancel/.test(d)&&(P.height=u.height,P.depth=u.depth),/cancel/.test(d)&&!y?buildCommon.makeSpan(["mord","cancel-lap"],[P],c):buildCommon.makeSpan(["mord"],[P],c)},mathmlBuilder$6=(a,c)=>{var u=0,d=new mathMLTree.MathNode(a.label.indexOf("colorbox")>-1?"mpadded":"menclose",[buildGroup(a.body,c)]);switch(a.label){case"\\cancel":d.setAttribute("notation","updiagonalstrike");break;case"\\bcancel":d.setAttribute("notation","downdiagonalstrike");break;case"\\phase":d.setAttribute("notation","phasorangle");break;case"\\sout":d.setAttribute("notation","horizontalstrike");break;case"\\fbox":d.setAttribute("notation","box");break;case"\\angl":d.setAttribute("notation","actuarial");break;case"\\fcolorbox":case"\\colorbox":if(u=c.fontMetrics().fboxsep*c.fontMetrics().ptPerEm,d.setAttribute("width","+"+2*u+"pt"),d.setAttribute("height","+"+2*u+"pt"),d.setAttribute("lspace",u+"pt"),d.setAttribute("voffset",u+"pt"),a.label==="\\fcolorbox"){var f=Math.max(c.fontMetrics().fboxrule,c.minRuleThickness);d.setAttribute("style","border: "+f+"em solid "+String(a.borderColor))}break;case"\\xcancel":d.setAttribute("notation","updiagonalstrike downdiagonalstrike");break}return a.backgroundColor&&d.setAttribute("mathbackground",a.backgroundColor),d};defineFunction({type:"enclose",names:["\\colorbox"],props:{numArgs:2,allowedInText:!0,argTypes:["color","text"]},handler(a,c,u){var{parser:d,funcName:f}=a,m=assertNodeType(c[0],"color-token").color,g=c[1];return{type:"enclose",mode:d.mode,label:f,backgroundColor:m,body:g}},htmlBuilder:htmlBuilder$7,mathmlBuilder:mathmlBuilder$6});defineFunction({type:"enclose",names:["\\fcolorbox"],props:{numArgs:3,allowedInText:!0,argTypes:["color","color","text"]},handler(a,c,u){var{parser:d,funcName:f}=a,m=assertNodeType(c[0],"color-token").color,g=assertNodeType(c[1],"color-token").color,y=c[2];return{type:"enclose",mode:d.mode,label:f,backgroundColor:g,borderColor:m,body:y}},htmlBuilder:htmlBuilder$7,mathmlBuilder:mathmlBuilder$6});defineFunction({type:"enclose",names:["\\fbox"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!0},handler(a,c){var{parser:u}=a;return{type:"enclose",mode:u.mode,label:"\\fbox",body:c[0]}}});defineFunction({type:"enclose",names:["\\cancel","\\bcancel","\\xcancel","\\sout","\\phase"],props:{numArgs:1},handler(a,c){var{parser:u,funcName:d}=a,f=c[0];return{type:"enclose",mode:u.mode,label:d,body:f}},htmlBuilder:htmlBuilder$7,mathmlBuilder:mathmlBuilder$6});defineFunction({type:"enclose",names:["\\angl"],props:{numArgs:1,argTypes:["hbox"],allowedInText:!1},handler(a,c){var{parser:u}=a;return{type:"enclose",mode:u.mode,label:"\\angl",body:c[0]}}});var _environments={};function defineEnvironment(a){for(var{type:c,names:u,props:d,handler:f,htmlBuilder:m,mathmlBuilder:g}=a,y={type:c,numArgs:d.numArgs||0,allowedInText:!1,numOptionalArgs:0,handler:f},b=0;b<u.length;++b)_environments[u[b]]=y;m&&(_htmlGroupBuilders[c]=m),g&&(_mathmlGroupBuilders[c]=g)}var _macros={};function defineMacro(a,c){_macros[a]=c}function getHLines(a){var c=[];a.consumeSpaces();var u=a.fetch().text;for(u==="\\relax"&&(a.consume(),a.consumeSpaces(),u=a.fetch().text);u==="\\hline"||u==="\\hdashline";)a.consume(),c.push(u==="\\hdashline"),a.consumeSpaces(),u=a.fetch().text;return c}var validateAmsEnvironmentContext=a=>{var c=a.parser.settings;if(!c.displayMode)throw new ParseError("{"+a.envName+"} can be used only in display mode.")};function getAutoTag(a){if(a.indexOf("ed")===-1)return a.indexOf("*")===-1}function parseArray(a,c,u){var{hskipBeforeAndAfter:d,addJot:f,cols:m,arraystretch:g,colSeparationType:y,autoTag:b,singleRow:E,emptySingleRow:C,maxNumCols:w,leqno:R}=c;if(a.gullet.beginGroup(),E||a.gullet.macros.set("\\cr","\\\\\\relax"),!g){var _=a.gullet.expandMacroAsText("\\arraystretch");if(_==null)g=1;else if(g=parseFloat(_),!g||g<0)throw new ParseError("Invalid \\arraystretch: "+_)}a.gullet.beginGroup();var M=[],I=[M],N=[],A=[],P=b!=null?[]:void 0;function z(){b&&a.gullet.macros.set("\\@eqnsw","1",!0)}function B(){P&&(a.gullet.macros.get("\\df@tag")?(P.push(a.subparse([new Token("\\df@tag")])),a.gullet.macros.set("\\df@tag",void 0,!0)):P.push(!!b&&a.gullet.macros.get("\\@eqnsw")==="1"))}for(z(),A.push(getHLines(a));;){var j=a.parseExpression(!1,E?"\\end":"\\\\");a.gullet.endGroup(),a.gullet.beginGroup(),j={type:"ordgroup",mode:a.mode,body:j},u&&(j={type:"styling",mode:a.mode,style:u,body:[j]}),M.push(j);var L=a.fetch().text;if(L==="&"){if(w&&M.length===w){if(E||y)throw new ParseError("Too many tab characters: &",a.nextToken);a.settings.reportNonstrict("textEnv","Too few columns specified in the {array} column argument.")}a.consume()}else if(L==="\\end"){B(),M.length===1&&j.type==="styling"&&j.body[0].body.length===0&&(I.length>1||!C)&&I.pop(),A.length<I.length+1&&A.push([]);break}else if(L==="\\\\"){a.consume();var U=void 0;a.gullet.future().text!==" "&&(U=a.parseSizeGroup(!0)),N.push(U?U.value:null),B(),A.push(getHLines(a)),M=[],I.push(M),z()}else throw new ParseError("Expected & or \\\\ or \\cr or \\end",a.nextToken)}return a.gullet.endGroup(),a.gullet.endGroup(),{type:"array",mode:a.mode,addJot:f,arraystretch:g,body:I,cols:m,rowGaps:N,hskipBeforeAndAfter:d,hLinesBeforeRow:A,colSeparationType:y,tags:P,leqno:R}}function dCellStyle(a){return a.slice(0,1)==="d"?"display":"text"}var htmlBuilder$6=function(c,u){var d,f,m=c.body.length,g=c.hLinesBeforeRow,y=0,b=new Array(m),E=[],C=Math.max(u.fontMetrics().arrayRuleWidth,u.minRuleThickness),w=1/u.fontMetrics().ptPerEm,R=5*w;if(c.colSeparationType&&c.colSeparationType==="small"){var _=u.havingStyle(Style$1.SCRIPT).sizeMultiplier;R=.2778*(_/u.sizeMultiplier)}var M=c.colSeparationType==="CD"?calculateSize({number:3,unit:"ex"},u):12*w,I=3*w,N=c.arraystretch*M,A=.7*N,P=.3*N,z=0;function B(Re){for(var De=0;De<Re.length;++De)De>0&&(z+=.25),E.push({pos:z,isDashed:Re[De]})}for(B(g[0]),d=0;d<c.body.length;++d){var j=c.body[d],L=A,U=P;y<j.length&&(y=j.length);var q=new Array(j.length);for(f=0;f<j.length;++f){var F=buildGroup$1(j[f],u);U<F.depth&&(U=F.depth),L<F.height&&(L=F.height),q[f]=F}var K=c.rowGaps[d],X=0;K&&(X=calculateSize(K,u),X>0&&(X+=P,U<X&&(U=X),X=0)),c.addJot&&(U+=I),q.height=L,q.depth=U,z+=L,q.pos=z,z+=U+X,b[d]=q,B(g[d+1])}var Q=z/2+u.fontMetrics().axisHeight,Y=c.cols||[],Z=[],J,W,G=[];if(c.tags&&c.tags.some(Re=>Re))for(d=0;d<m;++d){var te=b[d],ae=te.pos-Q,V=c.tags[d],ne=void 0;V===!0?ne=buildCommon.makeSpan(["eqn-num"],[],u):V===!1?ne=buildCommon.makeSpan([],[],u):ne=buildCommon.makeSpan([],buildExpression$1(V,u,!0),u),ne.depth=te.depth,ne.height=te.height,G.push({type:"elem",elem:ne,shift:ae})}for(f=0,W=0;f<y||W<Y.length;++f,++W){for(var le=Y[W]||{},ee=!0;le.type==="separator";){if(ee||(J=buildCommon.makeSpan(["arraycolsep"],[]),J.style.width=makeEm(u.fontMetrics().doubleRuleSep),Z.push(J)),le.separator==="|"||le.separator===":"){var ie=le.separator==="|"?"solid":"dashed",ce=buildCommon.makeSpan(["vertical-separator"],[],u);ce.style.height=makeEm(z),ce.style.borderRightWidth=makeEm(C),ce.style.borderRightStyle=ie,ce.style.margin="0 "+makeEm(-C/2);var ue=z-Q;ue&&(ce.style.verticalAlign=makeEm(-ue)),Z.push(ce)}else throw new ParseError("Invalid separator type: "+le.separator);W++,le=Y[W]||{},ee=!1}if(!(f>=y)){var me=void 0;(f>0||c.hskipBeforeAndAfter)&&(me=utils.deflt(le.pregap,R),me!==0&&(J=buildCommon.makeSpan(["arraycolsep"],[]),J.style.width=makeEm(me),Z.push(J)));var de=[];for(d=0;d<m;++d){var ge=b[d],Ce=ge[f];if(Ce){var ve=ge.pos-Q;Ce.depth=ge.depth,Ce.height=ge.height,de.push({type:"elem",elem:Ce,shift:ve})}}de=buildCommon.makeVList({positionType:"individualShift",children:de},u),de=buildCommon.makeSpan(["col-align-"+(le.align||"c")],[de]),Z.push(de),(f<y-1||c.hskipBeforeAndAfter)&&(me=utils.deflt(le.postgap,R),me!==0&&(J=buildCommon.makeSpan(["arraycolsep"],[]),J.style.width=makeEm(me),Z.push(J)))}}if(b=buildCommon.makeSpan(["mtable"],Z),E.length>0){for(var fe=buildCommon.makeLineSpan("hline",u,C),pe=buildCommon.makeLineSpan("hdashline",u,C),xe=[{type:"elem",elem:b,shift:0}];E.length>0;){var ye=E.pop(),he=ye.pos-Q;ye.isDashed?xe.push({type:"elem",elem:pe,shift:he}):xe.push({type:"elem",elem:fe,shift:he})}b=buildCommon.makeVList({positionType:"individualShift",children:xe},u)}if(G.length===0)return buildCommon.makeSpan(["mord"],[b],u);var we=buildCommon.makeVList({positionType:"individualShift",children:G},u);return we=buildCommon.makeSpan(["tag"],[we],u),buildCommon.makeFragment([b,we])},alignMap={c:"center ",l:"left ",r:"right "},mathmlBuilder$5=function(c,u){for(var d=[],f=new mathMLTree.MathNode("mtd",[],["mtr-glue"]),m=new mathMLTree.MathNode("mtd",[],["mml-eqn-num"]),g=0;g<c.body.length;g++){for(var y=c.body[g],b=[],E=0;E<y.length;E++)b.push(new mathMLTree.MathNode("mtd",[buildGroup(y[E],u)]));c.tags&&c.tags[g]&&(b.unshift(f),b.push(f),c.leqno?b.unshift(m):b.push(m)),d.push(new mathMLTree.MathNode("mtr",b))}var C=new mathMLTree.MathNode("mtable",d),w=c.arraystretch===.5?.1:.16+c.arraystretch-1+(c.addJot?.09:0);C.setAttribute("rowspacing",makeEm(w));var R="",_="";if(c.cols&&c.cols.length>0){var M=c.cols,I="",N=!1,A=0,P=M.length;M[0].type==="separator"&&(R+="top ",A=1),M[M.length-1].type==="separator"&&(R+="bottom ",P-=1);for(var z=A;z<P;z++)M[z].type==="align"?(_+=alignMap[M[z].align],N&&(I+="none "),N=!0):M[z].type==="separator"&&N&&(I+=M[z].separator==="|"?"solid ":"dashed ",N=!1);C.setAttribute("columnalign",_.trim()),/[sd]/.test(I)&&C.setAttribute("columnlines",I.trim())}if(c.colSeparationType==="align"){for(var B=c.cols||[],j="",L=1;L<B.length;L++)j+=L%2?"0em ":"1em ";C.setAttribute("columnspacing",j.trim())}else c.colSeparationType==="alignat"||c.colSeparationType==="gather"?C.setAttribute("columnspacing","0em"):c.colSeparationType==="small"?C.setAttribute("columnspacing","0.2778em"):c.colSeparationType==="CD"?C.setAttribute("columnspacing","0.5em"):C.setAttribute("columnspacing","1em");var U="",q=c.hLinesBeforeRow;R+=q[0].length>0?"left ":"",R+=q[q.length-1].length>0?"right ":"";for(var F=1;F<q.length-1;F++)U+=q[F].length===0?"none ":q[F][0]?"dashed ":"solid ";return/[sd]/.test(U)&&C.setAttribute("rowlines",U.trim()),R!==""&&(C=new mathMLTree.MathNode("menclose",[C]),C.setAttribute("notation",R.trim())),c.arraystretch&&c.arraystretch<1&&(C=new mathMLTree.MathNode("mstyle",[C]),C.setAttribute("scriptlevel","1")),C},alignedHandler=function(c,u){c.envName.indexOf("ed")===-1&&validateAmsEnvironmentContext(c);var d=[],f=c.envName.indexOf("at")>-1?"alignat":"align",m=c.envName==="split",g=parseArray(c.parser,{cols:d,addJot:!0,autoTag:m?void 0:getAutoTag(c.envName),emptySingleRow:!0,colSeparationType:f,maxNumCols:m?2:void 0,leqno:c.parser.settings.leqno},"display"),y,b=0,E={type:"ordgroup",mode:c.mode,body:[]};if(u[0]&&u[0].type==="ordgroup"){for(var C="",w=0;w<u[0].body.length;w++){var R=assertNodeType(u[0].body[w],"textord");C+=R.text}y=Number(C),b=y*2}var _=!b;g.body.forEach(function(A){for(var P=1;P<A.length;P+=2){var z=assertNodeType(A[P],"styling"),B=assertNodeType(z.body[0],"ordgroup");B.body.unshift(E)}if(_)b<A.length&&(b=A.length);else{var j=A.length/2;if(y<j)throw new ParseError("Too many math in a row: "+("expected "+y+", but got "+j),A[0])}});for(var M=0;M<b;++M){var I="r",N=0;M%2===1?I="l":M>0&&_&&(N=1),d[M]={type:"align",align:I,pregap:N,postgap:0}}return g.colSeparationType=_?"align":"alignat",g};defineEnvironment({type:"array",names:["array","darray"],props:{numArgs:1},handler(a,c){var u=checkSymbolNodeType(c[0]),d=u?[c[0]]:assertNodeType(c[0],"ordgroup").body,f=d.map(function(g){var y=assertSymbolNodeType(g),b=y.text;if("lcr".indexOf(b)!==-1)return{type:"align",align:b};if(b==="|")return{type:"separator",separator:"|"};if(b===":")return{type:"separator",separator:":"};throw new ParseError("Unknown column alignment: "+b,g)}),m={cols:f,hskipBeforeAndAfter:!0,maxNumCols:f.length};return parseArray(a.parser,m,dCellStyle(a.envName))},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["matrix","pmatrix","bmatrix","Bmatrix","vmatrix","Vmatrix","matrix*","pmatrix*","bmatrix*","Bmatrix*","vmatrix*","Vmatrix*"],props:{numArgs:0},handler(a){var c={matrix:null,pmatrix:["(",")"],bmatrix:["[","]"],Bmatrix:["\\{","\\}"],vmatrix:["|","|"],Vmatrix:["\\Vert","\\Vert"]}[a.envName.replace("*","")],u="c",d={hskipBeforeAndAfter:!1,cols:[{type:"align",align:u}]};if(a.envName.charAt(a.envName.length-1)==="*"){var f=a.parser;if(f.consumeSpaces(),f.fetch().text==="["){if(f.consume(),f.consumeSpaces(),u=f.fetch().text,"lcr".indexOf(u)===-1)throw new ParseError("Expected l or c or r",f.nextToken);f.consume(),f.consumeSpaces(),f.expect("]"),f.consume(),d.cols=[{type:"align",align:u}]}}var m=parseArray(a.parser,d,dCellStyle(a.envName)),g=Math.max(0,...m.body.map(y=>y.length));return m.cols=new Array(g).fill({type:"align",align:u}),c?{type:"leftright",mode:a.mode,body:[m],left:c[0],right:c[1],rightColor:void 0}:m},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["smallmatrix"],props:{numArgs:0},handler(a){var c={arraystretch:.5},u=parseArray(a.parser,c,"script");return u.colSeparationType="small",u},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["subarray"],props:{numArgs:1},handler(a,c){var u=checkSymbolNodeType(c[0]),d=u?[c[0]]:assertNodeType(c[0],"ordgroup").body,f=d.map(function(g){var y=assertSymbolNodeType(g),b=y.text;if("lc".indexOf(b)!==-1)return{type:"align",align:b};throw new ParseError("Unknown column alignment: "+b,g)});if(f.length>1)throw new ParseError("{subarray} can contain only one column");var m={cols:f,hskipBeforeAndAfter:!1,arraystretch:.5};if(m=parseArray(a.parser,m,"script"),m.body.length>0&&m.body[0].length>1)throw new ParseError("{subarray} can contain only one column");return m},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["cases","dcases","rcases","drcases"],props:{numArgs:0},handler(a){var c={arraystretch:1.2,cols:[{type:"align",align:"l",pregap:0,postgap:1},{type:"align",align:"l",pregap:0,postgap:0}]},u=parseArray(a.parser,c,dCellStyle(a.envName));return{type:"leftright",mode:a.mode,body:[u],left:a.envName.indexOf("r")>-1?".":"\\{",right:a.envName.indexOf("r")>-1?"\\}":".",rightColor:void 0}},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["align","align*","aligned","split"],props:{numArgs:0},handler:alignedHandler,htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["gathered","gather","gather*"],props:{numArgs:0},handler(a){utils.contains(["gather","gather*"],a.envName)&&validateAmsEnvironmentContext(a);var c={cols:[{type:"align",align:"c"}],addJot:!0,colSeparationType:"gather",autoTag:getAutoTag(a.envName),emptySingleRow:!0,leqno:a.parser.settings.leqno};return parseArray(a.parser,c,"display")},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["alignat","alignat*","alignedat"],props:{numArgs:1},handler:alignedHandler,htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["equation","equation*"],props:{numArgs:0},handler(a){validateAmsEnvironmentContext(a);var c={autoTag:getAutoTag(a.envName),emptySingleRow:!0,singleRow:!0,maxNumCols:1,leqno:a.parser.settings.leqno};return parseArray(a.parser,c,"display")},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineEnvironment({type:"array",names:["CD"],props:{numArgs:0},handler(a){return validateAmsEnvironmentContext(a),parseCD(a.parser)},htmlBuilder:htmlBuilder$6,mathmlBuilder:mathmlBuilder$5});defineMacro("\\nonumber","\\gdef\\@eqnsw{0}");defineMacro("\\notag","\\nonumber");defineFunction({type:"text",names:["\\hline","\\hdashline"],props:{numArgs:0,allowedInText:!0,allowedInMath:!0},handler(a,c){throw new ParseError(a.funcName+" valid only within array environment")}});var environments=_environments;defineFunction({type:"environment",names:["\\begin","\\end"],props:{numArgs:1,argTypes:["text"]},handler(a,c){var{parser:u,funcName:d}=a,f=c[0];if(f.type!=="ordgroup")throw new ParseError("Invalid environment name",f);for(var m="",g=0;g<f.body.length;++g)m+=assertNodeType(f.body[g],"textord").text;if(d==="\\begin"){if(!environments.hasOwnProperty(m))throw new ParseError("No such environment: "+m,f);var y=environments[m],{args:b,optArgs:E}=u.parseArguments("\\begin{"+m+"}",y),C={mode:u.mode,envName:m,parser:u},w=y.handler(C,b,E);u.expect("\\end",!1);var R=u.nextToken,_=assertNodeType(u.parseFunction(),"environment");if(_.name!==m)throw new ParseError("Mismatch: \\begin{"+m+"} matched by \\end{"+_.name+"}",R);return w}return{type:"environment",mode:u.mode,name:m,nameGroup:f}}});var htmlBuilder$5=(a,c)=>{var u=a.font,d=c.withFont(u);return buildGroup$1(a.body,d)},mathmlBuilder$4=(a,c)=>{var u=a.font,d=c.withFont(u);return buildGroup(a.body,d)},fontAliases={"\\Bbb":"\\mathbb","\\bold":"\\mathbf","\\frak":"\\mathfrak","\\bm":"\\boldsymbol"};defineFunction({type:"font",names:["\\mathrm","\\mathit","\\mathbf","\\mathnormal","\\mathsfit","\\mathbb","\\mathcal","\\mathfrak","\\mathscr","\\mathsf","\\mathtt","\\Bbb","\\bold","\\frak"],props:{numArgs:1,allowedInArgument:!0},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=normalizeArgument(c[0]),m=d;return m in fontAliases&&(m=fontAliases[m]),{type:"font",mode:u.mode,font:m.slice(1),body:f}},htmlBuilder:htmlBuilder$5,mathmlBuilder:mathmlBuilder$4});defineFunction({type:"mclass",names:["\\boldsymbol","\\bm"],props:{numArgs:1},handler:(a,c)=>{var{parser:u}=a,d=c[0],f=utils.isCharacterBox(d);return{type:"mclass",mode:u.mode,mclass:binrelClass(d),body:[{type:"font",mode:u.mode,font:"boldsymbol",body:d}],isCharacterBox:f}}});defineFunction({type:"font",names:["\\rm","\\sf","\\tt","\\bf","\\it","\\cal"],props:{numArgs:0,allowedInText:!0},handler:(a,c)=>{var{parser:u,funcName:d,breakOnTokenText:f}=a,{mode:m}=u,g=u.parseExpression(!0,f),y="math"+d.slice(1);return{type:"font",mode:m,font:y,body:{type:"ordgroup",mode:u.mode,body:g}}},htmlBuilder:htmlBuilder$5,mathmlBuilder:mathmlBuilder$4});var adjustStyle=(a,c)=>{var u=c;return a==="display"?u=u.id>=Style$1.SCRIPT.id?u.text():Style$1.DISPLAY:a==="text"&&u.size===Style$1.DISPLAY.size?u=Style$1.TEXT:a==="script"?u=Style$1.SCRIPT:a==="scriptscript"&&(u=Style$1.SCRIPTSCRIPT),u},htmlBuilder$4=(a,c)=>{var u=adjustStyle(a.size,c.style),d=u.fracNum(),f=u.fracDen(),m;m=c.havingStyle(d);var g=buildGroup$1(a.numer,m,c);if(a.continued){var y=8.5/c.fontMetrics().ptPerEm,b=3.5/c.fontMetrics().ptPerEm;g.height=g.height<y?y:g.height,g.depth=g.depth<b?b:g.depth}m=c.havingStyle(f);var E=buildGroup$1(a.denom,m,c),C,w,R;a.hasBarLine?(a.barSize?(w=calculateSize(a.barSize,c),C=buildCommon.makeLineSpan("frac-line",c,w)):C=buildCommon.makeLineSpan("frac-line",c),w=C.height,R=C.height):(C=null,w=0,R=c.fontMetrics().defaultRuleThickness);var _,M,I;u.size===Style$1.DISPLAY.size||a.size==="display"?(_=c.fontMetrics().num1,w>0?M=3*R:M=7*R,I=c.fontMetrics().denom1):(w>0?(_=c.fontMetrics().num2,M=R):(_=c.fontMetrics().num3,M=3*R),I=c.fontMetrics().denom2);var N;if(C){var P=c.fontMetrics().axisHeight;_-g.depth-(P+.5*w)<M&&(_+=M-(_-g.depth-(P+.5*w))),P-.5*w-(E.height-I)<M&&(I+=M-(P-.5*w-(E.height-I)));var z=-(P-.5*w);N=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:E,shift:I},{type:"elem",elem:C,shift:z},{type:"elem",elem:g,shift:-_}]},c)}else{var A=_-g.depth-(E.height-I);A<M&&(_+=.5*(M-A),I+=.5*(M-A)),N=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:E,shift:I},{type:"elem",elem:g,shift:-_}]},c)}m=c.havingStyle(u),N.height*=m.sizeMultiplier/c.sizeMultiplier,N.depth*=m.sizeMultiplier/c.sizeMultiplier;var B;u.size===Style$1.DISPLAY.size?B=c.fontMetrics().delim1:u.size===Style$1.SCRIPTSCRIPT.size?B=c.havingStyle(Style$1.SCRIPT).fontMetrics().delim2:B=c.fontMetrics().delim2;var j,L;return a.leftDelim==null?j=makeNullDelimiter(c,["mopen"]):j=delimiter.customSizedDelim(a.leftDelim,B,!0,c.havingStyle(u),a.mode,["mopen"]),a.continued?L=buildCommon.makeSpan([]):a.rightDelim==null?L=makeNullDelimiter(c,["mclose"]):L=delimiter.customSizedDelim(a.rightDelim,B,!0,c.havingStyle(u),a.mode,["mclose"]),buildCommon.makeSpan(["mord"].concat(m.sizingClasses(c)),[j,buildCommon.makeSpan(["mfrac"],[N]),L],c)},mathmlBuilder$3=(a,c)=>{var u=new mathMLTree.MathNode("mfrac",[buildGroup(a.numer,c),buildGroup(a.denom,c)]);if(!a.hasBarLine)u.setAttribute("linethickness","0px");else if(a.barSize){var d=calculateSize(a.barSize,c);u.setAttribute("linethickness",makeEm(d))}var f=adjustStyle(a.size,c.style);if(f.size!==c.style.size){u=new mathMLTree.MathNode("mstyle",[u]);var m=f.size===Style$1.DISPLAY.size?"true":"false";u.setAttribute("displaystyle",m),u.setAttribute("scriptlevel","0")}if(a.leftDelim!=null||a.rightDelim!=null){var g=[];if(a.leftDelim!=null){var y=new mathMLTree.MathNode("mo",[new mathMLTree.TextNode(a.leftDelim.replace("\\",""))]);y.setAttribute("fence","true"),g.push(y)}if(g.push(u),a.rightDelim!=null){var b=new mathMLTree.MathNode("mo",[new mathMLTree.TextNode(a.rightDelim.replace("\\",""))]);b.setAttribute("fence","true"),g.push(b)}return makeRow(g)}return u};defineFunction({type:"genfrac",names:["\\dfrac","\\frac","\\tfrac","\\dbinom","\\binom","\\tbinom","\\\\atopfrac","\\\\bracefrac","\\\\brackfrac"],props:{numArgs:2,allowedInArgument:!0},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=c[0],m=c[1],g,y=null,b=null,E="auto";switch(d){case"\\dfrac":case"\\frac":case"\\tfrac":g=!0;break;case"\\\\atopfrac":g=!1;break;case"\\dbinom":case"\\binom":case"\\tbinom":g=!1,y="(",b=")";break;case"\\\\bracefrac":g=!1,y="\\{",b="\\}";break;case"\\\\brackfrac":g=!1,y="[",b="]";break;default:throw new Error("Unrecognized genfrac command")}switch(d){case"\\dfrac":case"\\dbinom":E="display";break;case"\\tfrac":case"\\tbinom":E="text";break}return{type:"genfrac",mode:u.mode,continued:!1,numer:f,denom:m,hasBarLine:g,leftDelim:y,rightDelim:b,size:E,barSize:null}},htmlBuilder:htmlBuilder$4,mathmlBuilder:mathmlBuilder$3});defineFunction({type:"genfrac",names:["\\cfrac"],props:{numArgs:2},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=c[0],m=c[1];return{type:"genfrac",mode:u.mode,continued:!0,numer:f,denom:m,hasBarLine:!0,leftDelim:null,rightDelim:null,size:"display",barSize:null}}});defineFunction({type:"infix",names:["\\over","\\choose","\\atop","\\brace","\\brack"],props:{numArgs:0,infix:!0},handler(a){var{parser:c,funcName:u,token:d}=a,f;switch(u){case"\\over":f="\\frac";break;case"\\choose":f="\\binom";break;case"\\atop":f="\\\\atopfrac";break;case"\\brace":f="\\\\bracefrac";break;case"\\brack":f="\\\\brackfrac";break;default:throw new Error("Unrecognized infix genfrac command")}return{type:"infix",mode:c.mode,replaceWith:f,token:d}}});var stylArray=["display","text","script","scriptscript"],delimFromValue=function(c){var u=null;return c.length>0&&(u=c,u=u==="."?null:u),u};defineFunction({type:"genfrac",names:["\\genfrac"],props:{numArgs:6,allowedInArgument:!0,argTypes:["math","math","size","text","math","math"]},handler(a,c){var{parser:u}=a,d=c[4],f=c[5],m=normalizeArgument(c[0]),g=m.type==="atom"&&m.family==="open"?delimFromValue(m.text):null,y=normalizeArgument(c[1]),b=y.type==="atom"&&y.family==="close"?delimFromValue(y.text):null,E=assertNodeType(c[2],"size"),C,w=null;E.isBlank?C=!0:(w=E.value,C=w.number>0);var R="auto",_=c[3];if(_.type==="ordgroup"){if(_.body.length>0){var M=assertNodeType(_.body[0],"textord");R=stylArray[Number(M.text)]}}else _=assertNodeType(_,"textord"),R=stylArray[Number(_.text)];return{type:"genfrac",mode:u.mode,numer:d,denom:f,continued:!1,hasBarLine:C,barSize:w,leftDelim:g,rightDelim:b,size:R}},htmlBuilder:htmlBuilder$4,mathmlBuilder:mathmlBuilder$3});defineFunction({type:"infix",names:["\\above"],props:{numArgs:1,argTypes:["size"],infix:!0},handler(a,c){var{parser:u,funcName:d,token:f}=a;return{type:"infix",mode:u.mode,replaceWith:"\\\\abovefrac",size:assertNodeType(c[0],"size").value,token:f}}});defineFunction({type:"genfrac",names:["\\\\abovefrac"],props:{numArgs:3,argTypes:["math","size","math"]},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=c[0],m=assert(assertNodeType(c[1],"infix").size),g=c[2],y=m.number>0;return{type:"genfrac",mode:u.mode,numer:f,denom:g,continued:!1,hasBarLine:y,barSize:m,leftDelim:null,rightDelim:null,size:"auto"}},htmlBuilder:htmlBuilder$4,mathmlBuilder:mathmlBuilder$3});var htmlBuilder$3=(a,c)=>{var u=c.style,d,f;a.type==="supsub"?(d=a.sup?buildGroup$1(a.sup,c.havingStyle(u.sup()),c):buildGroup$1(a.sub,c.havingStyle(u.sub()),c),f=assertNodeType(a.base,"horizBrace")):f=assertNodeType(a,"horizBrace");var m=buildGroup$1(f.base,c.havingBaseStyle(Style$1.DISPLAY)),g=stretchy.svgSpan(f,c),y;if(f.isOver?(y=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:m},{type:"kern",size:.1},{type:"elem",elem:g}]},c),y.children[0].children[0].children[1].classes.push("svg-align")):(y=buildCommon.makeVList({positionType:"bottom",positionData:m.depth+.1+g.height,children:[{type:"elem",elem:g},{type:"kern",size:.1},{type:"elem",elem:m}]},c),y.children[0].children[0].children[0].classes.push("svg-align")),d){var b=buildCommon.makeSpan(["mord",f.isOver?"mover":"munder"],[y],c);f.isOver?y=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:b},{type:"kern",size:.2},{type:"elem",elem:d}]},c):y=buildCommon.makeVList({positionType:"bottom",positionData:b.depth+.2+d.height+d.depth,children:[{type:"elem",elem:d},{type:"kern",size:.2},{type:"elem",elem:b}]},c)}return buildCommon.makeSpan(["mord",f.isOver?"mover":"munder"],[y],c)},mathmlBuilder$2=(a,c)=>{var u=stretchy.mathMLnode(a.label);return new mathMLTree.MathNode(a.isOver?"mover":"munder",[buildGroup(a.base,c),u])};defineFunction({type:"horizBrace",names:["\\overbrace","\\underbrace"],props:{numArgs:1},handler(a,c){var{parser:u,funcName:d}=a;return{type:"horizBrace",mode:u.mode,label:d,isOver:/^\\over/.test(d),base:c[0]}},htmlBuilder:htmlBuilder$3,mathmlBuilder:mathmlBuilder$2});defineFunction({type:"href",names:["\\href"],props:{numArgs:2,argTypes:["url","original"],allowedInText:!0},handler:(a,c)=>{var{parser:u}=a,d=c[1],f=assertNodeType(c[0],"url").url;return u.settings.isTrusted({command:"\\href",url:f})?{type:"href",mode:u.mode,href:f,body:ordargument(d)}:u.formatUnsupportedCmd("\\href")},htmlBuilder:(a,c)=>{var u=buildExpression$1(a.body,c,!1);return buildCommon.makeAnchor(a.href,[],u,c)},mathmlBuilder:(a,c)=>{var u=buildExpressionRow(a.body,c);return u instanceof MathNode||(u=new MathNode("mrow",[u])),u.setAttribute("href",a.href),u}});defineFunction({type:"href",names:["\\url"],props:{numArgs:1,argTypes:["url"],allowedInText:!0},handler:(a,c)=>{var{parser:u}=a,d=assertNodeType(c[0],"url").url;if(!u.settings.isTrusted({command:"\\url",url:d}))return u.formatUnsupportedCmd("\\url");for(var f=[],m=0;m<d.length;m++){var g=d[m];g==="~"&&(g="\\textasciitilde"),f.push({type:"textord",mode:"text",text:g})}var y={type:"text",mode:u.mode,font:"\\texttt",body:f};return{type:"href",mode:u.mode,href:d,body:ordargument(y)}}});defineFunction({type:"hbox",names:["\\hbox"],props:{numArgs:1,argTypes:["text"],allowedInText:!0,primitive:!0},handler(a,c){var{parser:u}=a;return{type:"hbox",mode:u.mode,body:ordargument(c[0])}},htmlBuilder(a,c){var u=buildExpression$1(a.body,c,!1);return buildCommon.makeFragment(u)},mathmlBuilder(a,c){return new mathMLTree.MathNode("mrow",buildExpression(a.body,c))}});defineFunction({type:"html",names:["\\htmlClass","\\htmlId","\\htmlStyle","\\htmlData"],props:{numArgs:2,argTypes:["raw","original"],allowedInText:!0},handler:(a,c)=>{var{parser:u,funcName:d,token:f}=a,m=assertNodeType(c[0],"raw").string,g=c[1];u.settings.strict&&u.settings.reportNonstrict("htmlExtension","HTML extension is disabled on strict mode");var y,b={};switch(d){case"\\htmlClass":b.class=m,y={command:"\\htmlClass",class:m};break;case"\\htmlId":b.id=m,y={command:"\\htmlId",id:m};break;case"\\htmlStyle":b.style=m,y={command:"\\htmlStyle",style:m};break;case"\\htmlData":{for(var E=m.split(","),C=0;C<E.length;C++){var w=E[C].split("=");if(w.length!==2)throw new ParseError("Error parsing key-value for \\htmlData");b["data-"+w[0].trim()]=w[1].trim()}y={command:"\\htmlData",attributes:b};break}default:throw new Error("Unrecognized html command")}return u.settings.isTrusted(y)?{type:"html",mode:u.mode,attributes:b,body:ordargument(g)}:u.formatUnsupportedCmd(d)},htmlBuilder:(a,c)=>{var u=buildExpression$1(a.body,c,!1),d=["enclosing"];a.attributes.class&&d.push(...a.attributes.class.trim().split(/\s+/));var f=buildCommon.makeSpan(d,u,c);for(var m in a.attributes)m!=="class"&&a.attributes.hasOwnProperty(m)&&f.setAttribute(m,a.attributes[m]);return f},mathmlBuilder:(a,c)=>buildExpressionRow(a.body,c)});defineFunction({type:"htmlmathml",names:["\\html@mathml"],props:{numArgs:2,allowedInText:!0},handler:(a,c)=>{var{parser:u}=a;return{type:"htmlmathml",mode:u.mode,html:ordargument(c[0]),mathml:ordargument(c[1])}},htmlBuilder:(a,c)=>{var u=buildExpression$1(a.html,c,!1);return buildCommon.makeFragment(u)},mathmlBuilder:(a,c)=>buildExpressionRow(a.mathml,c)});var sizeData=function(c){if(/^[-+]? *(\d+(\.\d*)?|\.\d+)$/.test(c))return{number:+c,unit:"bp"};var u=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(c);if(!u)throw new ParseError("Invalid size: '"+c+"' in \\includegraphics");var d={number:+(u[1]+u[2]),unit:u[3]};if(!validUnit(d))throw new ParseError("Invalid unit: '"+d.unit+"' in \\includegraphics.");return d};defineFunction({type:"includegraphics",names:["\\includegraphics"],props:{numArgs:1,numOptionalArgs:1,argTypes:["raw","url"],allowedInText:!1},handler:(a,c,u)=>{var{parser:d}=a,f={number:0,unit:"em"},m={number:.9,unit:"em"},g={number:0,unit:"em"},y="";if(u[0])for(var b=assertNodeType(u[0],"raw").string,E=b.split(","),C=0;C<E.length;C++){var w=E[C].split("=");if(w.length===2){var R=w[1].trim();switch(w[0].trim()){case"alt":y=R;break;case"width":f=sizeData(R);break;case"height":m=sizeData(R);break;case"totalheight":g=sizeData(R);break;default:throw new ParseError("Invalid key: '"+w[0]+"' in \\includegraphics.")}}}var _=assertNodeType(c[0],"url").url;return y===""&&(y=_,y=y.replace(/^.*[\\/]/,""),y=y.substring(0,y.lastIndexOf("."))),d.settings.isTrusted({command:"\\includegraphics",url:_})?{type:"includegraphics",mode:d.mode,alt:y,width:f,height:m,totalheight:g,src:_}:d.formatUnsupportedCmd("\\includegraphics")},htmlBuilder:(a,c)=>{var u=calculateSize(a.height,c),d=0;a.totalheight.number>0&&(d=calculateSize(a.totalheight,c)-u);var f=0;a.width.number>0&&(f=calculateSize(a.width,c));var m={height:makeEm(u+d)};f>0&&(m.width=makeEm(f)),d>0&&(m.verticalAlign=makeEm(-d));var g=new Img(a.src,a.alt,m);return g.height=u,g.depth=d,g},mathmlBuilder:(a,c)=>{var u=new mathMLTree.MathNode("mglyph",[]);u.setAttribute("alt",a.alt);var d=calculateSize(a.height,c),f=0;if(a.totalheight.number>0&&(f=calculateSize(a.totalheight,c)-d,u.setAttribute("valign",makeEm(-f))),u.setAttribute("height",makeEm(d+f)),a.width.number>0){var m=calculateSize(a.width,c);u.setAttribute("width",makeEm(m))}return u.setAttribute("src",a.src),u}});defineFunction({type:"kern",names:["\\kern","\\mkern","\\hskip","\\mskip"],props:{numArgs:1,argTypes:["size"],primitive:!0,allowedInText:!0},handler(a,c){var{parser:u,funcName:d}=a,f=assertNodeType(c[0],"size");if(u.settings.strict){var m=d[1]==="m",g=f.value.unit==="mu";m?(g||u.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+d+" supports only mu units, "+("not "+f.value.unit+" units")),u.mode!=="math"&&u.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+d+" works only in math mode")):g&&u.settings.reportNonstrict("mathVsTextUnits","LaTeX's "+d+" doesn't support mu units")}return{type:"kern",mode:u.mode,dimension:f.value}},htmlBuilder(a,c){return buildCommon.makeGlue(a.dimension,c)},mathmlBuilder(a,c){var u=calculateSize(a.dimension,c);return new mathMLTree.SpaceNode(u)}});defineFunction({type:"lap",names:["\\mathllap","\\mathrlap","\\mathclap"],props:{numArgs:1,allowedInText:!0},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=c[0];return{type:"lap",mode:u.mode,alignment:d.slice(5),body:f}},htmlBuilder:(a,c)=>{var u;a.alignment==="clap"?(u=buildCommon.makeSpan([],[buildGroup$1(a.body,c)]),u=buildCommon.makeSpan(["inner"],[u],c)):u=buildCommon.makeSpan(["inner"],[buildGroup$1(a.body,c)]);var d=buildCommon.makeSpan(["fix"],[]),f=buildCommon.makeSpan([a.alignment],[u,d],c),m=buildCommon.makeSpan(["strut"]);return m.style.height=makeEm(f.height+f.depth),f.depth&&(m.style.verticalAlign=makeEm(-f.depth)),f.children.unshift(m),f=buildCommon.makeSpan(["thinbox"],[f],c),buildCommon.makeSpan(["mord","vbox"],[f],c)},mathmlBuilder:(a,c)=>{var u=new mathMLTree.MathNode("mpadded",[buildGroup(a.body,c)]);if(a.alignment!=="rlap"){var d=a.alignment==="llap"?"-1":"-0.5";u.setAttribute("lspace",d+"width")}return u.setAttribute("width","0px"),u}});defineFunction({type:"styling",names:["\\(","$"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(a,c){var{funcName:u,parser:d}=a,f=d.mode;d.switchMode("math");var m=u==="\\("?"\\)":"$",g=d.parseExpression(!1,m);return d.expect(m),d.switchMode(f),{type:"styling",mode:d.mode,style:"text",body:g}}});defineFunction({type:"text",names:["\\)","\\]"],props:{numArgs:0,allowedInText:!0,allowedInMath:!1},handler(a,c){throw new ParseError("Mismatched "+a.funcName)}});var chooseMathStyle=(a,c)=>{switch(c.style.size){case Style$1.DISPLAY.size:return a.display;case Style$1.TEXT.size:return a.text;case Style$1.SCRIPT.size:return a.script;case Style$1.SCRIPTSCRIPT.size:return a.scriptscript;default:return a.text}};defineFunction({type:"mathchoice",names:["\\mathchoice"],props:{numArgs:4,primitive:!0},handler:(a,c)=>{var{parser:u}=a;return{type:"mathchoice",mode:u.mode,display:ordargument(c[0]),text:ordargument(c[1]),script:ordargument(c[2]),scriptscript:ordargument(c[3])}},htmlBuilder:(a,c)=>{var u=chooseMathStyle(a,c),d=buildExpression$1(u,c,!1);return buildCommon.makeFragment(d)},mathmlBuilder:(a,c)=>{var u=chooseMathStyle(a,c);return buildExpressionRow(u,c)}});var assembleSupSub=(a,c,u,d,f,m,g)=>{a=buildCommon.makeSpan([],[a]);var y=u&&utils.isCharacterBox(u),b,E;if(c){var C=buildGroup$1(c,d.havingStyle(f.sup()),d);E={elem:C,kern:Math.max(d.fontMetrics().bigOpSpacing1,d.fontMetrics().bigOpSpacing3-C.depth)}}if(u){var w=buildGroup$1(u,d.havingStyle(f.sub()),d);b={elem:w,kern:Math.max(d.fontMetrics().bigOpSpacing2,d.fontMetrics().bigOpSpacing4-w.height)}}var R;if(E&&b){var _=d.fontMetrics().bigOpSpacing5+b.elem.height+b.elem.depth+b.kern+a.depth+g;R=buildCommon.makeVList({positionType:"bottom",positionData:_,children:[{type:"kern",size:d.fontMetrics().bigOpSpacing5},{type:"elem",elem:b.elem,marginLeft:makeEm(-m)},{type:"kern",size:b.kern},{type:"elem",elem:a},{type:"kern",size:E.kern},{type:"elem",elem:E.elem,marginLeft:makeEm(m)},{type:"kern",size:d.fontMetrics().bigOpSpacing5}]},d)}else if(b){var M=a.height-g;R=buildCommon.makeVList({positionType:"top",positionData:M,children:[{type:"kern",size:d.fontMetrics().bigOpSpacing5},{type:"elem",elem:b.elem,marginLeft:makeEm(-m)},{type:"kern",size:b.kern},{type:"elem",elem:a}]},d)}else if(E){var I=a.depth+g;R=buildCommon.makeVList({positionType:"bottom",positionData:I,children:[{type:"elem",elem:a},{type:"kern",size:E.kern},{type:"elem",elem:E.elem,marginLeft:makeEm(m)},{type:"kern",size:d.fontMetrics().bigOpSpacing5}]},d)}else return a;var N=[R];if(b&&m!==0&&!y){var A=buildCommon.makeSpan(["mspace"],[],d);A.style.marginRight=makeEm(m),N.unshift(A)}return buildCommon.makeSpan(["mop","op-limits"],N,d)},noSuccessor=["\\smallint"],htmlBuilder$2=(a,c)=>{var u,d,f=!1,m;a.type==="supsub"?(u=a.sup,d=a.sub,m=assertNodeType(a.base,"op"),f=!0):m=assertNodeType(a,"op");var g=c.style,y=!1;g.size===Style$1.DISPLAY.size&&m.symbol&&!utils.contains(noSuccessor,m.name)&&(y=!0);var b;if(m.symbol){var E=y?"Size2-Regular":"Size1-Regular",C="";if((m.name==="\\oiint"||m.name==="\\oiiint")&&(C=m.name.slice(1),m.name=C==="oiint"?"\\iint":"\\iiint"),b=buildCommon.makeSymbol(m.name,E,"math",c,["mop","op-symbol",y?"large-op":"small-op"]),C.length>0){var w=b.italic,R=buildCommon.staticSvg(C+"Size"+(y?"2":"1"),c);b=buildCommon.makeVList({positionType:"individualShift",children:[{type:"elem",elem:b,shift:0},{type:"elem",elem:R,shift:y?.08:0}]},c),m.name="\\"+C,b.classes.unshift("mop"),b.italic=w}}else if(m.body){var _=buildExpression$1(m.body,c,!0);_.length===1&&_[0]instanceof SymbolNode?(b=_[0],b.classes[0]="mop"):b=buildCommon.makeSpan(["mop"],_,c)}else{for(var M=[],I=1;I<m.name.length;I++)M.push(buildCommon.mathsym(m.name[I],m.mode,c));b=buildCommon.makeSpan(["mop"],M,c)}var N=0,A=0;return(b instanceof SymbolNode||m.name==="\\oiint"||m.name==="\\oiiint")&&!m.suppressBaseShift&&(N=(b.height-b.depth)/2-c.fontMetrics().axisHeight,A=b.italic),f?assembleSupSub(b,u,d,c,g,A,N):(N&&(b.style.position="relative",b.style.top=makeEm(N)),b)},mathmlBuilder$1=(a,c)=>{var u;if(a.symbol)u=new MathNode("mo",[makeText(a.name,a.mode)]),utils.contains(noSuccessor,a.name)&&u.setAttribute("largeop","false");else if(a.body)u=new MathNode("mo",buildExpression(a.body,c));else{u=new MathNode("mi",[new TextNode(a.name.slice(1))]);var d=new MathNode("mo",[makeText("⁡","text")]);a.parentIsSupSub?u=new MathNode("mrow",[u,d]):u=newDocumentFragment([u,d])}return u},singleCharBigOps={"∏":"\\prod","∐":"\\coprod","∑":"\\sum","⋀":"\\bigwedge","⋁":"\\bigvee","⋂":"\\bigcap","⋃":"\\bigcup","⨀":"\\bigodot","⨁":"\\bigoplus","⨂":"\\bigotimes","⨄":"\\biguplus","⨆":"\\bigsqcup"};defineFunction({type:"op",names:["\\coprod","\\bigvee","\\bigwedge","\\biguplus","\\bigcap","\\bigcup","\\intop","\\prod","\\sum","\\bigotimes","\\bigoplus","\\bigodot","\\bigsqcup","\\smallint","∏","∐","∑","⋀","⋁","⋂","⋃","⨀","⨁","⨂","⨄","⨆"],props:{numArgs:0},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=d;return f.length===1&&(f=singleCharBigOps[f]),{type:"op",mode:u.mode,limits:!0,parentIsSupSub:!1,symbol:!0,name:f}},htmlBuilder:htmlBuilder$2,mathmlBuilder:mathmlBuilder$1});defineFunction({type:"op",names:["\\mathop"],props:{numArgs:1,primitive:!0},handler:(a,c)=>{var{parser:u}=a,d=c[0];return{type:"op",mode:u.mode,limits:!1,parentIsSupSub:!1,symbol:!1,body:ordargument(d)}},htmlBuilder:htmlBuilder$2,mathmlBuilder:mathmlBuilder$1});var singleCharIntegrals={"∫":"\\int","∬":"\\iint","∭":"\\iiint","∮":"\\oint","∯":"\\oiint","∰":"\\oiiint"};defineFunction({type:"op",names:["\\arcsin","\\arccos","\\arctan","\\arctg","\\arcctg","\\arg","\\ch","\\cos","\\cosec","\\cosh","\\cot","\\cotg","\\coth","\\csc","\\ctg","\\cth","\\deg","\\dim","\\exp","\\hom","\\ker","\\lg","\\ln","\\log","\\sec","\\sin","\\sinh","\\sh","\\tan","\\tanh","\\tg","\\th"],props:{numArgs:0},handler(a){var{parser:c,funcName:u}=a;return{type:"op",mode:c.mode,limits:!1,parentIsSupSub:!1,symbol:!1,name:u}},htmlBuilder:htmlBuilder$2,mathmlBuilder:mathmlBuilder$1});defineFunction({type:"op",names:["\\det","\\gcd","\\inf","\\lim","\\max","\\min","\\Pr","\\sup"],props:{numArgs:0},handler(a){var{parser:c,funcName:u}=a;return{type:"op",mode:c.mode,limits:!0,parentIsSupSub:!1,symbol:!1,name:u}},htmlBuilder:htmlBuilder$2,mathmlBuilder:mathmlBuilder$1});defineFunction({type:"op",names:["\\int","\\iint","\\iiint","\\oint","\\oiint","\\oiiint","∫","∬","∭","∮","∯","∰"],props:{numArgs:0},handler(a){var{parser:c,funcName:u}=a,d=u;return d.length===1&&(d=singleCharIntegrals[d]),{type:"op",mode:c.mode,limits:!1,parentIsSupSub:!1,symbol:!0,name:d}},htmlBuilder:htmlBuilder$2,mathmlBuilder:mathmlBuilder$1});var htmlBuilder$1=(a,c)=>{var u,d,f=!1,m;a.type==="supsub"?(u=a.sup,d=a.sub,m=assertNodeType(a.base,"operatorname"),f=!0):m=assertNodeType(a,"operatorname");var g;if(m.body.length>0){for(var y=m.body.map(w=>{var R=w.text;return typeof R=="string"?{type:"textord",mode:w.mode,text:R}:w}),b=buildExpression$1(y,c.withFont("mathrm"),!0),E=0;E<b.length;E++){var C=b[E];C instanceof SymbolNode&&(C.text=C.text.replace(/\u2212/,"-").replace(/\u2217/,"*"))}g=buildCommon.makeSpan(["mop"],b,c)}else g=buildCommon.makeSpan(["mop"],[],c);return f?assembleSupSub(g,u,d,c,c.style,0,0):g},mathmlBuilder=(a,c)=>{for(var u=buildExpression(a.body,c.withFont("mathrm")),d=!0,f=0;f<u.length;f++){var m=u[f];if(!(m instanceof mathMLTree.SpaceNode))if(m instanceof mathMLTree.MathNode)switch(m.type){case"mi":case"mn":case"ms":case"mspace":case"mtext":break;case"mo":{var g=m.children[0];m.children.length===1&&g instanceof mathMLTree.TextNode?g.text=g.text.replace(/\u2212/,"-").replace(/\u2217/,"*"):d=!1;break}default:d=!1}else d=!1}if(d){var y=u.map(C=>C.toText()).join("");u=[new mathMLTree.TextNode(y)]}var b=new mathMLTree.MathNode("mi",u);b.setAttribute("mathvariant","normal");var E=new mathMLTree.MathNode("mo",[makeText("⁡","text")]);return a.parentIsSupSub?new mathMLTree.MathNode("mrow",[b,E]):mathMLTree.newDocumentFragment([b,E])};defineFunction({type:"operatorname",names:["\\operatorname@","\\operatornamewithlimits"],props:{numArgs:1},handler:(a,c)=>{var{parser:u,funcName:d}=a,f=c[0];return{type:"operatorname",mode:u.mode,body:ordargument(f),alwaysHandleSupSub:d==="\\operatornamewithlimits",limits:!1,parentIsSupSub:!1}},htmlBuilder:htmlBuilder$1,mathmlBuilder});defineMacro("\\operatorname","\\@ifstar\\operatornamewithlimits\\operatorname@");defineFunctionBuilders({type:"ordgroup",htmlBuilder(a,c){return a.semisimple?buildCommon.makeFragment(buildExpression$1(a.body,c,!1)):buildCommon.makeSpan(["mord"],buildExpression$1(a.body,c,!0),c)},mathmlBuilder(a,c){return buildExpressionRow(a.body,c,!0)}});defineFunction({type:"overline",names:["\\overline"],props:{numArgs:1},handler(a,c){var{parser:u}=a,d=c[0];return{type:"overline",mode:u.mode,body:d}},htmlBuilder(a,c){var u=buildGroup$1(a.body,c.havingCrampedStyle()),d=buildCommon.makeLineSpan("overline-line",c),f=c.fontMetrics().defaultRuleThickness,m=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:u},{type:"kern",size:3*f},{type:"elem",elem:d},{type:"kern",size:f}]},c);return buildCommon.makeSpan(["mord","overline"],[m],c)},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mo",[new mathMLTree.TextNode("‾")]);u.setAttribute("stretchy","true");var d=new mathMLTree.MathNode("mover",[buildGroup(a.body,c),u]);return d.setAttribute("accent","true"),d}});defineFunction({type:"phantom",names:["\\phantom"],props:{numArgs:1,allowedInText:!0},handler:(a,c)=>{var{parser:u}=a,d=c[0];return{type:"phantom",mode:u.mode,body:ordargument(d)}},htmlBuilder:(a,c)=>{var u=buildExpression$1(a.body,c.withPhantom(),!1);return buildCommon.makeFragment(u)},mathmlBuilder:(a,c)=>{var u=buildExpression(a.body,c);return new mathMLTree.MathNode("mphantom",u)}});defineFunction({type:"hphantom",names:["\\hphantom"],props:{numArgs:1,allowedInText:!0},handler:(a,c)=>{var{parser:u}=a,d=c[0];return{type:"hphantom",mode:u.mode,body:d}},htmlBuilder:(a,c)=>{var u=buildCommon.makeSpan([],[buildGroup$1(a.body,c.withPhantom())]);if(u.height=0,u.depth=0,u.children)for(var d=0;d<u.children.length;d++)u.children[d].height=0,u.children[d].depth=0;return u=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:u}]},c),buildCommon.makeSpan(["mord"],[u],c)},mathmlBuilder:(a,c)=>{var u=buildExpression(ordargument(a.body),c),d=new mathMLTree.MathNode("mphantom",u),f=new mathMLTree.MathNode("mpadded",[d]);return f.setAttribute("height","0px"),f.setAttribute("depth","0px"),f}});defineFunction({type:"vphantom",names:["\\vphantom"],props:{numArgs:1,allowedInText:!0},handler:(a,c)=>{var{parser:u}=a,d=c[0];return{type:"vphantom",mode:u.mode,body:d}},htmlBuilder:(a,c)=>{var u=buildCommon.makeSpan(["inner"],[buildGroup$1(a.body,c.withPhantom())]),d=buildCommon.makeSpan(["fix"],[]);return buildCommon.makeSpan(["mord","rlap"],[u,d],c)},mathmlBuilder:(a,c)=>{var u=buildExpression(ordargument(a.body),c),d=new mathMLTree.MathNode("mphantom",u),f=new mathMLTree.MathNode("mpadded",[d]);return f.setAttribute("width","0px"),f}});defineFunction({type:"raisebox",names:["\\raisebox"],props:{numArgs:2,argTypes:["size","hbox"],allowedInText:!0},handler(a,c){var{parser:u}=a,d=assertNodeType(c[0],"size").value,f=c[1];return{type:"raisebox",mode:u.mode,dy:d,body:f}},htmlBuilder(a,c){var u=buildGroup$1(a.body,c),d=calculateSize(a.dy,c);return buildCommon.makeVList({positionType:"shift",positionData:-d,children:[{type:"elem",elem:u}]},c)},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mpadded",[buildGroup(a.body,c)]),d=a.dy.number+a.dy.unit;return u.setAttribute("voffset",d),u}});defineFunction({type:"internal",names:["\\relax"],props:{numArgs:0,allowedInText:!0,allowedInArgument:!0},handler(a){var{parser:c}=a;return{type:"internal",mode:c.mode}}});defineFunction({type:"rule",names:["\\rule"],props:{numArgs:2,numOptionalArgs:1,allowedInText:!0,allowedInMath:!0,argTypes:["size","size","size"]},handler(a,c,u){var{parser:d}=a,f=u[0],m=assertNodeType(c[0],"size"),g=assertNodeType(c[1],"size");return{type:"rule",mode:d.mode,shift:f&&assertNodeType(f,"size").value,width:m.value,height:g.value}},htmlBuilder(a,c){var u=buildCommon.makeSpan(["mord","rule"],[],c),d=calculateSize(a.width,c),f=calculateSize(a.height,c),m=a.shift?calculateSize(a.shift,c):0;return u.style.borderRightWidth=makeEm(d),u.style.borderTopWidth=makeEm(f),u.style.bottom=makeEm(m),u.width=d,u.height=f+m,u.depth=-m,u.maxFontSize=f*1.125*c.sizeMultiplier,u},mathmlBuilder(a,c){var u=calculateSize(a.width,c),d=calculateSize(a.height,c),f=a.shift?calculateSize(a.shift,c):0,m=c.color&&c.getColor()||"black",g=new mathMLTree.MathNode("mspace");g.setAttribute("mathbackground",m),g.setAttribute("width",makeEm(u)),g.setAttribute("height",makeEm(d));var y=new mathMLTree.MathNode("mpadded",[g]);return f>=0?y.setAttribute("height",makeEm(f)):(y.setAttribute("height",makeEm(f)),y.setAttribute("depth",makeEm(-f))),y.setAttribute("voffset",makeEm(f)),y}});function sizingGroup(a,c,u){for(var d=buildExpression$1(a,c,!1),f=c.sizeMultiplier/u.sizeMultiplier,m=0;m<d.length;m++){var g=d[m].classes.indexOf("sizing");g<0?Array.prototype.push.apply(d[m].classes,c.sizingClasses(u)):d[m].classes[g+1]==="reset-size"+c.size&&(d[m].classes[g+1]="reset-size"+u.size),d[m].height*=f,d[m].depth*=f}return buildCommon.makeFragment(d)}var sizeFuncs=["\\tiny","\\sixptsize","\\scriptsize","\\footnotesize","\\small","\\normalsize","\\large","\\Large","\\LARGE","\\huge","\\Huge"],htmlBuilder=(a,c)=>{var u=c.havingSize(a.size);return sizingGroup(a.body,u,c)};defineFunction({type:"sizing",names:sizeFuncs,props:{numArgs:0,allowedInText:!0},handler:(a,c)=>{var{breakOnTokenText:u,funcName:d,parser:f}=a,m=f.parseExpression(!1,u);return{type:"sizing",mode:f.mode,size:sizeFuncs.indexOf(d)+1,body:m}},htmlBuilder,mathmlBuilder:(a,c)=>{var u=c.havingSize(a.size),d=buildExpression(a.body,u),f=new mathMLTree.MathNode("mstyle",d);return f.setAttribute("mathsize",makeEm(u.sizeMultiplier)),f}});defineFunction({type:"smash",names:["\\smash"],props:{numArgs:1,numOptionalArgs:1,allowedInText:!0},handler:(a,c,u)=>{var{parser:d}=a,f=!1,m=!1,g=u[0]&&assertNodeType(u[0],"ordgroup");if(g)for(var y="",b=0;b<g.body.length;++b){var E=g.body[b];if(y=E.text,y==="t")f=!0;else if(y==="b")m=!0;else{f=!1,m=!1;break}}else f=!0,m=!0;var C=c[0];return{type:"smash",mode:d.mode,body:C,smashHeight:f,smashDepth:m}},htmlBuilder:(a,c)=>{var u=buildCommon.makeSpan([],[buildGroup$1(a.body,c)]);if(!a.smashHeight&&!a.smashDepth)return u;if(a.smashHeight&&(u.height=0,u.children))for(var d=0;d<u.children.length;d++)u.children[d].height=0;if(a.smashDepth&&(u.depth=0,u.children))for(var f=0;f<u.children.length;f++)u.children[f].depth=0;var m=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:u}]},c);return buildCommon.makeSpan(["mord"],[m],c)},mathmlBuilder:(a,c)=>{var u=new mathMLTree.MathNode("mpadded",[buildGroup(a.body,c)]);return a.smashHeight&&u.setAttribute("height","0px"),a.smashDepth&&u.setAttribute("depth","0px"),u}});defineFunction({type:"sqrt",names:["\\sqrt"],props:{numArgs:1,numOptionalArgs:1},handler(a,c,u){var{parser:d}=a,f=u[0],m=c[0];return{type:"sqrt",mode:d.mode,body:m,index:f}},htmlBuilder(a,c){var u=buildGroup$1(a.body,c.havingCrampedStyle());u.height===0&&(u.height=c.fontMetrics().xHeight),u=buildCommon.wrapFragment(u,c);var d=c.fontMetrics(),f=d.defaultRuleThickness,m=f;c.style.id<Style$1.TEXT.id&&(m=c.fontMetrics().xHeight);var g=f+m/4,y=u.height+u.depth+g+f,{span:b,ruleWidth:E,advanceWidth:C}=delimiter.sqrtImage(y,c),w=b.height-E;w>u.height+u.depth+g&&(g=(g+w-u.height-u.depth)/2);var R=b.height-u.height-g-E;u.style.paddingLeft=makeEm(C);var _=buildCommon.makeVList({positionType:"firstBaseline",children:[{type:"elem",elem:u,wrapperClasses:["svg-align"]},{type:"kern",size:-(u.height+R)},{type:"elem",elem:b},{type:"kern",size:E}]},c);if(a.index){var M=c.havingStyle(Style$1.SCRIPTSCRIPT),I=buildGroup$1(a.index,M,c),N=.6*(_.height-_.depth),A=buildCommon.makeVList({positionType:"shift",positionData:-N,children:[{type:"elem",elem:I}]},c),P=buildCommon.makeSpan(["root"],[A]);return buildCommon.makeSpan(["mord","sqrt"],[P,_],c)}else return buildCommon.makeSpan(["mord","sqrt"],[_],c)},mathmlBuilder(a,c){var{body:u,index:d}=a;return d?new mathMLTree.MathNode("mroot",[buildGroup(u,c),buildGroup(d,c)]):new mathMLTree.MathNode("msqrt",[buildGroup(u,c)])}});var styleMap={display:Style$1.DISPLAY,text:Style$1.TEXT,script:Style$1.SCRIPT,scriptscript:Style$1.SCRIPTSCRIPT};defineFunction({type:"styling",names:["\\displaystyle","\\textstyle","\\scriptstyle","\\scriptscriptstyle"],props:{numArgs:0,allowedInText:!0,primitive:!0},handler(a,c){var{breakOnTokenText:u,funcName:d,parser:f}=a,m=f.parseExpression(!0,u),g=d.slice(1,d.length-5);return{type:"styling",mode:f.mode,style:g,body:m}},htmlBuilder(a,c){var u=styleMap[a.style],d=c.havingStyle(u).withFont("");return sizingGroup(a.body,d,c)},mathmlBuilder(a,c){var u=styleMap[a.style],d=c.havingStyle(u),f=buildExpression(a.body,d),m=new mathMLTree.MathNode("mstyle",f),g={display:["0","true"],text:["0","false"],script:["1","false"],scriptscript:["2","false"]},y=g[a.style];return m.setAttribute("scriptlevel",y[0]),m.setAttribute("displaystyle",y[1]),m}});var htmlBuilderDelegate=function(c,u){var d=c.base;if(d)if(d.type==="op"){var f=d.limits&&(u.style.size===Style$1.DISPLAY.size||d.alwaysHandleSupSub);return f?htmlBuilder$2:null}else if(d.type==="operatorname"){var m=d.alwaysHandleSupSub&&(u.style.size===Style$1.DISPLAY.size||d.limits);return m?htmlBuilder$1:null}else{if(d.type==="accent")return utils.isCharacterBox(d.base)?htmlBuilder$a:null;if(d.type==="horizBrace"){var g=!c.sub;return g===d.isOver?htmlBuilder$3:null}else return null}else return null};defineFunctionBuilders({type:"supsub",htmlBuilder(a,c){var u=htmlBuilderDelegate(a,c);if(u)return u(a,c);var{base:d,sup:f,sub:m}=a,g=buildGroup$1(d,c),y,b,E=c.fontMetrics(),C=0,w=0,R=d&&utils.isCharacterBox(d);if(f){var _=c.havingStyle(c.style.sup());y=buildGroup$1(f,_,c),R||(C=g.height-_.fontMetrics().supDrop*_.sizeMultiplier/c.sizeMultiplier)}if(m){var M=c.havingStyle(c.style.sub());b=buildGroup$1(m,M,c),R||(w=g.depth+M.fontMetrics().subDrop*M.sizeMultiplier/c.sizeMultiplier)}var I;c.style===Style$1.DISPLAY?I=E.sup1:c.style.cramped?I=E.sup3:I=E.sup2;var N=c.sizeMultiplier,A=makeEm(.5/E.ptPerEm/N),P=null;if(b){var z=a.base&&a.base.type==="op"&&a.base.name&&(a.base.name==="\\oiint"||a.base.name==="\\oiiint");(g instanceof SymbolNode||z)&&(P=makeEm(-g.italic))}var B;if(y&&b){C=Math.max(C,I,y.depth+.25*E.xHeight),w=Math.max(w,E.sub2);var j=E.defaultRuleThickness,L=4*j;if(C-y.depth-(b.height-w)<L){w=L-(C-y.depth)+b.height;var U=.8*E.xHeight-(C-y.depth);U>0&&(C+=U,w-=U)}var q=[{type:"elem",elem:b,shift:w,marginRight:A,marginLeft:P},{type:"elem",elem:y,shift:-C,marginRight:A}];B=buildCommon.makeVList({positionType:"individualShift",children:q},c)}else if(b){w=Math.max(w,E.sub1,b.height-.8*E.xHeight);var F=[{type:"elem",elem:b,marginLeft:P,marginRight:A}];B=buildCommon.makeVList({positionType:"shift",positionData:w,children:F},c)}else if(y)C=Math.max(C,I,y.depth+.25*E.xHeight),B=buildCommon.makeVList({positionType:"shift",positionData:-C,children:[{type:"elem",elem:y,marginRight:A}]},c);else throw new Error("supsub must have either sup or sub.");var K=getTypeOfDomTree(g,"right")||"mord";return buildCommon.makeSpan([K],[g,buildCommon.makeSpan(["msupsub"],[B])],c)},mathmlBuilder(a,c){var u=!1,d,f;a.base&&a.base.type==="horizBrace"&&(f=!!a.sup,f===a.base.isOver&&(u=!0,d=a.base.isOver)),a.base&&(a.base.type==="op"||a.base.type==="operatorname")&&(a.base.parentIsSupSub=!0);var m=[buildGroup(a.base,c)];a.sub&&m.push(buildGroup(a.sub,c)),a.sup&&m.push(buildGroup(a.sup,c));var g;if(u)g=d?"mover":"munder";else if(a.sub)if(a.sup){var E=a.base;E&&E.type==="op"&&E.limits&&c.style===Style$1.DISPLAY||E&&E.type==="operatorname"&&E.alwaysHandleSupSub&&(c.style===Style$1.DISPLAY||E.limits)?g="munderover":g="msubsup"}else{var b=a.base;b&&b.type==="op"&&b.limits&&(c.style===Style$1.DISPLAY||b.alwaysHandleSupSub)||b&&b.type==="operatorname"&&b.alwaysHandleSupSub&&(b.limits||c.style===Style$1.DISPLAY)?g="munder":g="msub"}else{var y=a.base;y&&y.type==="op"&&y.limits&&(c.style===Style$1.DISPLAY||y.alwaysHandleSupSub)||y&&y.type==="operatorname"&&y.alwaysHandleSupSub&&(y.limits||c.style===Style$1.DISPLAY)?g="mover":g="msup"}return new mathMLTree.MathNode(g,m)}});defineFunctionBuilders({type:"atom",htmlBuilder(a,c){return buildCommon.mathsym(a.text,a.mode,c,["m"+a.family])},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mo",[makeText(a.text,a.mode)]);if(a.family==="bin"){var d=getVariant(a,c);d==="bold-italic"&&u.setAttribute("mathvariant",d)}else a.family==="punct"?u.setAttribute("separator","true"):(a.family==="open"||a.family==="close")&&u.setAttribute("stretchy","false");return u}});var defaultVariant={mi:"italic",mn:"normal",mtext:"normal"};defineFunctionBuilders({type:"mathord",htmlBuilder(a,c){return buildCommon.makeOrd(a,c,"mathord")},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mi",[makeText(a.text,a.mode,c)]),d=getVariant(a,c)||"italic";return d!==defaultVariant[u.type]&&u.setAttribute("mathvariant",d),u}});defineFunctionBuilders({type:"textord",htmlBuilder(a,c){return buildCommon.makeOrd(a,c,"textord")},mathmlBuilder(a,c){var u=makeText(a.text,a.mode,c),d=getVariant(a,c)||"normal",f;return a.mode==="text"?f=new mathMLTree.MathNode("mtext",[u]):/[0-9]/.test(a.text)?f=new mathMLTree.MathNode("mn",[u]):a.text==="\\prime"?f=new mathMLTree.MathNode("mo",[u]):f=new mathMLTree.MathNode("mi",[u]),d!==defaultVariant[f.type]&&f.setAttribute("mathvariant",d),f}});var cssSpace={"\\nobreak":"nobreak","\\allowbreak":"allowbreak"},regularSpace={" ":{},"\\ ":{},"~":{className:"nobreak"},"\\space":{},"\\nobreakspace":{className:"nobreak"}};defineFunctionBuilders({type:"spacing",htmlBuilder(a,c){if(regularSpace.hasOwnProperty(a.text)){var u=regularSpace[a.text].className||"";if(a.mode==="text"){var d=buildCommon.makeOrd(a,c,"textord");return d.classes.push(u),d}else return buildCommon.makeSpan(["mspace",u],[buildCommon.mathsym(a.text,a.mode,c)],c)}else{if(cssSpace.hasOwnProperty(a.text))return buildCommon.makeSpan(["mspace",cssSpace[a.text]],[],c);throw new ParseError('Unknown type of space "'+a.text+'"')}},mathmlBuilder(a,c){var u;if(regularSpace.hasOwnProperty(a.text))u=new mathMLTree.MathNode("mtext",[new mathMLTree.TextNode(" ")]);else{if(cssSpace.hasOwnProperty(a.text))return new mathMLTree.MathNode("mspace");throw new ParseError('Unknown type of space "'+a.text+'"')}return u}});var pad=()=>{var a=new mathMLTree.MathNode("mtd",[]);return a.setAttribute("width","50%"),a};defineFunctionBuilders({type:"tag",mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mtable",[new mathMLTree.MathNode("mtr",[pad(),new mathMLTree.MathNode("mtd",[buildExpressionRow(a.body,c)]),pad(),new mathMLTree.MathNode("mtd",[buildExpressionRow(a.tag,c)])])]);return u.setAttribute("width","100%"),u}});var textFontFamilies={"\\text":void 0,"\\textrm":"textrm","\\textsf":"textsf","\\texttt":"texttt","\\textnormal":"textrm"},textFontWeights={"\\textbf":"textbf","\\textmd":"textmd"},textFontShapes={"\\textit":"textit","\\textup":"textup"},optionsWithFont=(a,c)=>{var u=a.font;if(u){if(textFontFamilies[u])return c.withTextFontFamily(textFontFamilies[u]);if(textFontWeights[u])return c.withTextFontWeight(textFontWeights[u]);if(u==="\\emph")return c.fontShape==="textit"?c.withTextFontShape("textup"):c.withTextFontShape("textit")}else return c;return c.withTextFontShape(textFontShapes[u])};defineFunction({type:"text",names:["\\text","\\textrm","\\textsf","\\texttt","\\textnormal","\\textbf","\\textmd","\\textit","\\textup","\\emph"],props:{numArgs:1,argTypes:["text"],allowedInArgument:!0,allowedInText:!0},handler(a,c){var{parser:u,funcName:d}=a,f=c[0];return{type:"text",mode:u.mode,body:ordargument(f),font:d}},htmlBuilder(a,c){var u=optionsWithFont(a,c),d=buildExpression$1(a.body,u,!0);return buildCommon.makeSpan(["mord","text"],d,u)},mathmlBuilder(a,c){var u=optionsWithFont(a,c);return buildExpressionRow(a.body,u)}});defineFunction({type:"underline",names:["\\underline"],props:{numArgs:1,allowedInText:!0},handler(a,c){var{parser:u}=a;return{type:"underline",mode:u.mode,body:c[0]}},htmlBuilder(a,c){var u=buildGroup$1(a.body,c),d=buildCommon.makeLineSpan("underline-line",c),f=c.fontMetrics().defaultRuleThickness,m=buildCommon.makeVList({positionType:"top",positionData:u.height,children:[{type:"kern",size:f},{type:"elem",elem:d},{type:"kern",size:3*f},{type:"elem",elem:u}]},c);return buildCommon.makeSpan(["mord","underline"],[m],c)},mathmlBuilder(a,c){var u=new mathMLTree.MathNode("mo",[new mathMLTree.TextNode("‾")]);u.setAttribute("stretchy","true");var d=new mathMLTree.MathNode("munder",[buildGroup(a.body,c),u]);return d.setAttribute("accentunder","true"),d}});defineFunction({type:"vcenter",names:["\\vcenter"],props:{numArgs:1,argTypes:["original"],allowedInText:!1},handler(a,c){var{parser:u}=a;return{type:"vcenter",mode:u.mode,body:c[0]}},htmlBuilder(a,c){var u=buildGroup$1(a.body,c),d=c.fontMetrics().axisHeight,f=.5*(u.height-d-(u.depth+d));return buildCommon.makeVList({positionType:"shift",positionData:f,children:[{type:"elem",elem:u}]},c)},mathmlBuilder(a,c){return new mathMLTree.MathNode("mpadded",[buildGroup(a.body,c)],["vcenter"])}});defineFunction({type:"verb",names:["\\verb"],props:{numArgs:0,allowedInText:!0},handler(a,c,u){throw new ParseError("\\verb ended by end of line instead of matching delimiter")},htmlBuilder(a,c){for(var u=makeVerb(a),d=[],f=c.havingStyle(c.style.text()),m=0;m<u.length;m++){var g=u[m];g==="~"&&(g="\\textasciitilde"),d.push(buildCommon.makeSymbol(g,"Typewriter-Regular",a.mode,f,["mord","texttt"]))}return buildCommon.makeSpan(["mord","text"].concat(f.sizingClasses(c)),buildCommon.tryCombineChars(d),f)},mathmlBuilder(a,c){var u=new mathMLTree.TextNode(makeVerb(a)),d=new mathMLTree.MathNode("mtext",[u]);return d.setAttribute("mathvariant","monospace"),d}});var makeVerb=a=>a.body.replace(/ /g,a.star?"␣":" "),functions=_functions,spaceRegexString=`[ \r
	]`,controlWordRegexString="\\\\[a-zA-Z@]+",controlSymbolRegexString="\\\\[^\uD800-\uDFFF]",controlWordWhitespaceRegexString="("+controlWordRegexString+")"+spaceRegexString+"*",controlSpaceRegexString=`\\\\(
|[ \r	]+
?)[ \r	]*`,combiningDiacriticalMarkString="[̀-ͯ]",combiningDiacriticalMarksEndRegex=new RegExp(combiningDiacriticalMarkString+"+$"),tokenRegexString="("+spaceRegexString+"+)|"+(controlSpaceRegexString+"|")+"([!-\\[\\]-‧‪-퟿豈-]"+(combiningDiacriticalMarkString+"*")+"|[\uD800-\uDBFF][\uDC00-\uDFFF]"+(combiningDiacriticalMarkString+"*")+"|\\\\verb\\*([^]).*?\\4|\\\\verb([^*a-zA-Z]).*?\\5"+("|"+controlWordWhitespaceRegexString)+("|"+controlSymbolRegexString+")");class Lexer{constructor(c,u){this.input=void 0,this.settings=void 0,this.tokenRegex=void 0,this.catcodes=void 0,this.input=c,this.settings=u,this.tokenRegex=new RegExp(tokenRegexString,"g"),this.catcodes={"%":14,"~":13}}setCatcode(c,u){this.catcodes[c]=u}lex(){var c=this.input,u=this.tokenRegex.lastIndex;if(u===c.length)return new Token("EOF",new SourceLocation(this,u,u));var d=this.tokenRegex.exec(c);if(d===null||d.index!==u)throw new ParseError("Unexpected character: '"+c[u]+"'",new Token(c[u],new SourceLocation(this,u,u+1)));var f=d[6]||d[3]||(d[2]?"\\ ":" ");if(this.catcodes[f]===14){var m=c.indexOf(`
`,this.tokenRegex.lastIndex);return m===-1?(this.tokenRegex.lastIndex=c.length,this.settings.reportNonstrict("commentAtEnd","% comment has no terminating newline; LaTeX would fail because of commenting the end of math mode (e.g. $)")):this.tokenRegex.lastIndex=m+1,this.lex()}return new Token(f,new SourceLocation(this,u,this.tokenRegex.lastIndex))}}class Namespace{constructor(c,u){c===void 0&&(c={}),u===void 0&&(u={}),this.current=void 0,this.builtins=void 0,this.undefStack=void 0,this.current=u,this.builtins=c,this.undefStack=[]}beginGroup(){this.undefStack.push({})}endGroup(){if(this.undefStack.length===0)throw new ParseError("Unbalanced namespace destruction: attempt to pop global namespace; please report this as a bug");var c=this.undefStack.pop();for(var u in c)c.hasOwnProperty(u)&&(c[u]==null?delete this.current[u]:this.current[u]=c[u])}endGroups(){for(;this.undefStack.length>0;)this.endGroup()}has(c){return this.current.hasOwnProperty(c)||this.builtins.hasOwnProperty(c)}get(c){return this.current.hasOwnProperty(c)?this.current[c]:this.builtins[c]}set(c,u,d){if(d===void 0&&(d=!1),d){for(var f=0;f<this.undefStack.length;f++)delete this.undefStack[f][c];this.undefStack.length>0&&(this.undefStack[this.undefStack.length-1][c]=u)}else{var m=this.undefStack[this.undefStack.length-1];m&&!m.hasOwnProperty(c)&&(m[c]=this.current[c])}u==null?delete this.current[c]:this.current[c]=u}}var macros=_macros;defineMacro("\\noexpand",function(a){var c=a.popToken();return a.isExpandable(c.text)&&(c.noexpand=!0,c.treatAsRelax=!0),{tokens:[c],numArgs:0}});defineMacro("\\expandafter",function(a){var c=a.popToken();return a.expandOnce(!0),{tokens:[c],numArgs:0}});defineMacro("\\@firstoftwo",function(a){var c=a.consumeArgs(2);return{tokens:c[0],numArgs:0}});defineMacro("\\@secondoftwo",function(a){var c=a.consumeArgs(2);return{tokens:c[1],numArgs:0}});defineMacro("\\@ifnextchar",function(a){var c=a.consumeArgs(3);a.consumeSpaces();var u=a.future();return c[0].length===1&&c[0][0].text===u.text?{tokens:c[1],numArgs:0}:{tokens:c[2],numArgs:0}});defineMacro("\\@ifstar","\\@ifnextchar *{\\@firstoftwo{#1}}");defineMacro("\\TextOrMath",function(a){var c=a.consumeArgs(2);return a.mode==="text"?{tokens:c[0],numArgs:0}:{tokens:c[1],numArgs:0}});var digitToNumber={0:0,1:1,2:2,3:3,4:4,5:5,6:6,7:7,8:8,9:9,a:10,A:10,b:11,B:11,c:12,C:12,d:13,D:13,e:14,E:14,f:15,F:15};defineMacro("\\char",function(a){var c=a.popToken(),u,d="";if(c.text==="'")u=8,c=a.popToken();else if(c.text==='"')u=16,c=a.popToken();else if(c.text==="`")if(c=a.popToken(),c.text[0]==="\\")d=c.text.charCodeAt(1);else{if(c.text==="EOF")throw new ParseError("\\char` missing argument");d=c.text.charCodeAt(0)}else u=10;if(u){if(d=digitToNumber[c.text],d==null||d>=u)throw new ParseError("Invalid base-"+u+" digit "+c.text);for(var f;(f=digitToNumber[a.future().text])!=null&&f<u;)d*=u,d+=f,a.popToken()}return"\\@char{"+d+"}"});var newcommand=(a,c,u,d)=>{var f=a.consumeArg().tokens;if(f.length!==1)throw new ParseError("\\newcommand's first argument must be a macro name");var m=f[0].text,g=a.isDefined(m);if(g&&!c)throw new ParseError("\\newcommand{"+m+"} attempting to redefine "+(m+"; use \\renewcommand"));if(!g&&!u)throw new ParseError("\\renewcommand{"+m+"} when command "+m+" does not yet exist; use \\newcommand");var y=0;if(f=a.consumeArg().tokens,f.length===1&&f[0].text==="["){for(var b="",E=a.expandNextToken();E.text!=="]"&&E.text!=="EOF";)b+=E.text,E=a.expandNextToken();if(!b.match(/^\s*[0-9]+\s*$/))throw new ParseError("Invalid number of arguments: "+b);y=parseInt(b),f=a.consumeArg().tokens}return g&&d||a.macros.set(m,{tokens:f,numArgs:y}),""};defineMacro("\\newcommand",a=>newcommand(a,!1,!0,!1));defineMacro("\\renewcommand",a=>newcommand(a,!0,!1,!1));defineMacro("\\providecommand",a=>newcommand(a,!0,!0,!0));defineMacro("\\message",a=>{var c=a.consumeArgs(1)[0];return console.log(c.reverse().map(u=>u.text).join("")),""});defineMacro("\\errmessage",a=>{var c=a.consumeArgs(1)[0];return console.error(c.reverse().map(u=>u.text).join("")),""});defineMacro("\\show",a=>{var c=a.popToken(),u=c.text;return console.log(c,a.macros.get(u),functions[u],symbols.math[u],symbols.text[u]),""});defineMacro("\\bgroup","{");defineMacro("\\egroup","}");defineMacro("~","\\nobreakspace");defineMacro("\\lq","`");defineMacro("\\rq","'");defineMacro("\\aa","\\r a");defineMacro("\\AA","\\r A");defineMacro("\\textcopyright","\\html@mathml{\\textcircled{c}}{\\char`©}");defineMacro("\\copyright","\\TextOrMath{\\textcopyright}{\\text{\\textcopyright}}");defineMacro("\\textregistered","\\html@mathml{\\textcircled{\\scriptsize R}}{\\char`®}");defineMacro("ℬ","\\mathscr{B}");defineMacro("ℰ","\\mathscr{E}");defineMacro("ℱ","\\mathscr{F}");defineMacro("ℋ","\\mathscr{H}");defineMacro("ℐ","\\mathscr{I}");defineMacro("ℒ","\\mathscr{L}");defineMacro("ℳ","\\mathscr{M}");defineMacro("ℛ","\\mathscr{R}");defineMacro("ℭ","\\mathfrak{C}");defineMacro("ℌ","\\mathfrak{H}");defineMacro("ℨ","\\mathfrak{Z}");defineMacro("\\Bbbk","\\Bbb{k}");defineMacro("·","\\cdotp");defineMacro("\\llap","\\mathllap{\\textrm{#1}}");defineMacro("\\rlap","\\mathrlap{\\textrm{#1}}");defineMacro("\\clap","\\mathclap{\\textrm{#1}}");defineMacro("\\mathstrut","\\vphantom{(}");defineMacro("\\underbar","\\underline{\\text{#1}}");defineMacro("\\not",'\\html@mathml{\\mathrel{\\mathrlap\\@not}}{\\char"338}');defineMacro("\\neq","\\html@mathml{\\mathrel{\\not=}}{\\mathrel{\\char`≠}}");defineMacro("\\ne","\\neq");defineMacro("≠","\\neq");defineMacro("\\notin","\\html@mathml{\\mathrel{{\\in}\\mathllap{/\\mskip1mu}}}{\\mathrel{\\char`∉}}");defineMacro("∉","\\notin");defineMacro("≘","\\html@mathml{\\mathrel{=\\kern{-1em}\\raisebox{0.4em}{$\\scriptsize\\frown$}}}{\\mathrel{\\char`≘}}");defineMacro("≙","\\html@mathml{\\stackrel{\\tiny\\wedge}{=}}{\\mathrel{\\char`≘}}");defineMacro("≚","\\html@mathml{\\stackrel{\\tiny\\vee}{=}}{\\mathrel{\\char`≚}}");defineMacro("≛","\\html@mathml{\\stackrel{\\scriptsize\\star}{=}}{\\mathrel{\\char`≛}}");defineMacro("≝","\\html@mathml{\\stackrel{\\tiny\\mathrm{def}}{=}}{\\mathrel{\\char`≝}}");defineMacro("≞","\\html@mathml{\\stackrel{\\tiny\\mathrm{m}}{=}}{\\mathrel{\\char`≞}}");defineMacro("≟","\\html@mathml{\\stackrel{\\tiny?}{=}}{\\mathrel{\\char`≟}}");defineMacro("⟂","\\perp");defineMacro("‼","\\mathclose{!\\mkern-0.8mu!}");defineMacro("∌","\\notni");defineMacro("⌜","\\ulcorner");defineMacro("⌝","\\urcorner");defineMacro("⌞","\\llcorner");defineMacro("⌟","\\lrcorner");defineMacro("©","\\copyright");defineMacro("®","\\textregistered");defineMacro("️","\\textregistered");defineMacro("\\ulcorner",'\\html@mathml{\\@ulcorner}{\\mathop{\\char"231c}}');defineMacro("\\urcorner",'\\html@mathml{\\@urcorner}{\\mathop{\\char"231d}}');defineMacro("\\llcorner",'\\html@mathml{\\@llcorner}{\\mathop{\\char"231e}}');defineMacro("\\lrcorner",'\\html@mathml{\\@lrcorner}{\\mathop{\\char"231f}}');defineMacro("\\vdots","{\\varvdots\\rule{0pt}{15pt}}");defineMacro("⋮","\\vdots");defineMacro("\\varGamma","\\mathit{\\Gamma}");defineMacro("\\varDelta","\\mathit{\\Delta}");defineMacro("\\varTheta","\\mathit{\\Theta}");defineMacro("\\varLambda","\\mathit{\\Lambda}");defineMacro("\\varXi","\\mathit{\\Xi}");defineMacro("\\varPi","\\mathit{\\Pi}");defineMacro("\\varSigma","\\mathit{\\Sigma}");defineMacro("\\varUpsilon","\\mathit{\\Upsilon}");defineMacro("\\varPhi","\\mathit{\\Phi}");defineMacro("\\varPsi","\\mathit{\\Psi}");defineMacro("\\varOmega","\\mathit{\\Omega}");defineMacro("\\substack","\\begin{subarray}{c}#1\\end{subarray}");defineMacro("\\colon","\\nobreak\\mskip2mu\\mathpunct{}\\mathchoice{\\mkern-3mu}{\\mkern-3mu}{}{}{:}\\mskip6mu\\relax");defineMacro("\\boxed","\\fbox{$\\displaystyle{#1}$}");defineMacro("\\iff","\\DOTSB\\;\\Longleftrightarrow\\;");defineMacro("\\implies","\\DOTSB\\;\\Longrightarrow\\;");defineMacro("\\impliedby","\\DOTSB\\;\\Longleftarrow\\;");defineMacro("\\dddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ...}}{#1}}");defineMacro("\\ddddot","{\\overset{\\raisebox{-0.1ex}{\\normalsize ....}}{#1}}");var dotsByToken={",":"\\dotsc","\\not":"\\dotsb","+":"\\dotsb","=":"\\dotsb","<":"\\dotsb",">":"\\dotsb","-":"\\dotsb","*":"\\dotsb",":":"\\dotsb","\\DOTSB":"\\dotsb","\\coprod":"\\dotsb","\\bigvee":"\\dotsb","\\bigwedge":"\\dotsb","\\biguplus":"\\dotsb","\\bigcap":"\\dotsb","\\bigcup":"\\dotsb","\\prod":"\\dotsb","\\sum":"\\dotsb","\\bigotimes":"\\dotsb","\\bigoplus":"\\dotsb","\\bigodot":"\\dotsb","\\bigsqcup":"\\dotsb","\\And":"\\dotsb","\\longrightarrow":"\\dotsb","\\Longrightarrow":"\\dotsb","\\longleftarrow":"\\dotsb","\\Longleftarrow":"\\dotsb","\\longleftrightarrow":"\\dotsb","\\Longleftrightarrow":"\\dotsb","\\mapsto":"\\dotsb","\\longmapsto":"\\dotsb","\\hookrightarrow":"\\dotsb","\\doteq":"\\dotsb","\\mathbin":"\\dotsb","\\mathrel":"\\dotsb","\\relbar":"\\dotsb","\\Relbar":"\\dotsb","\\xrightarrow":"\\dotsb","\\xleftarrow":"\\dotsb","\\DOTSI":"\\dotsi","\\int":"\\dotsi","\\oint":"\\dotsi","\\iint":"\\dotsi","\\iiint":"\\dotsi","\\iiiint":"\\dotsi","\\idotsint":"\\dotsi","\\DOTSX":"\\dotsx"};defineMacro("\\dots",function(a){var c="\\dotso",u=a.expandAfterFuture().text;return u in dotsByToken?c=dotsByToken[u]:(u.slice(0,4)==="\\not"||u in symbols.math&&utils.contains(["bin","rel"],symbols.math[u].group))&&(c="\\dotsb"),c});var spaceAfterDots={")":!0,"]":!0,"\\rbrack":!0,"\\}":!0,"\\rbrace":!0,"\\rangle":!0,"\\rceil":!0,"\\rfloor":!0,"\\rgroup":!0,"\\rmoustache":!0,"\\right":!0,"\\bigr":!0,"\\biggr":!0,"\\Bigr":!0,"\\Biggr":!0,$:!0,";":!0,".":!0,",":!0};defineMacro("\\dotso",function(a){var c=a.future().text;return c in spaceAfterDots?"\\ldots\\,":"\\ldots"});defineMacro("\\dotsc",function(a){var c=a.future().text;return c in spaceAfterDots&&c!==","?"\\ldots\\,":"\\ldots"});defineMacro("\\cdots",function(a){var c=a.future().text;return c in spaceAfterDots?"\\@cdots\\,":"\\@cdots"});defineMacro("\\dotsb","\\cdots");defineMacro("\\dotsm","\\cdots");defineMacro("\\dotsi","\\!\\cdots");defineMacro("\\dotsx","\\ldots\\,");defineMacro("\\DOTSI","\\relax");defineMacro("\\DOTSB","\\relax");defineMacro("\\DOTSX","\\relax");defineMacro("\\tmspace","\\TextOrMath{\\kern#1#3}{\\mskip#1#2}\\relax");defineMacro("\\,","\\tmspace+{3mu}{.1667em}");defineMacro("\\thinspace","\\,");defineMacro("\\>","\\mskip{4mu}");defineMacro("\\:","\\tmspace+{4mu}{.2222em}");defineMacro("\\medspace","\\:");defineMacro("\\;","\\tmspace+{5mu}{.2777em}");defineMacro("\\thickspace","\\;");defineMacro("\\!","\\tmspace-{3mu}{.1667em}");defineMacro("\\negthinspace","\\!");defineMacro("\\negmedspace","\\tmspace-{4mu}{.2222em}");defineMacro("\\negthickspace","\\tmspace-{5mu}{.277em}");defineMacro("\\enspace","\\kern.5em ");defineMacro("\\enskip","\\hskip.5em\\relax");defineMacro("\\quad","\\hskip1em\\relax");defineMacro("\\qquad","\\hskip2em\\relax");defineMacro("\\tag","\\@ifstar\\tag@literal\\tag@paren");defineMacro("\\tag@paren","\\tag@literal{({#1})}");defineMacro("\\tag@literal",a=>{if(a.macros.get("\\df@tag"))throw new ParseError("Multiple \\tag");return"\\gdef\\df@tag{\\text{#1}}"});defineMacro("\\bmod","\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}\\mathbin{\\rm mod}\\mathchoice{\\mskip1mu}{\\mskip1mu}{\\mskip5mu}{\\mskip5mu}");defineMacro("\\pod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern8mu}{\\mkern8mu}{\\mkern8mu}(#1)");defineMacro("\\pmod","\\pod{{\\rm mod}\\mkern6mu#1}");defineMacro("\\mod","\\allowbreak\\mathchoice{\\mkern18mu}{\\mkern12mu}{\\mkern12mu}{\\mkern12mu}{\\rm mod}\\,\\,#1");defineMacro("\\newline","\\\\\\relax");defineMacro("\\TeX","\\textrm{\\html@mathml{T\\kern-.1667em\\raisebox{-.5ex}{E}\\kern-.125emX}{TeX}}");var latexRaiseA=makeEm(fontMetricsData["Main-Regular"][84][1]-.7*fontMetricsData["Main-Regular"][65][1]);defineMacro("\\LaTeX","\\textrm{\\html@mathml{"+("L\\kern-.36em\\raisebox{"+latexRaiseA+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{LaTeX}}");defineMacro("\\KaTeX","\\textrm{\\html@mathml{"+("K\\kern-.17em\\raisebox{"+latexRaiseA+"}{\\scriptstyle A}")+"\\kern-.15em\\TeX}{KaTeX}}");defineMacro("\\hspace","\\@ifstar\\@hspacer\\@hspace");defineMacro("\\@hspace","\\hskip #1\\relax");defineMacro("\\@hspacer","\\rule{0pt}{0pt}\\hskip #1\\relax");defineMacro("\\ordinarycolon",":");defineMacro("\\vcentcolon","\\mathrel{\\mathop\\ordinarycolon}");defineMacro("\\dblcolon",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-.9mu}\\vcentcolon}}{\\mathop{\\char"2237}}');defineMacro("\\coloneqq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2254}}');defineMacro("\\Coloneqq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}=}}{\\mathop{\\char"2237\\char"3d}}');defineMacro("\\coloneq",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"3a\\char"2212}}');defineMacro("\\Coloneq",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\mathrel{-}}}{\\mathop{\\char"2237\\char"2212}}');defineMacro("\\eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2255}}');defineMacro("\\Eqqcolon",'\\html@mathml{\\mathrel{=\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"3d\\char"2237}}');defineMacro("\\eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\vcentcolon}}{\\mathop{\\char"2239}}');defineMacro("\\Eqcolon",'\\html@mathml{\\mathrel{\\mathrel{-}\\mathrel{\\mkern-1.2mu}\\dblcolon}}{\\mathop{\\char"2212\\char"2237}}');defineMacro("\\colonapprox",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"3a\\char"2248}}');defineMacro("\\Colonapprox",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\approx}}{\\mathop{\\char"2237\\char"2248}}');defineMacro("\\colonsim",'\\html@mathml{\\mathrel{\\vcentcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"3a\\char"223c}}');defineMacro("\\Colonsim",'\\html@mathml{\\mathrel{\\dblcolon\\mathrel{\\mkern-1.2mu}\\sim}}{\\mathop{\\char"2237\\char"223c}}');defineMacro("∷","\\dblcolon");defineMacro("∹","\\eqcolon");defineMacro("≔","\\coloneqq");defineMacro("≕","\\eqqcolon");defineMacro("⩴","\\Coloneqq");defineMacro("\\ratio","\\vcentcolon");defineMacro("\\coloncolon","\\dblcolon");defineMacro("\\colonequals","\\coloneqq");defineMacro("\\coloncolonequals","\\Coloneqq");defineMacro("\\equalscolon","\\eqqcolon");defineMacro("\\equalscoloncolon","\\Eqqcolon");defineMacro("\\colonminus","\\coloneq");defineMacro("\\coloncolonminus","\\Coloneq");defineMacro("\\minuscolon","\\eqcolon");defineMacro("\\minuscoloncolon","\\Eqcolon");defineMacro("\\coloncolonapprox","\\Colonapprox");defineMacro("\\coloncolonsim","\\Colonsim");defineMacro("\\simcolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\vcentcolon}");defineMacro("\\simcoloncolon","\\mathrel{\\sim\\mathrel{\\mkern-1.2mu}\\dblcolon}");defineMacro("\\approxcolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\vcentcolon}");defineMacro("\\approxcoloncolon","\\mathrel{\\approx\\mathrel{\\mkern-1.2mu}\\dblcolon}");defineMacro("\\notni","\\html@mathml{\\not\\ni}{\\mathrel{\\char`∌}}");defineMacro("\\limsup","\\DOTSB\\operatorname*{lim\\,sup}");defineMacro("\\liminf","\\DOTSB\\operatorname*{lim\\,inf}");defineMacro("\\injlim","\\DOTSB\\operatorname*{inj\\,lim}");defineMacro("\\projlim","\\DOTSB\\operatorname*{proj\\,lim}");defineMacro("\\varlimsup","\\DOTSB\\operatorname*{\\overline{lim}}");defineMacro("\\varliminf","\\DOTSB\\operatorname*{\\underline{lim}}");defineMacro("\\varinjlim","\\DOTSB\\operatorname*{\\underrightarrow{lim}}");defineMacro("\\varprojlim","\\DOTSB\\operatorname*{\\underleftarrow{lim}}");defineMacro("\\gvertneqq","\\html@mathml{\\@gvertneqq}{≩}");defineMacro("\\lvertneqq","\\html@mathml{\\@lvertneqq}{≨}");defineMacro("\\ngeqq","\\html@mathml{\\@ngeqq}{≱}");defineMacro("\\ngeqslant","\\html@mathml{\\@ngeqslant}{≱}");defineMacro("\\nleqq","\\html@mathml{\\@nleqq}{≰}");defineMacro("\\nleqslant","\\html@mathml{\\@nleqslant}{≰}");defineMacro("\\nshortmid","\\html@mathml{\\@nshortmid}{∤}");defineMacro("\\nshortparallel","\\html@mathml{\\@nshortparallel}{∦}");defineMacro("\\nsubseteqq","\\html@mathml{\\@nsubseteqq}{⊈}");defineMacro("\\nsupseteqq","\\html@mathml{\\@nsupseteqq}{⊉}");defineMacro("\\varsubsetneq","\\html@mathml{\\@varsubsetneq}{⊊}");defineMacro("\\varsubsetneqq","\\html@mathml{\\@varsubsetneqq}{⫋}");defineMacro("\\varsupsetneq","\\html@mathml{\\@varsupsetneq}{⊋}");defineMacro("\\varsupsetneqq","\\html@mathml{\\@varsupsetneqq}{⫌}");defineMacro("\\imath","\\html@mathml{\\@imath}{ı}");defineMacro("\\jmath","\\html@mathml{\\@jmath}{ȷ}");defineMacro("\\llbracket","\\html@mathml{\\mathopen{[\\mkern-3.2mu[}}{\\mathopen{\\char`⟦}}");defineMacro("\\rrbracket","\\html@mathml{\\mathclose{]\\mkern-3.2mu]}}{\\mathclose{\\char`⟧}}");defineMacro("⟦","\\llbracket");defineMacro("⟧","\\rrbracket");defineMacro("\\lBrace","\\html@mathml{\\mathopen{\\{\\mkern-3.2mu[}}{\\mathopen{\\char`⦃}}");defineMacro("\\rBrace","\\html@mathml{\\mathclose{]\\mkern-3.2mu\\}}}{\\mathclose{\\char`⦄}}");defineMacro("⦃","\\lBrace");defineMacro("⦄","\\rBrace");defineMacro("\\minuso","\\mathbin{\\html@mathml{{\\mathrlap{\\mathchoice{\\kern{0.145em}}{\\kern{0.145em}}{\\kern{0.1015em}}{\\kern{0.0725em}}\\circ}{-}}}{\\char`⦵}}");defineMacro("⦵","\\minuso");defineMacro("\\darr","\\downarrow");defineMacro("\\dArr","\\Downarrow");defineMacro("\\Darr","\\Downarrow");defineMacro("\\lang","\\langle");defineMacro("\\rang","\\rangle");defineMacro("\\uarr","\\uparrow");defineMacro("\\uArr","\\Uparrow");defineMacro("\\Uarr","\\Uparrow");defineMacro("\\N","\\mathbb{N}");defineMacro("\\R","\\mathbb{R}");defineMacro("\\Z","\\mathbb{Z}");defineMacro("\\alef","\\aleph");defineMacro("\\alefsym","\\aleph");defineMacro("\\Alpha","\\mathrm{A}");defineMacro("\\Beta","\\mathrm{B}");defineMacro("\\bull","\\bullet");defineMacro("\\Chi","\\mathrm{X}");defineMacro("\\clubs","\\clubsuit");defineMacro("\\cnums","\\mathbb{C}");defineMacro("\\Complex","\\mathbb{C}");defineMacro("\\Dagger","\\ddagger");defineMacro("\\diamonds","\\diamondsuit");defineMacro("\\empty","\\emptyset");defineMacro("\\Epsilon","\\mathrm{E}");defineMacro("\\Eta","\\mathrm{H}");defineMacro("\\exist","\\exists");defineMacro("\\harr","\\leftrightarrow");defineMacro("\\hArr","\\Leftrightarrow");defineMacro("\\Harr","\\Leftrightarrow");defineMacro("\\hearts","\\heartsuit");defineMacro("\\image","\\Im");defineMacro("\\infin","\\infty");defineMacro("\\Iota","\\mathrm{I}");defineMacro("\\isin","\\in");defineMacro("\\Kappa","\\mathrm{K}");defineMacro("\\larr","\\leftarrow");defineMacro("\\lArr","\\Leftarrow");defineMacro("\\Larr","\\Leftarrow");defineMacro("\\lrarr","\\leftrightarrow");defineMacro("\\lrArr","\\Leftrightarrow");defineMacro("\\Lrarr","\\Leftrightarrow");defineMacro("\\Mu","\\mathrm{M}");defineMacro("\\natnums","\\mathbb{N}");defineMacro("\\Nu","\\mathrm{N}");defineMacro("\\Omicron","\\mathrm{O}");defineMacro("\\plusmn","\\pm");defineMacro("\\rarr","\\rightarrow");defineMacro("\\rArr","\\Rightarrow");defineMacro("\\Rarr","\\Rightarrow");defineMacro("\\real","\\Re");defineMacro("\\reals","\\mathbb{R}");defineMacro("\\Reals","\\mathbb{R}");defineMacro("\\Rho","\\mathrm{P}");defineMacro("\\sdot","\\cdot");defineMacro("\\sect","\\S");defineMacro("\\spades","\\spadesuit");defineMacro("\\sub","\\subset");defineMacro("\\sube","\\subseteq");defineMacro("\\supe","\\supseteq");defineMacro("\\Tau","\\mathrm{T}");defineMacro("\\thetasym","\\vartheta");defineMacro("\\weierp","\\wp");defineMacro("\\Zeta","\\mathrm{Z}");defineMacro("\\argmin","\\DOTSB\\operatorname*{arg\\,min}");defineMacro("\\argmax","\\DOTSB\\operatorname*{arg\\,max}");defineMacro("\\plim","\\DOTSB\\mathop{\\operatorname{plim}}\\limits");defineMacro("\\bra","\\mathinner{\\langle{#1}|}");defineMacro("\\ket","\\mathinner{|{#1}\\rangle}");defineMacro("\\braket","\\mathinner{\\langle{#1}\\rangle}");defineMacro("\\Bra","\\left\\langle#1\\right|");defineMacro("\\Ket","\\left|#1\\right\\rangle");var braketHelper=a=>c=>{var u=c.consumeArg().tokens,d=c.consumeArg().tokens,f=c.consumeArg().tokens,m=c.consumeArg().tokens,g=c.macros.get("|"),y=c.macros.get("\\|");c.macros.beginGroup();var b=w=>R=>{a&&(R.macros.set("|",g),f.length&&R.macros.set("\\|",y));var _=w;if(!w&&f.length){var M=R.future();M.text==="|"&&(R.popToken(),_=!0)}return{tokens:_?f:d,numArgs:0}};c.macros.set("|",b(!1)),f.length&&c.macros.set("\\|",b(!0));var E=c.consumeArg().tokens,C=c.expandTokens([...m,...E,...u]);return c.macros.endGroup(),{tokens:C.reverse(),numArgs:0}};defineMacro("\\bra@ket",braketHelper(!1));defineMacro("\\bra@set",braketHelper(!0));defineMacro("\\Braket","\\bra@ket{\\left\\langle}{\\,\\middle\\vert\\,}{\\,\\middle\\vert\\,}{\\right\\rangle}");defineMacro("\\Set","\\bra@set{\\left\\{\\:}{\\;\\middle\\vert\\;}{\\;\\middle\\Vert\\;}{\\:\\right\\}}");defineMacro("\\set","\\bra@set{\\{\\,}{\\mid}{}{\\,\\}}");defineMacro("\\angln","{\\angl n}");defineMacro("\\blue","\\textcolor{##6495ed}{#1}");defineMacro("\\orange","\\textcolor{##ffa500}{#1}");defineMacro("\\pink","\\textcolor{##ff00af}{#1}");defineMacro("\\red","\\textcolor{##df0030}{#1}");defineMacro("\\green","\\textcolor{##28ae7b}{#1}");defineMacro("\\gray","\\textcolor{gray}{#1}");defineMacro("\\purple","\\textcolor{##9d38bd}{#1}");defineMacro("\\blueA","\\textcolor{##ccfaff}{#1}");defineMacro("\\blueB","\\textcolor{##80f6ff}{#1}");defineMacro("\\blueC","\\textcolor{##63d9ea}{#1}");defineMacro("\\blueD","\\textcolor{##11accd}{#1}");defineMacro("\\blueE","\\textcolor{##0c7f99}{#1}");defineMacro("\\tealA","\\textcolor{##94fff5}{#1}");defineMacro("\\tealB","\\textcolor{##26edd5}{#1}");defineMacro("\\tealC","\\textcolor{##01d1c1}{#1}");defineMacro("\\tealD","\\textcolor{##01a995}{#1}");defineMacro("\\tealE","\\textcolor{##208170}{#1}");defineMacro("\\greenA","\\textcolor{##b6ffb0}{#1}");defineMacro("\\greenB","\\textcolor{##8af281}{#1}");defineMacro("\\greenC","\\textcolor{##74cf70}{#1}");defineMacro("\\greenD","\\textcolor{##1fab54}{#1}");defineMacro("\\greenE","\\textcolor{##0d923f}{#1}");defineMacro("\\goldA","\\textcolor{##ffd0a9}{#1}");defineMacro("\\goldB","\\textcolor{##ffbb71}{#1}");defineMacro("\\goldC","\\textcolor{##ff9c39}{#1}");defineMacro("\\goldD","\\textcolor{##e07d10}{#1}");defineMacro("\\goldE","\\textcolor{##a75a05}{#1}");defineMacro("\\redA","\\textcolor{##fca9a9}{#1}");defineMacro("\\redB","\\textcolor{##ff8482}{#1}");defineMacro("\\redC","\\textcolor{##f9685d}{#1}");defineMacro("\\redD","\\textcolor{##e84d39}{#1}");defineMacro("\\redE","\\textcolor{##bc2612}{#1}");defineMacro("\\maroonA","\\textcolor{##ffbde0}{#1}");defineMacro("\\maroonB","\\textcolor{##ff92c6}{#1}");defineMacro("\\maroonC","\\textcolor{##ed5fa6}{#1}");defineMacro("\\maroonD","\\textcolor{##ca337c}{#1}");defineMacro("\\maroonE","\\textcolor{##9e034e}{#1}");defineMacro("\\purpleA","\\textcolor{##ddd7ff}{#1}");defineMacro("\\purpleB","\\textcolor{##c6b9fc}{#1}");defineMacro("\\purpleC","\\textcolor{##aa87ff}{#1}");defineMacro("\\purpleD","\\textcolor{##7854ab}{#1}");defineMacro("\\purpleE","\\textcolor{##543b78}{#1}");defineMacro("\\mintA","\\textcolor{##f5f9e8}{#1}");defineMacro("\\mintB","\\textcolor{##edf2df}{#1}");defineMacro("\\mintC","\\textcolor{##e0e5cc}{#1}");defineMacro("\\grayA","\\textcolor{##f6f7f7}{#1}");defineMacro("\\grayB","\\textcolor{##f0f1f2}{#1}");defineMacro("\\grayC","\\textcolor{##e3e5e6}{#1}");defineMacro("\\grayD","\\textcolor{##d6d8da}{#1}");defineMacro("\\grayE","\\textcolor{##babec2}{#1}");defineMacro("\\grayF","\\textcolor{##888d93}{#1}");defineMacro("\\grayG","\\textcolor{##626569}{#1}");defineMacro("\\grayH","\\textcolor{##3b3e40}{#1}");defineMacro("\\grayI","\\textcolor{##21242c}{#1}");defineMacro("\\kaBlue","\\textcolor{##314453}{#1}");defineMacro("\\kaGreen","\\textcolor{##71B307}{#1}");var implicitCommands={"^":!0,_:!0,"\\limits":!0,"\\nolimits":!0};class MacroExpander{constructor(c,u,d){this.settings=void 0,this.expansionCount=void 0,this.lexer=void 0,this.macros=void 0,this.stack=void 0,this.mode=void 0,this.settings=u,this.expansionCount=0,this.feed(c),this.macros=new Namespace(macros,u.macros),this.mode=d,this.stack=[]}feed(c){this.lexer=new Lexer(c,this.settings)}switchMode(c){this.mode=c}beginGroup(){this.macros.beginGroup()}endGroup(){this.macros.endGroup()}endGroups(){this.macros.endGroups()}future(){return this.stack.length===0&&this.pushToken(this.lexer.lex()),this.stack[this.stack.length-1]}popToken(){return this.future(),this.stack.pop()}pushToken(c){this.stack.push(c)}pushTokens(c){this.stack.push(...c)}scanArgument(c){var u,d,f;if(c){if(this.consumeSpaces(),this.future().text!=="[")return null;u=this.popToken(),{tokens:f,end:d}=this.consumeArg(["]"])}else({tokens:f,start:u,end:d}=this.consumeArg());return this.pushToken(new Token("EOF",d.loc)),this.pushTokens(f),u.range(d,"")}consumeSpaces(){for(;;){var c=this.future();if(c.text===" ")this.stack.pop();else break}}consumeArg(c){var u=[],d=c&&c.length>0;d||this.consumeSpaces();var f=this.future(),m,g=0,y=0;do{if(m=this.popToken(),u.push(m),m.text==="{")++g;else if(m.text==="}"){if(--g,g===-1)throw new ParseError("Extra }",m)}else if(m.text==="EOF")throw new ParseError("Unexpected end of input in a macro argument, expected '"+(c&&d?c[y]:"}")+"'",m);if(c&&d)if((g===0||g===1&&c[y]==="{")&&m.text===c[y]){if(++y,y===c.length){u.splice(-y,y);break}}else y=0}while(g!==0||d);return f.text==="{"&&u[u.length-1].text==="}"&&(u.pop(),u.shift()),u.reverse(),{tokens:u,start:f,end:m}}consumeArgs(c,u){if(u){if(u.length!==c+1)throw new ParseError("The length of delimiters doesn't match the number of args!");for(var d=u[0],f=0;f<d.length;f++){var m=this.popToken();if(d[f]!==m.text)throw new ParseError("Use of the macro doesn't match its definition",m)}}for(var g=[],y=0;y<c;y++)g.push(this.consumeArg(u&&u[y+1]).tokens);return g}countExpansion(c){if(this.expansionCount+=c,this.expansionCount>this.settings.maxExpand)throw new ParseError("Too many expansions: infinite loop or need to increase maxExpand setting")}expandOnce(c){var u=this.popToken(),d=u.text,f=u.noexpand?null:this._getExpansion(d);if(f==null||c&&f.unexpandable){if(c&&f==null&&d[0]==="\\"&&!this.isDefined(d))throw new ParseError("Undefined control sequence: "+d);return this.pushToken(u),!1}this.countExpansion(1);var m=f.tokens,g=this.consumeArgs(f.numArgs,f.delimiters);if(f.numArgs){m=m.slice();for(var y=m.length-1;y>=0;--y){var b=m[y];if(b.text==="#"){if(y===0)throw new ParseError("Incomplete placeholder at end of macro body",b);if(b=m[--y],b.text==="#")m.splice(y+1,1);else if(/^[1-9]$/.test(b.text))m.splice(y,2,...g[+b.text-1]);else throw new ParseError("Not a valid argument number",b)}}}return this.pushTokens(m),m.length}expandAfterFuture(){return this.expandOnce(),this.future()}expandNextToken(){for(;;)if(this.expandOnce()===!1){var c=this.stack.pop();return c.treatAsRelax&&(c.text="\\relax"),c}throw new Error}expandMacro(c){return this.macros.has(c)?this.expandTokens([new Token(c)]):void 0}expandTokens(c){var u=[],d=this.stack.length;for(this.pushTokens(c);this.stack.length>d;)if(this.expandOnce(!0)===!1){var f=this.stack.pop();f.treatAsRelax&&(f.noexpand=!1,f.treatAsRelax=!1),u.push(f)}return this.countExpansion(u.length),u}expandMacroAsText(c){var u=this.expandMacro(c);return u&&u.map(d=>d.text).join("")}_getExpansion(c){var u=this.macros.get(c);if(u==null)return u;if(c.length===1){var d=this.lexer.catcodes[c];if(d!=null&&d!==13)return}var f=typeof u=="function"?u(this):u;if(typeof f=="string"){var m=0;if(f.indexOf("#")!==-1)for(var g=f.replace(/##/g,"");g.indexOf("#"+(m+1))!==-1;)++m;for(var y=new Lexer(f,this.settings),b=[],E=y.lex();E.text!=="EOF";)b.push(E),E=y.lex();b.reverse();var C={tokens:b,numArgs:m};return C}return f}isDefined(c){return this.macros.has(c)||functions.hasOwnProperty(c)||symbols.math.hasOwnProperty(c)||symbols.text.hasOwnProperty(c)||implicitCommands.hasOwnProperty(c)}isExpandable(c){var u=this.macros.get(c);return u!=null?typeof u=="string"||typeof u=="function"||!u.unexpandable:functions.hasOwnProperty(c)&&!functions[c].primitive}}var unicodeSubRegEx=/^[₊₋₌₍₎₀₁₂₃₄₅₆₇₈₉ₐₑₕᵢⱼₖₗₘₙₒₚᵣₛₜᵤᵥₓᵦᵧᵨᵩᵪ]/,uSubsAndSups=Object.freeze({"₊":"+","₋":"-","₌":"=","₍":"(","₎":")","₀":"0","₁":"1","₂":"2","₃":"3","₄":"4","₅":"5","₆":"6","₇":"7","₈":"8","₉":"9","ₐ":"a","ₑ":"e","ₕ":"h","ᵢ":"i","ⱼ":"j","ₖ":"k","ₗ":"l","ₘ":"m","ₙ":"n","ₒ":"o","ₚ":"p","ᵣ":"r","ₛ":"s","ₜ":"t","ᵤ":"u","ᵥ":"v","ₓ":"x","ᵦ":"β","ᵧ":"γ","ᵨ":"ρ","ᵩ":"ϕ","ᵪ":"χ","⁺":"+","⁻":"-","⁼":"=","⁽":"(","⁾":")","⁰":"0","¹":"1","²":"2","³":"3","⁴":"4","⁵":"5","⁶":"6","⁷":"7","⁸":"8","⁹":"9","ᴬ":"A","ᴮ":"B","ᴰ":"D","ᴱ":"E","ᴳ":"G","ᴴ":"H","ᴵ":"I","ᴶ":"J","ᴷ":"K","ᴸ":"L","ᴹ":"M","ᴺ":"N","ᴼ":"O","ᴾ":"P","ᴿ":"R","ᵀ":"T","ᵁ":"U","ⱽ":"V","ᵂ":"W","ᵃ":"a","ᵇ":"b","ᶜ":"c","ᵈ":"d","ᵉ":"e","ᶠ":"f","ᵍ":"g",ʰ:"h","ⁱ":"i",ʲ:"j","ᵏ":"k",ˡ:"l","ᵐ":"m",ⁿ:"n","ᵒ":"o","ᵖ":"p",ʳ:"r",ˢ:"s","ᵗ":"t","ᵘ":"u","ᵛ":"v",ʷ:"w",ˣ:"x",ʸ:"y","ᶻ":"z","ᵝ":"β","ᵞ":"γ","ᵟ":"δ","ᵠ":"ϕ","ᵡ":"χ","ᶿ":"θ"}),unicodeAccents={"́":{text:"\\'",math:"\\acute"},"̀":{text:"\\`",math:"\\grave"},"̈":{text:'\\"',math:"\\ddot"},"̃":{text:"\\~",math:"\\tilde"},"̄":{text:"\\=",math:"\\bar"},"̆":{text:"\\u",math:"\\breve"},"̌":{text:"\\v",math:"\\check"},"̂":{text:"\\^",math:"\\hat"},"̇":{text:"\\.",math:"\\dot"},"̊":{text:"\\r",math:"\\mathring"},"̋":{text:"\\H"},"̧":{text:"\\c"}},unicodeSymbols={á:"á",à:"à",ä:"ä",ǟ:"ǟ",ã:"ã",ā:"ā",ă:"ă",ắ:"ắ",ằ:"ằ",ẵ:"ẵ",ǎ:"ǎ",â:"â",ấ:"ấ",ầ:"ầ",ẫ:"ẫ",ȧ:"ȧ",ǡ:"ǡ",å:"å",ǻ:"ǻ",ḃ:"ḃ",ć:"ć",ḉ:"ḉ",č:"č",ĉ:"ĉ",ċ:"ċ",ç:"ç",ď:"ď",ḋ:"ḋ",ḑ:"ḑ",é:"é",è:"è",ë:"ë",ẽ:"ẽ",ē:"ē",ḗ:"ḗ",ḕ:"ḕ",ĕ:"ĕ",ḝ:"ḝ",ě:"ě",ê:"ê",ế:"ế",ề:"ề",ễ:"ễ",ė:"ė",ȩ:"ȩ",ḟ:"ḟ",ǵ:"ǵ",ḡ:"ḡ",ğ:"ğ",ǧ:"ǧ",ĝ:"ĝ",ġ:"ġ",ģ:"ģ",ḧ:"ḧ",ȟ:"ȟ",ĥ:"ĥ",ḣ:"ḣ",ḩ:"ḩ",í:"í",ì:"ì",ï:"ï",ḯ:"ḯ",ĩ:"ĩ",ī:"ī",ĭ:"ĭ",ǐ:"ǐ",î:"î",ǰ:"ǰ",ĵ:"ĵ",ḱ:"ḱ",ǩ:"ǩ",ķ:"ķ",ĺ:"ĺ",ľ:"ľ",ļ:"ļ",ḿ:"ḿ",ṁ:"ṁ",ń:"ń",ǹ:"ǹ",ñ:"ñ",ň:"ň",ṅ:"ṅ",ņ:"ņ",ó:"ó",ò:"ò",ö:"ö",ȫ:"ȫ",õ:"õ",ṍ:"ṍ",ṏ:"ṏ",ȭ:"ȭ",ō:"ō",ṓ:"ṓ",ṑ:"ṑ",ŏ:"ŏ",ǒ:"ǒ",ô:"ô",ố:"ố",ồ:"ồ",ỗ:"ỗ",ȯ:"ȯ",ȱ:"ȱ",ő:"ő",ṕ:"ṕ",ṗ:"ṗ",ŕ:"ŕ",ř:"ř",ṙ:"ṙ",ŗ:"ŗ",ś:"ś",ṥ:"ṥ",š:"š",ṧ:"ṧ",ŝ:"ŝ",ṡ:"ṡ",ş:"ş",ẗ:"ẗ",ť:"ť",ṫ:"ṫ",ţ:"ţ",ú:"ú",ù:"ù",ü:"ü",ǘ:"ǘ",ǜ:"ǜ",ǖ:"ǖ",ǚ:"ǚ",ũ:"ũ",ṹ:"ṹ",ū:"ū",ṻ:"ṻ",ŭ:"ŭ",ǔ:"ǔ",û:"û",ů:"ů",ű:"ű",ṽ:"ṽ",ẃ:"ẃ",ẁ:"ẁ",ẅ:"ẅ",ŵ:"ŵ",ẇ:"ẇ",ẘ:"ẘ",ẍ:"ẍ",ẋ:"ẋ",ý:"ý",ỳ:"ỳ",ÿ:"ÿ",ỹ:"ỹ",ȳ:"ȳ",ŷ:"ŷ",ẏ:"ẏ",ẙ:"ẙ",ź:"ź",ž:"ž",ẑ:"ẑ",ż:"ż",Á:"Á",À:"À",Ä:"Ä",Ǟ:"Ǟ",Ã:"Ã",Ā:"Ā",Ă:"Ă",Ắ:"Ắ",Ằ:"Ằ",Ẵ:"Ẵ",Ǎ:"Ǎ",Â:"Â",Ấ:"Ấ",Ầ:"Ầ",Ẫ:"Ẫ",Ȧ:"Ȧ",Ǡ:"Ǡ",Å:"Å",Ǻ:"Ǻ",Ḃ:"Ḃ",Ć:"Ć",Ḉ:"Ḉ",Č:"Č",Ĉ:"Ĉ",Ċ:"Ċ",Ç:"Ç",Ď:"Ď",Ḋ:"Ḋ",Ḑ:"Ḑ",É:"É",È:"È",Ë:"Ë",Ẽ:"Ẽ",Ē:"Ē",Ḗ:"Ḗ",Ḕ:"Ḕ",Ĕ:"Ĕ",Ḝ:"Ḝ",Ě:"Ě",Ê:"Ê",Ế:"Ế",Ề:"Ề",Ễ:"Ễ",Ė:"Ė",Ȩ:"Ȩ",Ḟ:"Ḟ",Ǵ:"Ǵ",Ḡ:"Ḡ",Ğ:"Ğ",Ǧ:"Ǧ",Ĝ:"Ĝ",Ġ:"Ġ",Ģ:"Ģ",Ḧ:"Ḧ",Ȟ:"Ȟ",Ĥ:"Ĥ",Ḣ:"Ḣ",Ḩ:"Ḩ",Í:"Í",Ì:"Ì",Ï:"Ï",Ḯ:"Ḯ",Ĩ:"Ĩ",Ī:"Ī",Ĭ:"Ĭ",Ǐ:"Ǐ",Î:"Î",İ:"İ",Ĵ:"Ĵ",Ḱ:"Ḱ",Ǩ:"Ǩ",Ķ:"Ķ",Ĺ:"Ĺ",Ľ:"Ľ",Ļ:"Ļ",Ḿ:"Ḿ",Ṁ:"Ṁ",Ń:"Ń",Ǹ:"Ǹ",Ñ:"Ñ",Ň:"Ň",Ṅ:"Ṅ",Ņ:"Ņ",Ó:"Ó",Ò:"Ò",Ö:"Ö",Ȫ:"Ȫ",Õ:"Õ",Ṍ:"Ṍ",Ṏ:"Ṏ",Ȭ:"Ȭ",Ō:"Ō",Ṓ:"Ṓ",Ṑ:"Ṑ",Ŏ:"Ŏ",Ǒ:"Ǒ",Ô:"Ô",Ố:"Ố",Ồ:"Ồ",Ỗ:"Ỗ",Ȯ:"Ȯ",Ȱ:"Ȱ",Ő:"Ő",Ṕ:"Ṕ",Ṗ:"Ṗ",Ŕ:"Ŕ",Ř:"Ř",Ṙ:"Ṙ",Ŗ:"Ŗ",Ś:"Ś",Ṥ:"Ṥ",Š:"Š",Ṧ:"Ṧ",Ŝ:"Ŝ",Ṡ:"Ṡ",Ş:"Ş",Ť:"Ť",Ṫ:"Ṫ",Ţ:"Ţ",Ú:"Ú",Ù:"Ù",Ü:"Ü",Ǘ:"Ǘ",Ǜ:"Ǜ",Ǖ:"Ǖ",Ǚ:"Ǚ",Ũ:"Ũ",Ṹ:"Ṹ",Ū:"Ū",Ṻ:"Ṻ",Ŭ:"Ŭ",Ǔ:"Ǔ",Û:"Û",Ů:"Ů",Ű:"Ű",Ṽ:"Ṽ",Ẃ:"Ẃ",Ẁ:"Ẁ",Ẅ:"Ẅ",Ŵ:"Ŵ",Ẇ:"Ẇ",Ẍ:"Ẍ",Ẋ:"Ẋ",Ý:"Ý",Ỳ:"Ỳ",Ÿ:"Ÿ",Ỹ:"Ỹ",Ȳ:"Ȳ",Ŷ:"Ŷ",Ẏ:"Ẏ",Ź:"Ź",Ž:"Ž",Ẑ:"Ẑ",Ż:"Ż",ά:"ά",ὰ:"ὰ",ᾱ:"ᾱ",ᾰ:"ᾰ",έ:"έ",ὲ:"ὲ",ή:"ή",ὴ:"ὴ",ί:"ί",ὶ:"ὶ",ϊ:"ϊ",ΐ:"ΐ",ῒ:"ῒ",ῑ:"ῑ",ῐ:"ῐ",ό:"ό",ὸ:"ὸ",ύ:"ύ",ὺ:"ὺ",ϋ:"ϋ",ΰ:"ΰ",ῢ:"ῢ",ῡ:"ῡ",ῠ:"ῠ",ώ:"ώ",ὼ:"ὼ",Ύ:"Ύ",Ὺ:"Ὺ",Ϋ:"Ϋ",Ῡ:"Ῡ",Ῠ:"Ῠ",Ώ:"Ώ",Ὼ:"Ὼ"};class Parser{constructor(c,u){this.mode=void 0,this.gullet=void 0,this.settings=void 0,this.leftrightDepth=void 0,this.nextToken=void 0,this.mode="math",this.gullet=new MacroExpander(c,u,this.mode),this.settings=u,this.leftrightDepth=0}expect(c,u){if(u===void 0&&(u=!0),this.fetch().text!==c)throw new ParseError("Expected '"+c+"', got '"+this.fetch().text+"'",this.fetch());u&&this.consume()}consume(){this.nextToken=null}fetch(){return this.nextToken==null&&(this.nextToken=this.gullet.expandNextToken()),this.nextToken}switchMode(c){this.mode=c,this.gullet.switchMode(c)}parse(){this.settings.globalGroup||this.gullet.beginGroup(),this.settings.colorIsTextColor&&this.gullet.macros.set("\\color","\\textcolor");try{var c=this.parseExpression(!1);return this.expect("EOF"),this.settings.globalGroup||this.gullet.endGroup(),c}finally{this.gullet.endGroups()}}subparse(c){var u=this.nextToken;this.consume(),this.gullet.pushToken(new Token("}")),this.gullet.pushTokens(c);var d=this.parseExpression(!1);return this.expect("}"),this.nextToken=u,d}parseExpression(c,u){for(var d=[];;){this.mode==="math"&&this.consumeSpaces();var f=this.fetch();if(Parser.endOfExpression.indexOf(f.text)!==-1||u&&f.text===u||c&&functions[f.text]&&functions[f.text].infix)break;var m=this.parseAtom(u);if(m){if(m.type==="internal")continue}else break;d.push(m)}return this.mode==="text"&&this.formLigatures(d),this.handleInfixNodes(d)}handleInfixNodes(c){for(var u=-1,d,f=0;f<c.length;f++)if(c[f].type==="infix"){if(u!==-1)throw new ParseError("only one infix operator per group",c[f].token);u=f,d=c[f].replaceWith}if(u!==-1&&d){var m,g,y=c.slice(0,u),b=c.slice(u+1);y.length===1&&y[0].type==="ordgroup"?m=y[0]:m={type:"ordgroup",mode:this.mode,body:y},b.length===1&&b[0].type==="ordgroup"?g=b[0]:g={type:"ordgroup",mode:this.mode,body:b};var E;return d==="\\\\abovefrac"?E=this.callFunction(d,[m,c[u],g],[]):E=this.callFunction(d,[m,g],[]),[E]}else return c}handleSupSubscript(c){var u=this.fetch(),d=u.text;this.consume(),this.consumeSpaces();var f;do{var m;f=this.parseGroup(c)}while(((m=f)==null?void 0:m.type)==="internal");if(!f)throw new ParseError("Expected group after '"+d+"'",u);return f}formatUnsupportedCmd(c){for(var u=[],d=0;d<c.length;d++)u.push({type:"textord",mode:"text",text:c[d]});var f={type:"text",mode:this.mode,body:u},m={type:"color",mode:this.mode,color:this.settings.errorColor,body:[f]};return m}parseAtom(c){var u=this.parseGroup("atom",c);if((u==null?void 0:u.type)==="internal"||this.mode==="text")return u;for(var d,f;;){this.consumeSpaces();var m=this.fetch();if(m.text==="\\limits"||m.text==="\\nolimits"){if(u&&u.type==="op"){var g=m.text==="\\limits";u.limits=g,u.alwaysHandleSupSub=!0}else if(u&&u.type==="operatorname")u.alwaysHandleSupSub&&(u.limits=m.text==="\\limits");else throw new ParseError("Limit controls must follow a math operator",m);this.consume()}else if(m.text==="^"){if(d)throw new ParseError("Double superscript",m);d=this.handleSupSubscript("superscript")}else if(m.text==="_"){if(f)throw new ParseError("Double subscript",m);f=this.handleSupSubscript("subscript")}else if(m.text==="'"){if(d)throw new ParseError("Double superscript",m);var y={type:"textord",mode:this.mode,text:"\\prime"},b=[y];for(this.consume();this.fetch().text==="'";)b.push(y),this.consume();this.fetch().text==="^"&&b.push(this.handleSupSubscript("superscript")),d={type:"ordgroup",mode:this.mode,body:b}}else if(uSubsAndSups[m.text]){var E=unicodeSubRegEx.test(m.text),C=[];for(C.push(new Token(uSubsAndSups[m.text])),this.consume();;){var w=this.fetch().text;if(!uSubsAndSups[w]||unicodeSubRegEx.test(w)!==E)break;C.unshift(new Token(uSubsAndSups[w])),this.consume()}var R=this.subparse(C);E?f={type:"ordgroup",mode:"math",body:R}:d={type:"ordgroup",mode:"math",body:R}}else break}return d||f?{type:"supsub",mode:this.mode,base:u,sup:d,sub:f}:u}parseFunction(c,u){var d=this.fetch(),f=d.text,m=functions[f];if(!m)return null;if(this.consume(),u&&u!=="atom"&&!m.allowedInArgument)throw new ParseError("Got function '"+f+"' with no arguments"+(u?" as "+u:""),d);if(this.mode==="text"&&!m.allowedInText)throw new ParseError("Can't use function '"+f+"' in text mode",d);if(this.mode==="math"&&m.allowedInMath===!1)throw new ParseError("Can't use function '"+f+"' in math mode",d);var{args:g,optArgs:y}=this.parseArguments(f,m);return this.callFunction(f,g,y,d,c)}callFunction(c,u,d,f,m){var g={funcName:c,parser:this,token:f,breakOnTokenText:m},y=functions[c];if(y&&y.handler)return y.handler(g,u,d);throw new ParseError("No function handler for "+c)}parseArguments(c,u){var d=u.numArgs+u.numOptionalArgs;if(d===0)return{args:[],optArgs:[]};for(var f=[],m=[],g=0;g<d;g++){var y=u.argTypes&&u.argTypes[g],b=g<u.numOptionalArgs;(u.primitive&&y==null||u.type==="sqrt"&&g===1&&m[0]==null)&&(y="primitive");var E=this.parseGroupOfType("argument to '"+c+"'",y,b);if(b)m.push(E);else if(E!=null)f.push(E);else throw new ParseError("Null argument, please report this as a bug")}return{args:f,optArgs:m}}parseGroupOfType(c,u,d){switch(u){case"color":return this.parseColorGroup(d);case"size":return this.parseSizeGroup(d);case"url":return this.parseUrlGroup(d);case"math":case"text":return this.parseArgumentGroup(d,u);case"hbox":{var f=this.parseArgumentGroup(d,"text");return f!=null?{type:"styling",mode:f.mode,body:[f],style:"text"}:null}case"raw":{var m=this.parseStringGroup("raw",d);return m!=null?{type:"raw",mode:"text",string:m.text}:null}case"primitive":{if(d)throw new ParseError("A primitive argument cannot be optional");var g=this.parseGroup(c);if(g==null)throw new ParseError("Expected group as "+c,this.fetch());return g}case"original":case null:case void 0:return this.parseArgumentGroup(d);default:throw new ParseError("Unknown group type as "+c,this.fetch())}}consumeSpaces(){for(;this.fetch().text===" ";)this.consume()}parseStringGroup(c,u){var d=this.gullet.scanArgument(u);if(d==null)return null;for(var f="",m;(m=this.fetch()).text!=="EOF";)f+=m.text,this.consume();return this.consume(),d.text=f,d}parseRegexGroup(c,u){for(var d=this.fetch(),f=d,m="",g;(g=this.fetch()).text!=="EOF"&&c.test(m+g.text);)f=g,m+=f.text,this.consume();if(m==="")throw new ParseError("Invalid "+u+": '"+d.text+"'",d);return d.range(f,m)}parseColorGroup(c){var u=this.parseStringGroup("color",c);if(u==null)return null;var d=/^(#[a-f0-9]{3}|#?[a-f0-9]{6}|[a-z]+)$/i.exec(u.text);if(!d)throw new ParseError("Invalid color: '"+u.text+"'",u);var f=d[0];return/^[0-9a-f]{6}$/i.test(f)&&(f="#"+f),{type:"color-token",mode:this.mode,color:f}}parseSizeGroup(c){var u,d=!1;if(this.gullet.consumeSpaces(),!c&&this.gullet.future().text!=="{"?u=this.parseRegexGroup(/^[-+]? *(?:$|\d+|\d+\.\d*|\.\d*) *[a-z]{0,2} *$/,"size"):u=this.parseStringGroup("size",c),!u)return null;!c&&u.text.length===0&&(u.text="0pt",d=!0);var f=/([-+]?) *(\d+(?:\.\d*)?|\.\d+) *([a-z]{2})/.exec(u.text);if(!f)throw new ParseError("Invalid size: '"+u.text+"'",u);var m={number:+(f[1]+f[2]),unit:f[3]};if(!validUnit(m))throw new ParseError("Invalid unit: '"+m.unit+"'",u);return{type:"size",mode:this.mode,value:m,isBlank:d}}parseUrlGroup(c){this.gullet.lexer.setCatcode("%",13),this.gullet.lexer.setCatcode("~",12);var u=this.parseStringGroup("url",c);if(this.gullet.lexer.setCatcode("%",14),this.gullet.lexer.setCatcode("~",13),u==null)return null;var d=u.text.replace(/\\([#$%&~_^{}])/g,"$1");return{type:"url",mode:this.mode,url:d}}parseArgumentGroup(c,u){var d=this.gullet.scanArgument(c);if(d==null)return null;var f=this.mode;u&&this.switchMode(u),this.gullet.beginGroup();var m=this.parseExpression(!1,"EOF");this.expect("EOF"),this.gullet.endGroup();var g={type:"ordgroup",mode:this.mode,loc:d.loc,body:m};return u&&this.switchMode(f),g}parseGroup(c,u){var d=this.fetch(),f=d.text,m;if(f==="{"||f==="\\begingroup"){this.consume();var g=f==="{"?"}":"\\endgroup";this.gullet.beginGroup();var y=this.parseExpression(!1,g),b=this.fetch();this.expect(g),this.gullet.endGroup(),m={type:"ordgroup",mode:this.mode,loc:SourceLocation.range(d,b),body:y,semisimple:f==="\\begingroup"||void 0}}else if(m=this.parseFunction(u,c)||this.parseSymbol(),m==null&&f[0]==="\\"&&!implicitCommands.hasOwnProperty(f)){if(this.settings.throwOnError)throw new ParseError("Undefined control sequence: "+f,d);m=this.formatUnsupportedCmd(f),this.consume()}return m}formLigatures(c){for(var u=c.length-1,d=0;d<u;++d){var f=c[d],m=f.text;m==="-"&&c[d+1].text==="-"&&(d+1<u&&c[d+2].text==="-"?(c.splice(d,3,{type:"textord",mode:"text",loc:SourceLocation.range(f,c[d+2]),text:"---"}),u-=2):(c.splice(d,2,{type:"textord",mode:"text",loc:SourceLocation.range(f,c[d+1]),text:"--"}),u-=1)),(m==="'"||m==="`")&&c[d+1].text===m&&(c.splice(d,2,{type:"textord",mode:"text",loc:SourceLocation.range(f,c[d+1]),text:m+m}),u-=1)}}parseSymbol(){var c=this.fetch(),u=c.text;if(/^\\verb[^a-zA-Z]/.test(u)){this.consume();var d=u.slice(5),f=d.charAt(0)==="*";if(f&&(d=d.slice(1)),d.length<2||d.charAt(0)!==d.slice(-1))throw new ParseError(`\\verb assertion failed --
                    please report what input caused this bug`);return d=d.slice(1,-1),{type:"verb",mode:"text",body:d,star:f}}unicodeSymbols.hasOwnProperty(u[0])&&!symbols[this.mode][u[0]]&&(this.settings.strict&&this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Accented Unicode text character "'+u[0]+'" used in math mode',c),u=unicodeSymbols[u[0]]+u.slice(1));var m=combiningDiacriticalMarksEndRegex.exec(u);m&&(u=u.substring(0,m.index),u==="i"?u="ı":u==="j"&&(u="ȷ"));var g;if(symbols[this.mode][u]){this.settings.strict&&this.mode==="math"&&extraLatin.indexOf(u)>=0&&this.settings.reportNonstrict("unicodeTextInMathMode",'Latin-1/Unicode text character "'+u[0]+'" used in math mode',c);var y=symbols[this.mode][u].group,b=SourceLocation.range(c),E;if(ATOMS.hasOwnProperty(y)){var C=y;E={type:"atom",mode:this.mode,family:C,loc:b,text:u}}else E={type:y,mode:this.mode,loc:b,text:u};g=E}else if(u.charCodeAt(0)>=128)this.settings.strict&&(supportedCodepoint(u.charCodeAt(0))?this.mode==="math"&&this.settings.reportNonstrict("unicodeTextInMathMode",'Unicode text character "'+u[0]+'" used in math mode',c):this.settings.reportNonstrict("unknownSymbol",'Unrecognized Unicode character "'+u[0]+'"'+(" ("+u.charCodeAt(0)+")"),c)),g={type:"textord",mode:"text",loc:SourceLocation.range(c),text:u};else return null;if(this.consume(),m)for(var w=0;w<m[0].length;w++){var R=m[0][w];if(!unicodeAccents[R])throw new ParseError("Unknown accent ' "+R+"'",c);var _=unicodeAccents[R][this.mode]||unicodeAccents[R].text;if(!_)throw new ParseError("Accent "+R+" unsupported in "+this.mode+" mode",c);g={type:"accent",mode:this.mode,loc:SourceLocation.range(c),label:_,isStretchy:!1,isShifty:!0,base:g}}return g}}Parser.endOfExpression=["}","\\endgroup","\\end","\\right","&"];var parseTree=function(c,u){if(!(typeof c=="string"||c instanceof String))throw new TypeError("KaTeX can only parse string typed expression");var d=new Parser(c,u);delete d.gullet.macros.current["\\df@tag"];var f=d.parse();if(delete d.gullet.macros.current["\\current@color"],delete d.gullet.macros.current["\\color"],d.gullet.macros.get("\\df@tag")){if(!u.displayMode)throw new ParseError("\\tag works only in display equations");f=[{type:"tag",mode:"text",body:f,tag:d.subparse([new Token("\\df@tag")])}]}return f},render=function(c,u,d){u.textContent="";var f=renderToDomTree(c,d).toNode();u.appendChild(f)};typeof document<"u"&&document.compatMode!=="CSS1Compat"&&(typeof console<"u"&&console.warn("Warning: KaTeX doesn't work in quirks mode. Make sure your website has a suitable doctype."),render=function(){throw new ParseError("KaTeX doesn't work in quirks mode.")});var renderToString=function(c,u){var d=renderToDomTree(c,u).toMarkup();return d},generateParseTree=function(c,u){var d=new Settings(u);return parseTree(c,d)},renderError=function(c,u,d){if(d.throwOnError||!(c instanceof ParseError))throw c;var f=buildCommon.makeSpan(["katex-error"],[new SymbolNode(u)]);return f.setAttribute("title",c.toString()),f.setAttribute("style","color:"+d.errorColor),f},renderToDomTree=function(c,u){var d=new Settings(u);try{var f=parseTree(c,d);return buildTree(f,c,d)}catch(m){return renderError(m,c,d)}},renderToHTMLTree=function(c,u){var d=new Settings(u);try{var f=parseTree(c,d);return buildHTMLTree(f,c,d)}catch(m){return renderError(m,c,d)}},version="0.16.22",__domTree={Span,Anchor,SymbolNode,SvgNode,PathNode,LineNode},katex={version,render,renderToString,ParseError,SETTINGS_SCHEMA,__parse:generateParseTree,__renderToDomTree:renderToDomTree,__renderToHTMLTree:renderToHTMLTree,__setFontMetrics:setFontMetrics,__defineSymbol:defineSymbol,__defineFunction:defineFunction,__defineMacro:defineMacro,__domTree};const emptyOptions$1={};function remarkMath(a){const c=this,u=a||emptyOptions$1,d=c.data(),f=d.micromarkExtensions||(d.micromarkExtensions=[]),m=d.fromMarkdownExtensions||(d.fromMarkdownExtensions=[]),g=d.toMarkdownExtensions||(d.toMarkdownExtensions=[]);f.push(math$1(u)),m.push(mathFromMarkdown()),g.push(mathToMarkdown(u))}const search=/[#.]/g;function parseSelector(a,c){const u=a||"",d={};let f=0,m,g;for(;f<u.length;){search.lastIndex=f;const y=search.exec(u),b=u.slice(f,y?y.index:u.length);b&&(m?m==="#"?d.id=b:Array.isArray(d.className)?d.className.push(b):d.className=[b]:g=b,f+=b.length),y&&(m=y[0],f++)}return{type:"element",tagName:g||c||"div",properties:d,children:[]}}function createH(a,c,u){const d=u?createAdjustMap(u):void 0;function f(m,g,...y){let b;if(m==null){b={type:"root",children:[]};const E=g;y.unshift(E)}else{b=parseSelector(m,c);const E=b.tagName.toLowerCase(),C=d?d.get(E):void 0;if(b.tagName=C||E,isChild(g))y.unshift(g);else for(const[w,R]of Object.entries(g))addProperty(a,b.properties,w,R)}for(const E of y)addChild(b.children,E);return b.type==="element"&&b.tagName==="template"&&(b.content={type:"root",children:b.children},b.children=[]),b}return f}function isChild(a){if(a===null||typeof a!="object"||Array.isArray(a))return!0;if(typeof a.type!="string")return!1;const c=a,u=Object.keys(a);for(const d of u){const f=c[d];if(f&&typeof f=="object"){if(!Array.isArray(f))return!0;const m=f;for(const g of m)if(typeof g!="number"&&typeof g!="string")return!0}}return!!("children"in a&&Array.isArray(a.children))}function addProperty(a,c,u,d){const f=find(a,u);let m;if(d!=null){if(typeof d=="number"){if(Number.isNaN(d))return;m=d}else typeof d=="boolean"?m=d:typeof d=="string"?f.spaceSeparated?m=parse$1(d):f.commaSeparated?m=parse$2(d):f.commaOrSpaceSeparated?m=parse$1(parse$2(d).join(" ")):m=parsePrimitive(f,f.property,d):Array.isArray(d)?m=[...d]:m=f.property==="style"?style(d):String(d);if(Array.isArray(m)){const g=[];for(const y of m)g.push(parsePrimitive(f,f.property,y));m=g}f.property==="className"&&Array.isArray(c.className)&&(m=c.className.concat(m)),c[f.property]=m}}function addChild(a,c){if(c!=null)if(typeof c=="number"||typeof c=="string")a.push({type:"text",value:String(c)});else if(Array.isArray(c))for(const u of c)addChild(a,u);else if(typeof c=="object"&&"type"in c)c.type==="root"?addChild(a,c.children):a.push(c);else throw new Error("Expected node, nodes, or string, got `"+c+"`")}function parsePrimitive(a,c,u){if(typeof u=="string"){if(a.number&&u&&!Number.isNaN(Number(u)))return Number(u);if((a.boolean||a.overloadedBoolean)&&(u===""||normalize$1(u)===normalize$1(c)))return!0}return u}function style(a){const c=[];for(const[u,d]of Object.entries(a))c.push([u,d].join(": "));return c.join("; ")}function createAdjustMap(a){const c=new Map;for(const u of a)c.set(u.toLowerCase(),u);return c}const svgCaseSensitiveTagNames=["altGlyph","altGlyphDef","altGlyphItem","animateColor","animateMotion","animateTransform","clipPath","feBlend","feColorMatrix","feComponentTransfer","feComposite","feConvolveMatrix","feDiffuseLighting","feDisplacementMap","feDistantLight","feDropShadow","feFlood","feFuncA","feFuncB","feFuncG","feFuncR","feGaussianBlur","feImage","feMerge","feMergeNode","feMorphology","feOffset","fePointLight","feSpecularLighting","feSpotLight","feTile","feTurbulence","foreignObject","glyphRef","linearGradient","radialGradient","solidColor","textArea","textPath"],h=createH(html$2,"div"),s=createH(svg,"g",svgCaseSensitiveTagNames),webNamespaces={html:"http://www.w3.org/1999/xhtml",svg:"http://www.w3.org/2000/svg"};function fromDom(a,c){return transform(a,{})||{type:"root",children:[]}}function transform(a,c){const u=one(a,c);return u&&c.afterTransform&&c.afterTransform(a,u),u}function one(a,c){switch(a.nodeType){case 1:return element$1(a,c);case 3:return text(a);case 8:return comment(a);case 9:return root(a,c);case 10:return doctype();case 11:return root(a,c);default:return}}function root(a,c){return{type:"root",children:all(a,c)}}function doctype(){return{type:"doctype"}}function text(a){return{type:"text",value:a.nodeValue||""}}function comment(a){return{type:"comment",value:a.nodeValue||""}}function element$1(a,c){const u=a.namespaceURI,d=u===webNamespaces.svg?s:h,f=u===webNamespaces.html?a.tagName.toLowerCase():a.tagName,m=u===webNamespaces.html&&f==="template"?a.content:a,g=a.getAttributeNames(),y={};let b=-1;for(;++b<g.length;)y[g[b]]=a.getAttribute(g[b])||"";return d(f,y,all(m,c))}function all(a,c){const u=a.childNodes,d=[];let f=-1;for(;++f<u.length;){const m=transform(u[f],c);m!==void 0&&d.push(m)}return d}new DOMParser;function fromHtmlIsomorphic(a,c){const u=parseFragment(a);return fromDom(u)}function parseFragment(a){const c=document.createElement("template");return c.innerHTML=a,c.content}const findAfter=function(a,c,u){const d=convert(u);if(!a||!a.type||!a.children)throw new Error("Expected parent node");if(typeof c=="number"){if(c<0||c===Number.POSITIVE_INFINITY)throw new Error("Expected positive finite number as index")}else if(c=a.children.indexOf(c),c<0)throw new Error("Expected child node or index");for(;++c<a.children.length;)if(d(a.children[c],c,a))return a.children[c]},convertElement=function(a){if(a==null)return element;if(typeof a=="string")return tagNameFactory(a);if(typeof a=="object")return anyFactory(a);if(typeof a=="function")return castFactory(a);throw new Error("Expected function, string, or array as `test`")};function anyFactory(a){const c=[];let u=-1;for(;++u<a.length;)c[u]=convertElement(a[u]);return castFactory(d);function d(...f){let m=-1;for(;++m<c.length;)if(c[m].apply(this,f))return!0;return!1}}function tagNameFactory(a){return castFactory(c);function c(u){return u.tagName===a}}function castFactory(a){return c;function c(u,d,f){return!!(looksLikeAnElement(u)&&a.call(this,u,typeof d=="number"?d:void 0,f||void 0))}}function element(a){return!!(a&&typeof a=="object"&&"type"in a&&a.type==="element"&&"tagName"in a&&typeof a.tagName=="string")}function looksLikeAnElement(a){return a!==null&&typeof a=="object"&&"type"in a&&"tagName"in a}const searchLineFeeds=/\n/g,searchTabOrSpaces=/[\t ]+/g,br=convertElement("br"),cell=convertElement(isCell),p=convertElement("p"),row=convertElement("tr"),notRendered=convertElement(["datalist","head","noembed","noframes","noscript","rp","script","style","template","title",hidden,closedDialog]),blockOrCaption=convertElement(["address","article","aside","blockquote","body","caption","center","dd","dialog","dir","dl","dt","div","figure","figcaption","footer","form,","h1","h2","h3","h4","h5","h6","header","hgroup","hr","html","legend","li","listing","main","menu","nav","ol","p","plaintext","pre","section","ul","xmp"]);function toText(a,c){const u=c||{},d="children"in a?a.children:[],f=blockOrCaption(a),m=inferWhitespace(a,{whitespace:u.whitespace||"normal"}),g=[];(a.type==="text"||a.type==="comment")&&g.push(...collectText(a,{breakBefore:!0,breakAfter:!0}));let y=-1;for(;++y<d.length;)g.push(...renderedTextCollection(d[y],a,{whitespace:m,breakBefore:y?void 0:f,breakAfter:y<d.length-1?br(d[y+1]):f}));const b=[];let E;for(y=-1;++y<g.length;){const C=g[y];typeof C=="number"?E!==void 0&&C>E&&(E=C):C&&(E!==void 0&&E>-1&&b.push(`
`.repeat(E)||" "),E=-1,b.push(C))}return b.join("")}function renderedTextCollection(a,c,u){return a.type==="element"?collectElement(a,c,u):a.type==="text"?u.whitespace==="normal"?collectText(a,u):collectPreText(a):[]}function collectElement(a,c,u){const d=inferWhitespace(a,u),f=a.children||[];let m=-1,g=[];if(notRendered(a))return g;let y,b;for(br(a)||row(a)&&findAfter(c,a,row)?b=`
`:p(a)?(y=2,b=2):blockOrCaption(a)&&(y=1,b=1);++m<f.length;)g=g.concat(renderedTextCollection(f[m],a,{whitespace:d,breakBefore:m?void 0:y,breakAfter:m<f.length-1?br(f[m+1]):b}));return cell(a)&&findAfter(c,a,cell)&&g.push("	"),y&&g.unshift(y),b&&g.push(b),g}function collectText(a,c){const u=String(a.value),d=[],f=[];let m=0;for(;m<=u.length;){searchLineFeeds.lastIndex=m;const b=searchLineFeeds.exec(u),E=b&&"index"in b?b.index:u.length;d.push(trimAndCollapseSpacesAndTabs(u.slice(m,E).replace(/[\u061C\u200E\u200F\u202A-\u202E\u2066-\u2069]/g,""),m===0?c.breakBefore:!0,E===u.length?c.breakAfter:!0)),m=E+1}let g=-1,y;for(;++g<d.length;)d[g].charCodeAt(d[g].length-1)===8203||g<d.length-1&&d[g+1].charCodeAt(0)===8203?(f.push(d[g]),y=void 0):d[g]?(typeof y=="number"&&f.push(y),f.push(d[g]),y=0):(g===0||g===d.length-1)&&f.push(0);return f}function collectPreText(a){return[String(a.value)]}function trimAndCollapseSpacesAndTabs(a,c,u){const d=[];let f=0,m;for(;f<a.length;){searchTabOrSpaces.lastIndex=f;const g=searchTabOrSpaces.exec(a);m=g?g.index:a.length,!f&&!m&&g&&!c&&d.push(""),f!==m&&d.push(a.slice(f,m)),f=g?m+g[0].length:m}return f!==m&&!u&&d.push(""),d.join(" ")}function inferWhitespace(a,c){if(a.type==="element"){const u=a.properties||{};switch(a.tagName){case"listing":case"plaintext":case"xmp":return"pre";case"nobr":return"nowrap";case"pre":return u.wrap?"pre-wrap":"pre";case"td":case"th":return u.noWrap?"nowrap":c.whitespace;case"textarea":return"pre-wrap"}}return c.whitespace}function hidden(a){return!!(a.properties||{}).hidden}function isCell(a){return a.tagName==="td"||a.tagName==="th"}function closedDialog(a){return a.tagName==="dialog"&&!(a.properties||{}).open}const emptyOptions={},emptyClasses=[];function rehypeKatex(a){const c=a||emptyOptions;return function(u,d){visitParents(u,"element",function(f,m){const g=Array.isArray(f.properties.className)?f.properties.className:emptyClasses,y=g.includes("language-math"),b=g.includes("math-display"),E=g.includes("math-inline");let C=b;if(!y&&!b&&!E)return;let w=m[m.length-1],R=f;if(f.tagName==="code"&&y&&w&&w.type==="element"&&w.tagName==="pre"&&(R=w,w=m[m.length-2],C=!0),!w)return;const _=toText(R,{whitespace:"pre"});let M;try{M=katex.renderToString(_,{...c,displayMode:C,throwOnError:!0})}catch(N){const A=N,P=A.name.toLowerCase();d.message("Could not render math with KaTeX",{ancestors:[...m,f],cause:A,place:f.position,ruleId:P,source:"rehype-katex"});try{M=katex.renderToString(_,{...c,displayMode:C,strict:"ignore",throwOnError:!1})}catch{M=[{type:"element",tagName:"span",properties:{className:["katex-error"],style:"color:"+(c.errorColor||"#cc0000"),title:String(N)},children:[{type:"text",value:_}]}]}}typeof M=="string"&&(M=fromHtmlIsomorphic(M).children);const I=w.children.indexOf(R);return w.children.splice(I,1,...M),SKIP})}}const Markdown=({data:a})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Markdown$1,{children:a,rehypePlugins:[rehypeKatex],remarkPlugins:[remarkGfm,remarkMath],components:{img:({node:c,...u})=>jsxRuntimeExports.jsx("img",{...u,style:{maxWidth:"50%",height:"auto",margin:"1rem auto",display:"block"},alt:u.alt||""})}})}),TableView=({data:a,url:c})=>{const{Search:u}=Input,[d,f]=reactExports.useState([]),m=g=>Object.keys(g).map(y=>({title:y,dataIndex:y,key:y,ellipsis:!0,width:150}));return reactExports.useEffect(()=>{if(a){const g=a.map((y,b)=>({...y,key:b}));f(g)}},[a]),jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:Array.isArray(d)&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(ForwardTable,{title:()=>jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx(u,{placeholder:"input search text",allowClear:!0,onSearch:g=>{const y=a.filter(b=>Object.values(b).some(E=>typeof E=="string"&&E.includes(g)));f(y)},style:{width:304}}),c&&jsxRuntimeExports.jsx(Popover,{title:`${window.location.origin}${c}`,children:jsxRuntimeExports.jsx(Button$1,{onClick:()=>{window.open(c,"_blank")},style:{marginLeft:"1rem"},type:"primary",children:"下载"})})]}),scroll:{x:"max-content",y:55*5},dataSource:d,columns:m(a[0]),footer:()=>`一共${a.length}条记录`})})})},ImgView=({data:a,url:c})=>jsxRuntimeExports.jsx("div",{children:jsxRuntimeExports.jsxs("div",{style:{textAlign:"center"},children:[jsxRuntimeExports.jsx(Image,{src:a,style:{maxWidth:"20rem",marginRight:"0.5rem"}}),c&&jsxRuntimeExports.jsx("div",{children:jsxRuntimeExports.jsx(Popover,{title:`${window.location.origin}${c}`,children:jsxRuntimeExports.jsx(Button$1,{onClick:()=>{window.open(c,"_blank")},type:"primary",children:"下载"})})})]})}),{Paragraph}=Typography,StringView=({data:a})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Paragraph,{style:{background:"#13c2c2",padding:"1rem",border:"1px solid #1677ff"},children:a})}),HtmlView=({data:a})=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:a&&a.startsWith("/brave")?jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx("iframe",{src:a,width:"100%",style:{height:"80vh",border:"none"}})}):jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:a})}),AnalysisResultView=({htmlUrl:a,plotLoading:c,filePlot:u,tableDesc:d})=>{const f={table:TableView,string:StringView,html:HtmlView},m=({type:g,...y})=>{const b=f[g]||(()=>jsxRuntimeExports.jsxs("div",{children:["未知类型 ",g]}));return jsxRuntimeExports.jsx(b,{...y})};return jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[a&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx("iframe",{src:a,width:"100%",style:{height:"80vh",border:"none"}})}),jsxRuntimeExports.jsx(Spin,{spinning:c,tip:"请求中...",children:u?jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[u.img&&jsxRuntimeExports.jsx("div",{style:{display:"flex",justifyContent:"flex-start"},children:Array.isArray(u.img)?jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:u.img.map((g,y)=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:reactExports.createElement(ImgView,{...g,key:y})}))}):jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(ImgView,{...u.img})})}),u.dataList&&Array.isArray(u.dataList)&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:u.dataList.map((g,y)=>jsxRuntimeExports.jsx(m,{...g},y))}),u.data&&Array.isArray(u.data)&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(TableView,{data:u.data})})]}):jsxRuntimeExports.jsx("div",{style:{height:"100px"}})}),d&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Collapse$1,{ghost:!0,items:[{key:"1",label:"说明",children:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Markdown,{data:d})})}]})})]})},listAnalysisResult=async({project:a,analysisMethodValues:c,params:u})=>(await axios.post("/fast-api/find-analyais-result-by-analysis-method",{project:a,analysis_method:c,...u})).data,AnalysisForm=({form:a,resultTableList:c,formJson:u,formDom:d,moduleName:f,params:m,sampleGroupApI:g,setPlotLoading:y,inputAnalysisMethod:b,saveAnalysisMethod:E,project:C,setFilePlot:w,plotReloadTable:R,name:_})=>{const M=Form$1.useWatch(G=>G==null?void 0:G.id,a),I=Form$1.useWatch(G=>G==null?void 0:G.is_save_analysis_result,a),[N,A]=reactExports.useState([]),[P,z]=reactExports.useState("xlsx"),[B,j]=reactExports.useState("pdf"),[L,U]=staticMethods.useMessage(),q=async()=>{try{const te=(await axios.post("/fast-api/find-sample",{project:"hexiaoyan",sequencing_target:"DNA",sequencing_technique:"NGS",sample_composition:"meta_genome"})).data.map(ae=>({label:ae.sample_key,value:ae.sample_key,sample_group:ae.sample_group,sample_source:ae.sample_source,host_disease:ae.host_disease}));A(te)}catch(G){console.log(G)}},X={first_data_key:void 0,rank:[{label:"SGB",value:"SGB"},{label:"SPECIES",value:"SPECIES"},{label:"GENUS",value:"GENUS"},{label:"FAMILY",value:"FAMILY"},{label:"ORDER",value:"ORDER"},{label:"CLASS",value:"CLASS"},{label:"PHYLUM",value:"PHYLUM"}],group_field:[{label:"样本分组",value:"sample_group"},{label:"样本分组名称",value:"sample_group_name"},{label:"样本来源",value:"sample_source"},{label:"宿主疾病",value:"host_disease"}]},[Q,Y]=reactExports.useState(X),Z=async({moduleName:G,params:te})=>{var ne;const ae=await a.validateFields();console.log(ae),y(!0);const V={inputAnalysisMenthod:b,moduleName:G,params:te};try{const le={...te,...ae,project:C,analysis_method:E,table_type:P,imgType:B,...V,software:"python"},ee=await axios.post(`/fast-api/file-parse-plot/${G}`,le);w(ee.data),R&&ae.is_save_analysis_result&&R()}catch(le){console.log(le),(ne=le.response)!=null&&ne.data&&L.error(le.response.data.detail)}y(!1)};reactExports.useEffect(()=>{_&&a.setFieldValue("analysis_name",_)},[_]);const J=G=>{if(G&&Object.keys(G).length==1)return Object.keys(G)[0]},W=async G=>{const ae=(await listAnalysisResult({project:C,analysisMethodValues:G})).reduce((ne,le)=>{const ee=le.analysis_method;ne[ee]||(ne[ee]=[]);const{sample_key:ie,id:ce,sample_group:ue,...me}=le;return ne[ee].push({label:ie,value:ce,sample_group:ue||"no_group",sample_key:ie,id:ce,...me}),ne},{}),V={...X,...c,...ae,first_data_key:J(c)};console.log(V),Y(V)};return reactExports.useEffect(()=>{if(console.log(c),g)q();else{const G=u.filter(te=>te.inputAnalysisMethod!==void 0).map(te=>te.inputAnalysisMethod);G.length!=0?W(G):Y({...X,...c,first_data_key:J(c)})}},[JSON.stringify(c)]),jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[U,jsxRuntimeExports.jsxs(Form$1,{form:a,children:[jsxRuntimeExports.jsx(Form$1.Item,{name:"id",style:{display:"none"},children:jsxRuntimeExports.jsx(Input,{})}),jsxRuntimeExports.jsx(Form$1.Item,{initialValue:!1,name:"is_save_analysis_result",label:"是否保存分析结果",rules:[{required:!0,message:"该字段不能为空!"}],children:jsxRuntimeExports.jsx(Select,{options:[{label:"保存",value:!0},{label:"不保存",value:!1}]})}),I&&jsxRuntimeExports.jsx(Form$1.Item,{label:"分析名称",name:"analysis_name",style:{maxWidth:600},rules:[{required:!0,message:"该字段不能为空!"}],children:jsxRuntimeExports.jsx(Input,{})}),u&&jsxRuntimeExports.jsx(FormJsonComp,{project:C,formJson:u,dataMap:Q}),d&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:d}),(d||N||u)&&jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx(Button$1,{type:"primary",onClick:()=>{Z({moduleName:f,params:m})},children:M?jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:"更新"}):I?jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:"运行并保存"}):jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:"运行"})}),M&&jsxRuntimeExports.jsx(Button$1,{type:"primary",onClick:()=>a.setFieldValue("id",void 0),children:"取消更新"})]}),jsxRuntimeExports.jsx(Collapse$1,{ghost:!0,items:[{key:"1",label:"更多",children:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{noStyle:!0,shouldUpdate:!0,children:()=>jsxRuntimeExports.jsx(Typography,{children:jsxRuntimeExports.jsx("pre",{children:JSON.stringify(a.getFieldsValue(),null,2)})})})})}]})]})]})},AnalysisPanel=({wrapAnalysisPipeline:a,analysisPipline:c,parseAnalysisParams:u,inputAnalysisMethod:d,analysisMethod:f,appendSampleColumns:m,analysisType:g="nonSample",children:y,cardExtra:b,upstreamFormJson:E,downstreamAnalysis:C})=>{const{project:w}=useOutletContext(),[R,_]=reactExports.useState();return jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsxs(Row,{children:[jsxRuntimeExports.jsxs(Col,{lg:20,sm:24,xs:24,children:[d&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(UpstreamAnalysisInput,{cardExtra:b,wrapAnalysisPipeline:a,upstreamFormJson:E,analysisPipline:c,onClickItem:_,project:w,parseAnalysisParams:u,analysisMethod:f,inputAnalysisMethod:d})}),f&&jsxRuntimeExports.jsx(UpstreamAnalysisOutput,{children:y,onClickItem:_,downstreamAnalysis:C,project:w,analysisType:g,analysisMethod:f,appendSampleColumns:m})]}),jsxRuntimeExports.jsx(Col,{lg:4,sm:24,xs:24,style:{paddingLeft:"1rem"},children:jsxRuntimeExports.jsx(Card,{title:"详细信息",children:R?jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx("p",{children:`分析方法 (${R==null?void 0:R.analysis_method})`}),jsxRuntimeExports.jsx(Typography,{children:jsxRuntimeExports.jsx("pre",{children:JSON.stringify(R,null,2)})})]}):jsxRuntimeExports.jsx(Empty,{})})})]})})},UpstreamAnalysisInput=({project:a,analysisPipline:c,wrapAnalysisPipeline:u,parseAnalysisParams:d,upstreamFormJson:f,inputAnalysisMethod:m,onClickItem:g,cardExtra:y})=>{const[b]=Form$1.useForm(),[E,C]=reactExports.useState(),[w,R]=staticMethods.useMessage(),[_,M]=reactExports.useState(!1),I=Form$1.useWatch(K=>K==null?void 0:K.id,b),[N,A]=reactExports.useState(c||""),[P,z]=reactExports.useState(),B=reactExports.useRef(null),j=K=>({...K,project:a,analysis_pipline:N,wrap_analysis_pipeline:u,...d}),L=async()=>{var Q;const K=await b.validateFields(),X=j(K);M(!0);try{const Y=await axios.post("/fast-api/save-analysis",X);console.log(Y),B.current&&B.current.reload(),w.success("执行成功!")}catch(Y){console.log(Y),(Q=Y.response)!=null&&Q.data&&w.error(Y.response.data.detail)}M(!1)},q={host_genome_index:[{label:"人类",value:"/data/metagenome_data/bowtie2_index/human/human38"},{label:"小鼠",value:"/data/databases/mouse/bowtie2/Mus_musculus.GRCm39.dna_sm.toplevel.fa"}]},F=K=>{C(K)};return jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[R,jsxRuntimeExports.jsx(ResultList$1,{cardExtra:y,title:`输入文件 ${m.length>0?"":m.map(K=>K.label)}`,activeTabKey:P,setActiveTabKey:z,shouldTrigger:!0,analysisType:"sample",analysisMethod:m,setRecord:K=>g(K),setResultTableList:F}),jsxRuntimeExports.jsx("div",{style:{marginBottom:"1rem"}}),jsxRuntimeExports.jsxs(Form$1,{form:b,children:[jsxRuntimeExports.jsx(Form$1.Item,{name:"id",style:{display:"none"},children:jsxRuntimeExports.jsx(Input,{})}),jsxRuntimeExports.jsx(Collapse$1,{style:{marginTop:"1rem"},size:"small",items:[{key:"1",label:`执行分析 (${c})`,children:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsxs(Spin,{spinning:_,children:[jsxRuntimeExports.jsx(Form$1.Item,{name:"analysis_name",label:"分析名称",rules:[{required:!0,message:"该字段不能为空!"}],children:jsxRuntimeExports.jsx(Input,{})}),jsxRuntimeExports.jsx(FormJsonComp,{formJson:m,dataMap:E}),f&&jsxRuntimeExports.jsx(FormJsonComp,{formJson:f,dataMap:q}),jsxRuntimeExports.jsx(Button$1,{type:"primary",onClick:L,children:I?jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:"更新分析"}):jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:"保存分析"})}),I&&jsxRuntimeExports.jsx(Button$1,{onClick:()=>b.setFieldValue("id",void 0),children:"取消更新"}),jsxRuntimeExports.jsx("hr",{}),jsxRuntimeExports.jsx(ResultList,{project:a,ref:B,shouldTrigger:!0,analysisMethod:N,setRecord:K=>{const X=JSON.parse(K.request_param);console.log(X),b.resetFields(),b.setFieldsValue(X),K!=null&&K.id&&b.setFieldValue("id",K==null?void 0:K.id),g(K)}}),jsxRuntimeExports.jsx("hr",{}),jsxRuntimeExports.jsx(Collapse$1,{ghost:!0,items:[{key:"1",label:"更多",children:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Form$1.Item,{noStyle:!0,shouldUpdate:!0,children:()=>jsxRuntimeExports.jsx(Typography,{children:jsxRuntimeExports.jsx("pre",{children:JSON.stringify(j(b.getFieldsValue()),null,2)})})})})}]})]})})}]})]}),jsxRuntimeExports.jsx("div",{style:{marginBottom:"1rem"}})]})},UpstreamAnalysisOutput=({children:a,project:c,onClickItem:u,analysisType:d,analysisMethod:f,appendSampleColumns:m,downstreamAnalysis:g})=>{const[y]=Form$1.useForm(),[b,E]=reactExports.useState(),[C,w]=reactExports.useState(),[R,_]=reactExports.useState(!1),[M,I]=reactExports.useState(),[N,A]=reactExports.useState(),[P,z]=reactExports.useState(!1),[B,j]=reactExports.useState(),{Search:L}=Input,[U,q]=staticMethods.useMessage(),[F,K]=reactExports.useState(),[X,Q]=reactExports.useState(),[Y,Z]=reactExports.useState(),[J,W]=reactExports.useState([]),[G,te]=reactExports.useState(),[ae,V]=reactExports.useState("1"),[ne,le]=reactExports.useState(),[ee,ie]=reactExports.useState(),[ce,ue]=reactExports.useState(),[me,de]=reactExports.useState(!1),ge=reactExports.useRef(null),[Ce,ve]=reactExports.useState(!1),fe=()=>f.reduce((Re,De)=>(Re[De.name]=De,Re),{})[ne],pe=async({name:he,origin:we=!1,url:Re,moduleName:De,params:Ae,paramsFun:Ee,formDom:Ne,formJson:_e,tableDesc:ke,saveAnalysisMethod:Ke,sampleSelectComp:be=!1,sampleGroupJSON:Te=!0,sampleGroupApI:Le=!1})=>{if(ye(),V("1"),xe(void 0),Z(ke),I(Ne),K(De),Q(Ae),ve(Le),w(void 0),de(we),y.resetFields(),ue(he),A(_e),z(be),ie(Te),Ee&&(Ae=Ee(b),console.log(Ae),Q(Ae)),Ke&&te(Ke),we){const Oe=await axios.post(`/fast-api/file-parse-plot/${De}`,{...Ae,is_save_analysis_result:!1,origin:!0});console.log(Oe),w(Oe.data)}Re&&j(Re)},xe=(he,we=void 0)=>{j(he),I(void 0),Z(we),w(void 0),de(!1)},ye=()=>{I(void 0),w(void 0),xe(void 0),te(void 0)};return jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[q,jsxRuntimeExports.jsx(ResultList$1,{title:`输出文件 ${f.length>0?"":f.map(he=>he.name)}`,appendSampleColumns:m,activeTabKey:ne,setActiveTabKey:le,cleanDom:ye,analysisType:d,analysisMethod:f,shouldTrigger:!0,form:y,setResultTableList:W,setRecord:he=>{E(he),u(he)}}),jsxRuntimeExports.jsx("div",{style:{marginBottom:"1rem"}}),jsxRuntimeExports.jsx("div",{style:{marginBottom:"1rem"},children:g&&g.map((he,we)=>{const{name:Re,analysisType:De,...Ae}=he;return jsxRuntimeExports.jsxs("span",{children:[b&&De=="one"&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsxs(Button$1,{style:{marginRight:"0.5rem"},color:"purple",variant:Re==ce?"solid":"filled",onClick:()=>pe({...Ae,name:Re}),children:[Re,"(",b.sample_name,")"]})}),De!="one"&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Button$1,{style:{marginRight:"0.5rem"},color:"primary",variant:Re==ce?"solid":"filled",onClick:()=>pe({...Ae,name:Re}),children:Re})})]},we)})}),a&&React.cloneElement(a,{record:b,setHtmlUrl:xe,plot:pe,cleanDom:ye,form:y,activeTabKey:ne,resultTableList:J}),jsxRuntimeExports.jsx("div",{children:ce&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Collapse$1,{style:{marginTop:"1rem"},defaultActiveKey:["1"],size:"small",items:[{key:"1",label:jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:["执行分析",ce?`(${ce})`:""]}),children:jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[!me&&jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(Tabs,{items:[{key:"1",label:"分析",children:jsxRuntimeExports.jsx(AnalysisForm,{form:y,resultTableList:J,formJson:N,formDom:M,sampleGroupApI:Ce,moduleName:F,params:X,name:ce,setPlotLoading:_,inputAnalysisMethod:fe(),saveAnalysisMethod:G,project:c,setFilePlot:w,plotReloadTable:()=>{ge.current&&ge.current.reload()}})},{key:"2",label:"分析结果",children:jsxRuntimeExports.jsx(ResultList$1,{title:"下游分析历史记录",ref:ge,analysisType:"analysisResult",analysisMethod:[{name:G,label:G,inputKey:[G],mode:"multiple"}],form:y,setTableLoading:_,setTabletData:he=>{w(he)}})}]})}),jsxRuntimeExports.jsx(AnalysisResultView,{htmlUrl:B,plotLoading:R,filePlot:C,tableDesc:Y})]})}]})})})]})},formatUrl=a=>a.replace("/ssd1/wy/workspace2","http://10.110.1.11:8000"),colors=["magenta","red","volcano","orange","gold","lime","green","cyan","blue","geekblue","purple","magenta","red","volcano","orange","gold","lime","green","cyan","blue","geekblue","purple","magenta","red","volcano","orange","gold","lime","green","cyan","blue","geekblue","purple"],Pipeline=({name})=>{const[pipeline,setPipeline]=reactExports.useState(),[items,setItems]=reactExports.useState([]),navigate=useNavigate(),loadFunction=data=>{if(data)return data.map(item=>("paramsFun"in item&&(item.paramsFun=eval(item.paramsFun)),"formJson"in item&&item.formJson.map(it2=>("filter"in it2&&it2.filter.map(it3=>(it3.method=eval(it3.method),it3)),it2.field=eval(it2.field),it2)),item))},loadColumnRender=data=>data?data.map(item=>{if("render"in item){const render=eval(item.render);item.render=(a,c)=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:render(c)})}return item}):[],getPipline=(a,c)=>c.map((u,d)=>({key:d+1,label:u.name,children:jsxRuntimeExports.jsx(AnalysisPanel,{wrapAnalysisPipeline:a,inputAnalysisMethod:u.inputAnalysisMethod,analysisPipline:u.analysisPipline,analysisMethod:u.analysisMethod,downstreamAnalysis:loadFunction(u.downstreamAnalysis),upstreamFormJson:u.upstreamFormJson,appendSampleColumns:loadColumnRender(u.appendSampleColumns),parseAnalysisParams:{parse_analysis_module:u.parseAnalysisModule,parse_analysis_result_module:u.parseAnalysisResultModule},analysisType:u.analysisType?u.analysisType:"sample"})})),loadData=async()=>{const c=(await axios.get(`/get-pipeline/${name}`)).data;setPipeline(c);const u=getPipline(c.analysisPipline,c.items),d=c.items[0],f=c.items.filter(y=>y.upstreamFormJson&&Array.isArray(y.upstreamFormJson)).flatMap(y=>y.upstreamFormJson),m=c.items.filter(y=>y.parseAnalysisResultModule&&Array.isArray(y.parseAnalysisResultModule)).flatMap(y=>y.parseAnalysisResultModule),g={key:0,label:"总流程",children:jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(AnalysisPanel,{inputAnalysisMethod:d.inputAnalysisMethod,analysisPipline:c.analysisPipline,upstreamFormJson:f,appendSampleColumns:loadColumnRender(d.appendSampleColumns),parseAnalysisParams:{parse_analysis_module:c.parseAnalysisModule,parse_analysis_result_module:m},analysisType:d.analysisType?d.analysisType:"sample"})})};setItems([g,...u])};return reactExports.useEffect(()=>{loadData()},[]),jsxRuntimeExports.jsxs("div",{style:{maxWidth:"1800px",margin:"0 auto"},children:[jsxRuntimeExports.jsxs(Flex,{style:{marginBottom:"1rem"},justify:"space-between",align:"center",gap:"small",children:[jsxRuntimeExports.jsx("div",{children:pipeline?jsxRuntimeExports.jsxs(jsxRuntimeExports.Fragment,{children:[jsxRuntimeExports.jsx("h2",{style:{margin:0},children:pipeline==null?void 0:pipeline.name}),jsxRuntimeExports.jsx("p",{style:{margin:"0",color:"rgba(0, 0, 0, 0.45)"},children:pipeline==null?void 0:pipeline.description}),pipeline.tags&&Array.isArray(pipeline.tags)&&pipeline.tags.map((a,c)=>jsxRuntimeExports.jsx(Tag,{style:{marginTop:"0.5rem"},color:colors[c],children:a},c))]}):jsxRuntimeExports.jsx(Skeleton,{active:!0})}),jsxRuntimeExports.jsxs(Flex,{gap:"small",wrap:!0,children:[jsxRuntimeExports.jsx(Button$1,{color:"cyan",variant:"solid",children:"流程介绍"}),jsxRuntimeExports.jsx(Button$1,{color:"cyan",variant:"solid",onClick:loadData,children:"刷新"}),jsxRuntimeExports.jsx(Button$1,{color:"primary",variant:"solid",onClick:()=>navigate("/pipeline-card"),children:"返回"})]})]}),pipeline&&Array.isArray(pipeline==null?void 0:pipeline.items)?jsxRuntimeExports.jsx(Tabs,{items}):jsxRuntimeExports.jsx(Skeleton,{active:!0})]})},menuSlice=createSlice({name:"menu",initialState:{items:[],selectedKey:""},reducers:{setMenuItems:(a,c)=>{a.items=c.payload},setSelectedKey:(a,c)=>{a.selectedKey=c.payload}}}),{setMenuItems,setSelectedKey}=menuSlice.actions,menuReducer=menuSlice.reducer,listPipeline=async a=>{const c=await axios.get("/list-pipeline");return a(setMenuItems(c.data)),c.data},Sample=reactExports.lazy(()=>__vitePreload(()=>import("./index-DvoFO-WG.js"),__vite__mapDeps([0,1,2]),import.meta.url)),Project=reactExports.lazy(()=>__vitePreload(()=>import("./index-DBdIm_Nz.js"),[],import.meta.url)),Mutation=reactExports.lazy(()=>__vitePreload(()=>import("./index-BGpSNzo_.js"),[],import.meta.url)),MutationCompare=reactExports.lazy(()=>__vitePreload(()=>import("./index-DZv1haOu.js"),__vite__mapDeps([3,0,1,2]),import.meta.url)),Abundance=reactExports.lazy(()=>__vitePreload(()=>import("./index-DXu7euAS.js"),__vite__mapDeps([4,1,2,5,6]),import.meta.url)),Assembly=reactExports.lazy(()=>__vitePreload(()=>import("./index-q1syOj77.js"),[],import.meta.url)),GenePrediction=reactExports.lazy(()=>__vitePreload(()=>import("./index-Cui35cOX.js"),[],import.meta.url)),GeneAnnotation=reactExports.lazy(()=>__vitePreload(()=>import("./index-CQ3LWDKd.js"),[],import.meta.url)),GeneExpressison=reactExports.lazy(()=>__vitePreload(()=>import("./index-B-anftD_.js"),__vite__mapDeps([7,8]),import.meta.url)),ReadsBasedAbundanceAnalysis=reactExports.lazy(()=>__vitePreload(()=>import("./index-DkK2gsQm.js"),__vite__mapDeps([9,8]),import.meta.url)),RemoveHost=reactExports.lazy(()=>__vitePreload(()=>import("./index-DdGi63SI.js"),__vite__mapDeps([10,8]),import.meta.url)),AbundanceMeta=reactExports.lazy(()=>__vitePreload(()=>import("./index-BR6_aaON.js"),[],import.meta.url)),RecoveringMag=reactExports.lazy(()=>__vitePreload(()=>import("./index-C3Gmaeho.js"),[],import.meta.url)),SampleQC=reactExports.lazy(()=>__vitePreload(()=>import("./index-DOO0gF4q.js"),[],import.meta.url)),FunctionAnalysis=reactExports.lazy(()=>__vitePreload(()=>import("./index-C_YGCAyS.js"),__vite__mapDeps([11,8]),import.meta.url)),PipelineCard=reactExports.lazy(()=>__vitePreload(()=>import("./index-vC9vpSR0.js"),[],import.meta.url)),AnalysisResult=reactExports.lazy(()=>__vitePreload(()=>import("./index-CD9deHrI.js"),__vite__mapDeps([12,13,5,2]),import.meta.url)),Literature=reactExports.lazy(()=>__vitePreload(()=>import("./index-XJsuonX4.js"),[],import.meta.url)),childern=[{path:"/",element:jsxRuntimeExports.jsx(Project,{})},{path:"/pipeline-card",element:jsxRuntimeExports.jsx(PipelineCard,{})},{path:"/sample",element:jsxRuntimeExports.jsx(Sample,{})},{path:"/sample-qc",element:jsxRuntimeExports.jsx(SampleQC,{})},{path:"/analysis-result",element:jsxRuntimeExports.jsx(AnalysisResult,{})},{path:"/literature",element:jsxRuntimeExports.jsx(Literature,{})},{path:"/:project/meta_genome/reads-based-abundance-analysis",element:jsxRuntimeExports.jsx(ReadsBasedAbundanceAnalysis,{})},{path:"/:project/meta_genome/remove-host",element:jsxRuntimeExports.jsx(RemoveHost,{})},{path:"/:project/meta_genome/recovering-mag",element:jsxRuntimeExports.jsx(RecoveringMag,{})},{path:"/:project/meta_genome/abundance-meta",element:jsxRuntimeExports.jsx(AbundanceMeta,{})},{path:"/:project/meta_genome/abundance",element:jsxRuntimeExports.jsx(Abundance,{})},{path:"/:project/meta_genome/function-analysis",element:jsxRuntimeExports.jsx(FunctionAnalysis,{})},{path:"/:project/single_genome/mutation",element:jsxRuntimeExports.jsx(Mutation,{})},{path:"/:project/single_genome/mutation-compare",element:jsxRuntimeExports.jsx(MutationCompare,{})},{path:"/:project/single_genome/assembly",element:jsxRuntimeExports.jsx(Assembly,{})},{path:"/:project/single_genome/gene-prediction",element:jsxRuntimeExports.jsx(GenePrediction,{})},{path:"/:project/single_genome/gene-annotation",element:jsxRuntimeExports.jsx(GeneAnnotation,{})},{path:"/:project/single_genome/gene-expression",element:jsxRuntimeExports.jsx(GeneExpressison,{})}],RenderRouter=()=>{const[a,c]=reactExports.useState([]),u=useDispatch(),d=async()=>{const g=(await listPipeline(u)).flatMap(b=>b.items.map(E=>({path:`/${E.path}`,element:jsxRuntimeExports.jsx(Pipeline,{name:E.path})}))),y=[{path:"/",element:jsxRuntimeExports.jsx(App$1,{}),children:[...g,...childern]}];c(y)};return reactExports.useEffect(()=>{d()},[]),(a?useRoutes(a):null)??jsxRuntimeExports.jsx(Skeleton,{active:!0})},App=()=>jsxRuntimeExports.jsx(jsxRuntimeExports.Fragment,{children:jsxRuntimeExports.jsx(HashRouter,{children:jsxRuntimeExports.jsx(RenderRouter,{})})}),store=configureStore({reducer:{menu:menuReducer,project:projectReducer}});console.log("production");axios.defaults.baseURL="/brave-api";clientExports.createRoot(document.getElementById("root")).render(jsxRuntimeExports.jsx(Provider_default,{store,children:jsxRuntimeExports.jsx(App,{})}));export{RefIcon$x as $,AnalysisPanel as A,Button$1 as B,Col as C,Input as D,Markdown$1 as E,Form$1 as F,remarkGfm as G,remarkMath as H,Image as I,Space as J,Keyframe as K,genStyleHooks as L,Markdown as M,merge$2 as N,unit$1 as O,resetComponent as P,CONTAINER_MAX_OFFSET as Q,React as R,Select as S,Tabs as T,genFocusStyle as U,genSubStyleComponent as V,ConfigContext as W,useCSSVarCls as X,classNames as Y,Notify as Z,_possibleConstructorReturn as _,axios as a,RefIcon$p as a0,RefIcon$y as a1,RefIcon$h as a2,RefIcon$A as a3,devUseWarning as a4,useToken$1 as a5,useNotification as a6,NotificationProvider as a7,getReactRender as a8,ConfigProvider as a9,staticMethods as aA,useNavigate as aB,useDispatch as aC,useSelector as aD,Flex as aE,Meta as aF,Tooltip as aG,Tag as aH,colors as aI,Empty as aJ,listPipeline as aK,Radio as aL,AnalysisResultView as aM,AnalysisForm as aN,useComposeRef as aO,_extends as aP,pickAttrs as aQ,warningOnce$1 as aR,CSSMotion as aS,KeyCode as aT,useLayoutEffect$1 as aU,Portal as aV,useComponentConfig as aW,useEvent as aX,Popconfirm as aY,Pagination as aZ,globalConfig as aa,AppConfigContext as ab,Typography as ac,ResultList$1 as ad,ActionButton as ae,canUseDom as af,convertLegacyProps as ag,useLocale as ah,getConfirmLocale as ai,DisabledContextProvider as aj,useStyle$p as ak,useClosable as al,pickClosable as am,useZIndex as an,ContextIsolator as ao,zIndexContext as ap,DialogWrap as aq,getTransitionName as ar,Skeleton as as,prepareToken$3 as at,prepareComponentToken$k as au,clearFix as av,localeValues as aw,withPureRenderTheme as ax,Panel$1 as ay,TypedInputNumber as az,_getPrototypeOf as b,_isNativeReflectConstruct as c,_unsupportedIterableToArray as d,_inherits as e,formatUrl as f,getDefaultExportFromCjs as g,_createClass as h,_objectSpread2 as i,jsxRuntimeExports as j,_toConsumableArray as k,_classCallCheck as l,_slicedToArray as m,_defineProperty as n,_asyncToGenerator as o,_objectWithoutProperties as p,_regeneratorRuntime as q,reactExports as r,commonjsGlobal as s,Row as t,useParams as u,Card as v,ForwardTable as w,TextArea as x,Spin as y,useOutletContext as z};
